diff --git a/src/backend/catalog/Catalog.pm b/src/backend/catalog/Catalog.pm
index 6305a2b362..25b6edfd78 100644
--- a/src/backend/catalog/Catalog.pm
+++ b/src/backend/catalog/Catalog.pm
@@ -185,6 +185,12 @@ sub ParseHeader
 						{
 							$column{forcenotnull} = 1;
 						}
+						# We use quoted embedded variables to make sure
+						# syntax highlighters display them properly
+						elsif ($attopt =~ /BKI_DEFAULT\("(.*\${.*}.*)"\)/)
+						{
+							$column{default_substitution} = $1;
+						}
 						# We use quotes for values like \0 and \054, to
 						# make sure all compilers and syntax highlighters
 						# can recognize them properly.
@@ -311,6 +317,22 @@ sub AddDefaultValues
 		{
 			$row->{$attname} = $column->{default};
 		}
+		elsif (defined $column->{default_substitution})
+		{
+			my $substitution = $column->{default_substitution};
+			my @vars = $substitution =~ m/\${(\w+?)}/g;
+			foreach my $var (@vars)
+			{
+				my $replacement = $row->{$var};
+				if (!defined $replacement)
+				{
+					die sprintf "missing default substitution value %s in %s.dat line %s\n",
+						$var, $catname, $row->{line_number};
+				}
+				$substitution =~ s/\${$var}/$replacement/g;
+			}
+			$row->{$attname} = $substitution;
+		}
 		elsif ($catname eq 'pg_proc' && $attname eq 'pronargs' &&
 			   defined($row->{proargtypes}))
 		{
diff --git a/src/include/catalog/pg_proc.dat b/src/include/catalog/pg_proc.dat
index f643f564a6..6f5da8b7d8 100644
--- a/src/include/catalog/pg_proc.dat
+++ b/src/include/catalog/pg_proc.dat
@@ -37,147 +37,125 @@
 # OIDS 1 - 99
 
 { oid => '1242', descr => 'I/O',
-  proname => 'boolin', prorettype => 'bool', proargtypes => 'cstring',
-  prosrc => 'boolin' },
+  proname => 'boolin', prorettype => 'bool', proargtypes => 'cstring' },
 { oid => '1243', descr => 'I/O',
-  proname => 'boolout', prorettype => 'cstring', proargtypes => 'bool',
-  prosrc => 'boolout' },
+  proname => 'boolout', prorettype => 'cstring', proargtypes => 'bool' },
 { oid => '1244', descr => 'I/O',
-  proname => 'byteain', prorettype => 'bytea', proargtypes => 'cstring',
-  prosrc => 'byteain' },
+  proname => 'byteain', prorettype => 'bytea', proargtypes => 'cstring' },
 { oid => '31', descr => 'I/O',
-  proname => 'byteaout', prorettype => 'cstring', proargtypes => 'bytea',
-  prosrc => 'byteaout' },
+  proname => 'byteaout', prorettype => 'cstring', proargtypes => 'bytea' },
 { oid => '1245', descr => 'I/O',
-  proname => 'charin', prorettype => 'char', proargtypes => 'cstring',
-  prosrc => 'charin' },
+  proname => 'charin', prorettype => 'char', proargtypes => 'cstring' },
 { oid => '33', descr => 'I/O',
-  proname => 'charout', prorettype => 'cstring', proargtypes => 'char',
-  prosrc => 'charout' },
+  proname => 'charout', prorettype => 'cstring', proargtypes => 'char' },
 { oid => '34', descr => 'I/O',
-  proname => 'namein', prorettype => 'name', proargtypes => 'cstring',
-  prosrc => 'namein' },
+  proname => 'namein', prorettype => 'name', proargtypes => 'cstring' },
 { oid => '35', descr => 'I/O',
-  proname => 'nameout', prorettype => 'cstring', proargtypes => 'name',
-  prosrc => 'nameout' },
+  proname => 'nameout', prorettype => 'cstring', proargtypes => 'name' },
 { oid => '38', descr => 'I/O',
-  proname => 'int2in', prorettype => 'int2', proargtypes => 'cstring',
-  prosrc => 'int2in' },
+  proname => 'int2in', prorettype => 'int2', proargtypes => 'cstring' },
 { oid => '39', descr => 'I/O',
-  proname => 'int2out', prorettype => 'cstring', proargtypes => 'int2',
-  prosrc => 'int2out' },
+  proname => 'int2out', prorettype => 'cstring', proargtypes => 'int2' },
 { oid => '40', descr => 'I/O',
   proname => 'int2vectorin', prorettype => 'int2vector',
-  proargtypes => 'cstring', prosrc => 'int2vectorin' },
+  proargtypes => 'cstring' },
 { oid => '41', descr => 'I/O',
   proname => 'int2vectorout', prorettype => 'cstring',
-  proargtypes => 'int2vector', prosrc => 'int2vectorout' },
+  proargtypes => 'int2vector' },
 { oid => '42', descr => 'I/O',
-  proname => 'int4in', prorettype => 'int4', proargtypes => 'cstring',
-  prosrc => 'int4in' },
+  proname => 'int4in', prorettype => 'int4', proargtypes => 'cstring' },
 { oid => '43', descr => 'I/O',
-  proname => 'int4out', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'int4out' },
+  proname => 'int4out', prorettype => 'cstring', proargtypes => 'int4' },
 { oid => '44', descr => 'I/O',
   proname => 'regprocin', provolatile => 's', prorettype => 'regproc',
-  proargtypes => 'cstring', prosrc => 'regprocin' },
+  proargtypes => 'cstring' },
 { oid => '45', descr => 'I/O',
   proname => 'regprocout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regproc', prosrc => 'regprocout' },
+  proargtypes => 'regproc' },
 { oid => '3494', descr => 'convert proname to regproc',
   proname => 'to_regproc', provolatile => 's', prorettype => 'regproc',
-  proargtypes => 'text', prosrc => 'to_regproc' },
+  proargtypes => 'text' },
 { oid => '3479', descr => 'convert proname to regprocedure',
   proname => 'to_regprocedure', provolatile => 's',
-  prorettype => 'regprocedure', proargtypes => 'text',
-  prosrc => 'to_regprocedure' },
+  prorettype => 'regprocedure', proargtypes => 'text' },
 { oid => '46', descr => 'I/O',
-  proname => 'textin', prorettype => 'text', proargtypes => 'cstring',
-  prosrc => 'textin' },
+  proname => 'textin', prorettype => 'text', proargtypes => 'cstring' },
 { oid => '47', descr => 'I/O',
-  proname => 'textout', prorettype => 'cstring', proargtypes => 'text',
-  prosrc => 'textout' },
+  proname => 'textout', prorettype => 'cstring', proargtypes => 'text' },
 { oid => '48', descr => 'I/O',
-  proname => 'tidin', prorettype => 'tid', proargtypes => 'cstring',
-  prosrc => 'tidin' },
+  proname => 'tidin', prorettype => 'tid', proargtypes => 'cstring' },
 { oid => '49', descr => 'I/O',
-  proname => 'tidout', prorettype => 'cstring', proargtypes => 'tid',
-  prosrc => 'tidout' },
+  proname => 'tidout', prorettype => 'cstring', proargtypes => 'tid' },
 { oid => '50', descr => 'I/O',
-  proname => 'xidin', prorettype => 'xid', proargtypes => 'cstring',
-  prosrc => 'xidin' },
+  proname => 'xidin', prorettype => 'xid', proargtypes => 'cstring' },
 { oid => '51', descr => 'I/O',
-  proname => 'xidout', prorettype => 'cstring', proargtypes => 'xid',
-  prosrc => 'xidout' },
+  proname => 'xidout', prorettype => 'cstring', proargtypes => 'xid' },
 { oid => '52', descr => 'I/O',
-  proname => 'cidin', prorettype => 'cid', proargtypes => 'cstring',
-  prosrc => 'cidin' },
+  proname => 'cidin', prorettype => 'cid', proargtypes => 'cstring' },
 { oid => '53', descr => 'I/O',
-  proname => 'cidout', prorettype => 'cstring', proargtypes => 'cid',
-  prosrc => 'cidout' },
+  proname => 'cidout', prorettype => 'cstring', proargtypes => 'cid' },
 { oid => '54', descr => 'I/O',
-  proname => 'oidvectorin', prorettype => 'oidvector', proargtypes => 'cstring',
-  prosrc => 'oidvectorin' },
+  proname => 'oidvectorin', prorettype => 'oidvector', proargtypes => 'cstring' },
 { oid => '55', descr => 'I/O',
   proname => 'oidvectorout', prorettype => 'cstring',
-  proargtypes => 'oidvector', prosrc => 'oidvectorout' },
+  proargtypes => 'oidvector' },
 { oid => '56',
   proname => 'boollt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'boollt' },
+  proargtypes => 'bool bool' },
 { oid => '57',
   proname => 'boolgt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'boolgt' },
+  proargtypes => 'bool bool' },
 { oid => '60',
   proname => 'booleq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'booleq' },
+  proargtypes => 'bool bool' },
 { oid => '61',
   proname => 'chareq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'char char', prosrc => 'chareq' },
+  proargtypes => 'char char' },
 { oid => '62',
   proname => 'nameeq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'name name', prosrc => 'nameeq' },
+  proargtypes => 'name name' },
 { oid => '63',
   proname => 'int2eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int2', prosrc => 'int2eq' },
+  proargtypes => 'int2 int2' },
 { oid => '64',
   proname => 'int2lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int2', prosrc => 'int2lt' },
+  proargtypes => 'int2 int2' },
 { oid => '65',
   proname => 'int4eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int4', prosrc => 'int4eq' },
+  proargtypes => 'int4 int4' },
 { oid => '66',
   proname => 'int4lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int4', prosrc => 'int4lt' },
+  proargtypes => 'int4 int4' },
 { oid => '67',
   proname => 'texteq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'text text', prosrc => 'texteq' },
+  proargtypes => 'text text' },
 { oid => '3696',
   proname => 'starts_with', proleakproof => 't', prorettype => 'bool',
   proargtypes => 'text text', prosrc => 'text_starts_with' },
 { oid => '68',
   proname => 'xideq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'xid xid', prosrc => 'xideq' },
+  proargtypes => 'xid xid' },
 { oid => '3308',
   proname => 'xidneq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'xid xid', prosrc => 'xidneq' },
+  proargtypes => 'xid xid' },
 { oid => '69',
   proname => 'cideq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'cid cid', prosrc => 'cideq' },
+  proargtypes => 'cid cid' },
 { oid => '70',
   proname => 'charne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'char char', prosrc => 'charne' },
+  proargtypes => 'char char' },
 { oid => '1246',
   proname => 'charlt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'char char', prosrc => 'charlt' },
+  proargtypes => 'char char' },
 { oid => '72',
   proname => 'charle', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'char char', prosrc => 'charle' },
+  proargtypes => 'char char' },
 { oid => '73',
   proname => 'chargt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'char char', prosrc => 'chargt' },
+  proargtypes => 'char char' },
 { oid => '74',
   proname => 'charge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'char char', prosrc => 'charge' },
+  proargtypes => 'char char' },
 { oid => '77', descr => 'convert char to int4',
   proname => 'int4', prorettype => 'int4', proargtypes => 'char',
   prosrc => 'chartoi4' },
@@ -186,447 +164,362 @@
   prosrc => 'i4tochar' },
 
 { oid => '79',
-  proname => 'nameregexeq', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'nameregexeq' },
+  proname => 'nameregexeq', prorettype => 'bool', proargtypes => 'name text' },
 { oid => '1252',
-  proname => 'nameregexne', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'nameregexne' },
+  proname => 'nameregexne', prorettype => 'bool', proargtypes => 'name text' },
 { oid => '1254',
-  proname => 'textregexeq', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'textregexeq' },
+  proname => 'textregexeq', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '1256',
-  proname => 'textregexne', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'textregexne' },
+  proname => 'textregexne', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '1257', descr => 'length',
-  proname => 'textlen', prorettype => 'int4', proargtypes => 'text',
-  prosrc => 'textlen' },
+  proname => 'textlen', prorettype => 'int4', proargtypes => 'text' },
 { oid => '1258',
-  proname => 'textcat', prorettype => 'text', proargtypes => 'text text',
-  prosrc => 'textcat' },
+  proname => 'textcat', prorettype => 'text', proargtypes => 'text text' },
 
 { oid => '84',
   proname => 'boolne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'boolne' },
+  proargtypes => 'bool bool' },
 { oid => '89', descr => 'PostgreSQL version string',
   proname => 'version', provolatile => 's', prorettype => 'text',
   proargtypes => '', prosrc => 'pgsql_version' },
 
 { oid => '86', descr => 'I/O',
   proname => 'pg_ddl_command_in', prorettype => 'pg_ddl_command',
-  proargtypes => 'cstring', prosrc => 'pg_ddl_command_in' },
+  proargtypes => 'cstring' },
 { oid => '87', descr => 'I/O',
   proname => 'pg_ddl_command_out', prorettype => 'cstring',
-  proargtypes => 'pg_ddl_command', prosrc => 'pg_ddl_command_out' },
+  proargtypes => 'pg_ddl_command' },
 { oid => '88', descr => 'I/O',
   proname => 'pg_ddl_command_recv', prorettype => 'pg_ddl_command',
-  proargtypes => 'internal', prosrc => 'pg_ddl_command_recv' },
+  proargtypes => 'internal' },
 { oid => '90', descr => 'I/O',
   proname => 'pg_ddl_command_send', prorettype => 'bytea',
-  proargtypes => 'pg_ddl_command', prosrc => 'pg_ddl_command_send' },
+  proargtypes => 'pg_ddl_command' },
 
 # OIDS 100 - 199
 
 { oid => '101', descr => 'restriction selectivity of = and related operators',
   proname => 'eqsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'eqsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '102',
   descr => 'restriction selectivity of <> and related operators',
   proname => 'neqsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'neqsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '103',
   descr => 'restriction selectivity of < and related operators on scalar datatypes',
   proname => 'scalarltsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'scalarltsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '104',
   descr => 'restriction selectivity of > and related operators on scalar datatypes',
   proname => 'scalargtsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'scalargtsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '105', descr => 'join selectivity of = and related operators',
   proname => 'eqjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal', prosrc => 'eqjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '106', descr => 'join selectivity of <> and related operators',
   proname => 'neqjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'neqjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '107',
   descr => 'join selectivity of < and related operators on scalar datatypes',
   proname => 'scalarltjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'scalarltjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '108',
   descr => 'join selectivity of > and related operators on scalar datatypes',
   proname => 'scalargtjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'scalargtjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 
 { oid => '336',
   descr => 'restriction selectivity of <= and related operators on scalar datatypes',
   proname => 'scalarlesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'scalarlesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '337',
   descr => 'restriction selectivity of >= and related operators on scalar datatypes',
   proname => 'scalargesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'scalargesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '386',
   descr => 'join selectivity of <= and related operators on scalar datatypes',
   proname => 'scalarlejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'scalarlejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '398',
   descr => 'join selectivity of >= and related operators on scalar datatypes',
   proname => 'scalargejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'scalargejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 
 { oid => '109', descr => 'I/O',
-  proname => 'unknownin', prorettype => 'unknown', proargtypes => 'cstring',
-  prosrc => 'unknownin' },
+  proname => 'unknownin', prorettype => 'unknown', proargtypes => 'cstring' },
 { oid => '110', descr => 'I/O',
-  proname => 'unknownout', prorettype => 'cstring', proargtypes => 'unknown',
-  prosrc => 'unknownout' },
+  proname => 'unknownout', prorettype => 'cstring', proargtypes => 'unknown' },
 { oid => '111',
-  proname => 'numeric_fac', prorettype => 'numeric', proargtypes => 'int8',
-  prosrc => 'numeric_fac' },
+  proname => 'numeric_fac', prorettype => 'numeric', proargtypes => 'int8' },
 
 { oid => '115',
-  proname => 'box_above_eq', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_above_eq' },
+  proname => 'box_above_eq', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '116',
-  proname => 'box_below_eq', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_below_eq' },
+  proname => 'box_below_eq', prorettype => 'bool', proargtypes => 'box box' },
 
 { oid => '117', descr => 'I/O',
-  proname => 'point_in', prorettype => 'point', proargtypes => 'cstring',
-  prosrc => 'point_in' },
+  proname => 'point_in', prorettype => 'point', proargtypes => 'cstring' },
 { oid => '118', descr => 'I/O',
-  proname => 'point_out', prorettype => 'cstring', proargtypes => 'point',
-  prosrc => 'point_out' },
+  proname => 'point_out', prorettype => 'cstring', proargtypes => 'point' },
 { oid => '119', descr => 'I/O',
-  proname => 'lseg_in', prorettype => 'lseg', proargtypes => 'cstring',
-  prosrc => 'lseg_in' },
+  proname => 'lseg_in', prorettype => 'lseg', proargtypes => 'cstring' },
 { oid => '120', descr => 'I/O',
-  proname => 'lseg_out', prorettype => 'cstring', proargtypes => 'lseg',
-  prosrc => 'lseg_out' },
+  proname => 'lseg_out', prorettype => 'cstring', proargtypes => 'lseg' },
 { oid => '121', descr => 'I/O',
-  proname => 'path_in', prorettype => 'path', proargtypes => 'cstring',
-  prosrc => 'path_in' },
+  proname => 'path_in', prorettype => 'path', proargtypes => 'cstring' },
 { oid => '122', descr => 'I/O',
-  proname => 'path_out', prorettype => 'cstring', proargtypes => 'path',
-  prosrc => 'path_out' },
+  proname => 'path_out', prorettype => 'cstring', proargtypes => 'path' },
 { oid => '123', descr => 'I/O',
-  proname => 'box_in', prorettype => 'box', proargtypes => 'cstring',
-  prosrc => 'box_in' },
+  proname => 'box_in', prorettype => 'box', proargtypes => 'cstring' },
 { oid => '124', descr => 'I/O',
-  proname => 'box_out', prorettype => 'cstring', proargtypes => 'box',
-  prosrc => 'box_out' },
+  proname => 'box_out', prorettype => 'cstring', proargtypes => 'box' },
 { oid => '125',
-  proname => 'box_overlap', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_overlap' },
+  proname => 'box_overlap', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '126',
-  proname => 'box_ge', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_ge' },
+  proname => 'box_ge', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '127',
-  proname => 'box_gt', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_gt' },
+  proname => 'box_gt', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '128',
-  proname => 'box_eq', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_eq' },
+  proname => 'box_eq', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '129',
-  proname => 'box_lt', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_lt' },
+  proname => 'box_lt', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '130',
-  proname => 'box_le', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_le' },
+  proname => 'box_le', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '131',
-  proname => 'point_above', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_above' },
+  proname => 'point_above', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '132',
-  proname => 'point_left', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_left' },
+  proname => 'point_left', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '133',
-  proname => 'point_right', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_right' },
+  proname => 'point_right', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '134',
-  proname => 'point_below', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_below' },
+  proname => 'point_below', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '135',
-  proname => 'point_eq', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_eq' },
+  proname => 'point_eq', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '136',
-  proname => 'on_pb', prorettype => 'bool', proargtypes => 'point box',
-  prosrc => 'on_pb' },
+  proname => 'on_pb', prorettype => 'bool', proargtypes => 'point box' },
 { oid => '137',
-  proname => 'on_ppath', prorettype => 'bool', proargtypes => 'point path',
-  prosrc => 'on_ppath' },
+  proname => 'on_ppath', prorettype => 'bool', proargtypes => 'point path' },
 { oid => '138',
-  proname => 'box_center', prorettype => 'point', proargtypes => 'box',
-  prosrc => 'box_center' },
+  proname => 'box_center', prorettype => 'point', proargtypes => 'box' },
 { oid => '139',
   descr => 'restriction selectivity for area-comparison operators',
   proname => 'areasel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'areasel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '140', descr => 'join selectivity for area-comparison operators',
   proname => 'areajoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'areajoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '141',
-  proname => 'int4mul', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4mul' },
+  proname => 'int4mul', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '144',
   proname => 'int4ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int4', prosrc => 'int4ne' },
+  proargtypes => 'int4 int4' },
 { oid => '145',
   proname => 'int2ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int2', prosrc => 'int2ne' },
+  proargtypes => 'int2 int2' },
 { oid => '146',
   proname => 'int2gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int2', prosrc => 'int2gt' },
+  proargtypes => 'int2 int2' },
 { oid => '147',
   proname => 'int4gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int4', prosrc => 'int4gt' },
+  proargtypes => 'int4 int4' },
 { oid => '148',
   proname => 'int2le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int2', prosrc => 'int2le' },
+  proargtypes => 'int2 int2' },
 { oid => '149',
   proname => 'int4le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int4', prosrc => 'int4le' },
+  proargtypes => 'int4 int4' },
 { oid => '150',
   proname => 'int4ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int4', prosrc => 'int4ge' },
+  proargtypes => 'int4 int4' },
 { oid => '151',
   proname => 'int2ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int2', prosrc => 'int2ge' },
+  proargtypes => 'int2 int2' },
 { oid => '152',
-  proname => 'int2mul', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2mul' },
+  proname => 'int2mul', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '153',
-  proname => 'int2div', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2div' },
+  proname => 'int2div', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '154',
-  proname => 'int4div', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4div' },
+  proname => 'int4div', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '155',
-  proname => 'int2mod', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2mod' },
+  proname => 'int2mod', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '156',
-  proname => 'int4mod', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4mod' },
+  proname => 'int4mod', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '157',
   proname => 'textne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'text text', prosrc => 'textne' },
+  proargtypes => 'text text' },
 { oid => '158',
   proname => 'int24eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int4', prosrc => 'int24eq' },
+  proargtypes => 'int2 int4' },
 { oid => '159',
   proname => 'int42eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int2', prosrc => 'int42eq' },
+  proargtypes => 'int4 int2' },
 { oid => '160',
   proname => 'int24lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int4', prosrc => 'int24lt' },
+  proargtypes => 'int2 int4' },
 { oid => '161',
   proname => 'int42lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int2', prosrc => 'int42lt' },
+  proargtypes => 'int4 int2' },
 { oid => '162',
   proname => 'int24gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int4', prosrc => 'int24gt' },
+  proargtypes => 'int2 int4' },
 { oid => '163',
   proname => 'int42gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int2', prosrc => 'int42gt' },
+  proargtypes => 'int4 int2' },
 { oid => '164',
   proname => 'int24ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int4', prosrc => 'int24ne' },
+  proargtypes => 'int2 int4' },
 { oid => '165',
   proname => 'int42ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int2', prosrc => 'int42ne' },
+  proargtypes => 'int4 int2' },
 { oid => '166',
   proname => 'int24le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int4', prosrc => 'int24le' },
+  proargtypes => 'int2 int4' },
 { oid => '167',
   proname => 'int42le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int2', prosrc => 'int42le' },
+  proargtypes => 'int4 int2' },
 { oid => '168',
   proname => 'int24ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int4', prosrc => 'int24ge' },
+  proargtypes => 'int2 int4' },
 { oid => '169',
   proname => 'int42ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int2', prosrc => 'int42ge' },
+  proargtypes => 'int4 int2' },
 { oid => '170',
-  proname => 'int24mul', prorettype => 'int4', proargtypes => 'int2 int4',
-  prosrc => 'int24mul' },
+  proname => 'int24mul', prorettype => 'int4', proargtypes => 'int2 int4' },
 { oid => '171',
-  proname => 'int42mul', prorettype => 'int4', proargtypes => 'int4 int2',
-  prosrc => 'int42mul' },
+  proname => 'int42mul', prorettype => 'int4', proargtypes => 'int4 int2' },
 { oid => '172',
-  proname => 'int24div', prorettype => 'int4', proargtypes => 'int2 int4',
-  prosrc => 'int24div' },
+  proname => 'int24div', prorettype => 'int4', proargtypes => 'int2 int4' },
 { oid => '173',
-  proname => 'int42div', prorettype => 'int4', proargtypes => 'int4 int2',
-  prosrc => 'int42div' },
+  proname => 'int42div', prorettype => 'int4', proargtypes => 'int4 int2' },
 { oid => '176',
-  proname => 'int2pl', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2pl' },
+  proname => 'int2pl', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '177',
-  proname => 'int4pl', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4pl' },
+  proname => 'int4pl', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '178',
-  proname => 'int24pl', prorettype => 'int4', proargtypes => 'int2 int4',
-  prosrc => 'int24pl' },
+  proname => 'int24pl', prorettype => 'int4', proargtypes => 'int2 int4' },
 { oid => '179',
-  proname => 'int42pl', prorettype => 'int4', proargtypes => 'int4 int2',
-  prosrc => 'int42pl' },
+  proname => 'int42pl', prorettype => 'int4', proargtypes => 'int4 int2' },
 { oid => '180',
-  proname => 'int2mi', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2mi' },
+  proname => 'int2mi', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '181',
-  proname => 'int4mi', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4mi' },
+  proname => 'int4mi', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '182',
-  proname => 'int24mi', prorettype => 'int4', proargtypes => 'int2 int4',
-  prosrc => 'int24mi' },
+  proname => 'int24mi', prorettype => 'int4', proargtypes => 'int2 int4' },
 { oid => '183',
-  proname => 'int42mi', prorettype => 'int4', proargtypes => 'int4 int2',
-  prosrc => 'int42mi' },
+  proname => 'int42mi', prorettype => 'int4', proargtypes => 'int4 int2' },
 { oid => '184',
   proname => 'oideq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'oid oid', prosrc => 'oideq' },
+  proargtypes => 'oid oid' },
 { oid => '185',
   proname => 'oidne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'oid oid', prosrc => 'oidne' },
+  proargtypes => 'oid oid' },
 { oid => '186',
-  proname => 'box_same', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_same' },
+  proname => 'box_same', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '187',
-  proname => 'box_contain', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_contain' },
+  proname => 'box_contain', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '188',
-  proname => 'box_left', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_left' },
+  proname => 'box_left', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '189',
-  proname => 'box_overleft', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_overleft' },
+  proname => 'box_overleft', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '190',
-  proname => 'box_overright', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_overright' },
+  proname => 'box_overright', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '191',
-  proname => 'box_right', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_right' },
+  proname => 'box_right', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '192',
-  proname => 'box_contained', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_contained' },
+  proname => 'box_contained', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '193',
-  proname => 'box_contain_pt', prorettype => 'bool', proargtypes => 'box point',
-  prosrc => 'box_contain_pt' },
+  proname => 'box_contain_pt', prorettype => 'bool', proargtypes => 'box point' },
 
 { oid => '195', descr => 'I/O',
   proname => 'pg_node_tree_in', prorettype => 'pg_node_tree',
-  proargtypes => 'cstring', prosrc => 'pg_node_tree_in' },
+  proargtypes => 'cstring' },
 { oid => '196', descr => 'I/O',
   proname => 'pg_node_tree_out', prorettype => 'cstring',
-  proargtypes => 'pg_node_tree', prosrc => 'pg_node_tree_out' },
+  proargtypes => 'pg_node_tree' },
 { oid => '197', descr => 'I/O',
   proname => 'pg_node_tree_recv', provolatile => 's',
-  prorettype => 'pg_node_tree', proargtypes => 'internal',
-  prosrc => 'pg_node_tree_recv' },
+  prorettype => 'pg_node_tree', proargtypes => 'internal' },
 { oid => '198', descr => 'I/O',
   proname => 'pg_node_tree_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'pg_node_tree', prosrc => 'pg_node_tree_send' },
+  proargtypes => 'pg_node_tree' },
 
 # OIDS 200 - 299
 
 { oid => '200', descr => 'I/O',
-  proname => 'float4in', prorettype => 'float4', proargtypes => 'cstring',
-  prosrc => 'float4in' },
+  proname => 'float4in', prorettype => 'float4', proargtypes => 'cstring' },
 { oid => '201', descr => 'I/O',
-  proname => 'float4out', prorettype => 'cstring', proargtypes => 'float4',
-  prosrc => 'float4out' },
+  proname => 'float4out', prorettype => 'cstring', proargtypes => 'float4' },
 { oid => '202',
   proname => 'float4mul', prorettype => 'float4',
-  proargtypes => 'float4 float4', prosrc => 'float4mul' },
+  proargtypes => 'float4 float4' },
 { oid => '203',
   proname => 'float4div', prorettype => 'float4',
-  proargtypes => 'float4 float4', prosrc => 'float4div' },
+  proargtypes => 'float4 float4' },
 { oid => '204',
-  proname => 'float4pl', prorettype => 'float4', proargtypes => 'float4 float4',
-  prosrc => 'float4pl' },
+  proname => 'float4pl', prorettype => 'float4', proargtypes => 'float4 float4' },
 { oid => '205',
-  proname => 'float4mi', prorettype => 'float4', proargtypes => 'float4 float4',
-  prosrc => 'float4mi' },
+  proname => 'float4mi', prorettype => 'float4', proargtypes => 'float4 float4' },
 { oid => '206',
-  proname => 'float4um', prorettype => 'float4', proargtypes => 'float4',
-  prosrc => 'float4um' },
+  proname => 'float4um', prorettype => 'float4', proargtypes => 'float4' },
 { oid => '207',
-  proname => 'float4abs', prorettype => 'float4', proargtypes => 'float4',
-  prosrc => 'float4abs' },
+  proname => 'float4abs', prorettype => 'float4', proargtypes => 'float4' },
 { oid => '208', descr => 'aggregate transition function',
   proname => 'float4_accum', prorettype => '_float8',
-  proargtypes => '_float8 float4', prosrc => 'float4_accum' },
+  proargtypes => '_float8 float4' },
 { oid => '209', descr => 'larger of two',
   proname => 'float4larger', prorettype => 'float4',
-  proargtypes => 'float4 float4', prosrc => 'float4larger' },
+  proargtypes => 'float4 float4' },
 { oid => '211', descr => 'smaller of two',
   proname => 'float4smaller', prorettype => 'float4',
-  proargtypes => 'float4 float4', prosrc => 'float4smaller' },
+  proargtypes => 'float4 float4' },
 
 { oid => '212',
-  proname => 'int4um', prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'int4um' },
+  proname => 'int4um', prorettype => 'int4', proargtypes => 'int4' },
 { oid => '213',
-  proname => 'int2um', prorettype => 'int2', proargtypes => 'int2',
-  prosrc => 'int2um' },
+  proname => 'int2um', prorettype => 'int2', proargtypes => 'int2' },
 
 { oid => '214', descr => 'I/O',
-  proname => 'float8in', prorettype => 'float8', proargtypes => 'cstring',
-  prosrc => 'float8in' },
+  proname => 'float8in', prorettype => 'float8', proargtypes => 'cstring' },
 { oid => '215', descr => 'I/O',
-  proname => 'float8out', prorettype => 'cstring', proargtypes => 'float8',
-  prosrc => 'float8out' },
+  proname => 'float8out', prorettype => 'cstring', proargtypes => 'float8' },
 { oid => '216',
   proname => 'float8mul', prorettype => 'float8',
-  proargtypes => 'float8 float8', prosrc => 'float8mul' },
+  proargtypes => 'float8 float8' },
 { oid => '217',
   proname => 'float8div', prorettype => 'float8',
-  proargtypes => 'float8 float8', prosrc => 'float8div' },
+  proargtypes => 'float8 float8' },
 { oid => '218',
-  proname => 'float8pl', prorettype => 'float8', proargtypes => 'float8 float8',
-  prosrc => 'float8pl' },
+  proname => 'float8pl', prorettype => 'float8', proargtypes => 'float8 float8' },
 { oid => '219',
-  proname => 'float8mi', prorettype => 'float8', proargtypes => 'float8 float8',
-  prosrc => 'float8mi' },
+  proname => 'float8mi', prorettype => 'float8', proargtypes => 'float8 float8' },
 { oid => '220',
-  proname => 'float8um', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'float8um' },
+  proname => 'float8um', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '221',
-  proname => 'float8abs', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'float8abs' },
+  proname => 'float8abs', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '222', descr => 'aggregate transition function',
   proname => 'float8_accum', prorettype => '_float8',
-  proargtypes => '_float8 float8', prosrc => 'float8_accum' },
+  proargtypes => '_float8 float8' },
 { oid => '276', descr => 'aggregate combine function',
   proname => 'float8_combine', prorettype => '_float8',
-  proargtypes => '_float8 _float8', prosrc => 'float8_combine' },
+  proargtypes => '_float8 _float8' },
 { oid => '223', descr => 'larger of two',
   proname => 'float8larger', prorettype => 'float8',
-  proargtypes => 'float8 float8', prosrc => 'float8larger' },
+  proargtypes => 'float8 float8' },
 { oid => '224', descr => 'smaller of two',
   proname => 'float8smaller', prorettype => 'float8',
-  proargtypes => 'float8 float8', prosrc => 'float8smaller' },
+  proargtypes => 'float8 float8' },
 
 { oid => '225',
-  proname => 'lseg_center', prorettype => 'point', proargtypes => 'lseg',
-  prosrc => 'lseg_center' },
+  proname => 'lseg_center', prorettype => 'point', proargtypes => 'lseg' },
 { oid => '226',
-  proname => 'path_center', prorettype => 'point', proargtypes => 'path',
-  prosrc => 'path_center' },
+  proname => 'path_center', prorettype => 'point', proargtypes => 'path' },
 { oid => '227',
-  proname => 'poly_center', prorettype => 'point', proargtypes => 'polygon',
-  prosrc => 'poly_center' },
+  proname => 'poly_center', prorettype => 'point', proargtypes => 'polygon' },
 
 { oid => '228', descr => 'round to nearest integer',
-  proname => 'dround', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'dround' },
+  proname => 'dround', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '229', descr => 'truncate to integer',
-  proname => 'dtrunc', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'dtrunc' },
+  proname => 'dtrunc', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '2308', descr => 'nearest integer >= value',
   proname => 'ceil', prorettype => 'float8', proargtypes => 'float8',
   prosrc => 'dceil' },
@@ -640,20 +533,15 @@
   proname => 'sign', prorettype => 'float8', proargtypes => 'float8',
   prosrc => 'dsign' },
 { oid => '230',
-  proname => 'dsqrt', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'dsqrt' },
+  proname => 'dsqrt', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '231',
-  proname => 'dcbrt', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'dcbrt' },
+  proname => 'dcbrt', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '232',
-  proname => 'dpow', prorettype => 'float8', proargtypes => 'float8 float8',
-  prosrc => 'dpow' },
+  proname => 'dpow', prorettype => 'float8', proargtypes => 'float8 float8' },
 { oid => '233', descr => 'natural exponential (e^x)',
-  proname => 'dexp', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'dexp' },
+  proname => 'dexp', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '234', descr => 'natural logarithm',
-  proname => 'dlog1', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'dlog1' },
+  proname => 'dlog1', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '235', descr => 'convert int2 to float8',
   proname => 'float8', prorettype => 'float8', proargtypes => 'int2',
   prosrc => 'i2tod' },
@@ -668,227 +556,225 @@
   prosrc => 'ftoi2' },
 { oid => '239',
   proname => 'line_distance', prorettype => 'float8',
-  proargtypes => 'line line', prosrc => 'line_distance' },
+  proargtypes => 'line line' },
 
 { oid => '240', descr => 'I/O',
   proname => 'abstimein', provolatile => 's', prorettype => 'abstime',
-  proargtypes => 'cstring', prosrc => 'abstimein' },
+  proargtypes => 'cstring' },
 { oid => '241', descr => 'I/O',
   proname => 'abstimeout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'abstime', prosrc => 'abstimeout' },
+  proargtypes => 'abstime' },
 { oid => '242', descr => 'I/O',
   proname => 'reltimein', provolatile => 's', prorettype => 'reltime',
-  proargtypes => 'cstring', prosrc => 'reltimein' },
+  proargtypes => 'cstring' },
 { oid => '243', descr => 'I/O',
   proname => 'reltimeout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'reltime', prosrc => 'reltimeout' },
+  proargtypes => 'reltime' },
 { oid => '244',
   proname => 'timepl', prorettype => 'abstime',
-  proargtypes => 'abstime reltime', prosrc => 'timepl' },
+  proargtypes => 'abstime reltime' },
 { oid => '245',
   proname => 'timemi', prorettype => 'abstime',
-  proargtypes => 'abstime reltime', prosrc => 'timemi' },
+  proargtypes => 'abstime reltime' },
 { oid => '246', descr => 'I/O',
   proname => 'tintervalin', provolatile => 's', prorettype => 'tinterval',
-  proargtypes => 'cstring', prosrc => 'tintervalin' },
+  proargtypes => 'cstring' },
 { oid => '247', descr => 'I/O',
   proname => 'tintervalout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'tinterval', prosrc => 'tintervalout' },
+  proargtypes => 'tinterval' },
 { oid => '248',
   proname => 'intinterval', prorettype => 'bool',
-  proargtypes => 'abstime tinterval', prosrc => 'intinterval' },
+  proargtypes => 'abstime tinterval' },
 { oid => '249', descr => 'tinterval to reltime',
   proname => 'tintervalrel', prorettype => 'reltime',
-  proargtypes => 'tinterval', prosrc => 'tintervalrel' },
+  proargtypes => 'tinterval' },
 { oid => '250', descr => 'current date and time (abstime)',
   proname => 'timenow', provolatile => 's', prorettype => 'abstime',
-  proargtypes => '', prosrc => 'timenow' },
+  proargtypes => '' },
 { oid => '251',
   proname => 'abstimeeq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'abstime abstime', prosrc => 'abstimeeq' },
+  proargtypes => 'abstime abstime' },
 { oid => '252',
   proname => 'abstimene', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'abstime abstime', prosrc => 'abstimene' },
+  proargtypes => 'abstime abstime' },
 { oid => '253',
   proname => 'abstimelt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'abstime abstime', prosrc => 'abstimelt' },
+  proargtypes => 'abstime abstime' },
 { oid => '254',
   proname => 'abstimegt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'abstime abstime', prosrc => 'abstimegt' },
+  proargtypes => 'abstime abstime' },
 { oid => '255',
   proname => 'abstimele', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'abstime abstime', prosrc => 'abstimele' },
+  proargtypes => 'abstime abstime' },
 { oid => '256',
   proname => 'abstimege', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'abstime abstime', prosrc => 'abstimege' },
+  proargtypes => 'abstime abstime' },
 { oid => '257',
   proname => 'reltimeeq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'reltime reltime', prosrc => 'reltimeeq' },
+  proargtypes => 'reltime reltime' },
 { oid => '258',
   proname => 'reltimene', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'reltime reltime', prosrc => 'reltimene' },
+  proargtypes => 'reltime reltime' },
 { oid => '259',
   proname => 'reltimelt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'reltime reltime', prosrc => 'reltimelt' },
+  proargtypes => 'reltime reltime' },
 { oid => '260',
   proname => 'reltimegt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'reltime reltime', prosrc => 'reltimegt' },
+  proargtypes => 'reltime reltime' },
 { oid => '261',
   proname => 'reltimele', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'reltime reltime', prosrc => 'reltimele' },
+  proargtypes => 'reltime reltime' },
 { oid => '262',
   proname => 'reltimege', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'reltime reltime', prosrc => 'reltimege' },
+  proargtypes => 'reltime reltime' },
 { oid => '263',
   proname => 'tintervalsame', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervalsame' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '264',
   proname => 'tintervalct', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervalct' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '265',
   proname => 'tintervalov', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervalov' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '266',
   proname => 'tintervalleneq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval reltime', prosrc => 'tintervalleneq' },
+  proargtypes => 'tinterval reltime' },
 { oid => '267',
   proname => 'tintervallenne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval reltime', prosrc => 'tintervallenne' },
+  proargtypes => 'tinterval reltime' },
 { oid => '268',
   proname => 'tintervallenlt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval reltime', prosrc => 'tintervallenlt' },
+  proargtypes => 'tinterval reltime' },
 { oid => '269',
   proname => 'tintervallengt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval reltime', prosrc => 'tintervallengt' },
+  proargtypes => 'tinterval reltime' },
 { oid => '270',
   proname => 'tintervallenle', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval reltime', prosrc => 'tintervallenle' },
+  proargtypes => 'tinterval reltime' },
 { oid => '271',
   proname => 'tintervallenge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval reltime', prosrc => 'tintervallenge' },
+  proargtypes => 'tinterval reltime' },
 { oid => '272',
   proname => 'tintervalstart', prorettype => 'abstime',
-  proargtypes => 'tinterval', prosrc => 'tintervalstart' },
+  proargtypes => 'tinterval' },
 { oid => '273', descr => 'end of interval',
   proname => 'tintervalend', prorettype => 'abstime',
-  proargtypes => 'tinterval', prosrc => 'tintervalend' },
+  proargtypes => 'tinterval' },
 { oid => '274',
   descr => 'current date and time - increments during transactions',
   proname => 'timeofday', provolatile => 'v', prorettype => 'text',
-  proargtypes => '', prosrc => 'timeofday' },
+  proargtypes => '' },
 { oid => '275', descr => 'finite abstime?',
   proname => 'isfinite', prorettype => 'bool', proargtypes => 'abstime',
   prosrc => 'abstime_finite' },
 
 { oid => '277',
-  proname => 'inter_sl', prorettype => 'bool', proargtypes => 'lseg line',
-  prosrc => 'inter_sl' },
+  proname => 'inter_sl', prorettype => 'bool', proargtypes => 'lseg line' },
 { oid => '278',
-  proname => 'inter_lb', prorettype => 'bool', proargtypes => 'line box',
-  prosrc => 'inter_lb' },
+  proname => 'inter_lb', prorettype => 'bool', proargtypes => 'line box' },
 
 { oid => '279',
   proname => 'float48mul', prorettype => 'float8',
-  proargtypes => 'float4 float8', prosrc => 'float48mul' },
+  proargtypes => 'float4 float8' },
 { oid => '280',
   proname => 'float48div', prorettype => 'float8',
-  proargtypes => 'float4 float8', prosrc => 'float48div' },
+  proargtypes => 'float4 float8' },
 { oid => '281',
   proname => 'float48pl', prorettype => 'float8',
-  proargtypes => 'float4 float8', prosrc => 'float48pl' },
+  proargtypes => 'float4 float8' },
 { oid => '282',
   proname => 'float48mi', prorettype => 'float8',
-  proargtypes => 'float4 float8', prosrc => 'float48mi' },
+  proargtypes => 'float4 float8' },
 { oid => '283',
   proname => 'float84mul', prorettype => 'float8',
-  proargtypes => 'float8 float4', prosrc => 'float84mul' },
+  proargtypes => 'float8 float4' },
 { oid => '284',
   proname => 'float84div', prorettype => 'float8',
-  proargtypes => 'float8 float4', prosrc => 'float84div' },
+  proargtypes => 'float8 float4' },
 { oid => '285',
   proname => 'float84pl', prorettype => 'float8',
-  proargtypes => 'float8 float4', prosrc => 'float84pl' },
+  proargtypes => 'float8 float4' },
 { oid => '286',
   proname => 'float84mi', prorettype => 'float8',
-  proargtypes => 'float8 float4', prosrc => 'float84mi' },
+  proargtypes => 'float8 float4' },
 
 { oid => '287',
   proname => 'float4eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float4', prosrc => 'float4eq' },
+  proargtypes => 'float4 float4' },
 { oid => '288',
   proname => 'float4ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float4', prosrc => 'float4ne' },
+  proargtypes => 'float4 float4' },
 { oid => '289',
   proname => 'float4lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float4', prosrc => 'float4lt' },
+  proargtypes => 'float4 float4' },
 { oid => '290',
   proname => 'float4le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float4', prosrc => 'float4le' },
+  proargtypes => 'float4 float4' },
 { oid => '291',
   proname => 'float4gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float4', prosrc => 'float4gt' },
+  proargtypes => 'float4 float4' },
 { oid => '292',
   proname => 'float4ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float4', prosrc => 'float4ge' },
+  proargtypes => 'float4 float4' },
 
 { oid => '293',
   proname => 'float8eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float8', prosrc => 'float8eq' },
+  proargtypes => 'float8 float8' },
 { oid => '294',
   proname => 'float8ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float8', prosrc => 'float8ne' },
+  proargtypes => 'float8 float8' },
 { oid => '295',
   proname => 'float8lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float8', prosrc => 'float8lt' },
+  proargtypes => 'float8 float8' },
 { oid => '296',
   proname => 'float8le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float8', prosrc => 'float8le' },
+  proargtypes => 'float8 float8' },
 { oid => '297',
   proname => 'float8gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float8', prosrc => 'float8gt' },
+  proargtypes => 'float8 float8' },
 { oid => '298',
   proname => 'float8ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float8', prosrc => 'float8ge' },
+  proargtypes => 'float8 float8' },
 
 { oid => '299',
   proname => 'float48eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float8', prosrc => 'float48eq' },
+  proargtypes => 'float4 float8' },
 
 # OIDS 300 - 399
 
 { oid => '300',
   proname => 'float48ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float8', prosrc => 'float48ne' },
+  proargtypes => 'float4 float8' },
 { oid => '301',
   proname => 'float48lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float8', prosrc => 'float48lt' },
+  proargtypes => 'float4 float8' },
 { oid => '302',
   proname => 'float48le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float8', prosrc => 'float48le' },
+  proargtypes => 'float4 float8' },
 { oid => '303',
   proname => 'float48gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float8', prosrc => 'float48gt' },
+  proargtypes => 'float4 float8' },
 { oid => '304',
   proname => 'float48ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float4 float8', prosrc => 'float48ge' },
+  proargtypes => 'float4 float8' },
 { oid => '305',
   proname => 'float84eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float4', prosrc => 'float84eq' },
+  proargtypes => 'float8 float4' },
 { oid => '306',
   proname => 'float84ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float4', prosrc => 'float84ne' },
+  proargtypes => 'float8 float4' },
 { oid => '307',
   proname => 'float84lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float4', prosrc => 'float84lt' },
+  proargtypes => 'float8 float4' },
 { oid => '308',
   proname => 'float84le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float4', prosrc => 'float84le' },
+  proargtypes => 'float8 float4' },
 { oid => '309',
   proname => 'float84gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float4', prosrc => 'float84gt' },
+  proargtypes => 'float8 float4' },
 { oid => '310',
   proname => 'float84ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'float8 float4', prosrc => 'float84ge' },
+  proargtypes => 'float8 float4' },
 { oid => '320', descr => 'bucket number of operand in equal-width histogram',
   proname => 'width_bucket', prorettype => 'int4',
   proargtypes => 'float8 float8 float8 int4', prosrc => 'width_bucket_float8' },
@@ -921,154 +807,136 @@
 # Index access method handlers
 { oid => '330', descr => 'btree index access method handler',
   proname => 'bthandler', provolatile => 'v', prorettype => 'index_am_handler',
-  proargtypes => 'internal', prosrc => 'bthandler' },
+  proargtypes => 'internal' },
 { oid => '331', descr => 'hash index access method handler',
   proname => 'hashhandler', provolatile => 'v',
-  prorettype => 'index_am_handler', proargtypes => 'internal',
-  prosrc => 'hashhandler' },
+  prorettype => 'index_am_handler', proargtypes => 'internal' },
 { oid => '332', descr => 'gist index access method handler',
   proname => 'gisthandler', provolatile => 'v',
-  prorettype => 'index_am_handler', proargtypes => 'internal',
-  prosrc => 'gisthandler' },
+  prorettype => 'index_am_handler', proargtypes => 'internal' },
 { oid => '333', descr => 'gin index access method handler',
   proname => 'ginhandler', provolatile => 'v', prorettype => 'index_am_handler',
-  proargtypes => 'internal', prosrc => 'ginhandler' },
+  proargtypes => 'internal' },
 { oid => '334', descr => 'spgist index access method handler',
   proname => 'spghandler', provolatile => 'v', prorettype => 'index_am_handler',
-  proargtypes => 'internal', prosrc => 'spghandler' },
+  proargtypes => 'internal' },
 { oid => '335', descr => 'brin index access method handler',
   proname => 'brinhandler', provolatile => 'v',
-  prorettype => 'index_am_handler', proargtypes => 'internal',
-  prosrc => 'brinhandler' },
+  prorettype => 'index_am_handler', proargtypes => 'internal' },
 { oid => '3952', descr => 'brin: standalone scan new table pages',
   proname => 'brin_summarize_new_values', provolatile => 'v',
-  proparallel => 'u', prorettype => 'int4', proargtypes => 'regclass',
-  prosrc => 'brin_summarize_new_values' },
+  proparallel => 'u', prorettype => 'int4', proargtypes => 'regclass' },
 { oid => '3999', descr => 'brin: standalone scan new table pages',
   proname => 'brin_summarize_range', provolatile => 'v', proparallel => 'u',
-  prorettype => 'int4', proargtypes => 'regclass int8',
-  prosrc => 'brin_summarize_range' },
+  prorettype => 'int4', proargtypes => 'regclass int8' },
 { oid => '4014', descr => 'brin: desummarize page range',
   proname => 'brin_desummarize_range', provolatile => 'v', proparallel => 'u',
-  prorettype => 'void', proargtypes => 'regclass int8',
-  prosrc => 'brin_desummarize_range' },
+  prorettype => 'void', proargtypes => 'regclass int8' },
 
 { oid => '338', descr => 'validate an operator class',
   proname => 'amvalidate', provolatile => 'v', prorettype => 'bool',
-  proargtypes => 'oid', prosrc => 'amvalidate' },
+  proargtypes => 'oid' },
 
 { oid => '636', descr => 'test property of an index access method',
   proname => 'pg_indexam_has_property', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid text',
-  prosrc => 'pg_indexam_has_property' },
+  prorettype => 'bool', proargtypes => 'oid text' },
 { oid => '637', descr => 'test property of an index',
   proname => 'pg_index_has_property', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'regclass text', prosrc => 'pg_index_has_property' },
+  proargtypes => 'regclass text' },
 { oid => '638', descr => 'test property of an index column',
   proname => 'pg_index_column_has_property', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'regclass int4 text',
-  prosrc => 'pg_index_column_has_property' },
+  prorettype => 'bool', proargtypes => 'regclass int4 text' },
 
 { oid => '339',
   proname => 'poly_same', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_same' },
+  proargtypes => 'polygon polygon' },
 { oid => '340',
   proname => 'poly_contain', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_contain' },
+  proargtypes => 'polygon polygon' },
 { oid => '341',
   proname => 'poly_left', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_left' },
+  proargtypes => 'polygon polygon' },
 { oid => '342',
   proname => 'poly_overleft', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_overleft' },
+  proargtypes => 'polygon polygon' },
 { oid => '343',
   proname => 'poly_overright', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_overright' },
+  proargtypes => 'polygon polygon' },
 { oid => '344',
   proname => 'poly_right', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_right' },
+  proargtypes => 'polygon polygon' },
 { oid => '345',
   proname => 'poly_contained', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_contained' },
+  proargtypes => 'polygon polygon' },
 { oid => '346',
   proname => 'poly_overlap', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_overlap' },
+  proargtypes => 'polygon polygon' },
 { oid => '347', descr => 'I/O',
-  proname => 'poly_in', prorettype => 'polygon', proargtypes => 'cstring',
-  prosrc => 'poly_in' },
+  proname => 'poly_in', prorettype => 'polygon', proargtypes => 'cstring' },
 { oid => '348', descr => 'I/O',
-  proname => 'poly_out', prorettype => 'cstring', proargtypes => 'polygon',
-  prosrc => 'poly_out' },
+  proname => 'poly_out', prorettype => 'cstring', proargtypes => 'polygon' },
 
 { oid => '350', descr => 'less-equal-greater',
-  proname => 'btint2cmp', prorettype => 'int4', proargtypes => 'int2 int2',
-  prosrc => 'btint2cmp' },
+  proname => 'btint2cmp', prorettype => 'int4', proargtypes => 'int2 int2' },
 { oid => '3129', descr => 'sort support',
   proname => 'btint2sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btint2sortsupport' },
+  proargtypes => 'internal' },
 { oid => '351', descr => 'less-equal-greater',
-  proname => 'btint4cmp', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'btint4cmp' },
+  proname => 'btint4cmp', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '3130', descr => 'sort support',
   proname => 'btint4sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btint4sortsupport' },
+  proargtypes => 'internal' },
 { oid => '842', descr => 'less-equal-greater',
-  proname => 'btint8cmp', prorettype => 'int4', proargtypes => 'int8 int8',
-  prosrc => 'btint8cmp' },
+  proname => 'btint8cmp', prorettype => 'int4', proargtypes => 'int8 int8' },
 { oid => '3131', descr => 'sort support',
   proname => 'btint8sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btint8sortsupport' },
+  proargtypes => 'internal' },
 { oid => '354', descr => 'less-equal-greater',
   proname => 'btfloat4cmp', prorettype => 'int4',
-  proargtypes => 'float4 float4', prosrc => 'btfloat4cmp' },
+  proargtypes => 'float4 float4' },
 { oid => '3132', descr => 'sort support',
   proname => 'btfloat4sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btfloat4sortsupport' },
+  proargtypes => 'internal' },
 { oid => '355', descr => 'less-equal-greater',
   proname => 'btfloat8cmp', prorettype => 'int4',
-  proargtypes => 'float8 float8', prosrc => 'btfloat8cmp' },
+  proargtypes => 'float8 float8' },
 { oid => '3133', descr => 'sort support',
   proname => 'btfloat8sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btfloat8sortsupport' },
+  proargtypes => 'internal' },
 { oid => '356', descr => 'less-equal-greater',
-  proname => 'btoidcmp', prorettype => 'int4', proargtypes => 'oid oid',
-  prosrc => 'btoidcmp' },
+  proname => 'btoidcmp', prorettype => 'int4', proargtypes => 'oid oid' },
 { oid => '3134', descr => 'sort support',
   proname => 'btoidsortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btoidsortsupport' },
+  proargtypes => 'internal' },
 { oid => '404', descr => 'less-equal-greater',
   proname => 'btoidvectorcmp', prorettype => 'int4',
-  proargtypes => 'oidvector oidvector', prosrc => 'btoidvectorcmp' },
+  proargtypes => 'oidvector oidvector' },
 { oid => '357', descr => 'less-equal-greater',
   proname => 'btabstimecmp', prorettype => 'int4',
-  proargtypes => 'abstime abstime', prosrc => 'btabstimecmp' },
+  proargtypes => 'abstime abstime' },
 { oid => '358', descr => 'less-equal-greater',
-  proname => 'btcharcmp', prorettype => 'int4', proargtypes => 'char char',
-  prosrc => 'btcharcmp' },
+  proname => 'btcharcmp', prorettype => 'int4', proargtypes => 'char char' },
 { oid => '359', descr => 'less-equal-greater',
-  proname => 'btnamecmp', prorettype => 'int4', proargtypes => 'name name',
-  prosrc => 'btnamecmp' },
+  proname => 'btnamecmp', prorettype => 'int4', proargtypes => 'name name' },
 { oid => '3135', descr => 'sort support',
   proname => 'btnamesortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btnamesortsupport' },
+  proargtypes => 'internal' },
 { oid => '360', descr => 'less-equal-greater',
-  proname => 'bttextcmp', prorettype => 'int4', proargtypes => 'text text',
-  prosrc => 'bttextcmp' },
+  proname => 'bttextcmp', prorettype => 'int4', proargtypes => 'text text' },
 { oid => '3255', descr => 'sort support',
   proname => 'bttextsortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'bttextsortsupport' },
+  proargtypes => 'internal' },
 { oid => '377', descr => 'less-equal-greater',
-  proname => 'cash_cmp', prorettype => 'int4', proargtypes => 'money money',
-  prosrc => 'cash_cmp' },
+  proname => 'cash_cmp', prorettype => 'int4', proargtypes => 'money money' },
 { oid => '380', descr => 'less-equal-greater',
   proname => 'btreltimecmp', prorettype => 'int4',
-  proargtypes => 'reltime reltime', prosrc => 'btreltimecmp' },
+  proargtypes => 'reltime reltime' },
 { oid => '381', descr => 'less-equal-greater',
   proname => 'bttintervalcmp', prorettype => 'int4',
-  proargtypes => 'tinterval tinterval', prosrc => 'bttintervalcmp' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '382', descr => 'less-equal-greater',
   proname => 'btarraycmp', prorettype => 'int4',
-  proargtypes => 'anyarray anyarray', prosrc => 'btarraycmp' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '4126', descr => 'window RANGE support',
   proname => 'in_range', prorettype => 'bool',
   proargtypes => 'int8 int8 int8 bool bool', prosrc => 'in_range_int8_int8' },
@@ -1105,43 +973,32 @@
 
 { oid => '361',
   proname => 'lseg_distance', prorettype => 'float8',
-  proargtypes => 'lseg lseg', prosrc => 'lseg_distance' },
+  proargtypes => 'lseg lseg' },
 { oid => '362',
-  proname => 'lseg_interpt', prorettype => 'point', proargtypes => 'lseg lseg',
-  prosrc => 'lseg_interpt' },
+  proname => 'lseg_interpt', prorettype => 'point', proargtypes => 'lseg lseg' },
 { oid => '363',
-  proname => 'dist_ps', prorettype => 'float8', proargtypes => 'point lseg',
-  prosrc => 'dist_ps' },
+  proname => 'dist_ps', prorettype => 'float8', proargtypes => 'point lseg' },
 { oid => '364',
-  proname => 'dist_pb', prorettype => 'float8', proargtypes => 'point box',
-  prosrc => 'dist_pb' },
+  proname => 'dist_pb', prorettype => 'float8', proargtypes => 'point box' },
 { oid => '365',
-  proname => 'dist_sb', prorettype => 'float8', proargtypes => 'lseg box',
-  prosrc => 'dist_sb' },
+  proname => 'dist_sb', prorettype => 'float8', proargtypes => 'lseg box' },
 { oid => '366',
-  proname => 'close_ps', prorettype => 'point', proargtypes => 'point lseg',
-  prosrc => 'close_ps' },
+  proname => 'close_ps', prorettype => 'point', proargtypes => 'point lseg' },
 { oid => '367',
-  proname => 'close_pb', prorettype => 'point', proargtypes => 'point box',
-  prosrc => 'close_pb' },
+  proname => 'close_pb', prorettype => 'point', proargtypes => 'point box' },
 { oid => '368',
-  proname => 'close_sb', prorettype => 'point', proargtypes => 'lseg box',
-  prosrc => 'close_sb' },
+  proname => 'close_sb', prorettype => 'point', proargtypes => 'lseg box' },
 { oid => '369',
-  proname => 'on_ps', prorettype => 'bool', proargtypes => 'point lseg',
-  prosrc => 'on_ps' },
+  proname => 'on_ps', prorettype => 'bool', proargtypes => 'point lseg' },
 { oid => '370',
   proname => 'path_distance', prorettype => 'float8',
-  proargtypes => 'path path', prosrc => 'path_distance' },
+  proargtypes => 'path path' },
 { oid => '371',
-  proname => 'dist_ppath', prorettype => 'float8', proargtypes => 'point path',
-  prosrc => 'dist_ppath' },
+  proname => 'dist_ppath', prorettype => 'float8', proargtypes => 'point path' },
 { oid => '372',
-  proname => 'on_sb', prorettype => 'bool', proargtypes => 'lseg box',
-  prosrc => 'on_sb' },
+  proname => 'on_sb', prorettype => 'bool', proargtypes => 'lseg box' },
 { oid => '373',
-  proname => 'inter_sb', prorettype => 'bool', proargtypes => 'lseg box',
-  prosrc => 'inter_sb' },
+  proname => 'inter_sb', prorettype => 'bool', proargtypes => 'lseg box' },
 
 # OIDS 400 - 499
 
@@ -1162,101 +1019,84 @@
   prosrc => 'bpchar_name' },
 
 { oid => '449', descr => 'hash',
-  proname => 'hashint2', prorettype => 'int4', proargtypes => 'int2',
-  prosrc => 'hashint2' },
+  proname => 'hashint2', prorettype => 'int4', proargtypes => 'int2' },
 { oid => '441', descr => 'hash',
   proname => 'hashint2extended', prorettype => 'int8',
-  proargtypes => 'int2 int8', prosrc => 'hashint2extended' },
+  proargtypes => 'int2 int8' },
 { oid => '450', descr => 'hash',
-  proname => 'hashint4', prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'hashint4' },
+  proname => 'hashint4', prorettype => 'int4', proargtypes => 'int4' },
 { oid => '425', descr => 'hash',
   proname => 'hashint4extended', prorettype => 'int8',
-  proargtypes => 'int4 int8', prosrc => 'hashint4extended' },
+  proargtypes => 'int4 int8' },
 { oid => '949', descr => 'hash',
-  proname => 'hashint8', prorettype => 'int4', proargtypes => 'int8',
-  prosrc => 'hashint8' },
+  proname => 'hashint8', prorettype => 'int4', proargtypes => 'int8' },
 { oid => '442', descr => 'hash',
   proname => 'hashint8extended', prorettype => 'int8',
-  proargtypes => 'int8 int8', prosrc => 'hashint8extended' },
+  proargtypes => 'int8 int8' },
 { oid => '451', descr => 'hash',
-  proname => 'hashfloat4', prorettype => 'int4', proargtypes => 'float4',
-  prosrc => 'hashfloat4' },
+  proname => 'hashfloat4', prorettype => 'int4', proargtypes => 'float4' },
 { oid => '443', descr => 'hash',
   proname => 'hashfloat4extended', prorettype => 'int8',
-  proargtypes => 'float4 int8', prosrc => 'hashfloat4extended' },
+  proargtypes => 'float4 int8' },
 { oid => '452', descr => 'hash',
-  proname => 'hashfloat8', prorettype => 'int4', proargtypes => 'float8',
-  prosrc => 'hashfloat8' },
+  proname => 'hashfloat8', prorettype => 'int4', proargtypes => 'float8' },
 { oid => '444', descr => 'hash',
   proname => 'hashfloat8extended', prorettype => 'int8',
-  proargtypes => 'float8 int8', prosrc => 'hashfloat8extended' },
+  proargtypes => 'float8 int8' },
 { oid => '453', descr => 'hash',
-  proname => 'hashoid', prorettype => 'int4', proargtypes => 'oid',
-  prosrc => 'hashoid' },
+  proname => 'hashoid', prorettype => 'int4', proargtypes => 'oid' },
 { oid => '445', descr => 'hash',
-  proname => 'hashoidextended', prorettype => 'int8', proargtypes => 'oid int8',
-  prosrc => 'hashoidextended' },
+  proname => 'hashoidextended', prorettype => 'int8', proargtypes => 'oid int8' },
 { oid => '454', descr => 'hash',
-  proname => 'hashchar', prorettype => 'int4', proargtypes => 'char',
-  prosrc => 'hashchar' },
+  proname => 'hashchar', prorettype => 'int4', proargtypes => 'char' },
 { oid => '446', descr => 'hash',
   proname => 'hashcharextended', prorettype => 'int8',
-  proargtypes => 'char int8', prosrc => 'hashcharextended' },
+  proargtypes => 'char int8' },
 { oid => '455', descr => 'hash',
-  proname => 'hashname', prorettype => 'int4', proargtypes => 'name',
-  prosrc => 'hashname' },
+  proname => 'hashname', prorettype => 'int4', proargtypes => 'name' },
 { oid => '447', descr => 'hash',
   proname => 'hashnameextended', prorettype => 'int8',
-  proargtypes => 'name int8', prosrc => 'hashnameextended' },
+  proargtypes => 'name int8' },
 { oid => '400', descr => 'hash',
-  proname => 'hashtext', prorettype => 'int4', proargtypes => 'text',
-  prosrc => 'hashtext' },
+  proname => 'hashtext', prorettype => 'int4', proargtypes => 'text' },
 { oid => '448', descr => 'hash',
   proname => 'hashtextextended', prorettype => 'int8',
-  proargtypes => 'text int8', prosrc => 'hashtextextended' },
+  proargtypes => 'text int8' },
 { oid => '456', descr => 'hash',
-  proname => 'hashvarlena', prorettype => 'int4', proargtypes => 'internal',
-  prosrc => 'hashvarlena' },
+  proname => 'hashvarlena', prorettype => 'int4', proargtypes => 'internal' },
 { oid => '772', descr => 'hash',
   proname => 'hashvarlenaextended', prorettype => 'int8',
-  proargtypes => 'internal int8', prosrc => 'hashvarlenaextended' },
+  proargtypes => 'internal int8' },
 { oid => '457', descr => 'hash',
-  proname => 'hashoidvector', prorettype => 'int4', proargtypes => 'oidvector',
-  prosrc => 'hashoidvector' },
+  proname => 'hashoidvector', prorettype => 'int4', proargtypes => 'oidvector' },
 { oid => '776', descr => 'hash',
   proname => 'hashoidvectorextended', prorettype => 'int8',
-  proargtypes => 'oidvector int8', prosrc => 'hashoidvectorextended' },
+  proargtypes => 'oidvector int8' },
 { oid => '329', descr => 'hash',
-  proname => 'hash_aclitem', prorettype => 'int4', proargtypes => 'aclitem',
-  prosrc => 'hash_aclitem' },
+  proname => 'hash_aclitem', prorettype => 'int4', proargtypes => 'aclitem' },
 { oid => '777', descr => 'hash',
   proname => 'hash_aclitem_extended', prorettype => 'int8',
-  proargtypes => 'aclitem int8', prosrc => 'hash_aclitem_extended' },
+  proargtypes => 'aclitem int8' },
 { oid => '399', descr => 'hash',
-  proname => 'hashmacaddr', prorettype => 'int4', proargtypes => 'macaddr',
-  prosrc => 'hashmacaddr' },
+  proname => 'hashmacaddr', prorettype => 'int4', proargtypes => 'macaddr' },
 { oid => '778', descr => 'hash',
   proname => 'hashmacaddrextended', prorettype => 'int8',
-  proargtypes => 'macaddr int8', prosrc => 'hashmacaddrextended' },
+  proargtypes => 'macaddr int8' },
 { oid => '422', descr => 'hash',
-  proname => 'hashinet', prorettype => 'int4', proargtypes => 'inet',
-  prosrc => 'hashinet' },
+  proname => 'hashinet', prorettype => 'int4', proargtypes => 'inet' },
 { oid => '779', descr => 'hash',
   proname => 'hashinetextended', prorettype => 'int8',
-  proargtypes => 'inet int8', prosrc => 'hashinetextended' },
+  proargtypes => 'inet int8' },
 { oid => '432', descr => 'hash',
-  proname => 'hash_numeric', prorettype => 'int4', proargtypes => 'numeric',
-  prosrc => 'hash_numeric' },
+  proname => 'hash_numeric', prorettype => 'int4', proargtypes => 'numeric' },
 { oid => '780', descr => 'hash',
   proname => 'hash_numeric_extended', prorettype => 'int8',
-  proargtypes => 'numeric int8', prosrc => 'hash_numeric_extended' },
+  proargtypes => 'numeric int8' },
 { oid => '328', descr => 'hash',
-  proname => 'hashmacaddr8', prorettype => 'int4', proargtypes => 'macaddr8',
-  prosrc => 'hashmacaddr8' },
+  proname => 'hashmacaddr8', prorettype => 'int4', proargtypes => 'macaddr8' },
 { oid => '781', descr => 'hash',
   proname => 'hashmacaddr8extended', prorettype => 'int8',
-  proargtypes => 'macaddr8 int8', prosrc => 'hashmacaddr8extended' },
+  proargtypes => 'macaddr8 int8' },
 
 { oid => '438', descr => 'count the number of NULL arguments',
   proname => 'num_nulls', provariadic => 'any', proisstrict => 'f',
@@ -1268,70 +1108,61 @@
   proargmodes => '{v}', prosrc => 'pg_num_nonnulls' },
 
 { oid => '458', descr => 'larger of two',
-  proname => 'text_larger', prorettype => 'text', proargtypes => 'text text',
-  prosrc => 'text_larger' },
+  proname => 'text_larger', prorettype => 'text', proargtypes => 'text text' },
 { oid => '459', descr => 'smaller of two',
-  proname => 'text_smaller', prorettype => 'text', proargtypes => 'text text',
-  prosrc => 'text_smaller' },
+  proname => 'text_smaller', prorettype => 'text', proargtypes => 'text text' },
 
 { oid => '460', descr => 'I/O',
-  proname => 'int8in', prorettype => 'int8', proargtypes => 'cstring',
-  prosrc => 'int8in' },
+  proname => 'int8in', prorettype => 'int8', proargtypes => 'cstring' },
 { oid => '461', descr => 'I/O',
-  proname => 'int8out', prorettype => 'cstring', proargtypes => 'int8',
-  prosrc => 'int8out' },
+  proname => 'int8out', prorettype => 'cstring', proargtypes => 'int8' },
 { oid => '462',
-  proname => 'int8um', prorettype => 'int8', proargtypes => 'int8',
-  prosrc => 'int8um' },
+  proname => 'int8um', prorettype => 'int8', proargtypes => 'int8' },
 { oid => '463',
-  proname => 'int8pl', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8pl' },
+  proname => 'int8pl', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '464',
-  proname => 'int8mi', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8mi' },
+  proname => 'int8mi', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '465',
-  proname => 'int8mul', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8mul' },
+  proname => 'int8mul', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '466',
-  proname => 'int8div', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8div' },
+  proname => 'int8div', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '467',
   proname => 'int8eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int8', prosrc => 'int8eq' },
+  proargtypes => 'int8 int8' },
 { oid => '468',
   proname => 'int8ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int8', prosrc => 'int8ne' },
+  proargtypes => 'int8 int8' },
 { oid => '469',
   proname => 'int8lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int8', prosrc => 'int8lt' },
+  proargtypes => 'int8 int8' },
 { oid => '470',
   proname => 'int8gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int8', prosrc => 'int8gt' },
+  proargtypes => 'int8 int8' },
 { oid => '471',
   proname => 'int8le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int8', prosrc => 'int8le' },
+  proargtypes => 'int8 int8' },
 { oid => '472',
   proname => 'int8ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int8', prosrc => 'int8ge' },
+  proargtypes => 'int8 int8' },
 
 { oid => '474',
   proname => 'int84eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int4', prosrc => 'int84eq' },
+  proargtypes => 'int8 int4' },
 { oid => '475',
   proname => 'int84ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int4', prosrc => 'int84ne' },
+  proargtypes => 'int8 int4' },
 { oid => '476',
   proname => 'int84lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int4', prosrc => 'int84lt' },
+  proargtypes => 'int8 int4' },
 { oid => '477',
   proname => 'int84gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int4', prosrc => 'int84gt' },
+  proargtypes => 'int8 int4' },
 { oid => '478',
   proname => 'int84le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int4', prosrc => 'int84le' },
+  proargtypes => 'int8 int4' },
 { oid => '479',
   proname => 'int84ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int4', prosrc => 'int84ge' },
+  proargtypes => 'int8 int4' },
 
 { oid => '480', descr => 'convert int8 to int4',
   proname => 'int4', prorettype => 'int4', proargtypes => 'int8',
@@ -1351,11 +1182,10 @@
 # OIDS 600 - 699
 
 { oid => '626', descr => 'hash',
-  proname => 'hash_array', prorettype => 'int4', proargtypes => 'anyarray',
-  prosrc => 'hash_array' },
+  proname => 'hash_array', prorettype => 'int4', proargtypes => 'anyarray' },
 { oid => '782', descr => 'hash',
   proname => 'hash_array_extended', prorettype => 'int8',
-  proargtypes => 'anyarray int8', prosrc => 'hash_array_extended' },
+  proargtypes => 'anyarray int8' },
 
 { oid => '652', descr => 'convert int8 to float4',
   proname => 'float4', prorettype => 'float4', proargtypes => 'int8',
@@ -1373,53 +1203,52 @@
 
 { oid => '655',
   proname => 'namelt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'name name', prosrc => 'namelt' },
+  proargtypes => 'name name' },
 { oid => '656',
   proname => 'namele', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'name name', prosrc => 'namele' },
+  proargtypes => 'name name' },
 { oid => '657',
   proname => 'namegt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'name name', prosrc => 'namegt' },
+  proargtypes => 'name name' },
 { oid => '658',
   proname => 'namege', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'name name', prosrc => 'namege' },
+  proargtypes => 'name name' },
 { oid => '659',
   proname => 'namene', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'name name', prosrc => 'namene' },
+  proargtypes => 'name name' },
 
 { oid => '668', descr => 'adjust char() to typmod length',
   proname => 'bpchar', prorettype => 'bpchar',
-  proargtypes => 'bpchar int4 bool', prosrc => 'bpchar' },
+  proargtypes => 'bpchar int4 bool' },
 { oid => '3097', descr => 'transform a varchar length coercion',
   proname => 'varchar_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'varchar_transform' },
+  proargtypes => 'internal' },
 { oid => '669', descr => 'adjust varchar() to typmod length',
   proname => 'varchar', protransform => 'varchar_transform',
-  prorettype => 'varchar', proargtypes => 'varchar int4 bool',
-  prosrc => 'varchar' },
+  prorettype => 'varchar', proargtypes => 'varchar int4 bool' },
 
 { oid => '676',
   proname => 'mktinterval', prorettype => 'tinterval',
-  proargtypes => 'abstime abstime', prosrc => 'mktinterval' },
+  proargtypes => 'abstime abstime' },
 
 { oid => '619',
   proname => 'oidvectorne', prorettype => 'bool',
-  proargtypes => 'oidvector oidvector', prosrc => 'oidvectorne' },
+  proargtypes => 'oidvector oidvector' },
 { oid => '677',
   proname => 'oidvectorlt', prorettype => 'bool',
-  proargtypes => 'oidvector oidvector', prosrc => 'oidvectorlt' },
+  proargtypes => 'oidvector oidvector' },
 { oid => '678',
   proname => 'oidvectorle', prorettype => 'bool',
-  proargtypes => 'oidvector oidvector', prosrc => 'oidvectorle' },
+  proargtypes => 'oidvector oidvector' },
 { oid => '679',
   proname => 'oidvectoreq', prorettype => 'bool',
-  proargtypes => 'oidvector oidvector', prosrc => 'oidvectoreq' },
+  proargtypes => 'oidvector oidvector' },
 { oid => '680',
   proname => 'oidvectorge', prorettype => 'bool',
-  proargtypes => 'oidvector oidvector', prosrc => 'oidvectorge' },
+  proargtypes => 'oidvector oidvector' },
 { oid => '681',
   proname => 'oidvectorgt', prorettype => 'bool',
-  proargtypes => 'oidvector oidvector', prosrc => 'oidvectorgt' },
+  proargtypes => 'oidvector oidvector' },
 
 # OIDS 700 - 799
 { oid => '710', descr => 'deprecated, use current_user instead',
@@ -1427,10 +1256,10 @@
   proargtypes => '', prosrc => 'current_user' },
 { oid => '716',
   proname => 'oidlt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'oid oid', prosrc => 'oidlt' },
+  proargtypes => 'oid oid' },
 { oid => '717',
   proname => 'oidle', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'oid oid', prosrc => 'oidle' },
+  proargtypes => 'oid oid' },
 
 { oid => '720', descr => 'octet length',
   proname => 'octet_length', prorettype => 'int4', proargtypes => 'bytea',
@@ -1455,101 +1284,92 @@
   proargtypes => 'bytea bytea int4', prosrc => 'byteaoverlay_no_len' },
 
 { oid => '725',
-  proname => 'dist_pl', prorettype => 'float8', proargtypes => 'point line',
-  prosrc => 'dist_pl' },
+  proname => 'dist_pl', prorettype => 'float8', proargtypes => 'point line' },
 { oid => '726',
-  proname => 'dist_lb', prorettype => 'float8', proargtypes => 'line box',
-  prosrc => 'dist_lb' },
+  proname => 'dist_lb', prorettype => 'float8', proargtypes => 'line box' },
 { oid => '727',
-  proname => 'dist_sl', prorettype => 'float8', proargtypes => 'lseg line',
-  prosrc => 'dist_sl' },
+  proname => 'dist_sl', prorettype => 'float8', proargtypes => 'lseg line' },
 { oid => '728',
   proname => 'dist_cpoly', prorettype => 'float8',
-  proargtypes => 'circle polygon', prosrc => 'dist_cpoly' },
+  proargtypes => 'circle polygon' },
 { oid => '729',
   proname => 'poly_distance', prorettype => 'float8',
-  proargtypes => 'polygon polygon', prosrc => 'poly_distance' },
+  proargtypes => 'polygon polygon' },
 { oid => '3275',
   proname => 'dist_ppoly', prorettype => 'float8',
-  proargtypes => 'point polygon', prosrc => 'dist_ppoly' },
+  proargtypes => 'point polygon' },
 { oid => '3292',
   proname => 'dist_polyp', prorettype => 'float8',
-  proargtypes => 'polygon point', prosrc => 'dist_polyp' },
+  proargtypes => 'polygon point' },
 { oid => '3290',
   proname => 'dist_cpoint', prorettype => 'float8',
-  proargtypes => 'circle point', prosrc => 'dist_cpoint' },
+  proargtypes => 'circle point' },
 
 { oid => '740',
-  proname => 'text_lt', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'text_lt' },
+  proname => 'text_lt', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '741',
-  proname => 'text_le', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'text_le' },
+  proname => 'text_le', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '742',
-  proname => 'text_gt', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'text_gt' },
+  proname => 'text_gt', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '743',
-  proname => 'text_ge', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'text_ge' },
+  proname => 'text_ge', prorettype => 'bool', proargtypes => 'text text' },
 
 { oid => '745', descr => 'current user name',
   proname => 'current_user', provolatile => 's', prorettype => 'name',
-  proargtypes => '', prosrc => 'current_user' },
+  proargtypes => '' },
 { oid => '746', descr => 'session user name',
   proname => 'session_user', provolatile => 's', prorettype => 'name',
-  proargtypes => '', prosrc => 'session_user' },
+  proargtypes => '' },
 
 { oid => '744',
   proname => 'array_eq', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_eq' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '390',
   proname => 'array_ne', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_ne' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '391',
   proname => 'array_lt', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_lt' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '392',
   proname => 'array_gt', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_gt' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '393',
   proname => 'array_le', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_le' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '396',
   proname => 'array_ge', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_ge' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '747', descr => 'array dimensions',
-  proname => 'array_dims', prorettype => 'text', proargtypes => 'anyarray',
-  prosrc => 'array_dims' },
+  proname => 'array_dims', prorettype => 'text', proargtypes => 'anyarray' },
 { oid => '748', descr => 'number of array dimensions',
-  proname => 'array_ndims', prorettype => 'int4', proargtypes => 'anyarray',
-  prosrc => 'array_ndims' },
+  proname => 'array_ndims', prorettype => 'int4', proargtypes => 'anyarray' },
 { oid => '750', descr => 'I/O',
   proname => 'array_in', provolatile => 's', prorettype => 'anyarray',
-  proargtypes => 'cstring oid int4', prosrc => 'array_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '751', descr => 'I/O',
   proname => 'array_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'anyarray', prosrc => 'array_out' },
+  proargtypes => 'anyarray' },
 { oid => '2091', descr => 'array lower dimension',
   proname => 'array_lower', prorettype => 'int4',
-  proargtypes => 'anyarray int4', prosrc => 'array_lower' },
+  proargtypes => 'anyarray int4' },
 { oid => '2092', descr => 'array upper dimension',
   proname => 'array_upper', prorettype => 'int4',
-  proargtypes => 'anyarray int4', prosrc => 'array_upper' },
+  proargtypes => 'anyarray int4' },
 { oid => '2176', descr => 'array length',
   proname => 'array_length', prorettype => 'int4',
-  proargtypes => 'anyarray int4', prosrc => 'array_length' },
+  proargtypes => 'anyarray int4' },
 { oid => '3179', descr => 'array cardinality',
   proname => 'cardinality', prorettype => 'int4', proargtypes => 'anyarray',
   prosrc => 'array_cardinality' },
 { oid => '378', descr => 'append element onto end of array',
   proname => 'array_append', proisstrict => 'f', prorettype => 'anyarray',
-  proargtypes => 'anyarray anyelement', prosrc => 'array_append' },
+  proargtypes => 'anyarray anyelement' },
 { oid => '379', descr => 'prepend element onto front of array',
   proname => 'array_prepend', proisstrict => 'f', prorettype => 'anyarray',
-  proargtypes => 'anyelement anyarray', prosrc => 'array_prepend' },
+  proargtypes => 'anyelement anyarray' },
 { oid => '383',
   proname => 'array_cat', proisstrict => 'f', prorettype => 'anyarray',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_cat' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '394', descr => 'split delimited text into text[]',
   proname => 'string_to_array', proisstrict => 'f', prorettype => '_text',
   proargtypes => 'text text', prosrc => 'text_to_array' },
@@ -1567,13 +1387,13 @@
   prosrc => 'array_to_text_null' },
 { oid => '515', descr => 'larger of two',
   proname => 'array_larger', prorettype => 'anyarray',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_larger' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '516', descr => 'smaller of two',
   proname => 'array_smaller', prorettype => 'anyarray',
-  proargtypes => 'anyarray anyarray', prosrc => 'array_smaller' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '3277', descr => 'returns an offset of value in array',
   proname => 'array_position', proisstrict => 'f', prorettype => 'int4',
-  proargtypes => 'anyarray anyelement', prosrc => 'array_position' },
+  proargtypes => 'anyarray anyelement' },
 { oid => '3278',
   descr => 'returns an offset of value in array with start index',
   proname => 'array_position', proisstrict => 'f', prorettype => 'int4',
@@ -1581,18 +1401,17 @@
 { oid => '3279',
   descr => 'returns an array of offsets of some value in array',
   proname => 'array_positions', proisstrict => 'f', prorettype => '_int4',
-  proargtypes => 'anyarray anyelement', prosrc => 'array_positions' },
+  proargtypes => 'anyarray anyelement' },
 { oid => '1191', descr => 'array subscripts generator',
   proname => 'generate_subscripts', prorows => '1000', proretset => 't',
-  prorettype => 'int4', proargtypes => 'anyarray int4 bool',
-  prosrc => 'generate_subscripts' },
+  prorettype => 'int4', proargtypes => 'anyarray int4 bool' },
 { oid => '1192', descr => 'array subscripts generator',
   proname => 'generate_subscripts', prorows => '1000', proretset => 't',
   prorettype => 'int4', proargtypes => 'anyarray int4',
   prosrc => 'generate_subscripts_nodir' },
 { oid => '1193', descr => 'array constructor with value',
   proname => 'array_fill', proisstrict => 'f', prorettype => 'anyarray',
-  proargtypes => 'anyelement _int4', prosrc => 'array_fill' },
+  proargtypes => 'anyelement _int4' },
 { oid => '1286', descr => 'array constructor with value',
   proname => 'array_fill', proisstrict => 'f', prorettype => 'anyarray',
   proargtypes => 'anyelement _int4 _int4',
@@ -1604,28 +1423,26 @@
 { oid => '3167',
   descr => 'remove any occurrences of an element from an array',
   proname => 'array_remove', proisstrict => 'f', prorettype => 'anyarray',
-  proargtypes => 'anyarray anyelement', prosrc => 'array_remove' },
+  proargtypes => 'anyarray anyelement' },
 { oid => '3168', descr => 'replace any occurrences of an element in an array',
   proname => 'array_replace', proisstrict => 'f', prorettype => 'anyarray',
-  proargtypes => 'anyarray anyelement anyelement', prosrc => 'array_replace' },
+  proargtypes => 'anyarray anyelement anyelement' },
 { oid => '2333', descr => 'aggregate transition function',
   proname => 'array_agg_transfn', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal anynonarray', prosrc => 'array_agg_transfn' },
+  proargtypes => 'internal anynonarray' },
 { oid => '2334', descr => 'aggregate final function',
   proname => 'array_agg_finalfn', proisstrict => 'f', prorettype => 'anyarray',
-  proargtypes => 'internal anynonarray', prosrc => 'array_agg_finalfn' },
+  proargtypes => 'internal anynonarray' },
 { oid => '2335', descr => 'concatenate aggregate input into an array',
   proname => 'array_agg', prokind => 'a', proisstrict => 'f',
   prorettype => 'anyarray', proargtypes => 'anynonarray',
   prosrc => 'aggregate_dummy' },
 { oid => '4051', descr => 'aggregate transition function',
   proname => 'array_agg_array_transfn', proisstrict => 'f',
-  prorettype => 'internal', proargtypes => 'internal anyarray',
-  prosrc => 'array_agg_array_transfn' },
+  prorettype => 'internal', proargtypes => 'internal anyarray' },
 { oid => '4052', descr => 'aggregate final function',
   proname => 'array_agg_array_finalfn', proisstrict => 'f',
-  prorettype => 'anyarray', proargtypes => 'internal anyarray',
-  prosrc => 'array_agg_array_finalfn' },
+  prorettype => 'anyarray', proargtypes => 'internal anyarray' },
 { oid => '4053', descr => 'concatenate aggregate input into an array',
   proname => 'array_agg', prokind => 'a', proisstrict => 'f',
   prorettype => 'anyarray', proargtypes => 'anyarray',
@@ -1636,28 +1453,25 @@
   proargtypes => 'anyelement anyarray', prosrc => 'width_bucket_array' },
 { oid => '3816', descr => 'array typanalyze',
   proname => 'array_typanalyze', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'internal', prosrc => 'array_typanalyze' },
+  proargtypes => 'internal' },
 { oid => '3817',
   descr => 'restriction selectivity for array-containment operators',
   proname => 'arraycontsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'arraycontsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '3818', descr => 'join selectivity for array-containment operators',
   proname => 'arraycontjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'arraycontjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 
 { oid => '760', descr => 'I/O',
   proname => 'smgrin', provolatile => 's', prorettype => 'smgr',
-  proargtypes => 'cstring', prosrc => 'smgrin' },
+  proargtypes => 'cstring' },
 { oid => '761', descr => 'I/O',
   proname => 'smgrout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'smgr', prosrc => 'smgrout' },
+  proargtypes => 'smgr' },
 { oid => '762', descr => 'storage manager',
-  proname => 'smgreq', prorettype => 'bool', proargtypes => 'smgr smgr',
-  prosrc => 'smgreq' },
+  proname => 'smgreq', prorettype => 'bool', proargtypes => 'smgr smgr' },
 { oid => '763', descr => 'storage manager',
-  proname => 'smgrne', prorettype => 'bool', proargtypes => 'smgr smgr',
-  prosrc => 'smgrne' },
+  proname => 'smgrne', prorettype => 'bool', proargtypes => 'smgr smgr' },
 
 { oid => '764', descr => 'large object import',
   proname => 'lo_import', provolatile => 'v', proparallel => 'u',
@@ -1671,87 +1485,78 @@
   prorettype => 'int4', proargtypes => 'oid text', prosrc => 'be_lo_export' },
 
 { oid => '766', descr => 'increment',
-  proname => 'int4inc', prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'int4inc' },
+  proname => 'int4inc', prorettype => 'int4', proargtypes => 'int4' },
 { oid => '768', descr => 'larger of two',
-  proname => 'int4larger', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4larger' },
+  proname => 'int4larger', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '769', descr => 'smaller of two',
-  proname => 'int4smaller', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4smaller' },
+  proname => 'int4smaller', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '770', descr => 'larger of two',
-  proname => 'int2larger', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2larger' },
+  proname => 'int2larger', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '771', descr => 'smaller of two',
-  proname => 'int2smaller', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2smaller' },
+  proname => 'int2smaller', prorettype => 'int2', proargtypes => 'int2 int2' },
 
 { oid => '784',
   proname => 'tintervaleq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervaleq' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '785',
   proname => 'tintervalne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervalne' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '786',
   proname => 'tintervallt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervallt' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '787',
   proname => 'tintervalgt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervalgt' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '788',
   proname => 'tintervalle', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervalle' },
+  proargtypes => 'tinterval tinterval' },
 { oid => '789',
   proname => 'tintervalge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tinterval tinterval', prosrc => 'tintervalge' },
+  proargtypes => 'tinterval tinterval' },
 
 # OIDS 800 - 899
 
 { oid => '846',
   proname => 'cash_mul_flt4', prorettype => 'money',
-  proargtypes => 'money float4', prosrc => 'cash_mul_flt4' },
+  proargtypes => 'money float4' },
 { oid => '847',
   proname => 'cash_div_flt4', prorettype => 'money',
-  proargtypes => 'money float4', prosrc => 'cash_div_flt4' },
+  proargtypes => 'money float4' },
 { oid => '848',
   proname => 'flt4_mul_cash', prorettype => 'money',
-  proargtypes => 'float4 money', prosrc => 'flt4_mul_cash' },
+  proargtypes => 'float4 money' },
 
 { oid => '849', descr => 'position of substring',
   proname => 'position', prorettype => 'int4', proargtypes => 'text text',
   prosrc => 'textpos' },
 { oid => '850',
-  proname => 'textlike', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'textlike' },
+  proname => 'textlike', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '851',
-  proname => 'textnlike', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'textnlike' },
+  proname => 'textnlike', prorettype => 'bool', proargtypes => 'text text' },
 
 { oid => '852',
   proname => 'int48eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int8', prosrc => 'int48eq' },
+  proargtypes => 'int4 int8' },
 { oid => '853',
   proname => 'int48ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int8', prosrc => 'int48ne' },
+  proargtypes => 'int4 int8' },
 { oid => '854',
   proname => 'int48lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int8', prosrc => 'int48lt' },
+  proargtypes => 'int4 int8' },
 { oid => '855',
   proname => 'int48gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int8', prosrc => 'int48gt' },
+  proargtypes => 'int4 int8' },
 { oid => '856',
   proname => 'int48le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int8', prosrc => 'int48le' },
+  proargtypes => 'int4 int8' },
 { oid => '857',
   proname => 'int48ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int4 int8', prosrc => 'int48ge' },
+  proargtypes => 'int4 int8' },
 
 { oid => '858',
-  proname => 'namelike', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'namelike' },
+  proname => 'namelike', prorettype => 'bool', proargtypes => 'name text' },
 { oid => '859',
-  proname => 'namenlike', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'namenlike' },
+  proname => 'namenlike', prorettype => 'bool', proargtypes => 'name text' },
 
 { oid => '860', descr => 'convert char to char(n)',
   proname => 'bpchar', prorettype => 'bpchar', proargtypes => 'char',
@@ -1759,91 +1564,85 @@
 
 { oid => '861', descr => 'name of the current database',
   proname => 'current_database', provolatile => 's', prorettype => 'name',
-  proargtypes => '', prosrc => 'current_database' },
+  proargtypes => '' },
 { oid => '817', descr => 'get the currently executing query',
   proname => 'current_query', proisstrict => 'f', provolatile => 'v',
-  proparallel => 'r', prorettype => 'text', proargtypes => '',
-  prosrc => 'current_query' },
+  proparallel => 'r', prorettype => 'text', proargtypes => '' },
 
 { oid => '3399',
   proname => 'int8_mul_cash', prorettype => 'money',
-  proargtypes => 'int8 money', prosrc => 'int8_mul_cash' },
+  proargtypes => 'int8 money' },
 { oid => '862',
   proname => 'int4_mul_cash', prorettype => 'money',
-  proargtypes => 'int4 money', prosrc => 'int4_mul_cash' },
+  proargtypes => 'int4 money' },
 { oid => '863',
   proname => 'int2_mul_cash', prorettype => 'money',
-  proargtypes => 'int2 money', prosrc => 'int2_mul_cash' },
+  proargtypes => 'int2 money' },
 { oid => '3344',
   proname => 'cash_mul_int8', prorettype => 'money',
-  proargtypes => 'money int8', prosrc => 'cash_mul_int8' },
+  proargtypes => 'money int8' },
 { oid => '3345',
   proname => 'cash_div_int8', prorettype => 'money',
-  proargtypes => 'money int8', prosrc => 'cash_div_int8' },
+  proargtypes => 'money int8' },
 { oid => '864',
   proname => 'cash_mul_int4', prorettype => 'money',
-  proargtypes => 'money int4', prosrc => 'cash_mul_int4' },
+  proargtypes => 'money int4' },
 { oid => '865',
   proname => 'cash_div_int4', prorettype => 'money',
-  proargtypes => 'money int4', prosrc => 'cash_div_int4' },
+  proargtypes => 'money int4' },
 { oid => '866',
   proname => 'cash_mul_int2', prorettype => 'money',
-  proargtypes => 'money int2', prosrc => 'cash_mul_int2' },
+  proargtypes => 'money int2' },
 { oid => '867',
   proname => 'cash_div_int2', prorettype => 'money',
-  proargtypes => 'money int2', prosrc => 'cash_div_int2' },
+  proargtypes => 'money int2' },
 
 { oid => '886', descr => 'I/O',
   proname => 'cash_in', provolatile => 's', prorettype => 'money',
-  proargtypes => 'cstring', prosrc => 'cash_in' },
+  proargtypes => 'cstring' },
 { oid => '887', descr => 'I/O',
   proname => 'cash_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'money', prosrc => 'cash_out' },
+  proargtypes => 'money' },
 { oid => '888',
   proname => 'cash_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'money money', prosrc => 'cash_eq' },
+  proargtypes => 'money money' },
 { oid => '889',
   proname => 'cash_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'money money', prosrc => 'cash_ne' },
+  proargtypes => 'money money' },
 { oid => '890',
   proname => 'cash_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'money money', prosrc => 'cash_lt' },
+  proargtypes => 'money money' },
 { oid => '891',
   proname => 'cash_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'money money', prosrc => 'cash_le' },
+  proargtypes => 'money money' },
 { oid => '892',
   proname => 'cash_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'money money', prosrc => 'cash_gt' },
+  proargtypes => 'money money' },
 { oid => '893',
   proname => 'cash_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'money money', prosrc => 'cash_ge' },
+  proargtypes => 'money money' },
 { oid => '894',
-  proname => 'cash_pl', prorettype => 'money', proargtypes => 'money money',
-  prosrc => 'cash_pl' },
+  proname => 'cash_pl', prorettype => 'money', proargtypes => 'money money' },
 { oid => '895',
-  proname => 'cash_mi', prorettype => 'money', proargtypes => 'money money',
-  prosrc => 'cash_mi' },
+  proname => 'cash_mi', prorettype => 'money', proargtypes => 'money money' },
 { oid => '896',
   proname => 'cash_mul_flt8', prorettype => 'money',
-  proargtypes => 'money float8', prosrc => 'cash_mul_flt8' },
+  proargtypes => 'money float8' },
 { oid => '897',
   proname => 'cash_div_flt8', prorettype => 'money',
-  proargtypes => 'money float8', prosrc => 'cash_div_flt8' },
+  proargtypes => 'money float8' },
 { oid => '898', descr => 'larger of two',
-  proname => 'cashlarger', prorettype => 'money', proargtypes => 'money money',
-  prosrc => 'cashlarger' },
+  proname => 'cashlarger', prorettype => 'money', proargtypes => 'money money' },
 { oid => '899', descr => 'smaller of two',
-  proname => 'cashsmaller', prorettype => 'money', proargtypes => 'money money',
-  prosrc => 'cashsmaller' },
+  proname => 'cashsmaller', prorettype => 'money', proargtypes => 'money money' },
 { oid => '919',
   proname => 'flt8_mul_cash', prorettype => 'money',
-  proargtypes => 'float8 money', prosrc => 'flt8_mul_cash' },
+  proargtypes => 'float8 money' },
 { oid => '935', descr => 'output money amount as words',
-  proname => 'cash_words', prorettype => 'text', proargtypes => 'money',
-  prosrc => 'cash_words' },
+  proname => 'cash_words', prorettype => 'text', proargtypes => 'money' },
 { oid => '3822',
   proname => 'cash_div_cash', prorettype => 'float8',
-  proargtypes => 'money money', prosrc => 'cash_div_cash' },
+  proargtypes => 'money money' },
 { oid => '3823', descr => 'convert money to numeric',
   proname => 'numeric', provolatile => 's', prorettype => 'numeric',
   proargtypes => 'money', prosrc => 'cash_numeric' },
@@ -1867,8 +1666,7 @@
   prosrc => 'int4mod' },
 
 { oid => '945',
-  proname => 'int8mod', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8mod' },
+  proname => 'int8mod', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '947', descr => 'modulus',
   proname => 'mod', prorettype => 'int8', proargtypes => 'int8 int8',
   prosrc => 'int8mod' },
@@ -1938,28 +1736,22 @@
   prosrc => 'be_lo_put' },
 
 { oid => '959',
-  proname => 'on_pl', prorettype => 'bool', proargtypes => 'point line',
-  prosrc => 'on_pl' },
+  proname => 'on_pl', prorettype => 'bool', proargtypes => 'point line' },
 { oid => '960',
-  proname => 'on_sl', prorettype => 'bool', proargtypes => 'lseg line',
-  prosrc => 'on_sl' },
+  proname => 'on_sl', prorettype => 'bool', proargtypes => 'lseg line' },
 { oid => '961',
-  proname => 'close_pl', prorettype => 'point', proargtypes => 'point line',
-  prosrc => 'close_pl' },
+  proname => 'close_pl', prorettype => 'point', proargtypes => 'point line' },
 { oid => '962',
-  proname => 'close_sl', prorettype => 'point', proargtypes => 'lseg line',
-  prosrc => 'close_sl' },
+  proname => 'close_sl', prorettype => 'point', proargtypes => 'lseg line' },
 { oid => '963',
-  proname => 'close_lb', prorettype => 'point', proargtypes => 'line box',
-  prosrc => 'close_lb' },
+  proname => 'close_lb', prorettype => 'point', proargtypes => 'line box' },
 
 { oid => '964', descr => 'large object unlink (delete)',
   proname => 'lo_unlink', provolatile => 'v', proparallel => 'u',
   prorettype => 'int4', proargtypes => 'oid', prosrc => 'be_lo_unlink' },
 
 { oid => '973',
-  proname => 'path_inter', prorettype => 'bool', proargtypes => 'path path',
-  prosrc => 'path_inter' },
+  proname => 'path_inter', prorettype => 'bool', proargtypes => 'path path' },
 { oid => '975', descr => 'box area',
   proname => 'area', prorettype => 'float8', proargtypes => 'box',
   prosrc => 'box_area' },
@@ -1970,14 +1762,12 @@
   proname => 'height', prorettype => 'float8', proargtypes => 'box',
   prosrc => 'box_height' },
 { oid => '978',
-  proname => 'box_distance', prorettype => 'float8', proargtypes => 'box box',
-  prosrc => 'box_distance' },
+  proname => 'box_distance', prorettype => 'float8', proargtypes => 'box box' },
 { oid => '979', descr => 'area of a closed path',
   proname => 'area', prorettype => 'float8', proargtypes => 'path',
   prosrc => 'path_area' },
 { oid => '980',
-  proname => 'box_intersect', prorettype => 'box', proargtypes => 'box box',
-  prosrc => 'box_intersect' },
+  proname => 'box_intersect', prorettype => 'box', proargtypes => 'box box' },
 { oid => '4067', descr => 'bounding box of two boxes',
   proname => 'bound_box', prorettype => 'box', proargtypes => 'box box',
   prosrc => 'boxes_bound_box' },
@@ -1985,35 +1775,26 @@
   proname => 'diagonal', prorettype => 'lseg', proargtypes => 'box',
   prosrc => 'box_diagonal' },
 { oid => '982',
-  proname => 'path_n_lt', prorettype => 'bool', proargtypes => 'path path',
-  prosrc => 'path_n_lt' },
+  proname => 'path_n_lt', prorettype => 'bool', proargtypes => 'path path' },
 { oid => '983',
-  proname => 'path_n_gt', prorettype => 'bool', proargtypes => 'path path',
-  prosrc => 'path_n_gt' },
+  proname => 'path_n_gt', prorettype => 'bool', proargtypes => 'path path' },
 { oid => '984',
-  proname => 'path_n_eq', prorettype => 'bool', proargtypes => 'path path',
-  prosrc => 'path_n_eq' },
+  proname => 'path_n_eq', prorettype => 'bool', proargtypes => 'path path' },
 { oid => '985',
-  proname => 'path_n_le', prorettype => 'bool', proargtypes => 'path path',
-  prosrc => 'path_n_le' },
+  proname => 'path_n_le', prorettype => 'bool', proargtypes => 'path path' },
 { oid => '986',
-  proname => 'path_n_ge', prorettype => 'bool', proargtypes => 'path path',
-  prosrc => 'path_n_ge' },
+  proname => 'path_n_ge', prorettype => 'bool', proargtypes => 'path path' },
 { oid => '987',
-  proname => 'path_length', prorettype => 'float8', proargtypes => 'path',
-  prosrc => 'path_length' },
+  proname => 'path_length', prorettype => 'float8', proargtypes => 'path' },
 { oid => '988',
-  proname => 'point_ne', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_ne' },
+  proname => 'point_ne', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '989',
-  proname => 'point_vert', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_vert' },
+  proname => 'point_vert', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '990',
-  proname => 'point_horiz', prorettype => 'bool', proargtypes => 'point point',
-  prosrc => 'point_horiz' },
+  proname => 'point_horiz', prorettype => 'bool', proargtypes => 'point point' },
 { oid => '991',
   proname => 'point_distance', prorettype => 'float8',
-  proargtypes => 'point point', prosrc => 'point_distance' },
+  proargtypes => 'point point' },
 { oid => '992', descr => 'slope between points',
   proname => 'slope', prorettype => 'float8', proargtypes => 'point point',
   prosrc => 'point_slope' },
@@ -2021,29 +1802,24 @@
   proname => 'lseg', prorettype => 'lseg', proargtypes => 'point point',
   prosrc => 'lseg_construct' },
 { oid => '994',
-  proname => 'lseg_intersect', prorettype => 'bool', proargtypes => 'lseg lseg',
-  prosrc => 'lseg_intersect' },
+  proname => 'lseg_intersect', prorettype => 'bool', proargtypes => 'lseg lseg' },
 { oid => '995',
-  proname => 'lseg_parallel', prorettype => 'bool', proargtypes => 'lseg lseg',
-  prosrc => 'lseg_parallel' },
+  proname => 'lseg_parallel', prorettype => 'bool', proargtypes => 'lseg lseg' },
 { oid => '996',
-  proname => 'lseg_perp', prorettype => 'bool', proargtypes => 'lseg lseg',
-  prosrc => 'lseg_perp' },
+  proname => 'lseg_perp', prorettype => 'bool', proargtypes => 'lseg lseg' },
 { oid => '997',
-  proname => 'lseg_vertical', prorettype => 'bool', proargtypes => 'lseg',
-  prosrc => 'lseg_vertical' },
+  proname => 'lseg_vertical', prorettype => 'bool', proargtypes => 'lseg' },
 { oid => '998',
-  proname => 'lseg_horizontal', prorettype => 'bool', proargtypes => 'lseg',
-  prosrc => 'lseg_horizontal' },
+  proname => 'lseg_horizontal', prorettype => 'bool', proargtypes => 'lseg' },
 { oid => '999',
   proname => 'lseg_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'lseg lseg', prosrc => 'lseg_eq' },
+  proargtypes => 'lseg lseg' },
 
 # OIDS 1000 - 1999
 
 { oid => '3994', descr => 'transform a time zone adjustment',
   proname => 'timestamp_izone_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'timestamp_izone_transform' },
+  proargtypes => 'internal' },
 { oid => '1026', descr => 'adjust timestamp to new time zone',
   proname => 'timezone', protransform => 'timestamp_izone_transform',
   prorettype => 'timestamp', proargtypes => 'interval timestamptz',
@@ -2051,25 +1827,25 @@
 
 { oid => '1031', descr => 'I/O',
   proname => 'aclitemin', provolatile => 's', prorettype => 'aclitem',
-  proargtypes => 'cstring', prosrc => 'aclitemin' },
+  proargtypes => 'cstring' },
 { oid => '1032', descr => 'I/O',
   proname => 'aclitemout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'aclitem', prosrc => 'aclitemout' },
+  proargtypes => 'aclitem' },
 { oid => '1035', descr => 'add/update ACL item',
   proname => 'aclinsert', prorettype => '_aclitem',
-  proargtypes => '_aclitem aclitem', prosrc => 'aclinsert' },
+  proargtypes => '_aclitem aclitem' },
 { oid => '1036', descr => 'remove ACL item',
   proname => 'aclremove', prorettype => '_aclitem',
-  proargtypes => '_aclitem aclitem', prosrc => 'aclremove' },
+  proargtypes => '_aclitem aclitem' },
 { oid => '1037', descr => 'contains',
   proname => 'aclcontains', prorettype => 'bool',
-  proargtypes => '_aclitem aclitem', prosrc => 'aclcontains' },
+  proargtypes => '_aclitem aclitem' },
 { oid => '1062',
   proname => 'aclitemeq', prorettype => 'bool',
   proargtypes => 'aclitem aclitem', prosrc => 'aclitem_eq' },
 { oid => '1365', descr => 'make ACL item',
   proname => 'makeaclitem', prorettype => 'aclitem',
-  proargtypes => 'oid oid text bool', prosrc => 'makeaclitem' },
+  proargtypes => 'oid oid text bool' },
 { oid => '3943', descr => 'TODO',
   proname => 'acldefault', prorettype => '_aclitem', proargtypes => 'char oid',
   prosrc => 'acldefault_sql' },
@@ -2079,101 +1855,87 @@
   provolatile => 's', prorettype => 'record', proargtypes => '_aclitem',
   proallargtypes => '{_aclitem,oid,oid,text,bool}',
   proargmodes => '{i,o,o,o,o}',
-  proargnames => '{acl,grantor,grantee,privilege_type,is_grantable}',
-  prosrc => 'aclexplode' },
+  proargnames => '{acl,grantor,grantee,privilege_type,is_grantable}' },
 { oid => '1044', descr => 'I/O',
   proname => 'bpcharin', prorettype => 'bpchar',
-  proargtypes => 'cstring oid int4', prosrc => 'bpcharin' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1045', descr => 'I/O',
-  proname => 'bpcharout', prorettype => 'cstring', proargtypes => 'bpchar',
-  prosrc => 'bpcharout' },
+  proname => 'bpcharout', prorettype => 'cstring', proargtypes => 'bpchar' },
 { oid => '2913', descr => 'I/O typmod',
-  proname => 'bpchartypmodin', prorettype => 'int4', proargtypes => '_cstring',
-  prosrc => 'bpchartypmodin' },
+  proname => 'bpchartypmodin', prorettype => 'int4', proargtypes => '_cstring' },
 { oid => '2914', descr => 'I/O typmod',
-  proname => 'bpchartypmodout', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'bpchartypmodout' },
+  proname => 'bpchartypmodout', prorettype => 'cstring', proargtypes => 'int4' },
 { oid => '1046', descr => 'I/O',
   proname => 'varcharin', prorettype => 'varchar',
-  proargtypes => 'cstring oid int4', prosrc => 'varcharin' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1047', descr => 'I/O',
-  proname => 'varcharout', prorettype => 'cstring', proargtypes => 'varchar',
-  prosrc => 'varcharout' },
+  proname => 'varcharout', prorettype => 'cstring', proargtypes => 'varchar' },
 { oid => '2915', descr => 'I/O typmod',
-  proname => 'varchartypmodin', prorettype => 'int4', proargtypes => '_cstring',
-  prosrc => 'varchartypmodin' },
+  proname => 'varchartypmodin', prorettype => 'int4', proargtypes => '_cstring' },
 { oid => '2916', descr => 'I/O typmod',
-  proname => 'varchartypmodout', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'varchartypmodout' },
+  proname => 'varchartypmodout', prorettype => 'cstring', proargtypes => 'int4' },
 { oid => '1048',
   proname => 'bpchareq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpchareq' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '1049',
-  proname => 'bpcharlt', prorettype => 'bool', proargtypes => 'bpchar bpchar',
-  prosrc => 'bpcharlt' },
+  proname => 'bpcharlt', prorettype => 'bool', proargtypes => 'bpchar bpchar' },
 { oid => '1050',
-  proname => 'bpcharle', prorettype => 'bool', proargtypes => 'bpchar bpchar',
-  prosrc => 'bpcharle' },
+  proname => 'bpcharle', prorettype => 'bool', proargtypes => 'bpchar bpchar' },
 { oid => '1051',
-  proname => 'bpchargt', prorettype => 'bool', proargtypes => 'bpchar bpchar',
-  prosrc => 'bpchargt' },
+  proname => 'bpchargt', prorettype => 'bool', proargtypes => 'bpchar bpchar' },
 { oid => '1052',
-  proname => 'bpcharge', prorettype => 'bool', proargtypes => 'bpchar bpchar',
-  prosrc => 'bpcharge' },
+  proname => 'bpcharge', prorettype => 'bool', proargtypes => 'bpchar bpchar' },
 { oid => '1053',
   proname => 'bpcharne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpcharne' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '1063', descr => 'larger of two',
   proname => 'bpchar_larger', prorettype => 'bpchar',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpchar_larger' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '1064', descr => 'smaller of two',
   proname => 'bpchar_smaller', prorettype => 'bpchar',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpchar_smaller' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '1078', descr => 'less-equal-greater',
-  proname => 'bpcharcmp', prorettype => 'int4', proargtypes => 'bpchar bpchar',
-  prosrc => 'bpcharcmp' },
+  proname => 'bpcharcmp', prorettype => 'int4', proargtypes => 'bpchar bpchar' },
 { oid => '3328', descr => 'sort support',
   proname => 'bpchar_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'bpchar_sortsupport' },
+  proargtypes => 'internal' },
 { oid => '1080', descr => 'hash',
-  proname => 'hashbpchar', prorettype => 'int4', proargtypes => 'bpchar',
-  prosrc => 'hashbpchar' },
+  proname => 'hashbpchar', prorettype => 'int4', proargtypes => 'bpchar' },
 { oid => '972', descr => 'hash',
   proname => 'hashbpcharextended', prorettype => 'int8',
-  proargtypes => 'bpchar int8', prosrc => 'hashbpcharextended' },
+  proargtypes => 'bpchar int8' },
 { oid => '1081', descr => 'format a type oid and atttypmod to canonical SQL',
   proname => 'format_type', proisstrict => 'f', provolatile => 's',
-  prorettype => 'text', proargtypes => 'oid int4', prosrc => 'format_type' },
+  prorettype => 'text', proargtypes => 'oid int4' },
 { oid => '1084', descr => 'I/O',
   proname => 'date_in', provolatile => 's', prorettype => 'date',
-  proargtypes => 'cstring', prosrc => 'date_in' },
+  proargtypes => 'cstring' },
 { oid => '1085', descr => 'I/O',
   proname => 'date_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'date', prosrc => 'date_out' },
+  proargtypes => 'date' },
 { oid => '1086',
   proname => 'date_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'date date', prosrc => 'date_eq' },
+  proargtypes => 'date date' },
 { oid => '1087',
   proname => 'date_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'date date', prosrc => 'date_lt' },
+  proargtypes => 'date date' },
 { oid => '1088',
   proname => 'date_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'date date', prosrc => 'date_le' },
+  proargtypes => 'date date' },
 { oid => '1089',
   proname => 'date_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'date date', prosrc => 'date_gt' },
+  proargtypes => 'date date' },
 { oid => '1090',
   proname => 'date_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'date date', prosrc => 'date_ge' },
+  proargtypes => 'date date' },
 { oid => '1091',
   proname => 'date_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'date date', prosrc => 'date_ne' },
+  proargtypes => 'date date' },
 { oid => '1092', descr => 'less-equal-greater',
-  proname => 'date_cmp', prorettype => 'int4', proargtypes => 'date date',
-  prosrc => 'date_cmp' },
+  proname => 'date_cmp', prorettype => 'int4', proargtypes => 'date date' },
 { oid => '3136', descr => 'sort support',
   proname => 'date_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'date_sortsupport' },
+  proargtypes => 'internal' },
 { oid => '4133', descr => 'window RANGE support',
   proname => 'in_range', prorettype => 'bool',
   proargtypes => 'date date interval bool bool',
@@ -2183,78 +1945,69 @@
 
 { oid => '1102',
   proname => 'time_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'time time', prosrc => 'time_lt' },
+  proargtypes => 'time time' },
 { oid => '1103',
   proname => 'time_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'time time', prosrc => 'time_le' },
+  proargtypes => 'time time' },
 { oid => '1104',
   proname => 'time_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'time time', prosrc => 'time_gt' },
+  proargtypes => 'time time' },
 { oid => '1105',
   proname => 'time_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'time time', prosrc => 'time_ge' },
+  proargtypes => 'time time' },
 { oid => '1106',
   proname => 'time_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'time time', prosrc => 'time_ne' },
+  proargtypes => 'time time' },
 { oid => '1107', descr => 'less-equal-greater',
-  proname => 'time_cmp', prorettype => 'int4', proargtypes => 'time time',
-  prosrc => 'time_cmp' },
+  proname => 'time_cmp', prorettype => 'int4', proargtypes => 'time time' },
 { oid => '1138', descr => 'larger of two',
-  proname => 'date_larger', prorettype => 'date', proargtypes => 'date date',
-  prosrc => 'date_larger' },
+  proname => 'date_larger', prorettype => 'date', proargtypes => 'date date' },
 { oid => '1139', descr => 'smaller of two',
-  proname => 'date_smaller', prorettype => 'date', proargtypes => 'date date',
-  prosrc => 'date_smaller' },
+  proname => 'date_smaller', prorettype => 'date', proargtypes => 'date date' },
 { oid => '1140',
-  proname => 'date_mi', prorettype => 'int4', proargtypes => 'date date',
-  prosrc => 'date_mi' },
+  proname => 'date_mi', prorettype => 'int4', proargtypes => 'date date' },
 { oid => '1141',
-  proname => 'date_pli', prorettype => 'date', proargtypes => 'date int4',
-  prosrc => 'date_pli' },
+  proname => 'date_pli', prorettype => 'date', proargtypes => 'date int4' },
 { oid => '1142',
-  proname => 'date_mii', prorettype => 'date', proargtypes => 'date int4',
-  prosrc => 'date_mii' },
+  proname => 'date_mii', prorettype => 'date', proargtypes => 'date int4' },
 { oid => '1143', descr => 'I/O',
   proname => 'time_in', provolatile => 's', prorettype => 'time',
-  proargtypes => 'cstring oid int4', prosrc => 'time_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1144', descr => 'I/O',
-  proname => 'time_out', prorettype => 'cstring', proargtypes => 'time',
-  prosrc => 'time_out' },
+  proname => 'time_out', prorettype => 'cstring', proargtypes => 'time' },
 { oid => '2909', descr => 'I/O typmod',
-  proname => 'timetypmodin', prorettype => 'int4', proargtypes => '_cstring',
-  prosrc => 'timetypmodin' },
+  proname => 'timetypmodin', prorettype => 'int4', proargtypes => '_cstring' },
 { oid => '2910', descr => 'I/O typmod',
-  proname => 'timetypmodout', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'timetypmodout' },
+  proname => 'timetypmodout', prorettype => 'cstring', proargtypes => 'int4' },
 { oid => '1145',
   proname => 'time_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'time time', prosrc => 'time_eq' },
+  proargtypes => 'time time' },
 
 { oid => '1146',
   proname => 'circle_add_pt', prorettype => 'circle',
-  proargtypes => 'circle point', prosrc => 'circle_add_pt' },
+  proargtypes => 'circle point' },
 { oid => '1147',
   proname => 'circle_sub_pt', prorettype => 'circle',
-  proargtypes => 'circle point', prosrc => 'circle_sub_pt' },
+  proargtypes => 'circle point' },
 { oid => '1148',
   proname => 'circle_mul_pt', prorettype => 'circle',
-  proargtypes => 'circle point', prosrc => 'circle_mul_pt' },
+  proargtypes => 'circle point' },
 { oid => '1149',
   proname => 'circle_div_pt', prorettype => 'circle',
-  proargtypes => 'circle point', prosrc => 'circle_div_pt' },
+  proargtypes => 'circle point' },
 
 { oid => '1150', descr => 'I/O',
   proname => 'timestamptz_in', provolatile => 's', prorettype => 'timestamptz',
-  proargtypes => 'cstring oid int4', prosrc => 'timestamptz_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1151', descr => 'I/O',
   proname => 'timestamptz_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'timestamptz', prosrc => 'timestamptz_out' },
+  proargtypes => 'timestamptz' },
 { oid => '2907', descr => 'I/O typmod',
   proname => 'timestamptztypmodin', prorettype => 'int4',
-  proargtypes => '_cstring', prosrc => 'timestamptztypmodin' },
+  proargtypes => '_cstring' },
 { oid => '2908', descr => 'I/O typmod',
   proname => 'timestamptztypmodout', prorettype => 'cstring',
-  proargtypes => 'int4', prosrc => 'timestamptztypmodout' },
+  proargtypes => 'int4' },
 { oid => '1152',
   proname => 'timestamptz_eq', proleakproof => 't', prorettype => 'bool',
   proargtypes => 'timestamptz timestamptz', prosrc => 'timestamp_eq' },
@@ -2278,7 +2031,7 @@
   proargtypes => 'float8', prosrc => 'float8_timestamptz' },
 { oid => '3995', descr => 'transform a time zone adjustment',
   proname => 'timestamp_zone_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'timestamp_zone_transform' },
+  proargtypes => 'internal' },
 { oid => '1159', descr => 'adjust timestamp to new time zone',
   proname => 'timezone', protransform => 'timestamp_zone_transform',
   prorettype => 'timestamp', proargtypes => 'text timestamptz',
@@ -2286,43 +2039,41 @@
 
 { oid => '1160', descr => 'I/O',
   proname => 'interval_in', provolatile => 's', prorettype => 'interval',
-  proargtypes => 'cstring oid int4', prosrc => 'interval_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1161', descr => 'I/O',
-  proname => 'interval_out', prorettype => 'cstring', proargtypes => 'interval',
-  prosrc => 'interval_out' },
+  proname => 'interval_out', prorettype => 'cstring', proargtypes => 'interval' },
 { oid => '2903', descr => 'I/O typmod',
   proname => 'intervaltypmodin', prorettype => 'int4',
-  proargtypes => '_cstring', prosrc => 'intervaltypmodin' },
+  proargtypes => '_cstring' },
 { oid => '2904', descr => 'I/O typmod',
   proname => 'intervaltypmodout', prorettype => 'cstring',
-  proargtypes => 'int4', prosrc => 'intervaltypmodout' },
+  proargtypes => 'int4' },
 { oid => '1162',
   proname => 'interval_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'interval interval', prosrc => 'interval_eq' },
+  proargtypes => 'interval interval' },
 { oid => '1163',
   proname => 'interval_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'interval interval', prosrc => 'interval_ne' },
+  proargtypes => 'interval interval' },
 { oid => '1164',
   proname => 'interval_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'interval interval', prosrc => 'interval_lt' },
+  proargtypes => 'interval interval' },
 { oid => '1165',
   proname => 'interval_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'interval interval', prosrc => 'interval_le' },
+  proargtypes => 'interval interval' },
 { oid => '1166',
   proname => 'interval_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'interval interval', prosrc => 'interval_ge' },
+  proargtypes => 'interval interval' },
 { oid => '1167',
   proname => 'interval_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'interval interval', prosrc => 'interval_gt' },
+  proargtypes => 'interval interval' },
 { oid => '1168',
-  proname => 'interval_um', prorettype => 'interval', proargtypes => 'interval',
-  prosrc => 'interval_um' },
+  proname => 'interval_um', prorettype => 'interval', proargtypes => 'interval' },
 { oid => '1169',
   proname => 'interval_pl', prorettype => 'interval',
-  proargtypes => 'interval interval', prosrc => 'interval_pl' },
+  proargtypes => 'interval interval' },
 { oid => '1170',
   proname => 'interval_mi', prorettype => 'interval',
-  proargtypes => 'interval interval', prosrc => 'interval_mi' },
+  proargtypes => 'interval interval' },
 { oid => '1171', descr => 'extract field from timestamp with time zone',
   proname => 'date_part', provolatile => 's', prorettype => 'float8',
   proargtypes => 'text timestamptz', prosrc => 'timestamptz_part' },
@@ -2368,19 +2119,17 @@
 { oid => '3939',
   descr => 'age of a multi-transaction ID, in multi-transactions before current multi-transaction',
   proname => 'mxid_age', provolatile => 's', prorettype => 'int4',
-  proargtypes => 'xid', prosrc => 'mxid_age' },
+  proargtypes => 'xid' },
 
 { oid => '1188',
   proname => 'timestamptz_mi', prorettype => 'interval',
   proargtypes => 'timestamptz timestamptz', prosrc => 'timestamp_mi' },
 { oid => '1189',
   proname => 'timestamptz_pl_interval', provolatile => 's',
-  prorettype => 'timestamptz', proargtypes => 'timestamptz interval',
-  prosrc => 'timestamptz_pl_interval' },
+  prorettype => 'timestamptz', proargtypes => 'timestamptz interval' },
 { oid => '1190',
   proname => 'timestamptz_mi_interval', provolatile => 's',
-  prorettype => 'timestamptz', proargtypes => 'timestamptz interval',
-  prosrc => 'timestamptz_mi_interval' },
+  prorettype => 'timestamptz', proargtypes => 'timestamptz interval' },
 { oid => '1194', descr => 'convert interval to reltime',
   proname => 'reltime', prorettype => 'reltime', proargtypes => 'interval',
   prosrc => 'interval_reltime' },
@@ -2392,10 +2141,10 @@
   proargtypes => 'timestamptz timestamptz', prosrc => 'timestamp_larger' },
 { oid => '1197', descr => 'smaller of two',
   proname => 'interval_smaller', prorettype => 'interval',
-  proargtypes => 'interval interval', prosrc => 'interval_smaller' },
+  proargtypes => 'interval interval' },
 { oid => '1198', descr => 'larger of two',
   proname => 'interval_larger', prorettype => 'interval',
-  proargtypes => 'interval interval', prosrc => 'interval_larger' },
+  proargtypes => 'interval interval' },
 { oid => '1199', descr => 'date difference preserving months and years',
   proname => 'age', prorettype => 'interval',
   proargtypes => 'timestamptz timestamptz', prosrc => 'timestamptz_age' },
@@ -2404,7 +2153,7 @@
 
 { oid => '3918', descr => 'transform an interval length coercion',
   proname => 'interval_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'interval_transform' },
+  proargtypes => 'internal' },
 { oid => '1200', descr => 'adjust interval precision',
   proname => 'interval', protransform => 'interval_transform',
   prorettype => 'interval', proargtypes => 'interval int4',
@@ -2433,47 +2182,34 @@
   proargtypes => 'text interval', prosrc => 'interval_trunc' },
 
 { oid => '1219', descr => 'increment',
-  proname => 'int8inc', prorettype => 'int8', proargtypes => 'int8',
-  prosrc => 'int8inc' },
+  proname => 'int8inc', prorettype => 'int8', proargtypes => 'int8' },
 { oid => '3546', descr => 'decrement',
-  proname => 'int8dec', prorettype => 'int8', proargtypes => 'int8',
-  prosrc => 'int8dec' },
+  proname => 'int8dec', prorettype => 'int8', proargtypes => 'int8' },
 { oid => '2804', descr => 'increment, ignores second argument',
-  proname => 'int8inc_any', prorettype => 'int8', proargtypes => 'int8 any',
-  prosrc => 'int8inc_any' },
+  proname => 'int8inc_any', prorettype => 'int8', proargtypes => 'int8 any' },
 { oid => '3547', descr => 'decrement, ignores second argument',
-  proname => 'int8dec_any', prorettype => 'int8', proargtypes => 'int8 any',
-  prosrc => 'int8dec_any' },
+  proname => 'int8dec_any', prorettype => 'int8', proargtypes => 'int8 any' },
 { oid => '1230',
-  proname => 'int8abs', prorettype => 'int8', proargtypes => 'int8',
-  prosrc => 'int8abs' },
+  proname => 'int8abs', prorettype => 'int8', proargtypes => 'int8' },
 
 { oid => '1236', descr => 'larger of two',
-  proname => 'int8larger', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8larger' },
+  proname => 'int8larger', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '1237', descr => 'smaller of two',
-  proname => 'int8smaller', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8smaller' },
+  proname => 'int8smaller', prorettype => 'int8', proargtypes => 'int8 int8' },
 
 { oid => '1238',
-  proname => 'texticregexeq', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'texticregexeq' },
+  proname => 'texticregexeq', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '1239',
-  proname => 'texticregexne', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'texticregexne' },
+  proname => 'texticregexne', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '1240',
-  proname => 'nameicregexeq', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'nameicregexeq' },
+  proname => 'nameicregexeq', prorettype => 'bool', proargtypes => 'name text' },
 { oid => '1241',
-  proname => 'nameicregexne', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'nameicregexne' },
+  proname => 'nameicregexne', prorettype => 'bool', proargtypes => 'name text' },
 
 { oid => '1251',
-  proname => 'int4abs', prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'int4abs' },
+  proname => 'int4abs', prorettype => 'int4', proargtypes => 'int4' },
 { oid => '1253',
-  proname => 'int2abs', prorettype => 'int2', proargtypes => 'int2',
-  prosrc => 'int2abs' },
+  proname => 'int2abs', prorettype => 'int2', proargtypes => 'int2' },
 
 { oid => '1271', descr => 'intervals overlap?',
   proname => 'overlaps', proisstrict => 'f', prorettype => 'bool',
@@ -2485,54 +2221,38 @@
   proname => 'date_part', prorettype => 'float8', proargtypes => 'text timetz',
   prosrc => 'timetz_part' },
 { oid => '1274',
-  proname => 'int84pl', prorettype => 'int8', proargtypes => 'int8 int4',
-  prosrc => 'int84pl' },
+  proname => 'int84pl', prorettype => 'int8', proargtypes => 'int8 int4' },
 { oid => '1275',
-  proname => 'int84mi', prorettype => 'int8', proargtypes => 'int8 int4',
-  prosrc => 'int84mi' },
+  proname => 'int84mi', prorettype => 'int8', proargtypes => 'int8 int4' },
 { oid => '1276',
-  proname => 'int84mul', prorettype => 'int8', proargtypes => 'int8 int4',
-  prosrc => 'int84mul' },
+  proname => 'int84mul', prorettype => 'int8', proargtypes => 'int8 int4' },
 { oid => '1277',
-  proname => 'int84div', prorettype => 'int8', proargtypes => 'int8 int4',
-  prosrc => 'int84div' },
+  proname => 'int84div', prorettype => 'int8', proargtypes => 'int8 int4' },
 { oid => '1278',
-  proname => 'int48pl', prorettype => 'int8', proargtypes => 'int4 int8',
-  prosrc => 'int48pl' },
+  proname => 'int48pl', prorettype => 'int8', proargtypes => 'int4 int8' },
 { oid => '1279',
-  proname => 'int48mi', prorettype => 'int8', proargtypes => 'int4 int8',
-  prosrc => 'int48mi' },
+  proname => 'int48mi', prorettype => 'int8', proargtypes => 'int4 int8' },
 { oid => '1280',
-  proname => 'int48mul', prorettype => 'int8', proargtypes => 'int4 int8',
-  prosrc => 'int48mul' },
+  proname => 'int48mul', prorettype => 'int8', proargtypes => 'int4 int8' },
 { oid => '1281',
-  proname => 'int48div', prorettype => 'int8', proargtypes => 'int4 int8',
-  prosrc => 'int48div' },
+  proname => 'int48div', prorettype => 'int8', proargtypes => 'int4 int8' },
 
 { oid => '837',
-  proname => 'int82pl', prorettype => 'int8', proargtypes => 'int8 int2',
-  prosrc => 'int82pl' },
+  proname => 'int82pl', prorettype => 'int8', proargtypes => 'int8 int2' },
 { oid => '838',
-  proname => 'int82mi', prorettype => 'int8', proargtypes => 'int8 int2',
-  prosrc => 'int82mi' },
+  proname => 'int82mi', prorettype => 'int8', proargtypes => 'int8 int2' },
 { oid => '839',
-  proname => 'int82mul', prorettype => 'int8', proargtypes => 'int8 int2',
-  prosrc => 'int82mul' },
+  proname => 'int82mul', prorettype => 'int8', proargtypes => 'int8 int2' },
 { oid => '840',
-  proname => 'int82div', prorettype => 'int8', proargtypes => 'int8 int2',
-  prosrc => 'int82div' },
+  proname => 'int82div', prorettype => 'int8', proargtypes => 'int8 int2' },
 { oid => '841',
-  proname => 'int28pl', prorettype => 'int8', proargtypes => 'int2 int8',
-  prosrc => 'int28pl' },
+  proname => 'int28pl', prorettype => 'int8', proargtypes => 'int2 int8' },
 { oid => '942',
-  proname => 'int28mi', prorettype => 'int8', proargtypes => 'int2 int8',
-  prosrc => 'int28mi' },
+  proname => 'int28mi', prorettype => 'int8', proargtypes => 'int2 int8' },
 { oid => '943',
-  proname => 'int28mul', prorettype => 'int8', proargtypes => 'int2 int8',
-  prosrc => 'int28mul' },
+  proname => 'int28mul', prorettype => 'int8', proargtypes => 'int2 int8' },
 { oid => '948',
-  proname => 'int28div', prorettype => 'int8', proargtypes => 'int2 int8',
-  prosrc => 'int28div' },
+  proname => 'int28div', prorettype => 'int8', proargtypes => 'int2 int8' },
 
 { oid => '1287', descr => 'convert int8 to oid',
   proname => 'oid', prorettype => 'oid', proargtypes => 'int8',
@@ -2544,12 +2264,11 @@
 { oid => '1291',
   descr => 'trigger to suppress updates when new and old records match',
   proname => 'suppress_redundant_updates_trigger', provolatile => 'v',
-  prorettype => 'trigger', proargtypes => '',
-  prosrc => 'suppress_redundant_updates_trigger' },
+  prorettype => 'trigger', proargtypes => '' },
 
 { oid => '1292',
   proname => 'tideq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tid tid', prosrc => 'tideq' },
+  proargtypes => 'tid tid' },
 { oid => '1293', descr => 'latest tid of a tuple',
   proname => 'currtid', provolatile => 'v', proparallel => 'u',
   prorettype => 'tid', proargtypes => 'oid tid', prosrc => 'currtid_byreloid' },
@@ -2559,28 +2278,25 @@
   prosrc => 'currtid_byrelname' },
 { oid => '1265',
   proname => 'tidne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tid tid', prosrc => 'tidne' },
+  proargtypes => 'tid tid' },
 { oid => '2790',
   proname => 'tidgt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tid tid', prosrc => 'tidgt' },
+  proargtypes => 'tid tid' },
 { oid => '2791',
   proname => 'tidlt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tid tid', prosrc => 'tidlt' },
+  proargtypes => 'tid tid' },
 { oid => '2792',
   proname => 'tidge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tid tid', prosrc => 'tidge' },
+  proargtypes => 'tid tid' },
 { oid => '2793',
   proname => 'tidle', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'tid tid', prosrc => 'tidle' },
+  proargtypes => 'tid tid' },
 { oid => '2794', descr => 'less-equal-greater',
-  proname => 'bttidcmp', prorettype => 'int4', proargtypes => 'tid tid',
-  prosrc => 'bttidcmp' },
+  proname => 'bttidcmp', prorettype => 'int4', proargtypes => 'tid tid' },
 { oid => '2795', descr => 'larger of two',
-  proname => 'tidlarger', prorettype => 'tid', proargtypes => 'tid tid',
-  prosrc => 'tidlarger' },
+  proname => 'tidlarger', prorettype => 'tid', proargtypes => 'tid tid' },
 { oid => '2796', descr => 'smaller of two',
-  proname => 'tidsmaller', prorettype => 'tid', proargtypes => 'tid tid',
-  prosrc => 'tidsmaller' },
+  proname => 'tidsmaller', prorettype => 'tid', proargtypes => 'tid tid' },
 
 { oid => '1296',
   proname => 'timedate_pl', prolang => '14', prorettype => 'timestamp',
@@ -2593,38 +2309,35 @@
   proargtypes => 'timetz date', prosrc => 'select ($2 + $1)' },
 { oid => '1299', descr => 'current transaction time',
   proname => 'now', provolatile => 's', proparallel => 'r',
-  prorettype => 'timestamptz', proargtypes => '', prosrc => 'now' },
+  prorettype => 'timestamptz', proargtypes => '' },
 { oid => '2647', descr => 'current transaction time',
   proname => 'transaction_timestamp', provolatile => 's',
   prorettype => 'timestamptz', proargtypes => '', prosrc => 'now' },
 { oid => '2648', descr => 'current statement time',
   proname => 'statement_timestamp', provolatile => 's', proparallel => 'r',
-  prorettype => 'timestamptz', proargtypes => '',
-  prosrc => 'statement_timestamp' },
+  prorettype => 'timestamptz', proargtypes => '' },
 { oid => '2649', descr => 'current clock time',
   proname => 'clock_timestamp', provolatile => 'v', prorettype => 'timestamptz',
-  proargtypes => '', prosrc => 'clock_timestamp' },
+  proargtypes => '' },
 
 # OIDS 1300 - 1399
 
 { oid => '1300',
   descr => 'restriction selectivity for position-comparison operators',
   proname => 'positionsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'positionsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1301',
   descr => 'join selectivity for position-comparison operators',
   proname => 'positionjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'positionjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1302',
   descr => 'restriction selectivity for containment comparison operators',
   proname => 'contsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'contsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1303',
   descr => 'join selectivity for containment comparison operators',
   proname => 'contjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'contjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 
 { oid => '1304', descr => 'intervals overlap?',
   proname => 'overlaps', proisstrict => 'f', prorettype => 'bool',
@@ -2664,22 +2377,22 @@
 
 { oid => '1312', descr => 'I/O',
   proname => 'timestamp_in', provolatile => 's', prorettype => 'timestamp',
-  proargtypes => 'cstring oid int4', prosrc => 'timestamp_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1313', descr => 'I/O',
   proname => 'timestamp_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'timestamp', prosrc => 'timestamp_out' },
+  proargtypes => 'timestamp' },
 { oid => '2905', descr => 'I/O typmod',
   proname => 'timestamptypmodin', prorettype => 'int4',
-  proargtypes => '_cstring', prosrc => 'timestamptypmodin' },
+  proargtypes => '_cstring' },
 { oid => '2906', descr => 'I/O typmod',
   proname => 'timestamptypmodout', prorettype => 'cstring',
-  proargtypes => 'int4', prosrc => 'timestamptypmodout' },
+  proargtypes => 'int4' },
 { oid => '1314', descr => 'less-equal-greater',
   proname => 'timestamptz_cmp', prorettype => 'int4',
   proargtypes => 'timestamptz timestamptz', prosrc => 'timestamp_cmp' },
 { oid => '1315', descr => 'less-equal-greater',
   proname => 'interval_cmp', prorettype => 'int4',
-  proargtypes => 'interval interval', prosrc => 'interval_cmp' },
+  proargtypes => 'interval interval' },
 { oid => '1316', descr => 'convert timestamp to time',
   proname => 'time', prorettype => 'time', proargtypes => 'timestamp',
   prosrc => 'timestamp_time' },
@@ -2700,11 +2413,10 @@
 
 { oid => '1326',
   proname => 'interval_div', prorettype => 'interval',
-  proargtypes => 'interval float8', prosrc => 'interval_div' },
+  proargtypes => 'interval float8' },
 
 { oid => '1339', descr => 'base 10 logarithm',
-  proname => 'dlog10', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'dlog10' },
+  proname => 'dlog10', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '1340', descr => 'base 10 logarithm',
   proname => 'log', prorettype => 'float8', proargtypes => 'float8',
   prosrc => 'dlog10' },
@@ -2742,41 +2454,37 @@
 
 { oid => '1349', descr => 'print type names of oidvector field',
   proname => 'oidvectortypes', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oidvector', prosrc => 'oidvectortypes' },
+  proargtypes => 'oidvector' },
 
 { oid => '1350', descr => 'I/O',
   proname => 'timetz_in', provolatile => 's', prorettype => 'timetz',
-  proargtypes => 'cstring oid int4', prosrc => 'timetz_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1351', descr => 'I/O',
-  proname => 'timetz_out', prorettype => 'cstring', proargtypes => 'timetz',
-  prosrc => 'timetz_out' },
+  proname => 'timetz_out', prorettype => 'cstring', proargtypes => 'timetz' },
 { oid => '2911', descr => 'I/O typmod',
-  proname => 'timetztypmodin', prorettype => 'int4', proargtypes => '_cstring',
-  prosrc => 'timetztypmodin' },
+  proname => 'timetztypmodin', prorettype => 'int4', proargtypes => '_cstring' },
 { oid => '2912', descr => 'I/O typmod',
-  proname => 'timetztypmodout', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'timetztypmodout' },
+  proname => 'timetztypmodout', prorettype => 'cstring', proargtypes => 'int4' },
 { oid => '1352',
   proname => 'timetz_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_eq' },
+  proargtypes => 'timetz timetz' },
 { oid => '1353',
   proname => 'timetz_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_ne' },
+  proargtypes => 'timetz timetz' },
 { oid => '1354',
   proname => 'timetz_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_lt' },
+  proargtypes => 'timetz timetz' },
 { oid => '1355',
   proname => 'timetz_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_le' },
+  proargtypes => 'timetz timetz' },
 { oid => '1356',
   proname => 'timetz_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_ge' },
+  proargtypes => 'timetz timetz' },
 { oid => '1357',
   proname => 'timetz_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_gt' },
+  proargtypes => 'timetz timetz' },
 { oid => '1358', descr => 'less-equal-greater',
-  proname => 'timetz_cmp', prorettype => 'int4', proargtypes => 'timetz timetz',
-  prosrc => 'timetz_cmp' },
+  proname => 'timetz_cmp', prorettype => 'int4', proargtypes => 'timetz timetz' },
 { oid => '1359',
   descr => 'convert date and time with time zone to timestamp with time zone',
   proname => 'timestamptz', prorettype => 'timestamptz',
@@ -2808,17 +2516,15 @@
   prosrc => 'bpcharoctetlen' },
 
 { oid => '1377', descr => 'larger of two',
-  proname => 'time_larger', prorettype => 'time', proargtypes => 'time time',
-  prosrc => 'time_larger' },
+  proname => 'time_larger', prorettype => 'time', proargtypes => 'time time' },
 { oid => '1378', descr => 'smaller of two',
-  proname => 'time_smaller', prorettype => 'time', proargtypes => 'time time',
-  prosrc => 'time_smaller' },
+  proname => 'time_smaller', prorettype => 'time', proargtypes => 'time time' },
 { oid => '1379', descr => 'larger of two',
   proname => 'timetz_larger', prorettype => 'timetz',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_larger' },
+  proargtypes => 'timetz timetz' },
 { oid => '1380', descr => 'smaller of two',
   proname => 'timetz_smaller', prorettype => 'timetz',
-  proargtypes => 'timetz timetz', prosrc => 'timetz_smaller' },
+  proargtypes => 'timetz timetz' },
 
 { oid => '1381', descr => 'character length',
   proname => 'char_length', prorettype => 'int4', proargtypes => 'text',
@@ -2890,10 +2596,10 @@
 
 { oid => '1402', descr => 'current schema name',
   proname => 'current_schema', provolatile => 's', prorettype => 'name',
-  proargtypes => '', prosrc => 'current_schema' },
+  proargtypes => '' },
 { oid => '1403', descr => 'current schema search list',
   proname => 'current_schemas', provolatile => 's', prorettype => '_name',
-  proargtypes => 'bool', prosrc => 'current_schemas' },
+  proargtypes => 'bool' },
 
 { oid => '1404', descr => 'substitute portion of string',
   proname => 'overlay', prorettype => 'text',
@@ -2944,26 +2650,22 @@
   proname => 'box', prorettype => 'box', proargtypes => 'point point',
   prosrc => 'points_box' },
 { oid => '1422',
-  proname => 'box_add', prorettype => 'box', proargtypes => 'box point',
-  prosrc => 'box_add' },
+  proname => 'box_add', prorettype => 'box', proargtypes => 'box point' },
 { oid => '1423',
-  proname => 'box_sub', prorettype => 'box', proargtypes => 'box point',
-  prosrc => 'box_sub' },
+  proname => 'box_sub', prorettype => 'box', proargtypes => 'box point' },
 { oid => '1424',
-  proname => 'box_mul', prorettype => 'box', proargtypes => 'box point',
-  prosrc => 'box_mul' },
+  proname => 'box_mul', prorettype => 'box', proargtypes => 'box point' },
 { oid => '1425',
-  proname => 'box_div', prorettype => 'box', proargtypes => 'box point',
-  prosrc => 'box_div' },
+  proname => 'box_div', prorettype => 'box', proargtypes => 'box point' },
 { oid => '1426',
   proname => 'path_contain_pt', prolang => '14', prorettype => 'bool',
   proargtypes => 'path point', prosrc => 'select pg_catalog.on_ppath($2, $1)' },
 { oid => '1428',
   proname => 'poly_contain_pt', prorettype => 'bool',
-  proargtypes => 'polygon point', prosrc => 'poly_contain_pt' },
+  proargtypes => 'polygon point' },
 { oid => '1429',
   proname => 'pt_contained_poly', prorettype => 'bool',
-  proargtypes => 'point polygon', prosrc => 'pt_contained_poly' },
+  proargtypes => 'point polygon' },
 
 { oid => '1430', descr => 'path closed?',
   proname => 'isclosed', prorettype => 'bool', proargtypes => 'path',
@@ -2972,8 +2674,7 @@
   proname => 'isopen', prorettype => 'bool', proargtypes => 'path',
   prosrc => 'path_isopen' },
 { oid => '1432',
-  proname => 'path_npoints', prorettype => 'int4', proargtypes => 'path',
-  prosrc => 'path_npoints' },
+  proname => 'path_npoints', prorettype => 'int4', proargtypes => 'path' },
 
 # pclose and popen might better be named close and open, but that crashes initdb.
 # - thomas 97/04/20
@@ -2985,40 +2686,30 @@
   prosrc => 'path_open' },
 
 { oid => '1435',
-  proname => 'path_add', prorettype => 'path', proargtypes => 'path path',
-  prosrc => 'path_add' },
+  proname => 'path_add', prorettype => 'path', proargtypes => 'path path' },
 { oid => '1436',
-  proname => 'path_add_pt', prorettype => 'path', proargtypes => 'path point',
-  prosrc => 'path_add_pt' },
+  proname => 'path_add_pt', prorettype => 'path', proargtypes => 'path point' },
 { oid => '1437',
-  proname => 'path_sub_pt', prorettype => 'path', proargtypes => 'path point',
-  prosrc => 'path_sub_pt' },
+  proname => 'path_sub_pt', prorettype => 'path', proargtypes => 'path point' },
 { oid => '1438',
-  proname => 'path_mul_pt', prorettype => 'path', proargtypes => 'path point',
-  prosrc => 'path_mul_pt' },
+  proname => 'path_mul_pt', prorettype => 'path', proargtypes => 'path point' },
 { oid => '1439',
-  proname => 'path_div_pt', prorettype => 'path', proargtypes => 'path point',
-  prosrc => 'path_div_pt' },
+  proname => 'path_div_pt', prorettype => 'path', proargtypes => 'path point' },
 
 { oid => '1440', descr => 'convert x, y to point',
   proname => 'point', prorettype => 'point', proargtypes => 'float8 float8',
   prosrc => 'construct_point' },
 { oid => '1441',
-  proname => 'point_add', prorettype => 'point', proargtypes => 'point point',
-  prosrc => 'point_add' },
+  proname => 'point_add', prorettype => 'point', proargtypes => 'point point' },
 { oid => '1442',
-  proname => 'point_sub', prorettype => 'point', proargtypes => 'point point',
-  prosrc => 'point_sub' },
+  proname => 'point_sub', prorettype => 'point', proargtypes => 'point point' },
 { oid => '1443',
-  proname => 'point_mul', prorettype => 'point', proargtypes => 'point point',
-  prosrc => 'point_mul' },
+  proname => 'point_mul', prorettype => 'point', proargtypes => 'point point' },
 { oid => '1444',
-  proname => 'point_div', prorettype => 'point', proargtypes => 'point point',
-  prosrc => 'point_div' },
+  proname => 'point_div', prorettype => 'point', proargtypes => 'point point' },
 
 { oid => '1445',
-  proname => 'poly_npoints', prorettype => 'int4', proargtypes => 'polygon',
-  prosrc => 'poly_npoints' },
+  proname => 'poly_npoints', prorettype => 'int4', proargtypes => 'polygon' },
 { oid => '1446', descr => 'convert polygon to bounding box',
   proname => 'box', prorettype => 'box', proargtypes => 'polygon',
   prosrc => 'poly_box' },
@@ -3033,59 +2724,57 @@
   prosrc => 'path_poly' },
 
 { oid => '1450', descr => 'I/O',
-  proname => 'circle_in', prorettype => 'circle', proargtypes => 'cstring',
-  prosrc => 'circle_in' },
+  proname => 'circle_in', prorettype => 'circle', proargtypes => 'cstring' },
 { oid => '1451', descr => 'I/O',
-  proname => 'circle_out', prorettype => 'cstring', proargtypes => 'circle',
-  prosrc => 'circle_out' },
+  proname => 'circle_out', prorettype => 'cstring', proargtypes => 'circle' },
 { oid => '1452',
   proname => 'circle_same', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_same' },
+  proargtypes => 'circle circle' },
 { oid => '1453',
   proname => 'circle_contain', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_contain' },
+  proargtypes => 'circle circle' },
 { oid => '1454',
   proname => 'circle_left', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_left' },
+  proargtypes => 'circle circle' },
 { oid => '1455',
   proname => 'circle_overleft', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_overleft' },
+  proargtypes => 'circle circle' },
 { oid => '1456',
   proname => 'circle_overright', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_overright' },
+  proargtypes => 'circle circle' },
 { oid => '1457',
   proname => 'circle_right', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_right' },
+  proargtypes => 'circle circle' },
 { oid => '1458',
   proname => 'circle_contained', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_contained' },
+  proargtypes => 'circle circle' },
 { oid => '1459',
   proname => 'circle_overlap', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_overlap' },
+  proargtypes => 'circle circle' },
 { oid => '1460',
   proname => 'circle_below', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_below' },
+  proargtypes => 'circle circle' },
 { oid => '1461',
   proname => 'circle_above', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_above' },
+  proargtypes => 'circle circle' },
 { oid => '1462',
   proname => 'circle_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_eq' },
+  proargtypes => 'circle circle' },
 { oid => '1463',
   proname => 'circle_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_ne' },
+  proargtypes => 'circle circle' },
 { oid => '1464',
   proname => 'circle_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_lt' },
+  proargtypes => 'circle circle' },
 { oid => '1465',
   proname => 'circle_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_gt' },
+  proargtypes => 'circle circle' },
 { oid => '1466',
   proname => 'circle_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_le' },
+  proargtypes => 'circle circle' },
 { oid => '1467',
   proname => 'circle_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_ge' },
+  proargtypes => 'circle circle' },
 { oid => '1468', descr => 'area of circle',
   proname => 'area', prorettype => 'float8', proargtypes => 'circle',
   prosrc => 'circle_area' },
@@ -3097,10 +2786,9 @@
   prosrc => 'circle_radius' },
 { oid => '1471',
   proname => 'circle_distance', prorettype => 'float8',
-  proargtypes => 'circle circle', prosrc => 'circle_distance' },
+  proargtypes => 'circle circle' },
 { oid => '1472',
-  proname => 'circle_center', prorettype => 'point', proargtypes => 'circle',
-  prosrc => 'circle_center' },
+  proname => 'circle_center', prorettype => 'point', proargtypes => 'circle' },
 { oid => '1473', descr => 'convert point and radius to circle',
   proname => 'circle', prorettype => 'circle', proargtypes => 'point float8',
   prosrc => 'cr_circle' },
@@ -3111,14 +2799,13 @@
   proname => 'polygon', prorettype => 'polygon', proargtypes => 'int4 circle',
   prosrc => 'circle_poly' },
 { oid => '1476',
-  proname => 'dist_pc', prorettype => 'float8', proargtypes => 'point circle',
-  prosrc => 'dist_pc' },
+  proname => 'dist_pc', prorettype => 'float8', proargtypes => 'point circle' },
 { oid => '1477',
   proname => 'circle_contain_pt', prorettype => 'bool',
-  proargtypes => 'circle point', prosrc => 'circle_contain_pt' },
+  proargtypes => 'circle point' },
 { oid => '1478',
   proname => 'pt_contained_circle', prorettype => 'bool',
-  proargtypes => 'point circle', prosrc => 'pt_contained_circle' },
+  proargtypes => 'point circle' },
 { oid => '4091', descr => 'convert point to empty box',
   proname => 'box', prorettype => 'box', proargtypes => 'point',
   prosrc => 'point_box' },
@@ -3134,59 +2821,47 @@
 
 { oid => '1482',
   proname => 'lseg_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'lseg lseg', prosrc => 'lseg_ne' },
+  proargtypes => 'lseg lseg' },
 { oid => '1483',
   proname => 'lseg_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'lseg lseg', prosrc => 'lseg_lt' },
+  proargtypes => 'lseg lseg' },
 { oid => '1484',
   proname => 'lseg_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'lseg lseg', prosrc => 'lseg_le' },
+  proargtypes => 'lseg lseg' },
 { oid => '1485',
   proname => 'lseg_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'lseg lseg', prosrc => 'lseg_gt' },
+  proargtypes => 'lseg lseg' },
 { oid => '1486',
   proname => 'lseg_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'lseg lseg', prosrc => 'lseg_ge' },
+  proargtypes => 'lseg lseg' },
 { oid => '1487',
-  proname => 'lseg_length', prorettype => 'float8', proargtypes => 'lseg',
-  prosrc => 'lseg_length' },
+  proname => 'lseg_length', prorettype => 'float8', proargtypes => 'lseg' },
 { oid => '1488',
-  proname => 'close_ls', prorettype => 'point', proargtypes => 'line lseg',
-  prosrc => 'close_ls' },
+  proname => 'close_ls', prorettype => 'point', proargtypes => 'line lseg' },
 { oid => '1489',
-  proname => 'close_lseg', prorettype => 'point', proargtypes => 'lseg lseg',
-  prosrc => 'close_lseg' },
+  proname => 'close_lseg', prorettype => 'point', proargtypes => 'lseg lseg' },
 
 { oid => '1490', descr => 'I/O',
-  proname => 'line_in', prorettype => 'line', proargtypes => 'cstring',
-  prosrc => 'line_in' },
+  proname => 'line_in', prorettype => 'line', proargtypes => 'cstring' },
 { oid => '1491', descr => 'I/O',
-  proname => 'line_out', prorettype => 'cstring', proargtypes => 'line',
-  prosrc => 'line_out' },
+  proname => 'line_out', prorettype => 'cstring', proargtypes => 'line' },
 { oid => '1492',
-  proname => 'line_eq', prorettype => 'bool', proargtypes => 'line line',
-  prosrc => 'line_eq' },
+  proname => 'line_eq', prorettype => 'bool', proargtypes => 'line line' },
 { oid => '1493', descr => 'construct line from points',
   proname => 'line', prorettype => 'line', proargtypes => 'point point',
   prosrc => 'line_construct_pp' },
 { oid => '1494',
-  proname => 'line_interpt', prorettype => 'point', proargtypes => 'line line',
-  prosrc => 'line_interpt' },
+  proname => 'line_interpt', prorettype => 'point', proargtypes => 'line line' },
 { oid => '1495',
-  proname => 'line_intersect', prorettype => 'bool', proargtypes => 'line line',
-  prosrc => 'line_intersect' },
+  proname => 'line_intersect', prorettype => 'bool', proargtypes => 'line line' },
 { oid => '1496',
-  proname => 'line_parallel', prorettype => 'bool', proargtypes => 'line line',
-  prosrc => 'line_parallel' },
+  proname => 'line_parallel', prorettype => 'bool', proargtypes => 'line line' },
 { oid => '1497',
-  proname => 'line_perp', prorettype => 'bool', proargtypes => 'line line',
-  prosrc => 'line_perp' },
+  proname => 'line_perp', prorettype => 'bool', proargtypes => 'line line' },
 { oid => '1498',
-  proname => 'line_vertical', prorettype => 'bool', proargtypes => 'line',
-  prosrc => 'line_vertical' },
+  proname => 'line_vertical', prorettype => 'bool', proargtypes => 'line' },
 { oid => '1499',
-  proname => 'line_horizontal', prorettype => 'bool', proargtypes => 'line',
-  prosrc => 'line_horizontal' },
+  proname => 'line_horizontal', prorettype => 'bool', proargtypes => 'line' },
 
 # OIDS 1500 - 1599
 
@@ -3229,17 +2904,13 @@
   prosrc => 'poly_npoints' },
 
 { oid => '1564', descr => 'I/O',
-  proname => 'bit_in', prorettype => 'bit', proargtypes => 'cstring oid int4',
-  prosrc => 'bit_in' },
+  proname => 'bit_in', prorettype => 'bit', proargtypes => 'cstring oid int4' },
 { oid => '1565', descr => 'I/O',
-  proname => 'bit_out', prorettype => 'cstring', proargtypes => 'bit',
-  prosrc => 'bit_out' },
+  proname => 'bit_out', prorettype => 'cstring', proargtypes => 'bit' },
 { oid => '2919', descr => 'I/O typmod',
-  proname => 'bittypmodin', prorettype => 'int4', proargtypes => '_cstring',
-  prosrc => 'bittypmodin' },
+  proname => 'bittypmodin', prorettype => 'int4', proargtypes => '_cstring' },
 { oid => '2920', descr => 'I/O typmod',
-  proname => 'bittypmodout', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'bittypmodout' },
+  proname => 'bittypmodout', prorettype => 'cstring', proargtypes => 'int4' },
 
 { oid => '1569', descr => 'matches LIKE expression',
   proname => 'like', prorettype => 'bool', proargtypes => 'text text',
@@ -3275,54 +2946,48 @@
   prorettype => 'record', proargtypes => 'oid',
   proallargtypes => '{oid,int8,int8,int8,int8,bool,int8,oid}',
   proargmodes => '{i,o,o,o,o,o,o,o}',
-  proargnames => '{sequence_oid,start_value,minimum_value,maximum_value,increment,cycle_option,cache_size,data_type}',
-  prosrc => 'pg_sequence_parameters' },
+  proargnames => '{sequence_oid,start_value,minimum_value,maximum_value,increment,cycle_option,cache_size,data_type}' },
 { oid => '4032', descr => 'sequence last value',
   proname => 'pg_sequence_last_value', provolatile => 'v', proparallel => 'u',
-  prorettype => 'int8', proargtypes => 'regclass',
-  prosrc => 'pg_sequence_last_value' },
+  prorettype => 'int8', proargtypes => 'regclass' },
 
 { oid => '1579', descr => 'I/O',
   proname => 'varbit_in', prorettype => 'varbit',
-  proargtypes => 'cstring oid int4', prosrc => 'varbit_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1580', descr => 'I/O',
-  proname => 'varbit_out', prorettype => 'cstring', proargtypes => 'varbit',
-  prosrc => 'varbit_out' },
+  proname => 'varbit_out', prorettype => 'cstring', proargtypes => 'varbit' },
 { oid => '2902', descr => 'I/O typmod',
-  proname => 'varbittypmodin', prorettype => 'int4', proargtypes => '_cstring',
-  prosrc => 'varbittypmodin' },
+  proname => 'varbittypmodin', prorettype => 'int4', proargtypes => '_cstring' },
 { oid => '2921', descr => 'I/O typmod',
-  proname => 'varbittypmodout', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'varbittypmodout' },
+  proname => 'varbittypmodout', prorettype => 'cstring', proargtypes => 'int4' },
 
 { oid => '1581',
   proname => 'biteq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bit bit', prosrc => 'biteq' },
+  proargtypes => 'bit bit' },
 { oid => '1582',
   proname => 'bitne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bit bit', prosrc => 'bitne' },
+  proargtypes => 'bit bit' },
 { oid => '1592',
   proname => 'bitge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bit bit', prosrc => 'bitge' },
+  proargtypes => 'bit bit' },
 { oid => '1593',
   proname => 'bitgt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bit bit', prosrc => 'bitgt' },
+  proargtypes => 'bit bit' },
 { oid => '1594',
   proname => 'bitle', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bit bit', prosrc => 'bitle' },
+  proargtypes => 'bit bit' },
 { oid => '1595',
   proname => 'bitlt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bit bit', prosrc => 'bitlt' },
+  proargtypes => 'bit bit' },
 { oid => '1596', descr => 'less-equal-greater',
-  proname => 'bitcmp', prorettype => 'int4', proargtypes => 'bit bit',
-  prosrc => 'bitcmp' },
+  proname => 'bitcmp', prorettype => 'int4', proargtypes => 'bit bit' },
 
 { oid => '1598', descr => 'random value',
   proname => 'random', provolatile => 'v', proparallel => 'r',
   prorettype => 'float8', proargtypes => '', prosrc => 'drandom' },
 { oid => '1599', descr => 'set random seed',
   proname => 'setseed', provolatile => 'v', proparallel => 'r',
-  prorettype => 'void', proargtypes => 'float8', prosrc => 'setseed' },
+  prorettype => 'void', proargtypes => 'float8' },
 
 # OIDS 1600 - 1699
 
@@ -3377,35 +3042,30 @@
   prosrc => 'dcotd' },
 
 { oid => '1608', descr => 'radians to degrees',
-  proname => 'degrees', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'degrees' },
+  proname => 'degrees', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '1609', descr => 'degrees to radians',
-  proname => 'radians', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'radians' },
+  proname => 'radians', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '1610', descr => 'PI',
   proname => 'pi', prorettype => 'float8', proargtypes => '', prosrc => 'dpi' },
 
 { oid => '1618',
   proname => 'interval_mul', prorettype => 'interval',
-  proargtypes => 'interval float8', prosrc => 'interval_mul' },
+  proargtypes => 'interval float8' },
 
 { oid => '1620', descr => 'convert first char to int4',
-  proname => 'ascii', prorettype => 'int4', proargtypes => 'text',
-  prosrc => 'ascii' },
+  proname => 'ascii', prorettype => 'int4', proargtypes => 'text' },
 { oid => '1621', descr => 'convert int4 to char',
-  proname => 'chr', prorettype => 'text', proargtypes => 'int4',
-  prosrc => 'chr' },
+  proname => 'chr', prorettype => 'text', proargtypes => 'int4' },
 { oid => '1622', descr => 'replicate string n times',
-  proname => 'repeat', prorettype => 'text', proargtypes => 'text int4',
-  prosrc => 'repeat' },
+  proname => 'repeat', prorettype => 'text', proargtypes => 'text int4' },
 
 { oid => '1623', descr => 'convert SQL99 regexp pattern to POSIX style',
   proname => 'similar_escape', proisstrict => 'f', prorettype => 'text',
-  proargtypes => 'text text', prosrc => 'similar_escape' },
+  proargtypes => 'text text' },
 
 { oid => '1624',
   proname => 'mul_d_interval', prorettype => 'interval',
-  proargtypes => 'float8 interval', prosrc => 'mul_d_interval' },
+  proargtypes => 'float8 interval' },
 
 { oid => '1631',
   proname => 'bpcharlike', prorettype => 'bool', proargtypes => 'bpchar text',
@@ -3415,20 +3075,15 @@
   prosrc => 'textnlike' },
 
 { oid => '1633',
-  proname => 'texticlike', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'texticlike' },
+  proname => 'texticlike', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '1634',
-  proname => 'texticnlike', prorettype => 'bool', proargtypes => 'text text',
-  prosrc => 'texticnlike' },
+  proname => 'texticnlike', prorettype => 'bool', proargtypes => 'text text' },
 { oid => '1635',
-  proname => 'nameiclike', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'nameiclike' },
+  proname => 'nameiclike', prorettype => 'bool', proargtypes => 'name text' },
 { oid => '1636',
-  proname => 'nameicnlike', prorettype => 'bool', proargtypes => 'name text',
-  prosrc => 'nameicnlike' },
+  proname => 'nameicnlike', prorettype => 'bool', proargtypes => 'name text' },
 { oid => '1637', descr => 'convert LIKE pattern to use backslash escapes',
-  proname => 'like_escape', prorettype => 'text', proargtypes => 'text text',
-  prosrc => 'like_escape' },
+  proname => 'like_escape', prorettype => 'text', proargtypes => 'text text' },
 
 { oid => '1656',
   proname => 'bpcharicregexeq', prorettype => 'bool',
@@ -3454,32 +3109,24 @@
   proname => 'strpos', prorettype => 'int4', proargtypes => 'text text',
   prosrc => 'textpos' },
 { oid => '870', descr => 'lowercase',
-  proname => 'lower', prorettype => 'text', proargtypes => 'text',
-  prosrc => 'lower' },
+  proname => 'lower', prorettype => 'text', proargtypes => 'text' },
 { oid => '871', descr => 'uppercase',
-  proname => 'upper', prorettype => 'text', proargtypes => 'text',
-  prosrc => 'upper' },
+  proname => 'upper', prorettype => 'text', proargtypes => 'text' },
 { oid => '872', descr => 'capitalize each word',
-  proname => 'initcap', prorettype => 'text', proargtypes => 'text',
-  prosrc => 'initcap' },
+  proname => 'initcap', prorettype => 'text', proargtypes => 'text' },
 { oid => '873', descr => 'left-pad string to length',
-  proname => 'lpad', prorettype => 'text', proargtypes => 'text int4 text',
-  prosrc => 'lpad' },
+  proname => 'lpad', prorettype => 'text', proargtypes => 'text int4 text' },
 { oid => '874', descr => 'right-pad string to length',
-  proname => 'rpad', prorettype => 'text', proargtypes => 'text int4 text',
-  prosrc => 'rpad' },
+  proname => 'rpad', prorettype => 'text', proargtypes => 'text int4 text' },
 { oid => '875', descr => 'trim selected characters from left end of string',
-  proname => 'ltrim', prorettype => 'text', proargtypes => 'text text',
-  prosrc => 'ltrim' },
+  proname => 'ltrim', prorettype => 'text', proargtypes => 'text text' },
 { oid => '876', descr => 'trim selected characters from right end of string',
-  proname => 'rtrim', prorettype => 'text', proargtypes => 'text text',
-  prosrc => 'rtrim' },
+  proname => 'rtrim', prorettype => 'text', proargtypes => 'text text' },
 { oid => '877', descr => 'extract portion of string',
   proname => 'substr', prorettype => 'text', proargtypes => 'text int4 int4',
   prosrc => 'text_substr' },
 { oid => '878', descr => 'map a set of characters appearing in string',
-  proname => 'translate', prorettype => 'text', proargtypes => 'text text text',
-  prosrc => 'translate' },
+  proname => 'translate', prorettype => 'text', proargtypes => 'text text text' },
 { oid => '879', descr => 'left-pad string to length',
   proname => 'lpad', prolang => '14', prorettype => 'text',
   proargtypes => 'text int4',
@@ -3498,8 +3145,7 @@
   proname => 'substr', prorettype => 'text', proargtypes => 'text int4',
   prosrc => 'text_substr_no_len' },
 { oid => '884', descr => 'trim selected characters from both ends of string',
-  proname => 'btrim', prorettype => 'text', proargtypes => 'text text',
-  prosrc => 'btrim' },
+  proname => 'btrim', prorettype => 'text', proargtypes => 'text text' },
 { oid => '885', descr => 'trim spaces from both ends of string',
   proname => 'btrim', prorettype => 'text', proargtypes => 'text',
   prosrc => 'btrim1' },
@@ -3525,15 +3171,14 @@
   prosrc => 'regexp_match_no_flags' },
 { oid => '3397', descr => 'find first match for regexp',
   proname => 'regexp_match', prorettype => '_text',
-  proargtypes => 'text text text', prosrc => 'regexp_match' },
+  proargtypes => 'text text text' },
 { oid => '2763', descr => 'find match(es) for regexp',
   proname => 'regexp_matches', prorows => '1', proretset => 't',
   prorettype => '_text', proargtypes => 'text text',
   prosrc => 'regexp_matches_no_flags' },
 { oid => '2764', descr => 'find match(es) for regexp',
   proname => 'regexp_matches', prorows => '10', proretset => 't',
-  prorettype => '_text', proargtypes => 'text text text',
-  prosrc => 'regexp_matches' },
+  prorettype => '_text', proargtypes => 'text text text' },
 { oid => '2088', descr => 'split string by field_sep and return field_num',
   proname => 'split_part', prorettype => 'text',
   proargtypes => 'text text int4', prosrc => 'split_text' },
@@ -3543,14 +3188,13 @@
   prosrc => 'regexp_split_to_table_no_flags' },
 { oid => '2766', descr => 'split string by pattern',
   proname => 'regexp_split_to_table', prorows => '1000', proretset => 't',
-  prorettype => 'text', proargtypes => 'text text text',
-  prosrc => 'regexp_split_to_table' },
+  prorettype => 'text', proargtypes => 'text text text' },
 { oid => '2767', descr => 'split string by pattern',
   proname => 'regexp_split_to_array', prorettype => '_text',
   proargtypes => 'text text', prosrc => 'regexp_split_to_array_no_flags' },
 { oid => '2768', descr => 'split string by pattern',
   proname => 'regexp_split_to_array', prorettype => '_text',
-  proargtypes => 'text text text', prosrc => 'regexp_split_to_array' },
+  proargtypes => 'text text text' },
 { oid => '2089', descr => 'convert int4 number to hex',
   proname => 'to_hex', prorettype => 'text', proargtypes => 'int4',
   prosrc => 'to_hex32' },
@@ -3563,12 +3207,12 @@
 # return database encoding name
 { oid => '1039', descr => 'encoding name of current database',
   proname => 'getdatabaseencoding', provolatile => 's', prorettype => 'name',
-  proargtypes => '', prosrc => 'getdatabaseencoding' },
+  proargtypes => '' },
 
 # return client encoding name i.e. session encoding
 { oid => '810', descr => 'encoding name of current database',
   proname => 'pg_client_encoding', provolatile => 's', prorettype => 'name',
-  proargtypes => '', prosrc => 'pg_client_encoding' },
+  proargtypes => '' },
 
 { oid => '1713', descr => 'length of string in specified encoding',
   proname => 'length', provolatile => 's', prorettype => 'int4',
@@ -3603,154 +3247,138 @@
 
 { oid => '1638',
   proname => 'oidgt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'oid oid', prosrc => 'oidgt' },
+  proargtypes => 'oid oid' },
 { oid => '1639',
   proname => 'oidge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'oid oid', prosrc => 'oidge' },
+  proargtypes => 'oid oid' },
 
 # System-view support functions
 { oid => '1573', descr => 'source text of a rule',
   proname => 'pg_get_ruledef', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_get_ruledef' },
+  proargtypes => 'oid' },
 { oid => '1640', descr => 'select statement of a view',
   proname => 'pg_get_viewdef', provolatile => 's', proparallel => 'r',
   prorettype => 'text', proargtypes => 'text',
   prosrc => 'pg_get_viewdef_name' },
 { oid => '1641', descr => 'select statement of a view',
   proname => 'pg_get_viewdef', provolatile => 's', proparallel => 'r',
-  prorettype => 'text', proargtypes => 'oid', prosrc => 'pg_get_viewdef' },
+  prorettype => 'text', proargtypes => 'oid' },
 { oid => '1642', descr => 'role name by OID (with fallback)',
   proname => 'pg_get_userbyid', provolatile => 's', prorettype => 'name',
-  proargtypes => 'oid', prosrc => 'pg_get_userbyid' },
+  proargtypes => 'oid' },
 { oid => '1643', descr => 'index description',
   proname => 'pg_get_indexdef', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_get_indexdef' },
+  proargtypes => 'oid' },
 { oid => '3415', descr => 'extended statistics object description',
   proname => 'pg_get_statisticsobjdef', provolatile => 's',
-  prorettype => 'text', proargtypes => 'oid',
-  prosrc => 'pg_get_statisticsobjdef' },
+  prorettype => 'text', proargtypes => 'oid' },
 { oid => '3352', descr => 'partition key description',
   proname => 'pg_get_partkeydef', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_get_partkeydef' },
+  proargtypes => 'oid' },
 { oid => '3408', descr => 'partition constraint description',
   proname => 'pg_get_partition_constraintdef', provolatile => 's',
-  prorettype => 'text', proargtypes => 'oid',
-  prosrc => 'pg_get_partition_constraintdef' },
+  prorettype => 'text', proargtypes => 'oid' },
 { oid => '1662', descr => 'trigger description',
   proname => 'pg_get_triggerdef', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_get_triggerdef' },
+  proargtypes => 'oid' },
 { oid => '1387', descr => 'constraint description',
   proname => 'pg_get_constraintdef', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_get_constraintdef' },
+  proargtypes => 'oid' },
 { oid => '1716', descr => 'deparse an encoded expression',
   proname => 'pg_get_expr', provolatile => 's', prorettype => 'text',
-  proargtypes => 'pg_node_tree oid', prosrc => 'pg_get_expr' },
+  proargtypes => 'pg_node_tree oid' },
 { oid => '1665', descr => 'name of sequence for a serial column',
   proname => 'pg_get_serial_sequence', provolatile => 's', prorettype => 'text',
-  proargtypes => 'text text', prosrc => 'pg_get_serial_sequence' },
+  proargtypes => 'text text' },
 { oid => '2098', descr => 'definition of a function',
   proname => 'pg_get_functiondef', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_get_functiondef' },
+  proargtypes => 'oid' },
 { oid => '2162', descr => 'argument list of a function',
   proname => 'pg_get_function_arguments', provolatile => 's',
-  prorettype => 'text', proargtypes => 'oid',
-  prosrc => 'pg_get_function_arguments' },
+  prorettype => 'text', proargtypes => 'oid' },
 { oid => '2232', descr => 'identity argument list of a function',
   proname => 'pg_get_function_identity_arguments', provolatile => 's',
-  prorettype => 'text', proargtypes => 'oid',
-  prosrc => 'pg_get_function_identity_arguments' },
+  prorettype => 'text', proargtypes => 'oid' },
 { oid => '2165', descr => 'result type of a function',
   proname => 'pg_get_function_result', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_get_function_result' },
+  proargtypes => 'oid' },
 { oid => '3808', descr => 'function argument default',
   proname => 'pg_get_function_arg_default', provolatile => 's',
-  prorettype => 'text', proargtypes => 'oid int4',
-  prosrc => 'pg_get_function_arg_default' },
+  prorettype => 'text', proargtypes => 'oid int4' },
 
 { oid => '1686', descr => 'list of SQL keywords',
   proname => 'pg_get_keywords', procost => '10', prorows => '400',
   proretset => 't', provolatile => 's', prorettype => 'record',
   proargtypes => '', proallargtypes => '{text,char,text}',
-  proargmodes => '{o,o,o}', proargnames => '{word,catcode,catdesc}',
-  prosrc => 'pg_get_keywords' },
+  proargmodes => '{o,o,o}', proargnames => '{word,catcode,catdesc}' },
 
 { oid => '2289', descr => 'convert generic options array to name/value table',
   proname => 'pg_options_to_table', prorows => '3', proretset => 't',
   provolatile => 's', prorettype => 'record', proargtypes => '_text',
   proallargtypes => '{_text,text,text}', proargmodes => '{i,o,o}',
-  proargnames => '{options_array,option_name,option_value}',
-  prosrc => 'pg_options_to_table' },
+  proargnames => '{options_array,option_name,option_value}' },
 
 { oid => '1619', descr => 'type of the argument',
   proname => 'pg_typeof', proisstrict => 'f', provolatile => 's',
-  prorettype => 'regtype', proargtypes => 'any', prosrc => 'pg_typeof' },
+  prorettype => 'regtype', proargtypes => 'any' },
 { oid => '3162',
   descr => 'collation of the argument; implementation of the COLLATION FOR expression',
   proname => 'pg_collation_for', proisstrict => 'f', provolatile => 's',
-  prorettype => 'text', proargtypes => 'any', prosrc => 'pg_collation_for' },
+  prorettype => 'text', proargtypes => 'any' },
 
 { oid => '3842', descr => 'is a relation insertable/updatable/deletable',
   proname => 'pg_relation_is_updatable', procost => '10', provolatile => 's',
-  prorettype => 'int4', proargtypes => 'regclass bool',
-  prosrc => 'pg_relation_is_updatable' },
+  prorettype => 'int4', proargtypes => 'regclass bool' },
 { oid => '3843', descr => 'is a column updatable',
   proname => 'pg_column_is_updatable', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'regclass int2 bool',
-  prosrc => 'pg_column_is_updatable' },
+  prorettype => 'bool', proargtypes => 'regclass int2 bool' },
 
 { oid => '6120', descr => 'oid of replica identity index if any',
   proname => 'pg_get_replica_identity_index', procost => '10',
-  provolatile => 's', prorettype => 'regclass', proargtypes => 'regclass',
-  prosrc => 'pg_get_replica_identity_index' },
+  provolatile => 's', prorettype => 'regclass', proargtypes => 'regclass' },
 
 # Deferrable unique constraint trigger
 { oid => '1250', descr => 'deferred UNIQUE constraint check',
   proname => 'unique_key_recheck', provolatile => 'v', prorettype => 'trigger',
-  proargtypes => '', prosrc => 'unique_key_recheck' },
+  proargtypes => '' },
 
 # Generic referential integrity constraint triggers
 { oid => '1644', descr => 'referential integrity FOREIGN KEY ... REFERENCES',
   proname => 'RI_FKey_check_ins', provolatile => 'v', prorettype => 'trigger',
-  proargtypes => '', prosrc => 'RI_FKey_check_ins' },
+  proargtypes => '' },
 { oid => '1645', descr => 'referential integrity FOREIGN KEY ... REFERENCES',
   proname => 'RI_FKey_check_upd', provolatile => 'v', prorettype => 'trigger',
-  proargtypes => '', prosrc => 'RI_FKey_check_upd' },
+  proargtypes => '' },
 { oid => '1646', descr => 'referential integrity ON DELETE CASCADE',
   proname => 'RI_FKey_cascade_del', provolatile => 'v', prorettype => 'trigger',
-  proargtypes => '', prosrc => 'RI_FKey_cascade_del' },
+  proargtypes => '' },
 { oid => '1647', descr => 'referential integrity ON UPDATE CASCADE',
   proname => 'RI_FKey_cascade_upd', provolatile => 'v', prorettype => 'trigger',
-  proargtypes => '', prosrc => 'RI_FKey_cascade_upd' },
+  proargtypes => '' },
 { oid => '1648', descr => 'referential integrity ON DELETE RESTRICT',
   proname => 'RI_FKey_restrict_del', provolatile => 'v',
-  prorettype => 'trigger', proargtypes => '',
-  prosrc => 'RI_FKey_restrict_del' },
+  prorettype => 'trigger', proargtypes => '' },
 { oid => '1649', descr => 'referential integrity ON UPDATE RESTRICT',
   proname => 'RI_FKey_restrict_upd', provolatile => 'v',
-  prorettype => 'trigger', proargtypes => '',
-  prosrc => 'RI_FKey_restrict_upd' },
+  prorettype => 'trigger', proargtypes => '' },
 { oid => '1650', descr => 'referential integrity ON DELETE SET NULL',
   proname => 'RI_FKey_setnull_del', provolatile => 'v', prorettype => 'trigger',
-  proargtypes => '', prosrc => 'RI_FKey_setnull_del' },
+  proargtypes => '' },
 { oid => '1651', descr => 'referential integrity ON UPDATE SET NULL',
   proname => 'RI_FKey_setnull_upd', provolatile => 'v', prorettype => 'trigger',
-  proargtypes => '', prosrc => 'RI_FKey_setnull_upd' },
+  proargtypes => '' },
 { oid => '1652', descr => 'referential integrity ON DELETE SET DEFAULT',
   proname => 'RI_FKey_setdefault_del', provolatile => 'v',
-  prorettype => 'trigger', proargtypes => '',
-  prosrc => 'RI_FKey_setdefault_del' },
+  prorettype => 'trigger', proargtypes => '' },
 { oid => '1653', descr => 'referential integrity ON UPDATE SET DEFAULT',
   proname => 'RI_FKey_setdefault_upd', provolatile => 'v',
-  prorettype => 'trigger', proargtypes => '',
-  prosrc => 'RI_FKey_setdefault_upd' },
+  prorettype => 'trigger', proargtypes => '' },
 { oid => '1654', descr => 'referential integrity ON DELETE NO ACTION',
   proname => 'RI_FKey_noaction_del', provolatile => 'v',
-  prorettype => 'trigger', proargtypes => '',
-  prosrc => 'RI_FKey_noaction_del' },
+  prorettype => 'trigger', proargtypes => '' },
 { oid => '1655', descr => 'referential integrity ON UPDATE NO ACTION',
   proname => 'RI_FKey_noaction_upd', provolatile => 'v',
-  prorettype => 'trigger', proargtypes => '',
-  prosrc => 'RI_FKey_noaction_upd' },
+  prorettype => 'trigger', proargtypes => '' },
 
 { oid => '1666',
   proname => 'varbiteq', proleakproof => 't', prorettype => 'bool',
@@ -3782,20 +3410,15 @@
   proname => 'bitor', prorettype => 'bit', proargtypes => 'bit bit',
   prosrc => 'bit_or' },
 { oid => '1675',
-  proname => 'bitxor', prorettype => 'bit', proargtypes => 'bit bit',
-  prosrc => 'bitxor' },
+  proname => 'bitxor', prorettype => 'bit', proargtypes => 'bit bit' },
 { oid => '1676',
-  proname => 'bitnot', prorettype => 'bit', proargtypes => 'bit',
-  prosrc => 'bitnot' },
+  proname => 'bitnot', prorettype => 'bit', proargtypes => 'bit' },
 { oid => '1677',
-  proname => 'bitshiftleft', prorettype => 'bit', proargtypes => 'bit int4',
-  prosrc => 'bitshiftleft' },
+  proname => 'bitshiftleft', prorettype => 'bit', proargtypes => 'bit int4' },
 { oid => '1678',
-  proname => 'bitshiftright', prorettype => 'bit', proargtypes => 'bit int4',
-  prosrc => 'bitshiftright' },
+  proname => 'bitshiftright', prorettype => 'bit', proargtypes => 'bit int4' },
 { oid => '1679',
-  proname => 'bitcat', prorettype => 'varbit', proargtypes => 'varbit varbit',
-  prosrc => 'bitcat' },
+  proname => 'bitcat', prorettype => 'varbit', proargtypes => 'varbit varbit' },
 { oid => '1680', descr => 'extract portion of bitstring',
   proname => 'substring', prorettype => 'bit', proargtypes => 'bit int4 int4',
   prosrc => 'bitsubstr' },
@@ -3813,15 +3436,13 @@
   prosrc => 'bittoint4' },
 
 { oid => '1685', descr => 'adjust bit() to typmod length',
-  proname => 'bit', prorettype => 'bit', proargtypes => 'bit int4 bool',
-  prosrc => 'bit' },
+  proname => 'bit', prorettype => 'bit', proargtypes => 'bit int4 bool' },
 { oid => '3158', descr => 'transform a varbit length coercion',
   proname => 'varbit_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'varbit_transform' },
+  proargtypes => 'internal' },
 { oid => '1687', descr => 'adjust varbit() to typmod length',
   proname => 'varbit', protransform => 'varbit_transform',
-  prorettype => 'varbit', proargtypes => 'varbit int4 bool',
-  prosrc => 'varbit' },
+  prorettype => 'varbit', proargtypes => 'varbit int4 bool' },
 
 { oid => '1698', descr => 'position of sub-bitstring',
   proname => 'position', prorettype => 'int4', proargtypes => 'bit bit',
@@ -3845,11 +3466,9 @@
 
 # for macaddr type support
 { oid => '436', descr => 'I/O',
-  proname => 'macaddr_in', prorettype => 'macaddr', proargtypes => 'cstring',
-  prosrc => 'macaddr_in' },
+  proname => 'macaddr_in', prorettype => 'macaddr', proargtypes => 'cstring' },
 { oid => '437', descr => 'I/O',
-  proname => 'macaddr_out', prorettype => 'cstring', proargtypes => 'macaddr',
-  prosrc => 'macaddr_out' },
+  proname => 'macaddr_out', prorettype => 'cstring', proargtypes => 'macaddr' },
 
 { oid => '753', descr => 'MACADDR manufacturer fields',
   proname => 'trunc', prorettype => 'macaddr', proargtypes => 'macaddr',
@@ -3857,45 +3476,42 @@
 
 { oid => '830',
   proname => 'macaddr_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_eq' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '831',
   proname => 'macaddr_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_lt' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '832',
   proname => 'macaddr_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_le' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '833',
   proname => 'macaddr_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_gt' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '834',
   proname => 'macaddr_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_ge' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '835',
   proname => 'macaddr_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_ne' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '836', descr => 'less-equal-greater',
   proname => 'macaddr_cmp', prorettype => 'int4',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_cmp' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '3144',
-  proname => 'macaddr_not', prorettype => 'macaddr', proargtypes => 'macaddr',
-  prosrc => 'macaddr_not' },
+  proname => 'macaddr_not', prorettype => 'macaddr', proargtypes => 'macaddr' },
 { oid => '3145',
   proname => 'macaddr_and', prorettype => 'macaddr',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_and' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '3146',
   proname => 'macaddr_or', prorettype => 'macaddr',
-  proargtypes => 'macaddr macaddr', prosrc => 'macaddr_or' },
+  proargtypes => 'macaddr macaddr' },
 { oid => '3359', descr => 'sort support',
   proname => 'macaddr_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'macaddr_sortsupport' },
+  proargtypes => 'internal' },
 
 # for macaddr8 type support
 { oid => '4110', descr => 'I/O',
-  proname => 'macaddr8_in', prorettype => 'macaddr8', proargtypes => 'cstring',
-  prosrc => 'macaddr8_in' },
+  proname => 'macaddr8_in', prorettype => 'macaddr8', proargtypes => 'cstring' },
 { oid => '4111', descr => 'I/O',
-  proname => 'macaddr8_out', prorettype => 'cstring', proargtypes => 'macaddr8',
-  prosrc => 'macaddr8_out' },
+  proname => 'macaddr8_out', prorettype => 'cstring', proargtypes => 'macaddr8' },
 
 { oid => '4112', descr => 'MACADDR8 manufacturer fields',
   proname => 'trunc', prorettype => 'macaddr8', proargtypes => 'macaddr8',
@@ -3903,34 +3519,34 @@
 
 { oid => '4113',
   proname => 'macaddr8_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_eq' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4114',
   proname => 'macaddr8_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_lt' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4115',
   proname => 'macaddr8_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_le' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4116',
   proname => 'macaddr8_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_gt' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4117',
   proname => 'macaddr8_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_ge' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4118',
   proname => 'macaddr8_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_ne' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4119', descr => 'less-equal-greater',
   proname => 'macaddr8_cmp', prorettype => 'int4',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_cmp' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4120',
   proname => 'macaddr8_not', prorettype => 'macaddr8',
-  proargtypes => 'macaddr8', prosrc => 'macaddr8_not' },
+  proargtypes => 'macaddr8' },
 { oid => '4121',
   proname => 'macaddr8_and', prorettype => 'macaddr8',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_and' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4122',
   proname => 'macaddr8_or', prorettype => 'macaddr8',
-  proargtypes => 'macaddr8 macaddr8', prosrc => 'macaddr8_or' },
+  proargtypes => 'macaddr8 macaddr8' },
 { oid => '4123', descr => 'convert macaddr to macaddr8',
   proname => 'macaddr8', prorettype => 'macaddr8', proargtypes => 'macaddr',
   prosrc => 'macaddrtomacaddr8' },
@@ -3939,67 +3555,57 @@
   prosrc => 'macaddr8tomacaddr' },
 { oid => '4125', descr => 'set 7th bit in macaddr8',
   proname => 'macaddr8_set7bit', prorettype => 'macaddr8',
-  proargtypes => 'macaddr8', prosrc => 'macaddr8_set7bit' },
+  proargtypes => 'macaddr8' },
 
 # for inet type support
 { oid => '910', descr => 'I/O',
-  proname => 'inet_in', prorettype => 'inet', proargtypes => 'cstring',
-  prosrc => 'inet_in' },
+  proname => 'inet_in', prorettype => 'inet', proargtypes => 'cstring' },
 { oid => '911', descr => 'I/O',
-  proname => 'inet_out', prorettype => 'cstring', proargtypes => 'inet',
-  prosrc => 'inet_out' },
+  proname => 'inet_out', prorettype => 'cstring', proargtypes => 'inet' },
 
 # for cidr type support
 { oid => '1267', descr => 'I/O',
-  proname => 'cidr_in', prorettype => 'cidr', proargtypes => 'cstring',
-  prosrc => 'cidr_in' },
+  proname => 'cidr_in', prorettype => 'cidr', proargtypes => 'cstring' },
 { oid => '1427', descr => 'I/O',
-  proname => 'cidr_out', prorettype => 'cstring', proargtypes => 'cidr',
-  prosrc => 'cidr_out' },
+  proname => 'cidr_out', prorettype => 'cstring', proargtypes => 'cidr' },
 
 # these are used for both inet and cidr
 { oid => '920',
   proname => 'network_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'network_eq' },
+  proargtypes => 'inet inet' },
 { oid => '921',
   proname => 'network_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'network_lt' },
+  proargtypes => 'inet inet' },
 { oid => '922',
   proname => 'network_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'network_le' },
+  proargtypes => 'inet inet' },
 { oid => '923',
   proname => 'network_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'network_gt' },
+  proargtypes => 'inet inet' },
 { oid => '924',
   proname => 'network_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'network_ge' },
+  proargtypes => 'inet inet' },
 { oid => '925',
   proname => 'network_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'network_ne' },
+  proargtypes => 'inet inet' },
 { oid => '3562', descr => 'larger of two',
-  proname => 'network_larger', prorettype => 'inet', proargtypes => 'inet inet',
-  prosrc => 'network_larger' },
+  proname => 'network_larger', prorettype => 'inet', proargtypes => 'inet inet' },
 { oid => '3563', descr => 'smaller of two',
   proname => 'network_smaller', prorettype => 'inet',
-  proargtypes => 'inet inet', prosrc => 'network_smaller' },
+  proargtypes => 'inet inet' },
 { oid => '926', descr => 'less-equal-greater',
-  proname => 'network_cmp', prorettype => 'int4', proargtypes => 'inet inet',
-  prosrc => 'network_cmp' },
+  proname => 'network_cmp', prorettype => 'int4', proargtypes => 'inet inet' },
 { oid => '927',
-  proname => 'network_sub', prorettype => 'bool', proargtypes => 'inet inet',
-  prosrc => 'network_sub' },
+  proname => 'network_sub', prorettype => 'bool', proargtypes => 'inet inet' },
 { oid => '928',
-  proname => 'network_subeq', prorettype => 'bool', proargtypes => 'inet inet',
-  prosrc => 'network_subeq' },
+  proname => 'network_subeq', prorettype => 'bool', proargtypes => 'inet inet' },
 { oid => '929',
-  proname => 'network_sup', prorettype => 'bool', proargtypes => 'inet inet',
-  prosrc => 'network_sup' },
+  proname => 'network_sup', prorettype => 'bool', proargtypes => 'inet inet' },
 { oid => '930',
-  proname => 'network_supeq', prorettype => 'bool', proargtypes => 'inet inet',
-  prosrc => 'network_supeq' },
+  proname => 'network_supeq', prorettype => 'bool', proargtypes => 'inet inet' },
 { oid => '3551',
   proname => 'network_overlap', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'network_overlap' },
+  proargtypes => 'inet inet' },
 
 # inet/cidr functions
 { oid => '598', descr => 'abbreviated display of inet value',
@@ -4044,154 +3650,135 @@
 
 { oid => '2196', descr => 'inet address of the client',
   proname => 'inet_client_addr', proisstrict => 'f', provolatile => 's',
-  proparallel => 'r', prorettype => 'inet', proargtypes => '',
-  prosrc => 'inet_client_addr' },
+  proparallel => 'r', prorettype => 'inet', proargtypes => '' },
 { oid => '2197', descr => 'client\'s port number for this connection',
   proname => 'inet_client_port', proisstrict => 'f', provolatile => 's',
-  proparallel => 'r', prorettype => 'int4', proargtypes => '',
-  prosrc => 'inet_client_port' },
+  proparallel => 'r', prorettype => 'int4', proargtypes => '' },
 { oid => '2198', descr => 'inet address of the server',
   proname => 'inet_server_addr', proisstrict => 'f', provolatile => 's',
-  prorettype => 'inet', proargtypes => '', prosrc => 'inet_server_addr' },
+  prorettype => 'inet', proargtypes => '' },
 { oid => '2199', descr => 'server\'s port number for this connection',
   proname => 'inet_server_port', proisstrict => 'f', provolatile => 's',
-  prorettype => 'int4', proargtypes => '', prosrc => 'inet_server_port' },
+  prorettype => 'int4', proargtypes => '' },
 
 { oid => '2627',
-  proname => 'inetnot', prorettype => 'inet', proargtypes => 'inet',
-  prosrc => 'inetnot' },
+  proname => 'inetnot', prorettype => 'inet', proargtypes => 'inet' },
 { oid => '2628',
-  proname => 'inetand', prorettype => 'inet', proargtypes => 'inet inet',
-  prosrc => 'inetand' },
+  proname => 'inetand', prorettype => 'inet', proargtypes => 'inet inet' },
 { oid => '2629',
-  proname => 'inetor', prorettype => 'inet', proargtypes => 'inet inet',
-  prosrc => 'inetor' },
+  proname => 'inetor', prorettype => 'inet', proargtypes => 'inet inet' },
 { oid => '2630',
-  proname => 'inetpl', prorettype => 'inet', proargtypes => 'inet int8',
-  prosrc => 'inetpl' },
+  proname => 'inetpl', prorettype => 'inet', proargtypes => 'inet int8' },
 { oid => '2631',
   proname => 'int8pl_inet', prolang => '14', prorettype => 'inet',
   proargtypes => 'int8 inet', prosrc => 'select $2 + $1' },
 { oid => '2632',
-  proname => 'inetmi_int8', prorettype => 'inet', proargtypes => 'inet int8',
-  prosrc => 'inetmi_int8' },
+  proname => 'inetmi_int8', prorettype => 'inet', proargtypes => 'inet int8' },
 { oid => '2633',
-  proname => 'inetmi', prorettype => 'int8', proargtypes => 'inet inet',
-  prosrc => 'inetmi' },
+  proname => 'inetmi', prorettype => 'int8', proargtypes => 'inet inet' },
 { oid => '4071', descr => 'are the addresses from the same family?',
   proname => 'inet_same_family', prorettype => 'bool',
-  proargtypes => 'inet inet', prosrc => 'inet_same_family' },
+  proargtypes => 'inet inet' },
 { oid => '4063',
   descr => 'the smallest network which includes both of the given networks',
-  proname => 'inet_merge', prorettype => 'cidr', proargtypes => 'inet inet',
-  prosrc => 'inet_merge' },
+  proname => 'inet_merge', prorettype => 'cidr', proargtypes => 'inet inet' },
 
 # GiST support for inet and cidr
 { oid => '3553', descr => 'GiST support',
   proname => 'inet_gist_consistent', prorettype => 'bool',
-  proargtypes => 'internal inet int2 oid internal',
-  prosrc => 'inet_gist_consistent' },
+  proargtypes => 'internal inet int2 oid internal' },
 { oid => '3554', descr => 'GiST support',
   proname => 'inet_gist_union', prorettype => 'inet',
-  proargtypes => 'internal internal', prosrc => 'inet_gist_union' },
+  proargtypes => 'internal internal' },
 { oid => '3555', descr => 'GiST support',
   proname => 'inet_gist_compress', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'inet_gist_compress' },
+  proargtypes => 'internal' },
 { oid => '3573', descr => 'GiST support',
   proname => 'inet_gist_fetch', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'inet_gist_fetch' },
+  proargtypes => 'internal' },
 { oid => '3557', descr => 'GiST support',
   proname => 'inet_gist_penalty', prorettype => 'internal',
-  proargtypes => 'internal internal internal', prosrc => 'inet_gist_penalty' },
+  proargtypes => 'internal internal internal' },
 { oid => '3558', descr => 'GiST support',
   proname => 'inet_gist_picksplit', prorettype => 'internal',
-  proargtypes => 'internal internal', prosrc => 'inet_gist_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '3559', descr => 'GiST support',
   proname => 'inet_gist_same', prorettype => 'internal',
-  proargtypes => 'inet inet internal', prosrc => 'inet_gist_same' },
+  proargtypes => 'inet inet internal' },
 
 # SP-GiST support for inet and cidr
 { oid => '3795', descr => 'SP-GiST support',
   proname => 'inet_spg_config', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'inet_spg_config' },
+  proargtypes => 'internal internal' },
 { oid => '3796', descr => 'SP-GiST support',
   proname => 'inet_spg_choose', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'inet_spg_choose' },
+  proargtypes => 'internal internal' },
 { oid => '3797', descr => 'SP-GiST support',
   proname => 'inet_spg_picksplit', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'inet_spg_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '3798', descr => 'SP-GiST support',
   proname => 'inet_spg_inner_consistent', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'inet_spg_inner_consistent' },
+  proargtypes => 'internal internal' },
 { oid => '3799', descr => 'SP-GiST support',
   proname => 'inet_spg_leaf_consistent', prorettype => 'bool',
-  proargtypes => 'internal internal', prosrc => 'inet_spg_leaf_consistent' },
+  proargtypes => 'internal internal' },
 
 # Selectivity estimation for inet and cidr
 { oid => '3560', descr => 'restriction selectivity for network operators',
   proname => 'networksel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'networksel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '3561', descr => 'join selectivity for network operators',
   proname => 'networkjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'networkjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 
 { oid => '1690',
   proname => 'time_mi_time', prorettype => 'interval',
-  proargtypes => 'time time', prosrc => 'time_mi_time' },
+  proargtypes => 'time time' },
 
 { oid => '1691',
   proname => 'boolle', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'boolle' },
+  proargtypes => 'bool bool' },
 { oid => '1692',
   proname => 'boolge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'boolge' },
+  proargtypes => 'bool bool' },
 { oid => '1693', descr => 'less-equal-greater',
-  proname => 'btboolcmp', prorettype => 'int4', proargtypes => 'bool bool',
-  prosrc => 'btboolcmp' },
+  proname => 'btboolcmp', prorettype => 'int4', proargtypes => 'bool bool' },
 
 { oid => '1688', descr => 'hash',
-  proname => 'time_hash', prorettype => 'int4', proargtypes => 'time',
-  prosrc => 'time_hash' },
+  proname => 'time_hash', prorettype => 'int4', proargtypes => 'time' },
 { oid => '3409', descr => 'hash',
   proname => 'time_hash_extended', prorettype => 'int8',
-  proargtypes => 'time int8', prosrc => 'time_hash_extended' },
+  proargtypes => 'time int8' },
 { oid => '1696', descr => 'hash',
-  proname => 'timetz_hash', prorettype => 'int4', proargtypes => 'timetz',
-  prosrc => 'timetz_hash' },
+  proname => 'timetz_hash', prorettype => 'int4', proargtypes => 'timetz' },
 { oid => '3410', descr => 'hash',
   proname => 'timetz_hash_extended', prorettype => 'int8',
-  proargtypes => 'timetz int8', prosrc => 'timetz_hash_extended' },
+  proargtypes => 'timetz int8' },
 { oid => '1697', descr => 'hash',
-  proname => 'interval_hash', prorettype => 'int4', proargtypes => 'interval',
-  prosrc => 'interval_hash' },
+  proname => 'interval_hash', prorettype => 'int4', proargtypes => 'interval' },
 { oid => '3418', descr => 'hash',
   proname => 'interval_hash_extended', prorettype => 'int8',
-  proargtypes => 'interval int8', prosrc => 'interval_hash_extended' },
+  proargtypes => 'interval int8' },
 
 # OID's 1700 - 1799 NUMERIC data type
 
 { oid => '1701', descr => 'I/O',
   proname => 'numeric_in', prorettype => 'numeric',
-  proargtypes => 'cstring oid int4', prosrc => 'numeric_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '1702', descr => 'I/O',
-  proname => 'numeric_out', prorettype => 'cstring', proargtypes => 'numeric',
-  prosrc => 'numeric_out' },
+  proname => 'numeric_out', prorettype => 'cstring', proargtypes => 'numeric' },
 { oid => '2917', descr => 'I/O typmod',
-  proname => 'numerictypmodin', prorettype => 'int4', proargtypes => '_cstring',
-  prosrc => 'numerictypmodin' },
+  proname => 'numerictypmodin', prorettype => 'int4', proargtypes => '_cstring' },
 { oid => '2918', descr => 'I/O typmod',
-  proname => 'numerictypmodout', prorettype => 'cstring', proargtypes => 'int4',
-  prosrc => 'numerictypmodout' },
+  proname => 'numerictypmodout', prorettype => 'cstring', proargtypes => 'int4' },
 { oid => '3157', descr => 'transform a numeric length coercion',
   proname => 'numeric_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'numeric_transform' },
+  proargtypes => 'internal' },
 { oid => '1703', descr => 'adjust numeric to typmod precision/scale',
   proname => 'numeric', protransform => 'numeric_transform',
-  prorettype => 'numeric', proargtypes => 'numeric int4', prosrc => 'numeric' },
+  prorettype => 'numeric', proargtypes => 'numeric int4' },
 { oid => '1704',
-  proname => 'numeric_abs', prorettype => 'numeric', proargtypes => 'numeric',
-  prosrc => 'numeric_abs' },
+  proname => 'numeric_abs', prorettype => 'numeric', proargtypes => 'numeric' },
 { oid => '1705', descr => 'absolute value',
   proname => 'abs', prorettype => 'numeric', proargtypes => 'numeric',
   prosrc => 'numeric_abs' },
@@ -4221,64 +3808,61 @@
   prosrc => 'numeric_floor' },
 { oid => '1718',
   proname => 'numeric_eq', prorettype => 'bool',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_eq' },
+  proargtypes => 'numeric numeric' },
 { oid => '1719',
   proname => 'numeric_ne', prorettype => 'bool',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_ne' },
+  proargtypes => 'numeric numeric' },
 { oid => '1720',
   proname => 'numeric_gt', prorettype => 'bool',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_gt' },
+  proargtypes => 'numeric numeric' },
 { oid => '1721',
   proname => 'numeric_ge', prorettype => 'bool',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_ge' },
+  proargtypes => 'numeric numeric' },
 { oid => '1722',
   proname => 'numeric_lt', prorettype => 'bool',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_lt' },
+  proargtypes => 'numeric numeric' },
 { oid => '1723',
   proname => 'numeric_le', prorettype => 'bool',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_le' },
+  proargtypes => 'numeric numeric' },
 { oid => '1724',
   proname => 'numeric_add', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_add' },
+  proargtypes => 'numeric numeric' },
 { oid => '1725',
   proname => 'numeric_sub', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_sub' },
+  proargtypes => 'numeric numeric' },
 { oid => '1726',
   proname => 'numeric_mul', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_mul' },
+  proargtypes => 'numeric numeric' },
 { oid => '1727',
   proname => 'numeric_div', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_div' },
+  proargtypes => 'numeric numeric' },
 { oid => '1728', descr => 'modulus',
   proname => 'mod', prorettype => 'numeric', proargtypes => 'numeric numeric',
   prosrc => 'numeric_mod' },
 { oid => '1729',
   proname => 'numeric_mod', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_mod' },
+  proargtypes => 'numeric numeric' },
 { oid => '1730', descr => 'square root',
   proname => 'sqrt', prorettype => 'numeric', proargtypes => 'numeric',
   prosrc => 'numeric_sqrt' },
 { oid => '1731', descr => 'square root',
-  proname => 'numeric_sqrt', prorettype => 'numeric', proargtypes => 'numeric',
-  prosrc => 'numeric_sqrt' },
+  proname => 'numeric_sqrt', prorettype => 'numeric', proargtypes => 'numeric' },
 { oid => '1732', descr => 'natural exponential (e^x)',
   proname => 'exp', prorettype => 'numeric', proargtypes => 'numeric',
   prosrc => 'numeric_exp' },
 { oid => '1733', descr => 'natural exponential (e^x)',
-  proname => 'numeric_exp', prorettype => 'numeric', proargtypes => 'numeric',
-  prosrc => 'numeric_exp' },
+  proname => 'numeric_exp', prorettype => 'numeric', proargtypes => 'numeric' },
 { oid => '1734', descr => 'natural logarithm',
   proname => 'ln', prorettype => 'numeric', proargtypes => 'numeric',
   prosrc => 'numeric_ln' },
 { oid => '1735', descr => 'natural logarithm',
-  proname => 'numeric_ln', prorettype => 'numeric', proargtypes => 'numeric',
-  prosrc => 'numeric_ln' },
+  proname => 'numeric_ln', prorettype => 'numeric', proargtypes => 'numeric' },
 { oid => '1736', descr => 'logarithm base m of n',
   proname => 'log', prorettype => 'numeric', proargtypes => 'numeric numeric',
   prosrc => 'numeric_log' },
 { oid => '1737', descr => 'logarithm base m of n',
   proname => 'numeric_log', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_log' },
+  proargtypes => 'numeric numeric' },
 { oid => '1738', descr => 'exponentiation',
   proname => 'pow', prorettype => 'numeric', proargtypes => 'numeric numeric',
   prosrc => 'numeric_power' },
@@ -4287,7 +3871,7 @@
   prosrc => 'numeric_power' },
 { oid => '1739',
   proname => 'numeric_power', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_power' },
+  proargtypes => 'numeric numeric' },
 { oid => '3281', descr => 'number of decimal digits in the fractional part',
   proname => 'scale', prorettype => 'int4', proargtypes => 'numeric',
   prosrc => 'numeric_scale' },
@@ -4317,7 +3901,7 @@
   prosrc => 'numeric_div_trunc' },
 { oid => '1980', descr => 'trunc(x/y)',
   proname => 'numeric_div_trunc', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_div_trunc' },
+  proargtypes => 'numeric numeric' },
 { oid => '2170', descr => 'bucket number of operand in equal-width histogram',
   proname => 'width_bucket', prorettype => 'int4',
   proargtypes => 'numeric numeric numeric int4',
@@ -4325,35 +3909,34 @@
 
 { oid => '1747',
   proname => 'time_pl_interval', prorettype => 'time',
-  proargtypes => 'time interval', prosrc => 'time_pl_interval' },
+  proargtypes => 'time interval' },
 { oid => '1748',
   proname => 'time_mi_interval', prorettype => 'time',
-  proargtypes => 'time interval', prosrc => 'time_mi_interval' },
+  proargtypes => 'time interval' },
 { oid => '1749',
   proname => 'timetz_pl_interval', prorettype => 'timetz',
-  proargtypes => 'timetz interval', prosrc => 'timetz_pl_interval' },
+  proargtypes => 'timetz interval' },
 { oid => '1750',
   proname => 'timetz_mi_interval', prorettype => 'timetz',
-  proargtypes => 'timetz interval', prosrc => 'timetz_mi_interval' },
+  proargtypes => 'timetz interval' },
 
 { oid => '1764', descr => 'increment by one',
-  proname => 'numeric_inc', prorettype => 'numeric', proargtypes => 'numeric',
-  prosrc => 'numeric_inc' },
+  proname => 'numeric_inc', prorettype => 'numeric', proargtypes => 'numeric' },
 { oid => '1766', descr => 'smaller of two',
   proname => 'numeric_smaller', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_smaller' },
+  proargtypes => 'numeric numeric' },
 { oid => '1767', descr => 'larger of two',
   proname => 'numeric_larger', prorettype => 'numeric',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_larger' },
+  proargtypes => 'numeric numeric' },
 { oid => '1769', descr => 'less-equal-greater',
   proname => 'numeric_cmp', prorettype => 'int4',
-  proargtypes => 'numeric numeric', prosrc => 'numeric_cmp' },
+  proargtypes => 'numeric numeric' },
 { oid => '3283', descr => 'sort support',
   proname => 'numeric_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'numeric_sortsupport' },
+  proargtypes => 'internal' },
 { oid => '1771',
   proname => 'numeric_uminus', prorettype => 'numeric',
-  proargtypes => 'numeric', prosrc => 'numeric_uminus' },
+  proargtypes => 'numeric' },
 { oid => '1779', descr => 'convert numeric to int8',
   proname => 'int8', prorettype => 'int8', proargtypes => 'numeric',
   prosrc => 'numeric_int8' },
@@ -4413,20 +3996,18 @@
   proargtypes => 'text text', prosrc => 'numeric_to_number' },
 { oid => '1778', descr => 'convert text to timestamp with time zone',
   proname => 'to_timestamp', provolatile => 's', prorettype => 'timestamptz',
-  proargtypes => 'text text', prosrc => 'to_timestamp' },
+  proargtypes => 'text text' },
 { oid => '1780', descr => 'convert text to date',
   proname => 'to_date', provolatile => 's', prorettype => 'date',
-  proargtypes => 'text text', prosrc => 'to_date' },
+  proargtypes => 'text text' },
 { oid => '1768', descr => 'format interval to text',
   proname => 'to_char', provolatile => 's', prorettype => 'text',
   proargtypes => 'interval text', prosrc => 'interval_to_char' },
 
 { oid => '1282', descr => 'quote an identifier for usage in a querystring',
-  proname => 'quote_ident', prorettype => 'text', proargtypes => 'text',
-  prosrc => 'quote_ident' },
+  proname => 'quote_ident', prorettype => 'text', proargtypes => 'text' },
 { oid => '1283', descr => 'quote a literal for usage in a querystring',
-  proname => 'quote_literal', prorettype => 'text', proargtypes => 'text',
-  prosrc => 'quote_literal' },
+  proname => 'quote_literal', prorettype => 'text', proargtypes => 'text' },
 { oid => '1285', descr => 'quote a data value for usage in a querystring',
   proname => 'quote_literal', prolang => '14', provolatile => 's',
   prorettype => 'text', proargtypes => 'anyelement',
@@ -4434,7 +4015,7 @@
 { oid => '1289',
   descr => 'quote a possibly-null literal for usage in a querystring',
   proname => 'quote_nullable', proisstrict => 'f', prorettype => 'text',
-  proargtypes => 'text', prosrc => 'quote_nullable' },
+  proargtypes => 'text' },
 { oid => '1290',
   descr => 'quote a possibly-null data value for usage in a querystring',
   proname => 'quote_nullable', prolang => '14', proisstrict => 'f',
@@ -4442,11 +4023,9 @@
   prosrc => 'select pg_catalog.quote_nullable($1::pg_catalog.text)' },
 
 { oid => '1798', descr => 'I/O',
-  proname => 'oidin', prorettype => 'oid', proargtypes => 'cstring',
-  prosrc => 'oidin' },
+  proname => 'oidin', prorettype => 'oid', proargtypes => 'cstring' },
 { oid => '1799', descr => 'I/O',
-  proname => 'oidout', prorettype => 'cstring', proargtypes => 'oid',
-  prosrc => 'oidout' },
+  proname => 'oidout', prorettype => 'cstring', proargtypes => 'oid' },
 
 { oid => '3058', descr => 'concatenate values',
   proname => 'concat', provariadic => 'any', proisstrict => 'f',
@@ -4488,302 +4067,279 @@
 # Selectivity estimators for LIKE and related operators
 { oid => '1814', descr => 'restriction selectivity of ILIKE',
   proname => 'iclikesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'iclikesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1815', descr => 'restriction selectivity of NOT ILIKE',
   proname => 'icnlikesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'icnlikesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1816', descr => 'join selectivity of ILIKE',
   proname => 'iclikejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'iclikejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1817', descr => 'join selectivity of NOT ILIKE',
   proname => 'icnlikejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'icnlikejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1818', descr => 'restriction selectivity of regex match',
   proname => 'regexeqsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'regexeqsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1819', descr => 'restriction selectivity of LIKE',
   proname => 'likesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'likesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1820',
   descr => 'restriction selectivity of case-insensitive regex match',
   proname => 'icregexeqsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'icregexeqsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1821', descr => 'restriction selectivity of regex non-match',
   proname => 'regexnesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'regexnesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1822', descr => 'restriction selectivity of NOT LIKE',
   proname => 'nlikesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'nlikesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1823',
   descr => 'restriction selectivity of case-insensitive regex non-match',
   proname => 'icregexnesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'icregexnesel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '1824', descr => 'join selectivity of regex match',
   proname => 'regexeqjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'regexeqjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1825', descr => 'join selectivity of LIKE',
   proname => 'likejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'likejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1826', descr => 'join selectivity of case-insensitive regex match',
   proname => 'icregexeqjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'icregexeqjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1827', descr => 'join selectivity of regex non-match',
   proname => 'regexnejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'regexnejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1828', descr => 'join selectivity of NOT LIKE',
   proname => 'nlikejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'nlikejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '1829',
   descr => 'join selectivity of case-insensitive regex non-match',
   proname => 'icregexnejoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'icregexnejoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '3437', descr => 'restriction selectivity of exact prefix',
   proname => 'prefixsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'prefixsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '3438', descr => 'join selectivity of exact prefix',
   proname => 'prefixjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'prefixjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 
 # Aggregate-related functions
 { oid => '1830', descr => 'aggregate final function',
-  proname => 'float8_avg', prorettype => 'float8', proargtypes => '_float8',
-  prosrc => 'float8_avg' },
+  proname => 'float8_avg', prorettype => 'float8', proargtypes => '_float8' },
 { oid => '2512', descr => 'aggregate final function',
-  proname => 'float8_var_pop', prorettype => 'float8', proargtypes => '_float8',
-  prosrc => 'float8_var_pop' },
+  proname => 'float8_var_pop', prorettype => 'float8', proargtypes => '_float8' },
 { oid => '1831', descr => 'aggregate final function',
   proname => 'float8_var_samp', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_var_samp' },
+  proargtypes => '_float8' },
 { oid => '2513', descr => 'aggregate final function',
   proname => 'float8_stddev_pop', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_stddev_pop' },
+  proargtypes => '_float8' },
 { oid => '1832', descr => 'aggregate final function',
   proname => 'float8_stddev_samp', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_stddev_samp' },
+  proargtypes => '_float8' },
 { oid => '1833', descr => 'aggregate transition function',
   proname => 'numeric_accum', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal numeric', prosrc => 'numeric_accum' },
+  proargtypes => 'internal numeric' },
 { oid => '3341', descr => 'aggregate combine function',
   proname => 'numeric_combine', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal internal', prosrc => 'numeric_combine' },
+  proargtypes => 'internal internal' },
 { oid => '2858', descr => 'aggregate transition function',
   proname => 'numeric_avg_accum', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal numeric', prosrc => 'numeric_avg_accum' },
+  proargtypes => 'internal numeric' },
 { oid => '3337', descr => 'aggregate combine function',
   proname => 'numeric_avg_combine', proisstrict => 'f',
-  prorettype => 'internal', proargtypes => 'internal internal',
-  prosrc => 'numeric_avg_combine' },
+  prorettype => 'internal', proargtypes => 'internal internal' },
 { oid => '2740', descr => 'aggregate serial function',
   proname => 'numeric_avg_serialize', prorettype => 'bytea',
-  proargtypes => 'internal', prosrc => 'numeric_avg_serialize' },
+  proargtypes => 'internal' },
 { oid => '2741', descr => 'aggregate deserial function',
   proname => 'numeric_avg_deserialize', prorettype => 'internal',
-  proargtypes => 'bytea internal', prosrc => 'numeric_avg_deserialize' },
+  proargtypes => 'bytea internal' },
 { oid => '3335', descr => 'aggregate serial function',
   proname => 'numeric_serialize', prorettype => 'bytea',
-  proargtypes => 'internal', prosrc => 'numeric_serialize' },
+  proargtypes => 'internal' },
 { oid => '3336', descr => 'aggregate deserial function',
   proname => 'numeric_deserialize', prorettype => 'internal',
-  proargtypes => 'bytea internal', prosrc => 'numeric_deserialize' },
+  proargtypes => 'bytea internal' },
 { oid => '3548', descr => 'aggregate transition function',
   proname => 'numeric_accum_inv', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal numeric', prosrc => 'numeric_accum_inv' },
+  proargtypes => 'internal numeric' },
 { oid => '1834', descr => 'aggregate transition function',
   proname => 'int2_accum', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int2', prosrc => 'int2_accum' },
+  proargtypes => 'internal int2' },
 { oid => '1835', descr => 'aggregate transition function',
   proname => 'int4_accum', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int4', prosrc => 'int4_accum' },
+  proargtypes => 'internal int4' },
 { oid => '1836', descr => 'aggregate transition function',
   proname => 'int8_accum', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int8', prosrc => 'int8_accum' },
+  proargtypes => 'internal int8' },
 { oid => '3338', descr => 'aggregate combine function',
   proname => 'numeric_poly_combine', proisstrict => 'f',
-  prorettype => 'internal', proargtypes => 'internal internal',
-  prosrc => 'numeric_poly_combine' },
+  prorettype => 'internal', proargtypes => 'internal internal' },
 { oid => '3339', descr => 'aggregate serial function',
   proname => 'numeric_poly_serialize', prorettype => 'bytea',
-  proargtypes => 'internal', prosrc => 'numeric_poly_serialize' },
+  proargtypes => 'internal' },
 { oid => '3340', descr => 'aggregate deserial function',
   proname => 'numeric_poly_deserialize', prorettype => 'internal',
-  proargtypes => 'bytea internal', prosrc => 'numeric_poly_deserialize' },
+  proargtypes => 'bytea internal' },
 { oid => '2746', descr => 'aggregate transition function',
   proname => 'int8_avg_accum', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int8', prosrc => 'int8_avg_accum' },
+  proargtypes => 'internal int8' },
 { oid => '3567', descr => 'aggregate transition function',
   proname => 'int2_accum_inv', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int2', prosrc => 'int2_accum_inv' },
+  proargtypes => 'internal int2' },
 { oid => '3568', descr => 'aggregate transition function',
   proname => 'int4_accum_inv', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int4', prosrc => 'int4_accum_inv' },
+  proargtypes => 'internal int4' },
 { oid => '3569', descr => 'aggregate transition function',
   proname => 'int8_accum_inv', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int8', prosrc => 'int8_accum_inv' },
+  proargtypes => 'internal int8' },
 { oid => '3387', descr => 'aggregate transition function',
   proname => 'int8_avg_accum_inv', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal int8', prosrc => 'int8_avg_accum_inv' },
+  proargtypes => 'internal int8' },
 { oid => '2785', descr => 'aggregate combine function',
   proname => 'int8_avg_combine', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal internal', prosrc => 'int8_avg_combine' },
+  proargtypes => 'internal internal' },
 { oid => '2786', descr => 'aggregate serial function',
   proname => 'int8_avg_serialize', prorettype => 'bytea',
-  proargtypes => 'internal', prosrc => 'int8_avg_serialize' },
+  proargtypes => 'internal' },
 { oid => '2787', descr => 'aggregate deserial function',
   proname => 'int8_avg_deserialize', prorettype => 'internal',
-  proargtypes => 'bytea internal', prosrc => 'int8_avg_deserialize' },
+  proargtypes => 'bytea internal' },
 { oid => '3324', descr => 'aggregate combine function',
   proname => 'int4_avg_combine', prorettype => '_int8',
-  proargtypes => '_int8 _int8', prosrc => 'int4_avg_combine' },
+  proargtypes => '_int8 _int8' },
 { oid => '3178', descr => 'aggregate final function',
   proname => 'numeric_sum', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_sum' },
+  proargtypes => 'internal' },
 { oid => '1837', descr => 'aggregate final function',
   proname => 'numeric_avg', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_avg' },
+  proargtypes => 'internal' },
 { oid => '2514', descr => 'aggregate final function',
   proname => 'numeric_var_pop', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_var_pop' },
+  proargtypes => 'internal' },
 { oid => '1838', descr => 'aggregate final function',
   proname => 'numeric_var_samp', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_var_samp' },
+  proargtypes => 'internal' },
 { oid => '2596', descr => 'aggregate final function',
   proname => 'numeric_stddev_pop', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_stddev_pop' },
+  proargtypes => 'internal' },
 { oid => '1839', descr => 'aggregate final function',
   proname => 'numeric_stddev_samp', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_stddev_samp' },
+  proargtypes => 'internal' },
 { oid => '1840', descr => 'aggregate transition function',
   proname => 'int2_sum', proisstrict => 'f', prorettype => 'int8',
-  proargtypes => 'int8 int2', prosrc => 'int2_sum' },
+  proargtypes => 'int8 int2' },
 { oid => '1841', descr => 'aggregate transition function',
   proname => 'int4_sum', proisstrict => 'f', prorettype => 'int8',
-  proargtypes => 'int8 int4', prosrc => 'int4_sum' },
+  proargtypes => 'int8 int4' },
 { oid => '1842', descr => 'aggregate transition function',
   proname => 'int8_sum', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'numeric int8', prosrc => 'int8_sum' },
+  proargtypes => 'numeric int8' },
 { oid => '3388', descr => 'aggregate final function',
   proname => 'numeric_poly_sum', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_poly_sum' },
+  proargtypes => 'internal' },
 { oid => '3389', descr => 'aggregate final function',
   proname => 'numeric_poly_avg', proisstrict => 'f', prorettype => 'numeric',
-  proargtypes => 'internal', prosrc => 'numeric_poly_avg' },
+  proargtypes => 'internal' },
 { oid => '3390', descr => 'aggregate final function',
   proname => 'numeric_poly_var_pop', proisstrict => 'f',
-  prorettype => 'numeric', proargtypes => 'internal',
-  prosrc => 'numeric_poly_var_pop' },
+  prorettype => 'numeric', proargtypes => 'internal' },
 { oid => '3391', descr => 'aggregate final function',
   proname => 'numeric_poly_var_samp', proisstrict => 'f',
-  prorettype => 'numeric', proargtypes => 'internal',
-  prosrc => 'numeric_poly_var_samp' },
+  prorettype => 'numeric', proargtypes => 'internal' },
 { oid => '3392', descr => 'aggregate final function',
   proname => 'numeric_poly_stddev_pop', proisstrict => 'f',
-  prorettype => 'numeric', proargtypes => 'internal',
-  prosrc => 'numeric_poly_stddev_pop' },
+  prorettype => 'numeric', proargtypes => 'internal' },
 { oid => '3393', descr => 'aggregate final function',
   proname => 'numeric_poly_stddev_samp', proisstrict => 'f',
-  prorettype => 'numeric', proargtypes => 'internal',
-  prosrc => 'numeric_poly_stddev_samp' },
+  prorettype => 'numeric', proargtypes => 'internal' },
 
 { oid => '1843', descr => 'aggregate transition function',
   proname => 'interval_accum', prorettype => '_interval',
-  proargtypes => '_interval interval', prosrc => 'interval_accum' },
+  proargtypes => '_interval interval' },
 { oid => '3325', descr => 'aggregate combine function',
   proname => 'interval_combine', prorettype => '_interval',
-  proargtypes => '_interval _interval', prosrc => 'interval_combine' },
+  proargtypes => '_interval _interval' },
 { oid => '3549', descr => 'aggregate transition function',
   proname => 'interval_accum_inv', prorettype => '_interval',
-  proargtypes => '_interval interval', prosrc => 'interval_accum_inv' },
+  proargtypes => '_interval interval' },
 { oid => '1844', descr => 'aggregate final function',
   proname => 'interval_avg', prorettype => 'interval',
-  proargtypes => '_interval', prosrc => 'interval_avg' },
+  proargtypes => '_interval' },
 { oid => '1962', descr => 'aggregate transition function',
   proname => 'int2_avg_accum', prorettype => '_int8',
-  proargtypes => '_int8 int2', prosrc => 'int2_avg_accum' },
+  proargtypes => '_int8 int2' },
 { oid => '1963', descr => 'aggregate transition function',
   proname => 'int4_avg_accum', prorettype => '_int8',
-  proargtypes => '_int8 int4', prosrc => 'int4_avg_accum' },
+  proargtypes => '_int8 int4' },
 { oid => '3570', descr => 'aggregate transition function',
   proname => 'int2_avg_accum_inv', prorettype => '_int8',
-  proargtypes => '_int8 int2', prosrc => 'int2_avg_accum_inv' },
+  proargtypes => '_int8 int2' },
 { oid => '3571', descr => 'aggregate transition function',
   proname => 'int4_avg_accum_inv', prorettype => '_int8',
-  proargtypes => '_int8 int4', prosrc => 'int4_avg_accum_inv' },
+  proargtypes => '_int8 int4' },
 { oid => '1964', descr => 'aggregate final function',
-  proname => 'int8_avg', prorettype => 'numeric', proargtypes => '_int8',
-  prosrc => 'int8_avg' },
+  proname => 'int8_avg', prorettype => 'numeric', proargtypes => '_int8' },
 { oid => '3572', descr => 'aggregate final function',
-  proname => 'int2int4_sum', prorettype => 'int8', proargtypes => '_int8',
-  prosrc => 'int2int4_sum' },
+  proname => 'int2int4_sum', prorettype => 'int8', proargtypes => '_int8' },
 { oid => '2805', descr => 'aggregate transition function',
   proname => 'int8inc_float8_float8', prorettype => 'int8',
-  proargtypes => 'int8 float8 float8', prosrc => 'int8inc_float8_float8' },
+  proargtypes => 'int8 float8 float8' },
 { oid => '2806', descr => 'aggregate transition function',
   proname => 'float8_regr_accum', prorettype => '_float8',
-  proargtypes => '_float8 float8 float8', prosrc => 'float8_regr_accum' },
+  proargtypes => '_float8 float8 float8' },
 { oid => '3342', descr => 'aggregate combine function',
   proname => 'float8_regr_combine', prorettype => '_float8',
-  proargtypes => '_float8 _float8', prosrc => 'float8_regr_combine' },
+  proargtypes => '_float8 _float8' },
 { oid => '2807', descr => 'aggregate final function',
   proname => 'float8_regr_sxx', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_regr_sxx' },
+  proargtypes => '_float8' },
 { oid => '2808', descr => 'aggregate final function',
   proname => 'float8_regr_syy', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_regr_syy' },
+  proargtypes => '_float8' },
 { oid => '2809', descr => 'aggregate final function',
   proname => 'float8_regr_sxy', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_regr_sxy' },
+  proargtypes => '_float8' },
 { oid => '2810', descr => 'aggregate final function',
   proname => 'float8_regr_avgx', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_regr_avgx' },
+  proargtypes => '_float8' },
 { oid => '2811', descr => 'aggregate final function',
   proname => 'float8_regr_avgy', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_regr_avgy' },
+  proargtypes => '_float8' },
 { oid => '2812', descr => 'aggregate final function',
-  proname => 'float8_regr_r2', prorettype => 'float8', proargtypes => '_float8',
-  prosrc => 'float8_regr_r2' },
+  proname => 'float8_regr_r2', prorettype => 'float8', proargtypes => '_float8' },
 { oid => '2813', descr => 'aggregate final function',
   proname => 'float8_regr_slope', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_regr_slope' },
+  proargtypes => '_float8' },
 { oid => '2814', descr => 'aggregate final function',
   proname => 'float8_regr_intercept', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_regr_intercept' },
+  proargtypes => '_float8' },
 { oid => '2815', descr => 'aggregate final function',
   proname => 'float8_covar_pop', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_covar_pop' },
+  proargtypes => '_float8' },
 { oid => '2816', descr => 'aggregate final function',
   proname => 'float8_covar_samp', prorettype => 'float8',
-  proargtypes => '_float8', prosrc => 'float8_covar_samp' },
+  proargtypes => '_float8' },
 { oid => '2817', descr => 'aggregate final function',
-  proname => 'float8_corr', prorettype => 'float8', proargtypes => '_float8',
-  prosrc => 'float8_corr' },
+  proname => 'float8_corr', prorettype => 'float8', proargtypes => '_float8' },
 
 { oid => '3535', descr => 'aggregate transition function',
   proname => 'string_agg_transfn', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal text text', prosrc => 'string_agg_transfn' },
+  proargtypes => 'internal text text' },
 { oid => '3536', descr => 'aggregate final function',
   proname => 'string_agg_finalfn', proisstrict => 'f', prorettype => 'text',
-  proargtypes => 'internal', prosrc => 'string_agg_finalfn' },
+  proargtypes => 'internal' },
 { oid => '3538', descr => 'concatenate aggregate input into a string',
   proname => 'string_agg', prokind => 'a', proisstrict => 'f',
   prorettype => 'text', proargtypes => 'text text',
   prosrc => 'aggregate_dummy' },
 { oid => '3543', descr => 'aggregate transition function',
   proname => 'bytea_string_agg_transfn', proisstrict => 'f',
-  prorettype => 'internal', proargtypes => 'internal bytea bytea',
-  prosrc => 'bytea_string_agg_transfn' },
+  prorettype => 'internal', proargtypes => 'internal bytea bytea' },
 { oid => '3544', descr => 'aggregate final function',
   proname => 'bytea_string_agg_finalfn', proisstrict => 'f',
-  prorettype => 'bytea', proargtypes => 'internal',
-  prosrc => 'bytea_string_agg_finalfn' },
+  prorettype => 'bytea', proargtypes => 'internal' },
 { oid => '3545', descr => 'concatenate aggregate input into a bytea',
   proname => 'string_agg', prokind => 'a', proisstrict => 'f',
   prorettype => 'bytea', proargtypes => 'bytea bytea',
@@ -4806,117 +4362,93 @@
 
 { oid => '1850',
   proname => 'int28eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int8', prosrc => 'int28eq' },
+  proargtypes => 'int2 int8' },
 { oid => '1851',
   proname => 'int28ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int8', prosrc => 'int28ne' },
+  proargtypes => 'int2 int8' },
 { oid => '1852',
   proname => 'int28lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int8', prosrc => 'int28lt' },
+  proargtypes => 'int2 int8' },
 { oid => '1853',
   proname => 'int28gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int8', prosrc => 'int28gt' },
+  proargtypes => 'int2 int8' },
 { oid => '1854',
   proname => 'int28le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int8', prosrc => 'int28le' },
+  proargtypes => 'int2 int8' },
 { oid => '1855',
   proname => 'int28ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int2 int8', prosrc => 'int28ge' },
+  proargtypes => 'int2 int8' },
 
 { oid => '1856',
   proname => 'int82eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int2', prosrc => 'int82eq' },
+  proargtypes => 'int8 int2' },
 { oid => '1857',
   proname => 'int82ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int2', prosrc => 'int82ne' },
+  proargtypes => 'int8 int2' },
 { oid => '1858',
   proname => 'int82lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int2', prosrc => 'int82lt' },
+  proargtypes => 'int8 int2' },
 { oid => '1859',
   proname => 'int82gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int2', prosrc => 'int82gt' },
+  proargtypes => 'int8 int2' },
 { oid => '1860',
   proname => 'int82le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int2', prosrc => 'int82le' },
+  proargtypes => 'int8 int2' },
 { oid => '1861',
   proname => 'int82ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'int8 int2', prosrc => 'int82ge' },
+  proargtypes => 'int8 int2' },
 
 { oid => '1892',
-  proname => 'int2and', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2and' },
+  proname => 'int2and', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '1893',
-  proname => 'int2or', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2or' },
+  proname => 'int2or', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '1894',
-  proname => 'int2xor', prorettype => 'int2', proargtypes => 'int2 int2',
-  prosrc => 'int2xor' },
+  proname => 'int2xor', prorettype => 'int2', proargtypes => 'int2 int2' },
 { oid => '1895',
-  proname => 'int2not', prorettype => 'int2', proargtypes => 'int2',
-  prosrc => 'int2not' },
+  proname => 'int2not', prorettype => 'int2', proargtypes => 'int2' },
 { oid => '1896',
-  proname => 'int2shl', prorettype => 'int2', proargtypes => 'int2 int4',
-  prosrc => 'int2shl' },
+  proname => 'int2shl', prorettype => 'int2', proargtypes => 'int2 int4' },
 { oid => '1897',
-  proname => 'int2shr', prorettype => 'int2', proargtypes => 'int2 int4',
-  prosrc => 'int2shr' },
+  proname => 'int2shr', prorettype => 'int2', proargtypes => 'int2 int4' },
 
 { oid => '1898',
-  proname => 'int4and', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4and' },
+  proname => 'int4and', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '1899',
-  proname => 'int4or', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4or' },
+  proname => 'int4or', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '1900',
-  proname => 'int4xor', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4xor' },
+  proname => 'int4xor', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '1901',
-  proname => 'int4not', prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'int4not' },
+  proname => 'int4not', prorettype => 'int4', proargtypes => 'int4' },
 { oid => '1902',
-  proname => 'int4shl', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4shl' },
+  proname => 'int4shl', prorettype => 'int4', proargtypes => 'int4 int4' },
 { oid => '1903',
-  proname => 'int4shr', prorettype => 'int4', proargtypes => 'int4 int4',
-  prosrc => 'int4shr' },
+  proname => 'int4shr', prorettype => 'int4', proargtypes => 'int4 int4' },
 
 { oid => '1904',
-  proname => 'int8and', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8and' },
+  proname => 'int8and', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '1905',
-  proname => 'int8or', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8or' },
+  proname => 'int8or', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '1906',
-  proname => 'int8xor', prorettype => 'int8', proargtypes => 'int8 int8',
-  prosrc => 'int8xor' },
+  proname => 'int8xor', prorettype => 'int8', proargtypes => 'int8 int8' },
 { oid => '1907',
-  proname => 'int8not', prorettype => 'int8', proargtypes => 'int8',
-  prosrc => 'int8not' },
+  proname => 'int8not', prorettype => 'int8', proargtypes => 'int8' },
 { oid => '1908',
-  proname => 'int8shl', prorettype => 'int8', proargtypes => 'int8 int4',
-  prosrc => 'int8shl' },
+  proname => 'int8shl', prorettype => 'int8', proargtypes => 'int8 int4' },
 { oid => '1909',
-  proname => 'int8shr', prorettype => 'int8', proargtypes => 'int8 int4',
-  prosrc => 'int8shr' },
+  proname => 'int8shr', prorettype => 'int8', proargtypes => 'int8 int4' },
 
 { oid => '1910',
-  proname => 'int8up', prorettype => 'int8', proargtypes => 'int8',
-  prosrc => 'int8up' },
+  proname => 'int8up', prorettype => 'int8', proargtypes => 'int8' },
 { oid => '1911',
-  proname => 'int2up', prorettype => 'int2', proargtypes => 'int2',
-  prosrc => 'int2up' },
+  proname => 'int2up', prorettype => 'int2', proargtypes => 'int2' },
 { oid => '1912',
-  proname => 'int4up', prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'int4up' },
+  proname => 'int4up', prorettype => 'int4', proargtypes => 'int4' },
 { oid => '1913',
-  proname => 'float4up', prorettype => 'float4', proargtypes => 'float4',
-  prosrc => 'float4up' },
+  proname => 'float4up', prorettype => 'float4', proargtypes => 'float4' },
 { oid => '1914',
-  proname => 'float8up', prorettype => 'float8', proargtypes => 'float8',
-  prosrc => 'float8up' },
+  proname => 'float8up', prorettype => 'float8', proargtypes => 'float8' },
 { oid => '1915',
-  proname => 'numeric_uplus', prorettype => 'numeric', proargtypes => 'numeric',
-  prosrc => 'numeric_uplus' },
+  proname => 'numeric_uplus', prorettype => 'numeric', proargtypes => 'numeric' },
 
 { oid => '1922', descr => 'user privilege on relation by username, rel name',
   proname => 'has_table_privilege', provolatile => 's', prorettype => 'bool',
@@ -5044,117 +4576,95 @@
 
 { oid => '3355', descr => 'I/O',
   proname => 'pg_ndistinct_in', prorettype => 'pg_ndistinct',
-  proargtypes => 'cstring', prosrc => 'pg_ndistinct_in' },
+  proargtypes => 'cstring' },
 { oid => '3356', descr => 'I/O',
   proname => 'pg_ndistinct_out', prorettype => 'cstring',
-  proargtypes => 'pg_ndistinct', prosrc => 'pg_ndistinct_out' },
+  proargtypes => 'pg_ndistinct' },
 { oid => '3357', descr => 'I/O',
   proname => 'pg_ndistinct_recv', provolatile => 's',
-  prorettype => 'pg_ndistinct', proargtypes => 'internal',
-  prosrc => 'pg_ndistinct_recv' },
+  prorettype => 'pg_ndistinct', proargtypes => 'internal' },
 { oid => '3358', descr => 'I/O',
   proname => 'pg_ndistinct_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'pg_ndistinct', prosrc => 'pg_ndistinct_send' },
+  proargtypes => 'pg_ndistinct' },
 
 { oid => '3404', descr => 'I/O',
   proname => 'pg_dependencies_in', prorettype => 'pg_dependencies',
-  proargtypes => 'cstring', prosrc => 'pg_dependencies_in' },
+  proargtypes => 'cstring' },
 { oid => '3405', descr => 'I/O',
   proname => 'pg_dependencies_out', prorettype => 'cstring',
-  proargtypes => 'pg_dependencies', prosrc => 'pg_dependencies_out' },
+  proargtypes => 'pg_dependencies' },
 { oid => '3406', descr => 'I/O',
   proname => 'pg_dependencies_recv', provolatile => 's',
-  prorettype => 'pg_dependencies', proargtypes => 'internal',
-  prosrc => 'pg_dependencies_recv' },
+  prorettype => 'pg_dependencies', proargtypes => 'internal' },
 { oid => '3407', descr => 'I/O',
   proname => 'pg_dependencies_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'pg_dependencies', prosrc => 'pg_dependencies_send' },
+  proargtypes => 'pg_dependencies' },
 
 { oid => '1928', descr => 'statistics: number of scans done for table/index',
   proname => 'pg_stat_get_numscans', provolatile => 's', proparallel => 'r',
-  prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_numscans' },
+  prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1929', descr => 'statistics: number of tuples read by seqscan',
   proname => 'pg_stat_get_tuples_returned', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_tuples_returned' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1930', descr => 'statistics: number of tuples fetched by idxscan',
   proname => 'pg_stat_get_tuples_fetched', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_tuples_fetched' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1931', descr => 'statistics: number of tuples inserted',
   proname => 'pg_stat_get_tuples_inserted', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_tuples_inserted' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1932', descr => 'statistics: number of tuples updated',
   proname => 'pg_stat_get_tuples_updated', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_tuples_updated' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1933', descr => 'statistics: number of tuples deleted',
   proname => 'pg_stat_get_tuples_deleted', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_tuples_deleted' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1972', descr => 'statistics: number of tuples hot updated',
   proname => 'pg_stat_get_tuples_hot_updated', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_tuples_hot_updated' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2878', descr => 'statistics: number of live tuples',
   proname => 'pg_stat_get_live_tuples', provolatile => 's', proparallel => 'r',
-  prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_live_tuples' },
+  prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2879', descr => 'statistics: number of dead tuples',
   proname => 'pg_stat_get_dead_tuples', provolatile => 's', proparallel => 'r',
-  prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_dead_tuples' },
+  prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3177',
   descr => 'statistics: number of tuples changed since last analyze',
   proname => 'pg_stat_get_mod_since_analyze', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_mod_since_analyze' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1934', descr => 'statistics: number of blocks fetched',
   proname => 'pg_stat_get_blocks_fetched', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_blocks_fetched' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1935', descr => 'statistics: number of blocks found in cache',
   proname => 'pg_stat_get_blocks_hit', provolatile => 's', proparallel => 'r',
-  prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_blocks_hit' },
+  prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2781', descr => 'statistics: last manual vacuum time for a table',
   proname => 'pg_stat_get_last_vacuum_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_last_vacuum_time' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid' },
 { oid => '2782', descr => 'statistics: last auto vacuum time for a table',
   proname => 'pg_stat_get_last_autovacuum_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_last_autovacuum_time' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid' },
 { oid => '2783', descr => 'statistics: last manual analyze time for a table',
   proname => 'pg_stat_get_last_analyze_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_last_analyze_time' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid' },
 { oid => '2784', descr => 'statistics: last auto analyze time for a table',
   proname => 'pg_stat_get_last_autoanalyze_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_last_autoanalyze_time' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid' },
 { oid => '3054', descr => 'statistics: number of manual vacuums for a table',
   proname => 'pg_stat_get_vacuum_count', provolatile => 's', proparallel => 'r',
-  prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_vacuum_count' },
+  prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3055', descr => 'statistics: number of auto vacuums for a table',
   proname => 'pg_stat_get_autovacuum_count', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_autovacuum_count' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3056', descr => 'statistics: number of manual analyzes for a table',
   proname => 'pg_stat_get_analyze_count', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_analyze_count' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3057', descr => 'statistics: number of auto analyzes for a table',
   proname => 'pg_stat_get_autoanalyze_count', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_autoanalyze_count' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1936', descr => 'statistics: currently active backend IDs',
   proname => 'pg_stat_get_backend_idset', prorows => '100', proretset => 't',
   provolatile => 's', proparallel => 'r', prorettype => 'int4',
-  proargtypes => '', prosrc => 'pg_stat_get_backend_idset' },
+  proargtypes => '' },
 { oid => '2022',
   descr => 'statistics: information about currently active backends',
   proname => 'pg_stat_get_activity', prorows => '100', proisstrict => 'f',
@@ -5162,8 +4672,7 @@
   prorettype => 'record', proargtypes => 'int4',
   proallargtypes => '{int4,oid,int4,oid,text,text,text,text,text,timestamptz,timestamptz,timestamptz,timestamptz,inet,text,int4,xid,xid,text,bool,text,text,int4,bool,text}',
   proargmodes => '{i,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{pid,datid,pid,usesysid,application_name,state,query,wait_event_type,wait_event,xact_start,query_start,backend_start,state_change,client_addr,client_hostname,client_port,backend_xid,backend_xmin,backend_type,ssl,sslversion,sslcipher,sslbits,sslcompression,sslclientdn}',
-  prosrc => 'pg_stat_get_activity' },
+  proargnames => '{pid,datid,pid,usesysid,application_name,state,query,wait_event_type,wait_event,xact_start,query_start,backend_start,state_change,client_addr,client_hostname,client_port,backend_xid,backend_xmin,backend_type,ssl,sslversion,sslcipher,sslbits,sslcompression,sslclientdn}' },
 { oid => '3318',
   descr => 'statistics: information about progress of backends running maintenance command',
   proname => 'pg_stat_get_progress_info', prorows => '100', proretset => 't',
@@ -5171,8 +4680,7 @@
   proargtypes => 'text',
   proallargtypes => '{text,int4,oid,oid,int8,int8,int8,int8,int8,int8,int8,int8,int8,int8}',
   proargmodes => '{i,o,o,o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{cmdtype,pid,datid,relid,param1,param2,param3,param4,param5,param6,param7,param8,param9,param10}',
-  prosrc => 'pg_stat_get_progress_info' },
+  proargnames => '{cmdtype,pid,datid,relid,param1,param2,param3,param4,param5,param6,param7,param8,param9,param10}' },
 { oid => '3099',
   descr => 'statistics: information about currently active replication',
   proname => 'pg_stat_get_wal_senders', prorows => '10', proisstrict => 'f',
@@ -5180,341 +4688,275 @@
   prorettype => 'record', proargtypes => '',
   proallargtypes => '{int4,text,pg_lsn,pg_lsn,pg_lsn,pg_lsn,interval,interval,interval,int4,text}',
   proargmodes => '{o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{pid,state,sent_lsn,write_lsn,flush_lsn,replay_lsn,write_lag,flush_lag,replay_lag,sync_priority,sync_state}',
-  prosrc => 'pg_stat_get_wal_senders' },
+  proargnames => '{pid,state,sent_lsn,write_lsn,flush_lsn,replay_lsn,write_lag,flush_lag,replay_lag,sync_priority,sync_state}' },
 { oid => '3317', descr => 'statistics: information about WAL receiver',
   proname => 'pg_stat_get_wal_receiver', proisstrict => 'f', provolatile => 's',
   proparallel => 'r', prorettype => 'record', proargtypes => '',
   proallargtypes => '{int4,text,pg_lsn,int4,pg_lsn,int4,timestamptz,timestamptz,pg_lsn,timestamptz,text,text,int4,text}',
   proargmodes => '{o,o,o,o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{pid,status,receive_start_lsn,receive_start_tli,received_lsn,received_tli,last_msg_send_time,last_msg_receipt_time,latest_end_lsn,latest_end_time,slot_name,sender_host,sender_port,conninfo}',
-  prosrc => 'pg_stat_get_wal_receiver' },
+  proargnames => '{pid,status,receive_start_lsn,receive_start_tli,received_lsn,received_tli,last_msg_send_time,last_msg_receipt_time,latest_end_lsn,latest_end_time,slot_name,sender_host,sender_port,conninfo}' },
 { oid => '6118', descr => 'statistics: information about subscription',
   proname => 'pg_stat_get_subscription', proisstrict => 'f', provolatile => 's',
   proparallel => 'r', prorettype => 'record', proargtypes => 'oid',
   proallargtypes => '{oid,oid,oid,int4,pg_lsn,timestamptz,timestamptz,pg_lsn,timestamptz}',
   proargmodes => '{i,o,o,o,o,o,o,o,o}',
-  proargnames => '{subid,subid,relid,pid,received_lsn,last_msg_send_time,last_msg_receipt_time,latest_end_lsn,latest_end_time}',
-  prosrc => 'pg_stat_get_subscription' },
+  proargnames => '{subid,subid,relid,pid,received_lsn,last_msg_send_time,last_msg_receipt_time,latest_end_lsn,latest_end_time}' },
 { oid => '2026', descr => 'statistics: current backend PID',
   proname => 'pg_backend_pid', provolatile => 's', proparallel => 'r',
-  prorettype => 'int4', proargtypes => '', prosrc => 'pg_backend_pid' },
+  prorettype => 'int4', proargtypes => '' },
 { oid => '1937', descr => 'statistics: PID of backend',
   proname => 'pg_stat_get_backend_pid', provolatile => 's', proparallel => 'r',
-  prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_pid' },
+  prorettype => 'int4', proargtypes => 'int4' },
 { oid => '1938', descr => 'statistics: database ID of backend',
   proname => 'pg_stat_get_backend_dbid', provolatile => 's', proparallel => 'r',
-  prorettype => 'oid', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_dbid' },
+  prorettype => 'oid', proargtypes => 'int4' },
 { oid => '1939', descr => 'statistics: user ID of backend',
   proname => 'pg_stat_get_backend_userid', provolatile => 's',
-  proparallel => 'r', prorettype => 'oid', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_userid' },
+  proparallel => 'r', prorettype => 'oid', proargtypes => 'int4' },
 { oid => '1940', descr => 'statistics: current query of backend',
   proname => 'pg_stat_get_backend_activity', provolatile => 's',
-  proparallel => 'r', prorettype => 'text', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_activity' },
+  proparallel => 'r', prorettype => 'text', proargtypes => 'int4' },
 { oid => '2788',
   descr => 'statistics: wait event type on which backend is currently waiting',
   proname => 'pg_stat_get_backend_wait_event_type', provolatile => 's',
-  proparallel => 'r', prorettype => 'text', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_wait_event_type' },
+  proparallel => 'r', prorettype => 'text', proargtypes => 'int4' },
 { oid => '2853',
   descr => 'statistics: wait event on which backend is currently waiting',
   proname => 'pg_stat_get_backend_wait_event', provolatile => 's',
-  proparallel => 'r', prorettype => 'text', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_wait_event' },
+  proparallel => 'r', prorettype => 'text', proargtypes => 'int4' },
 { oid => '2094',
   descr => 'statistics: start time for current query of backend',
   proname => 'pg_stat_get_backend_activity_start', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_activity_start' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'int4' },
 { oid => '2857',
   descr => 'statistics: start time for backend\'s current transaction',
   proname => 'pg_stat_get_backend_xact_start', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_xact_start' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'int4' },
 { oid => '1391',
   descr => 'statistics: start time for current backend session',
   proname => 'pg_stat_get_backend_start', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_start' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'int4' },
 { oid => '1392',
   descr => 'statistics: address of client connected to backend',
   proname => 'pg_stat_get_backend_client_addr', provolatile => 's',
-  proparallel => 'r', prorettype => 'inet', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_client_addr' },
+  proparallel => 'r', prorettype => 'inet', proargtypes => 'int4' },
 { oid => '1393',
   descr => 'statistics: port number of client connected to backend',
   proname => 'pg_stat_get_backend_client_port', provolatile => 's',
-  proparallel => 'r', prorettype => 'int4', proargtypes => 'int4',
-  prosrc => 'pg_stat_get_backend_client_port' },
+  proparallel => 'r', prorettype => 'int4', proargtypes => 'int4' },
 { oid => '1941', descr => 'statistics: number of backends in database',
   proname => 'pg_stat_get_db_numbackends', provolatile => 's',
-  proparallel => 'r', prorettype => 'int4', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_numbackends' },
+  proparallel => 'r', prorettype => 'int4', proargtypes => 'oid' },
 { oid => '1942', descr => 'statistics: transactions committed',
   proname => 'pg_stat_get_db_xact_commit', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_xact_commit' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1943', descr => 'statistics: transactions rolled back',
   proname => 'pg_stat_get_db_xact_rollback', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_xact_rollback' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1944', descr => 'statistics: blocks fetched for database',
   proname => 'pg_stat_get_db_blocks_fetched', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_blocks_fetched' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '1945', descr => 'statistics: blocks found in cache for database',
   proname => 'pg_stat_get_db_blocks_hit', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_blocks_hit' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2758', descr => 'statistics: tuples returned for database',
   proname => 'pg_stat_get_db_tuples_returned', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_tuples_returned' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2759', descr => 'statistics: tuples fetched for database',
   proname => 'pg_stat_get_db_tuples_fetched', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_tuples_fetched' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2760', descr => 'statistics: tuples inserted in database',
   proname => 'pg_stat_get_db_tuples_inserted', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_tuples_inserted' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2761', descr => 'statistics: tuples updated in database',
   proname => 'pg_stat_get_db_tuples_updated', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_tuples_updated' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2762', descr => 'statistics: tuples deleted in database',
   proname => 'pg_stat_get_db_tuples_deleted', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_tuples_deleted' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3065',
   descr => 'statistics: recovery conflicts in database caused by drop tablespace',
   proname => 'pg_stat_get_db_conflict_tablespace', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_conflict_tablespace' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3066',
   descr => 'statistics: recovery conflicts in database caused by relation lock',
   proname => 'pg_stat_get_db_conflict_lock', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_conflict_lock' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3067',
   descr => 'statistics: recovery conflicts in database caused by snapshot expiry',
   proname => 'pg_stat_get_db_conflict_snapshot', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_conflict_snapshot' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3068',
   descr => 'statistics: recovery conflicts in database caused by shared buffer pin',
   proname => 'pg_stat_get_db_conflict_bufferpin', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_conflict_bufferpin' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3069',
   descr => 'statistics: recovery conflicts in database caused by buffer deadlock',
   proname => 'pg_stat_get_db_conflict_startup_deadlock', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_conflict_startup_deadlock' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3070', descr => 'statistics: recovery conflicts in database',
   proname => 'pg_stat_get_db_conflict_all', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_conflict_all' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3152', descr => 'statistics: deadlocks detected in database',
   proname => 'pg_stat_get_db_deadlocks', provolatile => 's', proparallel => 'r',
-  prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_deadlocks' },
+  prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3074', descr => 'statistics: last reset for a database',
   proname => 'pg_stat_get_db_stat_reset_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_stat_reset_time' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => 'oid' },
 { oid => '3150', descr => 'statistics: number of temporary files written',
   proname => 'pg_stat_get_db_temp_files', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_temp_files' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3151',
   descr => 'statistics: number of bytes in temporary files written',
   proname => 'pg_stat_get_db_temp_bytes', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_temp_bytes' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2844', descr => 'statistics: block read time, in milliseconds',
   proname => 'pg_stat_get_db_blk_read_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_blk_read_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid' },
 { oid => '2845', descr => 'statistics: block write time, in milliseconds',
   proname => 'pg_stat_get_db_blk_write_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_db_blk_write_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid' },
 { oid => '3195', descr => 'statistics: information about WAL archiver',
   proname => 'pg_stat_get_archiver', proisstrict => 'f', provolatile => 's',
   proparallel => 'r', prorettype => 'record', proargtypes => '',
   proallargtypes => '{int8,text,timestamptz,int8,text,timestamptz,timestamptz}',
   proargmodes => '{o,o,o,o,o,o,o}',
-  proargnames => '{archived_count,last_archived_wal,last_archived_time,failed_count,last_failed_wal,last_failed_time,stats_reset}',
-  prosrc => 'pg_stat_get_archiver' },
+  proargnames => '{archived_count,last_archived_wal,last_archived_time,failed_count,last_failed_wal,last_failed_time,stats_reset}' },
 { oid => '2769',
   descr => 'statistics: number of timed checkpoints started by the bgwriter',
   proname => 'pg_stat_get_bgwriter_timed_checkpoints', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => '',
-  prosrc => 'pg_stat_get_bgwriter_timed_checkpoints' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => '' },
 { oid => '2770',
   descr => 'statistics: number of backend requested checkpoints started by the bgwriter',
   proname => 'pg_stat_get_bgwriter_requested_checkpoints', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => '',
-  prosrc => 'pg_stat_get_bgwriter_requested_checkpoints' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => '' },
 { oid => '2771',
   descr => 'statistics: number of buffers written by the bgwriter during checkpoints',
   proname => 'pg_stat_get_bgwriter_buf_written_checkpoints', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => '',
-  prosrc => 'pg_stat_get_bgwriter_buf_written_checkpoints' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => '' },
 { oid => '2772',
   descr => 'statistics: number of buffers written by the bgwriter for cleaning dirty buffers',
   proname => 'pg_stat_get_bgwriter_buf_written_clean', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => '',
-  prosrc => 'pg_stat_get_bgwriter_buf_written_clean' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => '' },
 { oid => '2773',
   descr => 'statistics: number of times the bgwriter stopped processing when it had written too many buffers while cleaning',
   proname => 'pg_stat_get_bgwriter_maxwritten_clean', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => '',
-  prosrc => 'pg_stat_get_bgwriter_maxwritten_clean' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => '' },
 { oid => '3075', descr => 'statistics: last reset for the bgwriter',
   proname => 'pg_stat_get_bgwriter_stat_reset_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => '',
-  prosrc => 'pg_stat_get_bgwriter_stat_reset_time' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => '' },
 { oid => '3160',
   descr => 'statistics: checkpoint time spent writing buffers to disk, in milliseconds',
   proname => 'pg_stat_get_checkpoint_write_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'float8', proargtypes => '',
-  prosrc => 'pg_stat_get_checkpoint_write_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => '' },
 { oid => '3161',
   descr => 'statistics: checkpoint time spent synchronizing buffers to disk, in milliseconds',
   proname => 'pg_stat_get_checkpoint_sync_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'float8', proargtypes => '',
-  prosrc => 'pg_stat_get_checkpoint_sync_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => '' },
 { oid => '2775', descr => 'statistics: number of buffers written by backends',
   proname => 'pg_stat_get_buf_written_backend', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => '',
-  prosrc => 'pg_stat_get_buf_written_backend' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => '' },
 { oid => '3063',
   descr => 'statistics: number of backend buffer writes that did their own fsync',
   proname => 'pg_stat_get_buf_fsync_backend', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => '',
-  prosrc => 'pg_stat_get_buf_fsync_backend' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => '' },
 { oid => '2859', descr => 'statistics: number of buffer allocations',
   proname => 'pg_stat_get_buf_alloc', provolatile => 's', proparallel => 'r',
-  prorettype => 'int8', proargtypes => '', prosrc => 'pg_stat_get_buf_alloc' },
+  prorettype => 'int8', proargtypes => '' },
 
 { oid => '2978', descr => 'statistics: number of function calls',
   proname => 'pg_stat_get_function_calls', provolatile => 's',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_function_calls' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '2979',
   descr => 'statistics: total execution time of function, in milliseconds',
   proname => 'pg_stat_get_function_total_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_function_total_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid' },
 { oid => '2980',
   descr => 'statistics: self execution time of function, in milliseconds',
   proname => 'pg_stat_get_function_self_time', provolatile => 's',
-  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_function_self_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid' },
 
 { oid => '3037',
   descr => 'statistics: number of scans done for table/index in current transaction',
   proname => 'pg_stat_get_xact_numscans', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_numscans' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3038',
   descr => 'statistics: number of tuples read by seqscan in current transaction',
   proname => 'pg_stat_get_xact_tuples_returned', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_tuples_returned' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3039',
   descr => 'statistics: number of tuples fetched by idxscan in current transaction',
   proname => 'pg_stat_get_xact_tuples_fetched', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_tuples_fetched' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3040',
   descr => 'statistics: number of tuples inserted in current transaction',
   proname => 'pg_stat_get_xact_tuples_inserted', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_tuples_inserted' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3041',
   descr => 'statistics: number of tuples updated in current transaction',
   proname => 'pg_stat_get_xact_tuples_updated', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_tuples_updated' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3042',
   descr => 'statistics: number of tuples deleted in current transaction',
   proname => 'pg_stat_get_xact_tuples_deleted', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_tuples_deleted' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3043',
   descr => 'statistics: number of tuples hot updated in current transaction',
   proname => 'pg_stat_get_xact_tuples_hot_updated', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_tuples_hot_updated' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3044',
   descr => 'statistics: number of blocks fetched in current transaction',
   proname => 'pg_stat_get_xact_blocks_fetched', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_blocks_fetched' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3045',
   descr => 'statistics: number of blocks found in cache in current transaction',
   proname => 'pg_stat_get_xact_blocks_hit', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_blocks_hit' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3046',
   descr => 'statistics: number of function calls in current transaction',
   proname => 'pg_stat_get_xact_function_calls', provolatile => 'v',
-  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_function_calls' },
+  proparallel => 'r', prorettype => 'int8', proargtypes => 'oid' },
 { oid => '3047',
   descr => 'statistics: total execution time of function in current transaction, in milliseconds',
   proname => 'pg_stat_get_xact_function_total_time', provolatile => 'v',
-  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_function_total_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid' },
 { oid => '3048',
   descr => 'statistics: self execution time of function in current transaction, in milliseconds',
   proname => 'pg_stat_get_xact_function_self_time', provolatile => 'v',
-  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid',
-  prosrc => 'pg_stat_get_xact_function_self_time' },
+  proparallel => 'r', prorettype => 'float8', proargtypes => 'oid' },
 
 { oid => '3788',
   descr => 'statistics: timestamp of the current statistics snapshot',
   proname => 'pg_stat_get_snapshot_timestamp', provolatile => 's',
-  proparallel => 'r', prorettype => 'timestamptz', proargtypes => '',
-  prosrc => 'pg_stat_get_snapshot_timestamp' },
+  proparallel => 'r', prorettype => 'timestamptz', proargtypes => '' },
 { oid => '2230',
   descr => 'statistics: discard current transaction\'s statistics snapshot',
   proname => 'pg_stat_clear_snapshot', proisstrict => 'f', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => '',
-  prosrc => 'pg_stat_clear_snapshot' },
+  proparallel => 'r', prorettype => 'void', proargtypes => '' },
 { oid => '2274',
   descr => 'statistics: reset collected statistics for current database',
   proname => 'pg_stat_reset', proisstrict => 'f', provolatile => 'v',
-  prorettype => 'void', proargtypes => '', prosrc => 'pg_stat_reset' },
+  prorettype => 'void', proargtypes => '' },
 { oid => '3775',
   descr => 'statistics: reset collected statistics shared across the cluster',
   proname => 'pg_stat_reset_shared', provolatile => 'v', prorettype => 'void',
-  proargtypes => 'text', prosrc => 'pg_stat_reset_shared' },
+  proargtypes => 'text' },
 { oid => '3776',
   descr => 'statistics: reset collected statistics for a single table or index in the current database',
   proname => 'pg_stat_reset_single_table_counters', provolatile => 'v',
-  prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'pg_stat_reset_single_table_counters' },
+  prorettype => 'void', proargtypes => 'oid' },
 { oid => '3777',
   descr => 'statistics: reset collected statistics for a single function in the current database',
   proname => 'pg_stat_reset_single_function_counters', provolatile => 'v',
-  prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'pg_stat_reset_single_function_counters' },
+  prorettype => 'void', proargtypes => 'oid' },
 
 { oid => '3163', descr => 'current trigger depth',
   proname => 'pg_trigger_depth', provolatile => 's', proparallel => 'r',
-  prorettype => 'int4', proargtypes => '', prosrc => 'pg_trigger_depth' },
+  prorettype => 'int4', proargtypes => '' },
 
 { oid => '3778', descr => 'tablespace location',
   proname => 'pg_tablespace_location', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid', prosrc => 'pg_tablespace_location' },
+  proargtypes => 'oid' },
 
 { oid => '1946',
   descr => 'convert bytea value into some ascii-only text string',
@@ -5527,35 +4969,34 @@
 
 { oid => '1948',
   proname => 'byteaeq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bytea bytea', prosrc => 'byteaeq' },
+  proargtypes => 'bytea bytea' },
 { oid => '1949',
   proname => 'bytealt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bytea bytea', prosrc => 'bytealt' },
+  proargtypes => 'bytea bytea' },
 { oid => '1950',
   proname => 'byteale', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bytea bytea', prosrc => 'byteale' },
+  proargtypes => 'bytea bytea' },
 { oid => '1951',
   proname => 'byteagt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bytea bytea', prosrc => 'byteagt' },
+  proargtypes => 'bytea bytea' },
 { oid => '1952',
   proname => 'byteage', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bytea bytea', prosrc => 'byteage' },
+  proargtypes => 'bytea bytea' },
 { oid => '1953',
   proname => 'byteane', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'bytea bytea', prosrc => 'byteane' },
+  proargtypes => 'bytea bytea' },
 { oid => '1954', descr => 'less-equal-greater',
-  proname => 'byteacmp', prorettype => 'int4', proargtypes => 'bytea bytea',
-  prosrc => 'byteacmp' },
+  proname => 'byteacmp', prorettype => 'int4', proargtypes => 'bytea bytea' },
 { oid => '3331', descr => 'sort support',
   proname => 'bytea_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'bytea_sortsupport' },
+  proargtypes => 'internal' },
 
 { oid => '3917', descr => 'transform a timestamp length coercion',
   proname => 'timestamp_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'timestamp_transform' },
+  proargtypes => 'internal' },
 { oid => '3944', descr => 'transform a time length coercion',
   proname => 'time_transform', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'time_transform' },
+  proargtypes => 'internal' },
 
 { oid => '1961', descr => 'adjust timestamp precision',
   proname => 'timestamp', protransform => 'timestamp_transform',
@@ -5563,11 +5004,9 @@
   prosrc => 'timestamp_scale' },
 
 { oid => '1965', descr => 'larger of two',
-  proname => 'oidlarger', prorettype => 'oid', proargtypes => 'oid oid',
-  prosrc => 'oidlarger' },
+  proname => 'oidlarger', prorettype => 'oid', proargtypes => 'oid oid' },
 { oid => '1966', descr => 'smaller of two',
-  proname => 'oidsmaller', prorettype => 'oid', proargtypes => 'oid oid',
-  prosrc => 'oidsmaller' },
+  proname => 'oidsmaller', prorettype => 'oid', proargtypes => 'oid oid' },
 
 { oid => '1967', descr => 'adjust timestamptz precision',
   proname => 'timestamptz', protransform => 'timestamp_transform',
@@ -5590,11 +5029,9 @@
   prosrc => 'select $1::pg_catalog.text || $2' },
 
 { oid => '2005',
-  proname => 'bytealike', prorettype => 'bool', proargtypes => 'bytea bytea',
-  prosrc => 'bytealike' },
+  proname => 'bytealike', prorettype => 'bool', proargtypes => 'bytea bytea' },
 { oid => '2006',
-  proname => 'byteanlike', prorettype => 'bool', proargtypes => 'bytea bytea',
-  prosrc => 'byteanlike' },
+  proname => 'byteanlike', prorettype => 'bool', proargtypes => 'bytea bytea' },
 { oid => '2007', descr => 'matches LIKE expression',
   proname => 'like', prorettype => 'bool', proargtypes => 'bytea bytea',
   prosrc => 'bytealike' },
@@ -5608,8 +5045,7 @@
   proname => 'length', prorettype => 'int4', proargtypes => 'bytea',
   prosrc => 'byteaoctetlen' },
 { oid => '2011',
-  proname => 'byteacat', prorettype => 'bytea', proargtypes => 'bytea bytea',
-  prosrc => 'byteacat' },
+  proname => 'byteacat', prorettype => 'bytea', proargtypes => 'bytea bytea' },
 { oid => '2012', descr => 'extract portion of string',
   proname => 'substring', prorettype => 'bytea',
   proargtypes => 'bytea int4 int4', prosrc => 'bytea_substr' },
@@ -5661,19 +5097,19 @@
   proargtypes => 'timestamp', prosrc => 'timestamp_abstime' },
 { oid => '2031',
   proname => 'timestamp_mi', prorettype => 'interval',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_mi' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2032',
   proname => 'timestamp_pl_interval', prorettype => 'timestamp',
-  proargtypes => 'timestamp interval', prosrc => 'timestamp_pl_interval' },
+  proargtypes => 'timestamp interval' },
 { oid => '2033',
   proname => 'timestamp_mi_interval', prorettype => 'timestamp',
-  proargtypes => 'timestamp interval', prosrc => 'timestamp_mi_interval' },
+  proargtypes => 'timestamp interval' },
 { oid => '2035', descr => 'smaller of two',
   proname => 'timestamp_smaller', prorettype => 'timestamp',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_smaller' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2036', descr => 'larger of two',
   proname => 'timestamp_larger', prorettype => 'timestamp',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_larger' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2037', descr => 'adjust time with time zone to new zone',
   proname => 'timezone', provolatile => 'v', prorettype => 'timetz',
   proargtypes => 'text timetz', prosrc => 'timetz_zone' },
@@ -5681,11 +5117,10 @@
   proname => 'timezone', prorettype => 'timetz',
   proargtypes => 'interval timetz', prosrc => 'timetz_izone' },
 { oid => '2039', descr => 'hash',
-  proname => 'timestamp_hash', prorettype => 'int4', proargtypes => 'timestamp',
-  prosrc => 'timestamp_hash' },
+  proname => 'timestamp_hash', prorettype => 'int4', proargtypes => 'timestamp' },
 { oid => '3411', descr => 'hash',
   proname => 'timestamp_hash_extended', prorettype => 'int8',
-  proargtypes => 'timestamp int8', prosrc => 'timestamp_hash_extended' },
+  proargtypes => 'timestamp int8' },
 { oid => '2041', descr => 'intervals overlap?',
   proname => 'overlaps', proisstrict => 'f', prorettype => 'bool',
   proargtypes => 'timestamp timestamp timestamp timestamp',
@@ -5704,10 +5139,10 @@
   prosrc => 'select ($1, ($1 + $2)) overlaps ($3, $4)' },
 { oid => '2045', descr => 'less-equal-greater',
   proname => 'timestamp_cmp', prorettype => 'int4',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_cmp' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '3137', descr => 'sort support',
   proname => 'timestamp_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'timestamp_sortsupport' },
+  proargtypes => 'internal' },
 
 { oid => '4134', descr => 'window RANGE support',
   proname => 'in_range', prorettype => 'bool',
@@ -5744,22 +5179,22 @@
   proargtypes => 'timestamp text', prosrc => 'timestamp_to_char' },
 { oid => '2052',
   proname => 'timestamp_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_eq' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2053',
   proname => 'timestamp_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_ne' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2054',
   proname => 'timestamp_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_lt' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2055',
   proname => 'timestamp_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_le' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2056',
   proname => 'timestamp_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_ge' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2057',
   proname => 'timestamp_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'timestamp timestamp', prosrc => 'timestamp_gt' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '2058', descr => 'date difference preserving months and years',
   proname => 'age', prorettype => 'interval',
   proargtypes => 'timestamp timestamp', prosrc => 'timestamp_age' },
@@ -5779,10 +5214,10 @@
   prosrc => 'timestamp_izone' },
 { oid => '2071',
   proname => 'date_pl_interval', prorettype => 'timestamp',
-  proargtypes => 'date interval', prosrc => 'date_pl_interval' },
+  proargtypes => 'date interval' },
 { oid => '2072',
   proname => 'date_mi_interval', prorettype => 'timestamp',
-  proargtypes => 'date interval', prosrc => 'date_mi_interval' },
+  proargtypes => 'date interval' },
 
 { oid => '2073', descr => 'extract text matching regular expression',
   proname => 'substring', prorettype => 'text', proargtypes => 'text text',
@@ -5829,56 +5264,50 @@
   provolatile => 'v', prorettype => 'record', proargtypes => '',
   proallargtypes => '{int4,text,_text,_text,text,text,text,_text,text}',
   proargmodes => '{o,o,o,o,o,o,o,o,o}',
-  proargnames => '{line_number,type,database,user_name,address,netmask,auth_method,options,error}',
-  prosrc => 'pg_hba_file_rules' },
+  proargnames => '{line_number,type,database,user_name,address,netmask,auth_method,options,error}' },
 { oid => '1371', descr => 'view system lock information',
   proname => 'pg_lock_status', prorows => '1000', proretset => 't',
   provolatile => 'v', prorettype => 'record', proargtypes => '',
   proallargtypes => '{text,oid,oid,int4,int2,text,xid,oid,oid,int2,text,int4,text,bool,bool}',
   proargmodes => '{o,o,o,o,o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{locktype,database,relation,page,tuple,virtualxid,transactionid,classid,objid,objsubid,virtualtransaction,pid,mode,granted,fastpath}',
-  prosrc => 'pg_lock_status' },
+  proargnames => '{locktype,database,relation,page,tuple,virtualxid,transactionid,classid,objid,objsubid,virtualtransaction,pid,mode,granted,fastpath}' },
 { oid => '2561',
   descr => 'get array of PIDs of sessions blocking specified backend PID from acquiring a heavyweight lock',
   proname => 'pg_blocking_pids', provolatile => 'v', prorettype => '_int4',
-  proargtypes => 'int4', prosrc => 'pg_blocking_pids' },
+  proargtypes => 'int4' },
 { oid => '3376',
   descr => 'get array of PIDs of sessions blocking specified backend PID from acquiring a safe snapshot',
   proname => 'pg_safe_snapshot_blocking_pids', provolatile => 'v',
-  prorettype => '_int4', proargtypes => 'int4',
-  prosrc => 'pg_safe_snapshot_blocking_pids' },
+  prorettype => '_int4', proargtypes => 'int4' },
 { oid => '3378', descr => 'isolationtester support function',
   proname => 'pg_isolation_test_session_is_blocked', provolatile => 'v',
-  prorettype => 'bool', proargtypes => 'int4 _int4',
-  prosrc => 'pg_isolation_test_session_is_blocked' },
+  prorettype => 'bool', proargtypes => 'int4 _int4' },
 { oid => '1065', descr => 'view two-phase transactions',
   proname => 'pg_prepared_xact', prorows => '1000', proretset => 't',
   provolatile => 'v', prorettype => 'record', proargtypes => '',
   proallargtypes => '{xid,text,timestamptz,oid,oid}',
   proargmodes => '{o,o,o,o,o}',
-  proargnames => '{transaction,gid,prepared,ownerid,dbid}',
-  prosrc => 'pg_prepared_xact' },
+  proargnames => '{transaction,gid,prepared,ownerid,dbid}' },
 { oid => '3819', descr => 'view members of a multixactid',
   proname => 'pg_get_multixact_members', prorows => '1000', proretset => 't',
   provolatile => 'v', prorettype => 'record', proargtypes => 'xid',
   proallargtypes => '{xid,xid,text}', proargmodes => '{i,o,o}',
-  proargnames => '{multixid,xid,mode}', prosrc => 'pg_get_multixact_members' },
+  proargnames => '{multixid,xid,mode}' },
 
 { oid => '3581', descr => 'get commit timestamp of a transaction',
   proname => 'pg_xact_commit_timestamp', provolatile => 'v',
-  prorettype => 'timestamptz', proargtypes => 'xid',
-  prosrc => 'pg_xact_commit_timestamp' },
+  prorettype => 'timestamptz', proargtypes => 'xid' },
 
 { oid => '3583',
   descr => 'get transaction Id and commit timestamp of latest transaction commit',
   proname => 'pg_last_committed_xact', provolatile => 'v',
   prorettype => 'record', proargtypes => '',
   proallargtypes => '{xid,timestamptz}', proargmodes => '{o,o}',
-  proargnames => '{xid,timestamp}', prosrc => 'pg_last_committed_xact' },
+  proargnames => '{xid,timestamp}' },
 
 { oid => '3537', descr => 'get identification of SQL object',
   proname => 'pg_describe_object', provolatile => 's', prorettype => 'text',
-  proargtypes => 'oid oid int4', prosrc => 'pg_describe_object' },
+  proargtypes => 'oid oid int4' },
 
 { oid => '3839',
   descr => 'get machine-parseable identification of SQL object',
@@ -5886,8 +5315,7 @@
   proargtypes => 'oid oid int4',
   proallargtypes => '{oid,oid,int4,text,text,text,text}',
   proargmodes => '{i,i,i,o,o,o,o}',
-  proargnames => '{classid,objid,objsubid,type,schema,name,identity}',
-  prosrc => 'pg_identify_object' },
+  proargnames => '{classid,objid,objsubid,type,schema,name,identity}' },
 
 { oid => '3382',
   descr => 'get identification of SQL object for pg_get_object_address()',
@@ -5895,8 +5323,7 @@
   prorettype => 'record', proargtypes => 'oid oid int4',
   proallargtypes => '{oid,oid,int4,text,_text,_text}',
   proargmodes => '{i,i,i,o,o,o}',
-  proargnames => '{classid,objid,objsubid,type,object_names,object_args}',
-  prosrc => 'pg_identify_object_as_address' },
+  proargnames => '{classid,objid,objsubid,type,object_names,object_args}' },
 
 { oid => '3954',
   descr => 'get OID-based object address from name/args arrays',
@@ -5904,82 +5331,68 @@
   prorettype => 'record', proargtypes => 'text _text _text',
   proallargtypes => '{text,_text,_text,oid,oid,int4}',
   proargmodes => '{i,i,i,o,o,o}',
-  proargnames => '{type,name,args,classid,objid,objsubid}',
-  prosrc => 'pg_get_object_address' },
+  proargnames => '{type,name,args,classid,objid,objsubid}' },
 
 { oid => '2079', descr => 'is table visible in search path?',
   proname => 'pg_table_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid', prosrc => 'pg_table_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '2080', descr => 'is type visible in search path?',
   proname => 'pg_type_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid', prosrc => 'pg_type_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '2081', descr => 'is function visible in search path?',
   proname => 'pg_function_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_function_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '2082', descr => 'is operator visible in search path?',
   proname => 'pg_operator_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_operator_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '2083', descr => 'is opclass visible in search path?',
   proname => 'pg_opclass_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_opclass_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '3829', descr => 'is opfamily visible in search path?',
   proname => 'pg_opfamily_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_opfamily_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '2093', descr => 'is conversion visible in search path?',
   proname => 'pg_conversion_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_conversion_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '3403', descr => 'is statistics object visible in search path?',
   proname => 'pg_statistics_obj_is_visible', procost => '10',
-  provolatile => 's', prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_statistics_obj_is_visible' },
+  provolatile => 's', prorettype => 'bool', proargtypes => 'oid' },
 { oid => '3756', descr => 'is text search parser visible in search path?',
   proname => 'pg_ts_parser_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_ts_parser_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '3757', descr => 'is text search dictionary visible in search path?',
   proname => 'pg_ts_dict_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_ts_dict_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '3768', descr => 'is text search template visible in search path?',
   proname => 'pg_ts_template_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_ts_template_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '3758',
   descr => 'is text search configuration visible in search path?',
   proname => 'pg_ts_config_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_ts_config_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 { oid => '3815', descr => 'is collation visible in search path?',
   proname => 'pg_collation_is_visible', procost => '10', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_collation_is_visible' },
+  prorettype => 'bool', proargtypes => 'oid' },
 
 { oid => '2854', descr => 'get OID of current session\'s temp schema, if any',
   proname => 'pg_my_temp_schema', provolatile => 's', proparallel => 'r',
-  prorettype => 'oid', proargtypes => '', prosrc => 'pg_my_temp_schema' },
+  prorettype => 'oid', proargtypes => '' },
 { oid => '2855', descr => 'is schema another session\'s temp schema?',
   proname => 'pg_is_other_temp_schema', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'oid',
-  prosrc => 'pg_is_other_temp_schema' },
+  prorettype => 'bool', proargtypes => 'oid' },
 
 { oid => '2171', descr => 'cancel a server process\' current query',
   proname => 'pg_cancel_backend', provolatile => 'v', prorettype => 'bool',
-  proargtypes => 'int4', prosrc => 'pg_cancel_backend' },
+  proargtypes => 'int4' },
 { oid => '2096', descr => 'terminate a server process',
   proname => 'pg_terminate_backend', provolatile => 'v', prorettype => 'bool',
-  proargtypes => 'int4', prosrc => 'pg_terminate_backend' },
+  proargtypes => 'int4' },
 { oid => '2172', descr => 'prepare for taking an online backup',
   proname => 'pg_start_backup', provolatile => 'v', proparallel => 'r',
-  prorettype => 'pg_lsn', proargtypes => 'text bool bool',
-  prosrc => 'pg_start_backup' },
+  prorettype => 'pg_lsn', proargtypes => 'text bool bool' },
 { oid => '2173', descr => 'finish taking an online backup',
   proname => 'pg_stop_backup', provolatile => 'v', proparallel => 'r',
-  prorettype => 'pg_lsn', proargtypes => '', prosrc => 'pg_stop_backup' },
+  prorettype => 'pg_lsn', proargtypes => '' },
 { oid => '2739', descr => 'finish taking an online backup',
   proname => 'pg_stop_backup', prorows => '1', proretset => 't',
   provolatile => 'v', proparallel => 'r', prorettype => 'record',
@@ -5989,78 +5402,68 @@
   prosrc => 'pg_stop_backup_v2' },
 { oid => '3813', descr => 'true if server is in online backup',
   proname => 'pg_is_in_backup', provolatile => 'v', prorettype => 'bool',
-  proargtypes => '', prosrc => 'pg_is_in_backup' },
+  proargtypes => '' },
 { oid => '3814', descr => 'start time of an online backup',
   proname => 'pg_backup_start_time', provolatile => 's',
-  prorettype => 'timestamptz', proargtypes => '',
-  prosrc => 'pg_backup_start_time' },
+  prorettype => 'timestamptz', proargtypes => '' },
 { oid => '2848', descr => 'switch to new wal file',
   proname => 'pg_switch_wal', provolatile => 'v', prorettype => 'pg_lsn',
-  proargtypes => '', prosrc => 'pg_switch_wal' },
+  proargtypes => '' },
 { oid => '3098', descr => 'create a named restore point',
   proname => 'pg_create_restore_point', provolatile => 'v',
-  prorettype => 'pg_lsn', proargtypes => 'text',
-  prosrc => 'pg_create_restore_point' },
+  prorettype => 'pg_lsn', proargtypes => 'text' },
 { oid => '2849', descr => 'current wal write location',
   proname => 'pg_current_wal_lsn', provolatile => 'v', prorettype => 'pg_lsn',
-  proargtypes => '', prosrc => 'pg_current_wal_lsn' },
+  proargtypes => '' },
 { oid => '2852', descr => 'current wal insert location',
   proname => 'pg_current_wal_insert_lsn', provolatile => 'v',
-  prorettype => 'pg_lsn', proargtypes => '',
-  prosrc => 'pg_current_wal_insert_lsn' },
+  prorettype => 'pg_lsn', proargtypes => '' },
 { oid => '3330', descr => 'current wal flush location',
   proname => 'pg_current_wal_flush_lsn', provolatile => 'v',
-  prorettype => 'pg_lsn', proargtypes => '',
-  prosrc => 'pg_current_wal_flush_lsn' },
+  prorettype => 'pg_lsn', proargtypes => '' },
 { oid => '2850',
   descr => 'wal filename and byte offset, given a wal location',
   proname => 'pg_walfile_name_offset', prorettype => 'record',
   proargtypes => 'pg_lsn', proallargtypes => '{pg_lsn,text,int4}',
-  proargmodes => '{i,o,o}', proargnames => '{lsn,file_name,file_offset}',
-  prosrc => 'pg_walfile_name_offset' },
+  proargmodes => '{i,o,o}', proargnames => '{lsn,file_name,file_offset}' },
 { oid => '2851', descr => 'wal filename, given a wal location',
-  proname => 'pg_walfile_name', prorettype => 'text', proargtypes => 'pg_lsn',
-  prosrc => 'pg_walfile_name' },
+  proname => 'pg_walfile_name', prorettype => 'text', proargtypes => 'pg_lsn' },
 
 { oid => '3165', descr => 'difference in bytes, given two wal locations',
   proname => 'pg_wal_lsn_diff', prorettype => 'numeric',
-  proargtypes => 'pg_lsn pg_lsn', prosrc => 'pg_wal_lsn_diff' },
+  proargtypes => 'pg_lsn pg_lsn' },
 
 { oid => '3809', descr => 'export a snapshot',
   proname => 'pg_export_snapshot', provolatile => 'v', proparallel => 'u',
-  prorettype => 'text', proargtypes => '', prosrc => 'pg_export_snapshot' },
+  prorettype => 'text', proargtypes => '' },
 
 { oid => '3810', descr => 'true if server is in recovery',
   proname => 'pg_is_in_recovery', provolatile => 'v', prorettype => 'bool',
-  proargtypes => '', prosrc => 'pg_is_in_recovery' },
+  proargtypes => '' },
 
 { oid => '3820', descr => 'current wal flush location',
   proname => 'pg_last_wal_receive_lsn', provolatile => 'v',
-  prorettype => 'pg_lsn', proargtypes => '',
-  prosrc => 'pg_last_wal_receive_lsn' },
+  prorettype => 'pg_lsn', proargtypes => '' },
 { oid => '3821', descr => 'last wal replay location',
   proname => 'pg_last_wal_replay_lsn', provolatile => 'v',
-  prorettype => 'pg_lsn', proargtypes => '',
-  prosrc => 'pg_last_wal_replay_lsn' },
+  prorettype => 'pg_lsn', proargtypes => '' },
 { oid => '3830', descr => 'timestamp of last replay xact',
   proname => 'pg_last_xact_replay_timestamp', provolatile => 'v',
-  prorettype => 'timestamptz', proargtypes => '',
-  prosrc => 'pg_last_xact_replay_timestamp' },
+  prorettype => 'timestamptz', proargtypes => '' },
 
 { oid => '3071', descr => 'pause wal replay',
   proname => 'pg_wal_replay_pause', provolatile => 'v', prorettype => 'void',
-  proargtypes => '', prosrc => 'pg_wal_replay_pause' },
+  proargtypes => '' },
 { oid => '3072', descr => 'resume wal replay, if it was paused',
   proname => 'pg_wal_replay_resume', provolatile => 'v', prorettype => 'void',
-  proargtypes => '', prosrc => 'pg_wal_replay_resume' },
+  proargtypes => '' },
 { oid => '3073', descr => 'true if wal replay is paused',
   proname => 'pg_is_wal_replay_paused', provolatile => 'v',
-  prorettype => 'bool', proargtypes => '',
-  prosrc => 'pg_is_wal_replay_paused' },
+  prorettype => 'bool', proargtypes => '' },
 
 { oid => '2621', descr => 'reload configuration files',
   proname => 'pg_reload_conf', provolatile => 'v', prorettype => 'bool',
-  proargtypes => '', prosrc => 'pg_reload_conf' },
+  proargtypes => '' },
 { oid => '2622', descr => 'rotate log file',
   proname => 'pg_rotate_logfile', provolatile => 'v', prorettype => 'bool',
   proargtypes => '', prosrc => 'pg_rotate_logfile_v2' },
@@ -6069,7 +5472,7 @@
   proargtypes => '', prosrc => 'pg_rotate_logfile' },
 { oid => '3800', descr => 'current logging collector file location',
   proname => 'pg_current_logfile', proisstrict => 'f', provolatile => 'v',
-  prorettype => 'text', proargtypes => '', prosrc => 'pg_current_logfile' },
+  prorettype => 'text', proargtypes => '' },
 { oid => '3801', descr => 'current logging collector file location',
   proname => 'pg_current_logfile', proisstrict => 'f', provolatile => 'v',
   prorettype => 'text', proargtypes => 'text',
@@ -6087,8 +5490,7 @@
   proargtypes => 'text bool',
   proallargtypes => '{text,bool,int8,timestamptz,timestamptz,timestamptz,timestamptz,bool}',
   proargmodes => '{i,i,o,o,o,o,o,o}',
-  proargnames => '{filename,missing_ok,size,access,modification,change,creation,isdir}',
-  prosrc => 'pg_stat_file' },
+  proargnames => '{filename,missing_ok,size,access,modification,change,creation,isdir}' },
 { oid => '2624', descr => 'read text from a file',
   proname => 'pg_read_file', provolatile => 'v', prorettype => 'text',
   proargtypes => 'text int8 int8', prosrc => 'pg_read_file_off_len' },
@@ -6107,7 +5509,7 @@
   proargtypes => 'text int8 int8', prosrc => 'pg_read_binary_file_off_len' },
 { oid => '3295', descr => 'read bytea from a file',
   proname => 'pg_read_binary_file', provolatile => 'v', prorettype => 'bytea',
-  proargtypes => 'text int8 int8 bool', prosrc => 'pg_read_binary_file' },
+  proargtypes => 'text int8 int8 bool' },
 { oid => '3828', descr => 'read bytea from a file',
   proname => 'pg_read_binary_file', provolatile => 'v', prorettype => 'bytea',
   proargtypes => 'text', prosrc => 'pg_read_binary_file_all' },
@@ -6117,11 +5519,10 @@
   prosrc => 'pg_ls_dir_1arg' },
 { oid => '3297', descr => 'list all files in a directory',
   proname => 'pg_ls_dir', prorows => '1000', proretset => 't',
-  provolatile => 'v', prorettype => 'text', proargtypes => 'text bool bool',
-  prosrc => 'pg_ls_dir' },
+  provolatile => 'v', prorettype => 'text', proargtypes => 'text bool bool' },
 { oid => '2626', descr => 'sleep for the specified time in seconds',
   proname => 'pg_sleep', provolatile => 'v', prorettype => 'void',
-  proargtypes => 'float8', prosrc => 'pg_sleep' },
+  proargtypes => 'float8' },
 { oid => '3935', descr => 'sleep for the specified interval',
   proname => 'pg_sleep_for', prolang => '14', provolatile => 'v',
   prorettype => 'void', proargtypes => 'interval',
@@ -6132,7 +5533,7 @@
   prosrc => 'select pg_catalog.pg_sleep(extract(epoch from $1) operator(pg_catalog.-) extract(epoch from pg_catalog.clock_timestamp()))' },
 { oid => '315', descr => 'Is JIT compilation available in this session?',
   proname => 'pg_jit_available', provolatile => 'v', prorettype => 'bool',
-  proargtypes => '', prosrc => 'pg_jit_available' },
+  proargtypes => '' },
 
 { oid => '2971', descr => 'convert boolean to text',
   proname => 'text', prorettype => 'text', proargtypes => 'bool',
@@ -6548,149 +5949,141 @@
 
 { oid => '2160',
   proname => 'text_pattern_lt', prorettype => 'bool',
-  proargtypes => 'text text', prosrc => 'text_pattern_lt' },
+  proargtypes => 'text text' },
 { oid => '2161',
   proname => 'text_pattern_le', prorettype => 'bool',
-  proargtypes => 'text text', prosrc => 'text_pattern_le' },
+  proargtypes => 'text text' },
 { oid => '2163',
   proname => 'text_pattern_ge', prorettype => 'bool',
-  proargtypes => 'text text', prosrc => 'text_pattern_ge' },
+  proargtypes => 'text text' },
 { oid => '2164',
   proname => 'text_pattern_gt', prorettype => 'bool',
-  proargtypes => 'text text', prosrc => 'text_pattern_gt' },
+  proargtypes => 'text text' },
 { oid => '2166', descr => 'less-equal-greater',
   proname => 'bttext_pattern_cmp', prorettype => 'int4',
-  proargtypes => 'text text', prosrc => 'bttext_pattern_cmp' },
+  proargtypes => 'text text' },
 { oid => '3332', descr => 'sort support',
   proname => 'bttext_pattern_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'bttext_pattern_sortsupport' },
+  proargtypes => 'internal' },
 
 { oid => '2174',
   proname => 'bpchar_pattern_lt', prorettype => 'bool',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpchar_pattern_lt' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '2175',
   proname => 'bpchar_pattern_le', prorettype => 'bool',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpchar_pattern_le' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '2177',
   proname => 'bpchar_pattern_ge', prorettype => 'bool',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpchar_pattern_ge' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '2178',
   proname => 'bpchar_pattern_gt', prorettype => 'bool',
-  proargtypes => 'bpchar bpchar', prosrc => 'bpchar_pattern_gt' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '2180', descr => 'less-equal-greater',
   proname => 'btbpchar_pattern_cmp', prorettype => 'int4',
-  proargtypes => 'bpchar bpchar', prosrc => 'btbpchar_pattern_cmp' },
+  proargtypes => 'bpchar bpchar' },
 { oid => '3333', descr => 'sort support',
   proname => 'btbpchar_pattern_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'btbpchar_pattern_sortsupport' },
+  proargtypes => 'internal' },
 
 { oid => '2188', descr => 'less-equal-greater',
-  proname => 'btint48cmp', prorettype => 'int4', proargtypes => 'int4 int8',
-  prosrc => 'btint48cmp' },
+  proname => 'btint48cmp', prorettype => 'int4', proargtypes => 'int4 int8' },
 { oid => '2189', descr => 'less-equal-greater',
-  proname => 'btint84cmp', prorettype => 'int4', proargtypes => 'int8 int4',
-  prosrc => 'btint84cmp' },
+  proname => 'btint84cmp', prorettype => 'int4', proargtypes => 'int8 int4' },
 { oid => '2190', descr => 'less-equal-greater',
-  proname => 'btint24cmp', prorettype => 'int4', proargtypes => 'int2 int4',
-  prosrc => 'btint24cmp' },
+  proname => 'btint24cmp', prorettype => 'int4', proargtypes => 'int2 int4' },
 { oid => '2191', descr => 'less-equal-greater',
-  proname => 'btint42cmp', prorettype => 'int4', proargtypes => 'int4 int2',
-  prosrc => 'btint42cmp' },
+  proname => 'btint42cmp', prorettype => 'int4', proargtypes => 'int4 int2' },
 { oid => '2192', descr => 'less-equal-greater',
-  proname => 'btint28cmp', prorettype => 'int4', proargtypes => 'int2 int8',
-  prosrc => 'btint28cmp' },
+  proname => 'btint28cmp', prorettype => 'int4', proargtypes => 'int2 int8' },
 { oid => '2193', descr => 'less-equal-greater',
-  proname => 'btint82cmp', prorettype => 'int4', proargtypes => 'int8 int2',
-  prosrc => 'btint82cmp' },
+  proname => 'btint82cmp', prorettype => 'int4', proargtypes => 'int8 int2' },
 { oid => '2194', descr => 'less-equal-greater',
   proname => 'btfloat48cmp', prorettype => 'int4',
-  proargtypes => 'float4 float8', prosrc => 'btfloat48cmp' },
+  proargtypes => 'float4 float8' },
 { oid => '2195', descr => 'less-equal-greater',
   proname => 'btfloat84cmp', prorettype => 'int4',
-  proargtypes => 'float8 float4', prosrc => 'btfloat84cmp' },
+  proargtypes => 'float8 float4' },
 
 { oid => '2212', descr => 'I/O',
   proname => 'regprocedurein', provolatile => 's', prorettype => 'regprocedure',
-  proargtypes => 'cstring', prosrc => 'regprocedurein' },
+  proargtypes => 'cstring' },
 { oid => '2213', descr => 'I/O',
   proname => 'regprocedureout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regprocedure', prosrc => 'regprocedureout' },
+  proargtypes => 'regprocedure' },
 { oid => '2214', descr => 'I/O',
   proname => 'regoperin', provolatile => 's', prorettype => 'regoper',
-  proargtypes => 'cstring', prosrc => 'regoperin' },
+  proargtypes => 'cstring' },
 { oid => '2215', descr => 'I/O',
   proname => 'regoperout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regoper', prosrc => 'regoperout' },
+  proargtypes => 'regoper' },
 { oid => '3492', descr => 'convert operator name to regoper',
   proname => 'to_regoper', provolatile => 's', prorettype => 'regoper',
-  proargtypes => 'text', prosrc => 'to_regoper' },
+  proargtypes => 'text' },
 { oid => '3476', descr => 'convert operator name to regoperator',
   proname => 'to_regoperator', provolatile => 's', prorettype => 'regoperator',
-  proargtypes => 'text', prosrc => 'to_regoperator' },
+  proargtypes => 'text' },
 { oid => '2216', descr => 'I/O',
   proname => 'regoperatorin', provolatile => 's', prorettype => 'regoperator',
-  proargtypes => 'cstring', prosrc => 'regoperatorin' },
+  proargtypes => 'cstring' },
 { oid => '2217', descr => 'I/O',
   proname => 'regoperatorout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regoperator', prosrc => 'regoperatorout' },
+  proargtypes => 'regoperator' },
 { oid => '2218', descr => 'I/O',
   proname => 'regclassin', provolatile => 's', prorettype => 'regclass',
-  proargtypes => 'cstring', prosrc => 'regclassin' },
+  proargtypes => 'cstring' },
 { oid => '2219', descr => 'I/O',
   proname => 'regclassout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regclass', prosrc => 'regclassout' },
+  proargtypes => 'regclass' },
 { oid => '3495', descr => 'convert classname to regclass',
   proname => 'to_regclass', provolatile => 's', prorettype => 'regclass',
-  proargtypes => 'text', prosrc => 'to_regclass' },
+  proargtypes => 'text' },
 { oid => '2220', descr => 'I/O',
   proname => 'regtypein', provolatile => 's', prorettype => 'regtype',
-  proargtypes => 'cstring', prosrc => 'regtypein' },
+  proargtypes => 'cstring' },
 { oid => '2221', descr => 'I/O',
   proname => 'regtypeout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regtype', prosrc => 'regtypeout' },
+  proargtypes => 'regtype' },
 { oid => '3493', descr => 'convert type name to regtype',
   proname => 'to_regtype', provolatile => 's', prorettype => 'regtype',
-  proargtypes => 'text', prosrc => 'to_regtype' },
+  proargtypes => 'text' },
 { oid => '1079', descr => 'convert text to regclass',
   proname => 'regclass', provolatile => 's', prorettype => 'regclass',
   proargtypes => 'text', prosrc => 'text_regclass' },
 
 { oid => '4098', descr => 'I/O',
   proname => 'regrolein', provolatile => 's', prorettype => 'regrole',
-  proargtypes => 'cstring', prosrc => 'regrolein' },
+  proargtypes => 'cstring' },
 { oid => '4092', descr => 'I/O',
   proname => 'regroleout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regrole', prosrc => 'regroleout' },
+  proargtypes => 'regrole' },
 { oid => '4093', descr => 'convert role name to regrole',
   proname => 'to_regrole', provolatile => 's', prorettype => 'regrole',
-  proargtypes => 'text', prosrc => 'to_regrole' },
+  proargtypes => 'text' },
 
 { oid => '4084', descr => 'I/O',
   proname => 'regnamespacein', provolatile => 's', prorettype => 'regnamespace',
-  proargtypes => 'cstring', prosrc => 'regnamespacein' },
+  proargtypes => 'cstring' },
 { oid => '4085', descr => 'I/O',
   proname => 'regnamespaceout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regnamespace', prosrc => 'regnamespaceout' },
+  proargtypes => 'regnamespace' },
 { oid => '4086', descr => 'convert namespace name to regnamespace',
   proname => 'to_regnamespace', provolatile => 's',
-  prorettype => 'regnamespace', proargtypes => 'text',
-  prosrc => 'to_regnamespace' },
+  prorettype => 'regnamespace', proargtypes => 'text' },
 
 { oid => '1268',
   descr => 'parse qualified identifier to array of identifiers',
   proname => 'parse_ident', prorettype => '_text', proargtypes => 'text bool',
-  proargnames => '{str,strict}', prosrc => 'parse_ident' },
+  proargnames => '{str,strict}' },
 
 { oid => '2246', descr => '(internal)',
   proname => 'fmgr_internal_validator', provolatile => 's',
-  prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'fmgr_internal_validator' },
+  prorettype => 'void', proargtypes => 'oid' },
 { oid => '2247', descr => '(internal)',
   proname => 'fmgr_c_validator', provolatile => 's', prorettype => 'void',
-  proargtypes => 'oid', prosrc => 'fmgr_c_validator' },
+  proargtypes => 'oid' },
 { oid => '2248', descr => '(internal)',
   proname => 'fmgr_sql_validator', provolatile => 's', prorettype => 'void',
-  proargtypes => 'oid', prosrc => 'fmgr_sql_validator' },
+  proargtypes => 'oid' },
 
 { oid => '2250',
   descr => 'user privilege on database by username, database name',
@@ -6911,7 +6304,7 @@
 { oid => '1269',
   descr => 'bytes required to store the value, perhaps with compression',
   proname => 'pg_column_size', provolatile => 's', prorettype => 'int4',
-  proargtypes => 'any', prosrc => 'pg_column_size' },
+  proargtypes => 'any' },
 { oid => '2322',
   descr => 'total disk space usage for the specified tablespace',
   proname => 'pg_tablespace_size', provolatile => 'v', prorettype => 'int8',
@@ -6934,153 +6327,134 @@
 { oid => '2332',
   descr => 'disk space usage for the specified fork of a table or index',
   proname => 'pg_relation_size', provolatile => 'v', prorettype => 'int8',
-  proargtypes => 'regclass text', prosrc => 'pg_relation_size' },
+  proargtypes => 'regclass text' },
 { oid => '2286',
   descr => 'total disk space usage for the specified table and associated indexes',
   proname => 'pg_total_relation_size', provolatile => 'v', prorettype => 'int8',
-  proargtypes => 'regclass', prosrc => 'pg_total_relation_size' },
+  proargtypes => 'regclass' },
 { oid => '2288',
   descr => 'convert a long int to a human readable text using size units',
-  proname => 'pg_size_pretty', prorettype => 'text', proargtypes => 'int8',
-  prosrc => 'pg_size_pretty' },
+  proname => 'pg_size_pretty', prorettype => 'text', proargtypes => 'int8' },
 { oid => '3166',
   descr => 'convert a numeric to a human readable text using size units',
   proname => 'pg_size_pretty', prorettype => 'text', proargtypes => 'numeric',
   prosrc => 'pg_size_pretty_numeric' },
 { oid => '3334',
   descr => 'convert a size in human-readable format with size units into bytes',
-  proname => 'pg_size_bytes', prorettype => 'int8', proargtypes => 'text',
-  prosrc => 'pg_size_bytes' },
+  proname => 'pg_size_bytes', prorettype => 'int8', proargtypes => 'text' },
 { oid => '2997',
   descr => 'disk space usage for the specified table, including TOAST, free space and visibility map',
   proname => 'pg_table_size', provolatile => 'v', prorettype => 'int8',
-  proargtypes => 'regclass', prosrc => 'pg_table_size' },
+  proargtypes => 'regclass' },
 { oid => '2998',
   descr => 'disk space usage for all indexes attached to the specified table',
   proname => 'pg_indexes_size', provolatile => 'v', prorettype => 'int8',
-  proargtypes => 'regclass', prosrc => 'pg_indexes_size' },
+  proargtypes => 'regclass' },
 { oid => '2999', descr => 'filenode identifier of relation',
   proname => 'pg_relation_filenode', provolatile => 's', prorettype => 'oid',
-  proargtypes => 'regclass', prosrc => 'pg_relation_filenode' },
+  proargtypes => 'regclass' },
 { oid => '3454', descr => 'relation OID for filenode and tablespace',
   proname => 'pg_filenode_relation', provolatile => 's',
-  prorettype => 'regclass', proargtypes => 'oid oid',
-  prosrc => 'pg_filenode_relation' },
+  prorettype => 'regclass', proargtypes => 'oid oid' },
 { oid => '3034', descr => 'file path of relation',
   proname => 'pg_relation_filepath', provolatile => 's', prorettype => 'text',
-  proargtypes => 'regclass', prosrc => 'pg_relation_filepath' },
+  proargtypes => 'regclass' },
 
 { oid => '2316', descr => '(internal)',
   proname => 'postgresql_fdw_validator', prorettype => 'bool',
-  proargtypes => '_text oid', prosrc => 'postgresql_fdw_validator' },
+  proargtypes => '_text oid' },
 
 { oid => '2290', descr => 'I/O',
   proname => 'record_in', provolatile => 's', prorettype => 'record',
-  proargtypes => 'cstring oid int4', prosrc => 'record_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '2291', descr => 'I/O',
   proname => 'record_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'record', prosrc => 'record_out' },
+  proargtypes => 'record' },
 { oid => '2292', descr => 'I/O',
-  proname => 'cstring_in', prorettype => 'cstring', proargtypes => 'cstring',
-  prosrc => 'cstring_in' },
+  proname => 'cstring_in', prorettype => 'cstring', proargtypes => 'cstring' },
 { oid => '2293', descr => 'I/O',
-  proname => 'cstring_out', prorettype => 'cstring', proargtypes => 'cstring',
-  prosrc => 'cstring_out' },
+  proname => 'cstring_out', prorettype => 'cstring', proargtypes => 'cstring' },
 { oid => '2294', descr => 'I/O',
-  proname => 'any_in', prorettype => 'any', proargtypes => 'cstring',
-  prosrc => 'any_in' },
+  proname => 'any_in', prorettype => 'any', proargtypes => 'cstring' },
 { oid => '2295', descr => 'I/O',
-  proname => 'any_out', prorettype => 'cstring', proargtypes => 'any',
-  prosrc => 'any_out' },
+  proname => 'any_out', prorettype => 'cstring', proargtypes => 'any' },
 { oid => '2296', descr => 'I/O',
-  proname => 'anyarray_in', prorettype => 'anyarray', proargtypes => 'cstring',
-  prosrc => 'anyarray_in' },
+  proname => 'anyarray_in', prorettype => 'anyarray', proargtypes => 'cstring' },
 { oid => '2297', descr => 'I/O',
   proname => 'anyarray_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'anyarray', prosrc => 'anyarray_out' },
+  proargtypes => 'anyarray' },
 { oid => '2298', descr => 'I/O',
-  proname => 'void_in', prorettype => 'void', proargtypes => 'cstring',
-  prosrc => 'void_in' },
+  proname => 'void_in', prorettype => 'void', proargtypes => 'cstring' },
 { oid => '2299', descr => 'I/O',
-  proname => 'void_out', prorettype => 'cstring', proargtypes => 'void',
-  prosrc => 'void_out' },
+  proname => 'void_out', prorettype => 'cstring', proargtypes => 'void' },
 { oid => '2300', descr => 'I/O',
   proname => 'trigger_in', proisstrict => 'f', prorettype => 'trigger',
-  proargtypes => 'cstring', prosrc => 'trigger_in' },
+  proargtypes => 'cstring' },
 { oid => '2301', descr => 'I/O',
-  proname => 'trigger_out', prorettype => 'cstring', proargtypes => 'trigger',
-  prosrc => 'trigger_out' },
+  proname => 'trigger_out', prorettype => 'cstring', proargtypes => 'trigger' },
 { oid => '3594', descr => 'I/O',
   proname => 'event_trigger_in', proisstrict => 'f',
-  prorettype => 'event_trigger', proargtypes => 'cstring',
-  prosrc => 'event_trigger_in' },
+  prorettype => 'event_trigger', proargtypes => 'cstring' },
 { oid => '3595', descr => 'I/O',
   proname => 'event_trigger_out', prorettype => 'cstring',
-  proargtypes => 'event_trigger', prosrc => 'event_trigger_out' },
+  proargtypes => 'event_trigger' },
 { oid => '2302', descr => 'I/O',
   proname => 'language_handler_in', proisstrict => 'f',
-  prorettype => 'language_handler', proargtypes => 'cstring',
-  prosrc => 'language_handler_in' },
+  prorettype => 'language_handler', proargtypes => 'cstring' },
 { oid => '2303', descr => 'I/O',
   proname => 'language_handler_out', prorettype => 'cstring',
-  proargtypes => 'language_handler', prosrc => 'language_handler_out' },
+  proargtypes => 'language_handler' },
 { oid => '2304', descr => 'I/O',
   proname => 'internal_in', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'cstring', prosrc => 'internal_in' },
+  proargtypes => 'cstring' },
 { oid => '2305', descr => 'I/O',
-  proname => 'internal_out', prorettype => 'cstring', proargtypes => 'internal',
-  prosrc => 'internal_out' },
+  proname => 'internal_out', prorettype => 'cstring', proargtypes => 'internal' },
 { oid => '2306', descr => 'I/O',
   proname => 'opaque_in', proisstrict => 'f', prorettype => 'opaque',
-  proargtypes => 'cstring', prosrc => 'opaque_in' },
+  proargtypes => 'cstring' },
 { oid => '2307', descr => 'I/O',
-  proname => 'opaque_out', prorettype => 'cstring', proargtypes => 'opaque',
-  prosrc => 'opaque_out' },
+  proname => 'opaque_out', prorettype => 'cstring', proargtypes => 'opaque' },
 { oid => '2312', descr => 'I/O',
   proname => 'anyelement_in', prorettype => 'anyelement',
-  proargtypes => 'cstring', prosrc => 'anyelement_in' },
+  proargtypes => 'cstring' },
 { oid => '2313', descr => 'I/O',
   proname => 'anyelement_out', prorettype => 'cstring',
-  proargtypes => 'anyelement', prosrc => 'anyelement_out' },
+  proargtypes => 'anyelement' },
 { oid => '2398', descr => 'I/O',
   proname => 'shell_in', proisstrict => 'f', prorettype => 'opaque',
-  proargtypes => 'cstring', prosrc => 'shell_in' },
+  proargtypes => 'cstring' },
 { oid => '2399', descr => 'I/O',
-  proname => 'shell_out', prorettype => 'cstring', proargtypes => 'opaque',
-  prosrc => 'shell_out' },
+  proname => 'shell_out', prorettype => 'cstring', proargtypes => 'opaque' },
 { oid => '2597', descr => 'I/O',
   proname => 'domain_in', proisstrict => 'f', provolatile => 's',
-  prorettype => 'any', proargtypes => 'cstring oid int4',
-  prosrc => 'domain_in' },
+  prorettype => 'any', proargtypes => 'cstring oid int4' },
 { oid => '2598', descr => 'I/O',
   proname => 'domain_recv', proisstrict => 'f', provolatile => 's',
-  prorettype => 'any', proargtypes => 'internal oid int4',
-  prosrc => 'domain_recv' },
+  prorettype => 'any', proargtypes => 'internal oid int4' },
 { oid => '2777', descr => 'I/O',
   proname => 'anynonarray_in', prorettype => 'anynonarray',
-  proargtypes => 'cstring', prosrc => 'anynonarray_in' },
+  proargtypes => 'cstring' },
 { oid => '2778', descr => 'I/O',
   proname => 'anynonarray_out', prorettype => 'cstring',
-  proargtypes => 'anynonarray', prosrc => 'anynonarray_out' },
+  proargtypes => 'anynonarray' },
 { oid => '3116', descr => 'I/O',
   proname => 'fdw_handler_in', proisstrict => 'f', prorettype => 'fdw_handler',
-  proargtypes => 'cstring', prosrc => 'fdw_handler_in' },
+  proargtypes => 'cstring' },
 { oid => '3117', descr => 'I/O',
   proname => 'fdw_handler_out', prorettype => 'cstring',
-  proargtypes => 'fdw_handler', prosrc => 'fdw_handler_out' },
+  proargtypes => 'fdw_handler' },
 { oid => '326', descr => 'I/O',
   proname => 'index_am_handler_in', proisstrict => 'f',
-  prorettype => 'index_am_handler', proargtypes => 'cstring',
-  prosrc => 'index_am_handler_in' },
+  prorettype => 'index_am_handler', proargtypes => 'cstring' },
 { oid => '327', descr => 'I/O',
   proname => 'index_am_handler_out', prorettype => 'cstring',
-  proargtypes => 'index_am_handler', prosrc => 'index_am_handler_out' },
+  proargtypes => 'index_am_handler' },
 { oid => '3311', descr => 'I/O',
   proname => 'tsm_handler_in', proisstrict => 'f', prorettype => 'tsm_handler',
-  proargtypes => 'cstring', prosrc => 'tsm_handler_in' },
+  proargtypes => 'cstring' },
 { oid => '3312', descr => 'I/O',
   proname => 'tsm_handler_out', prorettype => 'cstring',
-  proargtypes => 'tsm_handler', prosrc => 'tsm_handler_out' },
+  proargtypes => 'tsm_handler' },
 
 # tablesample method handlers
 { oid => '3313', descr => 'BERNOULLI tablesample method handler',
@@ -7113,489 +6487,401 @@
 # crosstype operations for date vs. timestamp and timestamptz
 { oid => '2338',
   proname => 'date_lt_timestamp', prorettype => 'bool',
-  proargtypes => 'date timestamp', prosrc => 'date_lt_timestamp' },
+  proargtypes => 'date timestamp' },
 { oid => '2339',
   proname => 'date_le_timestamp', prorettype => 'bool',
-  proargtypes => 'date timestamp', prosrc => 'date_le_timestamp' },
+  proargtypes => 'date timestamp' },
 { oid => '2340',
   proname => 'date_eq_timestamp', prorettype => 'bool',
-  proargtypes => 'date timestamp', prosrc => 'date_eq_timestamp' },
+  proargtypes => 'date timestamp' },
 { oid => '2341',
   proname => 'date_gt_timestamp', prorettype => 'bool',
-  proargtypes => 'date timestamp', prosrc => 'date_gt_timestamp' },
+  proargtypes => 'date timestamp' },
 { oid => '2342',
   proname => 'date_ge_timestamp', prorettype => 'bool',
-  proargtypes => 'date timestamp', prosrc => 'date_ge_timestamp' },
+  proargtypes => 'date timestamp' },
 { oid => '2343',
   proname => 'date_ne_timestamp', prorettype => 'bool',
-  proargtypes => 'date timestamp', prosrc => 'date_ne_timestamp' },
+  proargtypes => 'date timestamp' },
 { oid => '2344', descr => 'less-equal-greater',
   proname => 'date_cmp_timestamp', prorettype => 'int4',
-  proargtypes => 'date timestamp', prosrc => 'date_cmp_timestamp' },
+  proargtypes => 'date timestamp' },
 
 { oid => '2351',
   proname => 'date_lt_timestamptz', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'date timestamptz', prosrc => 'date_lt_timestamptz' },
+  proargtypes => 'date timestamptz' },
 { oid => '2352',
   proname => 'date_le_timestamptz', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'date timestamptz', prosrc => 'date_le_timestamptz' },
+  proargtypes => 'date timestamptz' },
 { oid => '2353',
   proname => 'date_eq_timestamptz', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'date timestamptz', prosrc => 'date_eq_timestamptz' },
+  proargtypes => 'date timestamptz' },
 { oid => '2354',
   proname => 'date_gt_timestamptz', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'date timestamptz', prosrc => 'date_gt_timestamptz' },
+  proargtypes => 'date timestamptz' },
 { oid => '2355',
   proname => 'date_ge_timestamptz', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'date timestamptz', prosrc => 'date_ge_timestamptz' },
+  proargtypes => 'date timestamptz' },
 { oid => '2356',
   proname => 'date_ne_timestamptz', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'date timestamptz', prosrc => 'date_ne_timestamptz' },
+  proargtypes => 'date timestamptz' },
 { oid => '2357', descr => 'less-equal-greater',
   proname => 'date_cmp_timestamptz', provolatile => 's', prorettype => 'int4',
-  proargtypes => 'date timestamptz', prosrc => 'date_cmp_timestamptz' },
+  proargtypes => 'date timestamptz' },
 
 { oid => '2364',
   proname => 'timestamp_lt_date', prorettype => 'bool',
-  proargtypes => 'timestamp date', prosrc => 'timestamp_lt_date' },
+  proargtypes => 'timestamp date' },
 { oid => '2365',
   proname => 'timestamp_le_date', prorettype => 'bool',
-  proargtypes => 'timestamp date', prosrc => 'timestamp_le_date' },
+  proargtypes => 'timestamp date' },
 { oid => '2366',
   proname => 'timestamp_eq_date', prorettype => 'bool',
-  proargtypes => 'timestamp date', prosrc => 'timestamp_eq_date' },
+  proargtypes => 'timestamp date' },
 { oid => '2367',
   proname => 'timestamp_gt_date', prorettype => 'bool',
-  proargtypes => 'timestamp date', prosrc => 'timestamp_gt_date' },
+  proargtypes => 'timestamp date' },
 { oid => '2368',
   proname => 'timestamp_ge_date', prorettype => 'bool',
-  proargtypes => 'timestamp date', prosrc => 'timestamp_ge_date' },
+  proargtypes => 'timestamp date' },
 { oid => '2369',
   proname => 'timestamp_ne_date', prorettype => 'bool',
-  proargtypes => 'timestamp date', prosrc => 'timestamp_ne_date' },
+  proargtypes => 'timestamp date' },
 { oid => '2370', descr => 'less-equal-greater',
   proname => 'timestamp_cmp_date', prorettype => 'int4',
-  proargtypes => 'timestamp date', prosrc => 'timestamp_cmp_date' },
+  proargtypes => 'timestamp date' },
 
 { oid => '2377',
   proname => 'timestamptz_lt_date', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'timestamptz date', prosrc => 'timestamptz_lt_date' },
+  proargtypes => 'timestamptz date' },
 { oid => '2378',
   proname => 'timestamptz_le_date', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'timestamptz date', prosrc => 'timestamptz_le_date' },
+  proargtypes => 'timestamptz date' },
 { oid => '2379',
   proname => 'timestamptz_eq_date', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'timestamptz date', prosrc => 'timestamptz_eq_date' },
+  proargtypes => 'timestamptz date' },
 { oid => '2380',
   proname => 'timestamptz_gt_date', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'timestamptz date', prosrc => 'timestamptz_gt_date' },
+  proargtypes => 'timestamptz date' },
 { oid => '2381',
   proname => 'timestamptz_ge_date', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'timestamptz date', prosrc => 'timestamptz_ge_date' },
+  proargtypes => 'timestamptz date' },
 { oid => '2382',
   proname => 'timestamptz_ne_date', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'timestamptz date', prosrc => 'timestamptz_ne_date' },
+  proargtypes => 'timestamptz date' },
 { oid => '2383', descr => 'less-equal-greater',
   proname => 'timestamptz_cmp_date', provolatile => 's', prorettype => 'int4',
-  proargtypes => 'timestamptz date', prosrc => 'timestamptz_cmp_date' },
+  proargtypes => 'timestamptz date' },
 
 # crosstype operations for timestamp vs. timestamptz
 { oid => '2520',
   proname => 'timestamp_lt_timestamptz', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamp timestamptz',
-  prosrc => 'timestamp_lt_timestamptz' },
+  prorettype => 'bool', proargtypes => 'timestamp timestamptz' },
 { oid => '2521',
   proname => 'timestamp_le_timestamptz', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamp timestamptz',
-  prosrc => 'timestamp_le_timestamptz' },
+  prorettype => 'bool', proargtypes => 'timestamp timestamptz' },
 { oid => '2522',
   proname => 'timestamp_eq_timestamptz', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamp timestamptz',
-  prosrc => 'timestamp_eq_timestamptz' },
+  prorettype => 'bool', proargtypes => 'timestamp timestamptz' },
 { oid => '2523',
   proname => 'timestamp_gt_timestamptz', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamp timestamptz',
-  prosrc => 'timestamp_gt_timestamptz' },
+  prorettype => 'bool', proargtypes => 'timestamp timestamptz' },
 { oid => '2524',
   proname => 'timestamp_ge_timestamptz', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamp timestamptz',
-  prosrc => 'timestamp_ge_timestamptz' },
+  prorettype => 'bool', proargtypes => 'timestamp timestamptz' },
 { oid => '2525',
   proname => 'timestamp_ne_timestamptz', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamp timestamptz',
-  prosrc => 'timestamp_ne_timestamptz' },
+  prorettype => 'bool', proargtypes => 'timestamp timestamptz' },
 { oid => '2526', descr => 'less-equal-greater',
   proname => 'timestamp_cmp_timestamptz', provolatile => 's',
-  prorettype => 'int4', proargtypes => 'timestamp timestamptz',
-  prosrc => 'timestamp_cmp_timestamptz' },
+  prorettype => 'int4', proargtypes => 'timestamp timestamptz' },
 
 { oid => '2527',
   proname => 'timestamptz_lt_timestamp', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamptz timestamp',
-  prosrc => 'timestamptz_lt_timestamp' },
+  prorettype => 'bool', proargtypes => 'timestamptz timestamp' },
 { oid => '2528',
   proname => 'timestamptz_le_timestamp', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamptz timestamp',
-  prosrc => 'timestamptz_le_timestamp' },
+  prorettype => 'bool', proargtypes => 'timestamptz timestamp' },
 { oid => '2529',
   proname => 'timestamptz_eq_timestamp', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamptz timestamp',
-  prosrc => 'timestamptz_eq_timestamp' },
+  prorettype => 'bool', proargtypes => 'timestamptz timestamp' },
 { oid => '2530',
   proname => 'timestamptz_gt_timestamp', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamptz timestamp',
-  prosrc => 'timestamptz_gt_timestamp' },
+  prorettype => 'bool', proargtypes => 'timestamptz timestamp' },
 { oid => '2531',
   proname => 'timestamptz_ge_timestamp', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamptz timestamp',
-  prosrc => 'timestamptz_ge_timestamp' },
+  prorettype => 'bool', proargtypes => 'timestamptz timestamp' },
 { oid => '2532',
   proname => 'timestamptz_ne_timestamp', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'timestamptz timestamp',
-  prosrc => 'timestamptz_ne_timestamp' },
+  prorettype => 'bool', proargtypes => 'timestamptz timestamp' },
 { oid => '2533', descr => 'less-equal-greater',
   proname => 'timestamptz_cmp_timestamp', provolatile => 's',
-  prorettype => 'int4', proargtypes => 'timestamptz timestamp',
-  prosrc => 'timestamptz_cmp_timestamp' },
+  prorettype => 'int4', proargtypes => 'timestamptz timestamp' },
 
 # send/receive functions
 { oid => '2400', descr => 'I/O',
   proname => 'array_recv', provolatile => 's', prorettype => 'anyarray',
-  proargtypes => 'internal oid int4', prosrc => 'array_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2401', descr => 'I/O',
   proname => 'array_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'anyarray', prosrc => 'array_send' },
+  proargtypes => 'anyarray' },
 { oid => '2402', descr => 'I/O',
   proname => 'record_recv', provolatile => 's', prorettype => 'record',
-  proargtypes => 'internal oid int4', prosrc => 'record_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2403', descr => 'I/O',
   proname => 'record_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'record', prosrc => 'record_send' },
+  proargtypes => 'record' },
 { oid => '2404', descr => 'I/O',
-  proname => 'int2recv', prorettype => 'int2', proargtypes => 'internal',
-  prosrc => 'int2recv' },
+  proname => 'int2recv', prorettype => 'int2', proargtypes => 'internal' },
 { oid => '2405', descr => 'I/O',
-  proname => 'int2send', prorettype => 'bytea', proargtypes => 'int2',
-  prosrc => 'int2send' },
+  proname => 'int2send', prorettype => 'bytea', proargtypes => 'int2' },
 { oid => '2406', descr => 'I/O',
-  proname => 'int4recv', prorettype => 'int4', proargtypes => 'internal',
-  prosrc => 'int4recv' },
+  proname => 'int4recv', prorettype => 'int4', proargtypes => 'internal' },
 { oid => '2407', descr => 'I/O',
-  proname => 'int4send', prorettype => 'bytea', proargtypes => 'int4',
-  prosrc => 'int4send' },
+  proname => 'int4send', prorettype => 'bytea', proargtypes => 'int4' },
 { oid => '2408', descr => 'I/O',
-  proname => 'int8recv', prorettype => 'int8', proargtypes => 'internal',
-  prosrc => 'int8recv' },
+  proname => 'int8recv', prorettype => 'int8', proargtypes => 'internal' },
 { oid => '2409', descr => 'I/O',
-  proname => 'int8send', prorettype => 'bytea', proargtypes => 'int8',
-  prosrc => 'int8send' },
+  proname => 'int8send', prorettype => 'bytea', proargtypes => 'int8' },
 { oid => '2410', descr => 'I/O',
   proname => 'int2vectorrecv', prorettype => 'int2vector',
-  proargtypes => 'internal', prosrc => 'int2vectorrecv' },
+  proargtypes => 'internal' },
 { oid => '2411', descr => 'I/O',
   proname => 'int2vectorsend', prorettype => 'bytea',
-  proargtypes => 'int2vector', prosrc => 'int2vectorsend' },
+  proargtypes => 'int2vector' },
 { oid => '2412', descr => 'I/O',
-  proname => 'bytearecv', prorettype => 'bytea', proargtypes => 'internal',
-  prosrc => 'bytearecv' },
+  proname => 'bytearecv', prorettype => 'bytea', proargtypes => 'internal' },
 { oid => '2413', descr => 'I/O',
-  proname => 'byteasend', prorettype => 'bytea', proargtypes => 'bytea',
-  prosrc => 'byteasend' },
+  proname => 'byteasend', prorettype => 'bytea', proargtypes => 'bytea' },
 { oid => '2414', descr => 'I/O',
   proname => 'textrecv', provolatile => 's', prorettype => 'text',
-  proargtypes => 'internal', prosrc => 'textrecv' },
+  proargtypes => 'internal' },
 { oid => '2415', descr => 'I/O',
   proname => 'textsend', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'text', prosrc => 'textsend' },
+  proargtypes => 'text' },
 { oid => '2416', descr => 'I/O',
-  proname => 'unknownrecv', prorettype => 'unknown', proargtypes => 'internal',
-  prosrc => 'unknownrecv' },
+  proname => 'unknownrecv', prorettype => 'unknown', proargtypes => 'internal' },
 { oid => '2417', descr => 'I/O',
-  proname => 'unknownsend', prorettype => 'bytea', proargtypes => 'unknown',
-  prosrc => 'unknownsend' },
+  proname => 'unknownsend', prorettype => 'bytea', proargtypes => 'unknown' },
 { oid => '2418', descr => 'I/O',
-  proname => 'oidrecv', prorettype => 'oid', proargtypes => 'internal',
-  prosrc => 'oidrecv' },
+  proname => 'oidrecv', prorettype => 'oid', proargtypes => 'internal' },
 { oid => '2419', descr => 'I/O',
-  proname => 'oidsend', prorettype => 'bytea', proargtypes => 'oid',
-  prosrc => 'oidsend' },
+  proname => 'oidsend', prorettype => 'bytea', proargtypes => 'oid' },
 { oid => '2420', descr => 'I/O',
   proname => 'oidvectorrecv', prorettype => 'oidvector',
-  proargtypes => 'internal', prosrc => 'oidvectorrecv' },
+  proargtypes => 'internal' },
 { oid => '2421', descr => 'I/O',
-  proname => 'oidvectorsend', prorettype => 'bytea', proargtypes => 'oidvector',
-  prosrc => 'oidvectorsend' },
+  proname => 'oidvectorsend', prorettype => 'bytea', proargtypes => 'oidvector' },
 { oid => '2422', descr => 'I/O',
   proname => 'namerecv', provolatile => 's', prorettype => 'name',
-  proargtypes => 'internal', prosrc => 'namerecv' },
+  proargtypes => 'internal' },
 { oid => '2423', descr => 'I/O',
   proname => 'namesend', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'name', prosrc => 'namesend' },
+  proargtypes => 'name' },
 { oid => '2424', descr => 'I/O',
-  proname => 'float4recv', prorettype => 'float4', proargtypes => 'internal',
-  prosrc => 'float4recv' },
+  proname => 'float4recv', prorettype => 'float4', proargtypes => 'internal' },
 { oid => '2425', descr => 'I/O',
-  proname => 'float4send', prorettype => 'bytea', proargtypes => 'float4',
-  prosrc => 'float4send' },
+  proname => 'float4send', prorettype => 'bytea', proargtypes => 'float4' },
 { oid => '2426', descr => 'I/O',
-  proname => 'float8recv', prorettype => 'float8', proargtypes => 'internal',
-  prosrc => 'float8recv' },
+  proname => 'float8recv', prorettype => 'float8', proargtypes => 'internal' },
 { oid => '2427', descr => 'I/O',
-  proname => 'float8send', prorettype => 'bytea', proargtypes => 'float8',
-  prosrc => 'float8send' },
+  proname => 'float8send', prorettype => 'bytea', proargtypes => 'float8' },
 { oid => '2428', descr => 'I/O',
-  proname => 'point_recv', prorettype => 'point', proargtypes => 'internal',
-  prosrc => 'point_recv' },
+  proname => 'point_recv', prorettype => 'point', proargtypes => 'internal' },
 { oid => '2429', descr => 'I/O',
-  proname => 'point_send', prorettype => 'bytea', proargtypes => 'point',
-  prosrc => 'point_send' },
+  proname => 'point_send', prorettype => 'bytea', proargtypes => 'point' },
 { oid => '2430', descr => 'I/O',
   proname => 'bpcharrecv', provolatile => 's', prorettype => 'bpchar',
-  proargtypes => 'internal oid int4', prosrc => 'bpcharrecv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2431', descr => 'I/O',
   proname => 'bpcharsend', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'bpchar', prosrc => 'bpcharsend' },
+  proargtypes => 'bpchar' },
 { oid => '2432', descr => 'I/O',
   proname => 'varcharrecv', provolatile => 's', prorettype => 'varchar',
-  proargtypes => 'internal oid int4', prosrc => 'varcharrecv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2433', descr => 'I/O',
   proname => 'varcharsend', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'varchar', prosrc => 'varcharsend' },
+  proargtypes => 'varchar' },
 { oid => '2434', descr => 'I/O',
-  proname => 'charrecv', prorettype => 'char', proargtypes => 'internal',
-  prosrc => 'charrecv' },
+  proname => 'charrecv', prorettype => 'char', proargtypes => 'internal' },
 { oid => '2435', descr => 'I/O',
-  proname => 'charsend', prorettype => 'bytea', proargtypes => 'char',
-  prosrc => 'charsend' },
+  proname => 'charsend', prorettype => 'bytea', proargtypes => 'char' },
 { oid => '2436', descr => 'I/O',
-  proname => 'boolrecv', prorettype => 'bool', proargtypes => 'internal',
-  prosrc => 'boolrecv' },
+  proname => 'boolrecv', prorettype => 'bool', proargtypes => 'internal' },
 { oid => '2437', descr => 'I/O',
-  proname => 'boolsend', prorettype => 'bytea', proargtypes => 'bool',
-  prosrc => 'boolsend' },
+  proname => 'boolsend', prorettype => 'bytea', proargtypes => 'bool' },
 { oid => '2438', descr => 'I/O',
-  proname => 'tidrecv', prorettype => 'tid', proargtypes => 'internal',
-  prosrc => 'tidrecv' },
+  proname => 'tidrecv', prorettype => 'tid', proargtypes => 'internal' },
 { oid => '2439', descr => 'I/O',
-  proname => 'tidsend', prorettype => 'bytea', proargtypes => 'tid',
-  prosrc => 'tidsend' },
+  proname => 'tidsend', prorettype => 'bytea', proargtypes => 'tid' },
 { oid => '2440', descr => 'I/O',
-  proname => 'xidrecv', prorettype => 'xid', proargtypes => 'internal',
-  prosrc => 'xidrecv' },
+  proname => 'xidrecv', prorettype => 'xid', proargtypes => 'internal' },
 { oid => '2441', descr => 'I/O',
-  proname => 'xidsend', prorettype => 'bytea', proargtypes => 'xid',
-  prosrc => 'xidsend' },
+  proname => 'xidsend', prorettype => 'bytea', proargtypes => 'xid' },
 { oid => '2442', descr => 'I/O',
-  proname => 'cidrecv', prorettype => 'cid', proargtypes => 'internal',
-  prosrc => 'cidrecv' },
+  proname => 'cidrecv', prorettype => 'cid', proargtypes => 'internal' },
 { oid => '2443', descr => 'I/O',
-  proname => 'cidsend', prorettype => 'bytea', proargtypes => 'cid',
-  prosrc => 'cidsend' },
+  proname => 'cidsend', prorettype => 'bytea', proargtypes => 'cid' },
 { oid => '2444', descr => 'I/O',
-  proname => 'regprocrecv', prorettype => 'regproc', proargtypes => 'internal',
-  prosrc => 'regprocrecv' },
+  proname => 'regprocrecv', prorettype => 'regproc', proargtypes => 'internal' },
 { oid => '2445', descr => 'I/O',
-  proname => 'regprocsend', prorettype => 'bytea', proargtypes => 'regproc',
-  prosrc => 'regprocsend' },
+  proname => 'regprocsend', prorettype => 'bytea', proargtypes => 'regproc' },
 { oid => '2446', descr => 'I/O',
   proname => 'regprocedurerecv', prorettype => 'regprocedure',
-  proargtypes => 'internal', prosrc => 'regprocedurerecv' },
+  proargtypes => 'internal' },
 { oid => '2447', descr => 'I/O',
   proname => 'regproceduresend', prorettype => 'bytea',
-  proargtypes => 'regprocedure', prosrc => 'regproceduresend' },
+  proargtypes => 'regprocedure' },
 { oid => '2448', descr => 'I/O',
-  proname => 'regoperrecv', prorettype => 'regoper', proargtypes => 'internal',
-  prosrc => 'regoperrecv' },
+  proname => 'regoperrecv', prorettype => 'regoper', proargtypes => 'internal' },
 { oid => '2449', descr => 'I/O',
-  proname => 'regopersend', prorettype => 'bytea', proargtypes => 'regoper',
-  prosrc => 'regopersend' },
+  proname => 'regopersend', prorettype => 'bytea', proargtypes => 'regoper' },
 { oid => '2450', descr => 'I/O',
   proname => 'regoperatorrecv', prorettype => 'regoperator',
-  proargtypes => 'internal', prosrc => 'regoperatorrecv' },
+  proargtypes => 'internal' },
 { oid => '2451', descr => 'I/O',
   proname => 'regoperatorsend', prorettype => 'bytea',
-  proargtypes => 'regoperator', prosrc => 'regoperatorsend' },
+  proargtypes => 'regoperator' },
 { oid => '2452', descr => 'I/O',
   proname => 'regclassrecv', prorettype => 'regclass',
-  proargtypes => 'internal', prosrc => 'regclassrecv' },
+  proargtypes => 'internal' },
 { oid => '2453', descr => 'I/O',
-  proname => 'regclasssend', prorettype => 'bytea', proargtypes => 'regclass',
-  prosrc => 'regclasssend' },
+  proname => 'regclasssend', prorettype => 'bytea', proargtypes => 'regclass' },
 { oid => '2454', descr => 'I/O',
-  proname => 'regtyperecv', prorettype => 'regtype', proargtypes => 'internal',
-  prosrc => 'regtyperecv' },
+  proname => 'regtyperecv', prorettype => 'regtype', proargtypes => 'internal' },
 { oid => '2455', descr => 'I/O',
-  proname => 'regtypesend', prorettype => 'bytea', proargtypes => 'regtype',
-  prosrc => 'regtypesend' },
+  proname => 'regtypesend', prorettype => 'bytea', proargtypes => 'regtype' },
 
 { oid => '4094', descr => 'I/O',
-  proname => 'regrolerecv', prorettype => 'regrole', proargtypes => 'internal',
-  prosrc => 'regrolerecv' },
+  proname => 'regrolerecv', prorettype => 'regrole', proargtypes => 'internal' },
 { oid => '4095', descr => 'I/O',
-  proname => 'regrolesend', prorettype => 'bytea', proargtypes => 'regrole',
-  prosrc => 'regrolesend' },
+  proname => 'regrolesend', prorettype => 'bytea', proargtypes => 'regrole' },
 { oid => '4087', descr => 'I/O',
   proname => 'regnamespacerecv', prorettype => 'regnamespace',
-  proargtypes => 'internal', prosrc => 'regnamespacerecv' },
+  proargtypes => 'internal' },
 { oid => '4088', descr => 'I/O',
   proname => 'regnamespacesend', prorettype => 'bytea',
-  proargtypes => 'regnamespace', prosrc => 'regnamespacesend' },
+  proargtypes => 'regnamespace' },
 { oid => '2456', descr => 'I/O',
   proname => 'bit_recv', prorettype => 'bit',
-  proargtypes => 'internal oid int4', prosrc => 'bit_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2457', descr => 'I/O',
-  proname => 'bit_send', prorettype => 'bytea', proargtypes => 'bit',
-  prosrc => 'bit_send' },
+  proname => 'bit_send', prorettype => 'bytea', proargtypes => 'bit' },
 { oid => '2458', descr => 'I/O',
   proname => 'varbit_recv', prorettype => 'varbit',
-  proargtypes => 'internal oid int4', prosrc => 'varbit_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2459', descr => 'I/O',
-  proname => 'varbit_send', prorettype => 'bytea', proargtypes => 'varbit',
-  prosrc => 'varbit_send' },
+  proname => 'varbit_send', prorettype => 'bytea', proargtypes => 'varbit' },
 { oid => '2460', descr => 'I/O',
   proname => 'numeric_recv', prorettype => 'numeric',
-  proargtypes => 'internal oid int4', prosrc => 'numeric_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2461', descr => 'I/O',
-  proname => 'numeric_send', prorettype => 'bytea', proargtypes => 'numeric',
-  prosrc => 'numeric_send' },
+  proname => 'numeric_send', prorettype => 'bytea', proargtypes => 'numeric' },
 { oid => '2462', descr => 'I/O',
-  proname => 'abstimerecv', prorettype => 'abstime', proargtypes => 'internal',
-  prosrc => 'abstimerecv' },
+  proname => 'abstimerecv', prorettype => 'abstime', proargtypes => 'internal' },
 { oid => '2463', descr => 'I/O',
-  proname => 'abstimesend', prorettype => 'bytea', proargtypes => 'abstime',
-  prosrc => 'abstimesend' },
+  proname => 'abstimesend', prorettype => 'bytea', proargtypes => 'abstime' },
 { oid => '2464', descr => 'I/O',
-  proname => 'reltimerecv', prorettype => 'reltime', proargtypes => 'internal',
-  prosrc => 'reltimerecv' },
+  proname => 'reltimerecv', prorettype => 'reltime', proargtypes => 'internal' },
 { oid => '2465', descr => 'I/O',
-  proname => 'reltimesend', prorettype => 'bytea', proargtypes => 'reltime',
-  prosrc => 'reltimesend' },
+  proname => 'reltimesend', prorettype => 'bytea', proargtypes => 'reltime' },
 { oid => '2466', descr => 'I/O',
   proname => 'tintervalrecv', prorettype => 'tinterval',
-  proargtypes => 'internal', prosrc => 'tintervalrecv' },
+  proargtypes => 'internal' },
 { oid => '2467', descr => 'I/O',
-  proname => 'tintervalsend', prorettype => 'bytea', proargtypes => 'tinterval',
-  prosrc => 'tintervalsend' },
+  proname => 'tintervalsend', prorettype => 'bytea', proargtypes => 'tinterval' },
 { oid => '2468', descr => 'I/O',
-  proname => 'date_recv', prorettype => 'date', proargtypes => 'internal',
-  prosrc => 'date_recv' },
+  proname => 'date_recv', prorettype => 'date', proargtypes => 'internal' },
 { oid => '2469', descr => 'I/O',
-  proname => 'date_send', prorettype => 'bytea', proargtypes => 'date',
-  prosrc => 'date_send' },
+  proname => 'date_send', prorettype => 'bytea', proargtypes => 'date' },
 { oid => '2470', descr => 'I/O',
   proname => 'time_recv', prorettype => 'time',
-  proargtypes => 'internal oid int4', prosrc => 'time_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2471', descr => 'I/O',
-  proname => 'time_send', prorettype => 'bytea', proargtypes => 'time',
-  prosrc => 'time_send' },
+  proname => 'time_send', prorettype => 'bytea', proargtypes => 'time' },
 { oid => '2472', descr => 'I/O',
   proname => 'timetz_recv', prorettype => 'timetz',
-  proargtypes => 'internal oid int4', prosrc => 'timetz_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2473', descr => 'I/O',
-  proname => 'timetz_send', prorettype => 'bytea', proargtypes => 'timetz',
-  prosrc => 'timetz_send' },
+  proname => 'timetz_send', prorettype => 'bytea', proargtypes => 'timetz' },
 { oid => '2474', descr => 'I/O',
   proname => 'timestamp_recv', prorettype => 'timestamp',
-  proargtypes => 'internal oid int4', prosrc => 'timestamp_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2475', descr => 'I/O',
   proname => 'timestamp_send', prorettype => 'bytea',
-  proargtypes => 'timestamp', prosrc => 'timestamp_send' },
+  proargtypes => 'timestamp' },
 { oid => '2476', descr => 'I/O',
   proname => 'timestamptz_recv', prorettype => 'timestamptz',
-  proargtypes => 'internal oid int4', prosrc => 'timestamptz_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2477', descr => 'I/O',
   proname => 'timestamptz_send', prorettype => 'bytea',
-  proargtypes => 'timestamptz', prosrc => 'timestamptz_send' },
+  proargtypes => 'timestamptz' },
 { oid => '2478', descr => 'I/O',
   proname => 'interval_recv', prorettype => 'interval',
-  proargtypes => 'internal oid int4', prosrc => 'interval_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '2479', descr => 'I/O',
-  proname => 'interval_send', prorettype => 'bytea', proargtypes => 'interval',
-  prosrc => 'interval_send' },
+  proname => 'interval_send', prorettype => 'bytea', proargtypes => 'interval' },
 { oid => '2480', descr => 'I/O',
-  proname => 'lseg_recv', prorettype => 'lseg', proargtypes => 'internal',
-  prosrc => 'lseg_recv' },
+  proname => 'lseg_recv', prorettype => 'lseg', proargtypes => 'internal' },
 { oid => '2481', descr => 'I/O',
-  proname => 'lseg_send', prorettype => 'bytea', proargtypes => 'lseg',
-  prosrc => 'lseg_send' },
+  proname => 'lseg_send', prorettype => 'bytea', proargtypes => 'lseg' },
 { oid => '2482', descr => 'I/O',
-  proname => 'path_recv', prorettype => 'path', proargtypes => 'internal',
-  prosrc => 'path_recv' },
+  proname => 'path_recv', prorettype => 'path', proargtypes => 'internal' },
 { oid => '2483', descr => 'I/O',
-  proname => 'path_send', prorettype => 'bytea', proargtypes => 'path',
-  prosrc => 'path_send' },
+  proname => 'path_send', prorettype => 'bytea', proargtypes => 'path' },
 { oid => '2484', descr => 'I/O',
-  proname => 'box_recv', prorettype => 'box', proargtypes => 'internal',
-  prosrc => 'box_recv' },
+  proname => 'box_recv', prorettype => 'box', proargtypes => 'internal' },
 { oid => '2485', descr => 'I/O',
-  proname => 'box_send', prorettype => 'bytea', proargtypes => 'box',
-  prosrc => 'box_send' },
+  proname => 'box_send', prorettype => 'bytea', proargtypes => 'box' },
 { oid => '2486', descr => 'I/O',
-  proname => 'poly_recv', prorettype => 'polygon', proargtypes => 'internal',
-  prosrc => 'poly_recv' },
+  proname => 'poly_recv', prorettype => 'polygon', proargtypes => 'internal' },
 { oid => '2487', descr => 'I/O',
-  proname => 'poly_send', prorettype => 'bytea', proargtypes => 'polygon',
-  prosrc => 'poly_send' },
+  proname => 'poly_send', prorettype => 'bytea', proargtypes => 'polygon' },
 { oid => '2488', descr => 'I/O',
-  proname => 'line_recv', prorettype => 'line', proargtypes => 'internal',
-  prosrc => 'line_recv' },
+  proname => 'line_recv', prorettype => 'line', proargtypes => 'internal' },
 { oid => '2489', descr => 'I/O',
-  proname => 'line_send', prorettype => 'bytea', proargtypes => 'line',
-  prosrc => 'line_send' },
+  proname => 'line_send', prorettype => 'bytea', proargtypes => 'line' },
 { oid => '2490', descr => 'I/O',
-  proname => 'circle_recv', prorettype => 'circle', proargtypes => 'internal',
-  prosrc => 'circle_recv' },
+  proname => 'circle_recv', prorettype => 'circle', proargtypes => 'internal' },
 { oid => '2491', descr => 'I/O',
-  proname => 'circle_send', prorettype => 'bytea', proargtypes => 'circle',
-  prosrc => 'circle_send' },
+  proname => 'circle_send', prorettype => 'bytea', proargtypes => 'circle' },
 { oid => '2492', descr => 'I/O',
-  proname => 'cash_recv', prorettype => 'money', proargtypes => 'internal',
-  prosrc => 'cash_recv' },
+  proname => 'cash_recv', prorettype => 'money', proargtypes => 'internal' },
 { oid => '2493', descr => 'I/O',
-  proname => 'cash_send', prorettype => 'bytea', proargtypes => 'money',
-  prosrc => 'cash_send' },
+  proname => 'cash_send', prorettype => 'bytea', proargtypes => 'money' },
 { oid => '2494', descr => 'I/O',
-  proname => 'macaddr_recv', prorettype => 'macaddr', proargtypes => 'internal',
-  prosrc => 'macaddr_recv' },
+  proname => 'macaddr_recv', prorettype => 'macaddr', proargtypes => 'internal' },
 { oid => '2495', descr => 'I/O',
-  proname => 'macaddr_send', prorettype => 'bytea', proargtypes => 'macaddr',
-  prosrc => 'macaddr_send' },
+  proname => 'macaddr_send', prorettype => 'bytea', proargtypes => 'macaddr' },
 { oid => '2496', descr => 'I/O',
-  proname => 'inet_recv', prorettype => 'inet', proargtypes => 'internal',
-  prosrc => 'inet_recv' },
+  proname => 'inet_recv', prorettype => 'inet', proargtypes => 'internal' },
 { oid => '2497', descr => 'I/O',
-  proname => 'inet_send', prorettype => 'bytea', proargtypes => 'inet',
-  prosrc => 'inet_send' },
+  proname => 'inet_send', prorettype => 'bytea', proargtypes => 'inet' },
 { oid => '2498', descr => 'I/O',
-  proname => 'cidr_recv', prorettype => 'cidr', proargtypes => 'internal',
-  prosrc => 'cidr_recv' },
+  proname => 'cidr_recv', prorettype => 'cidr', proargtypes => 'internal' },
 { oid => '2499', descr => 'I/O',
-  proname => 'cidr_send', prorettype => 'bytea', proargtypes => 'cidr',
-  prosrc => 'cidr_send' },
+  proname => 'cidr_send', prorettype => 'bytea', proargtypes => 'cidr' },
 { oid => '2500', descr => 'I/O',
   proname => 'cstring_recv', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'internal', prosrc => 'cstring_recv' },
+  proargtypes => 'internal' },
 { oid => '2501', descr => 'I/O',
   proname => 'cstring_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'cstring', prosrc => 'cstring_send' },
+  proargtypes => 'cstring' },
 { oid => '2502', descr => 'I/O',
   proname => 'anyarray_recv', provolatile => 's', prorettype => 'anyarray',
-  proargtypes => 'internal', prosrc => 'anyarray_recv' },
+  proargtypes => 'internal' },
 { oid => '2503', descr => 'I/O',
   proname => 'anyarray_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'anyarray', prosrc => 'anyarray_send' },
+  proargtypes => 'anyarray' },
 { oid => '3120', descr => 'I/O',
-  proname => 'void_recv', prorettype => 'void', proargtypes => 'internal',
-  prosrc => 'void_recv' },
+  proname => 'void_recv', prorettype => 'void', proargtypes => 'internal' },
 { oid => '3121', descr => 'I/O',
-  proname => 'void_send', prorettype => 'bytea', proargtypes => 'void',
-  prosrc => 'void_send' },
+  proname => 'void_send', prorettype => 'bytea', proargtypes => 'void' },
 { oid => '3446', descr => 'I/O',
   proname => 'macaddr8_recv', prorettype => 'macaddr8',
-  proargtypes => 'internal', prosrc => 'macaddr8_recv' },
+  proargtypes => 'internal' },
 { oid => '3447', descr => 'I/O',
-  proname => 'macaddr8_send', prorettype => 'bytea', proargtypes => 'macaddr8',
-  prosrc => 'macaddr8_send' },
+  proname => 'macaddr8_send', prorettype => 'bytea', proargtypes => 'macaddr8' },
 
 # System-view support functions with pretty-print option
 { oid => '2504', descr => 'source text of a rule with pretty-print option',
@@ -7632,27 +6918,23 @@
   provolatile => 's', proparallel => 'r', prorettype => 'record',
   proargtypes => '', proallargtypes => '{text,text,timestamptz,_regtype,bool}',
   proargmodes => '{o,o,o,o,o}',
-  proargnames => '{name,statement,prepare_time,parameter_types,from_sql}',
-  prosrc => 'pg_prepared_statement' },
+  proargnames => '{name,statement,prepare_time,parameter_types,from_sql}' },
 { oid => '2511', descr => 'get the open cursors for this session',
   proname => 'pg_cursor', prorows => '1000', proretset => 't',
   provolatile => 's', proparallel => 'r', prorettype => 'record',
   proargtypes => '', proallargtypes => '{text,text,bool,bool,bool,timestamptz}',
   proargmodes => '{o,o,o,o,o,o}',
-  proargnames => '{name,statement,is_holdable,is_binary,is_scrollable,creation_time}',
-  prosrc => 'pg_cursor' },
+  proargnames => '{name,statement,is_holdable,is_binary,is_scrollable,creation_time}' },
 { oid => '2599', descr => 'get the available time zone abbreviations',
   proname => 'pg_timezone_abbrevs', prorows => '1000', proretset => 't',
   provolatile => 's', prorettype => 'record', proargtypes => '',
   proallargtypes => '{text,interval,bool}', proargmodes => '{o,o,o}',
-  proargnames => '{abbrev,utc_offset,is_dst}',
-  prosrc => 'pg_timezone_abbrevs' },
+  proargnames => '{abbrev,utc_offset,is_dst}' },
 { oid => '2856', descr => 'get the available time zone names',
   proname => 'pg_timezone_names', prorows => '1000', proretset => 't',
   provolatile => 's', prorettype => 'record', proargtypes => '',
   proallargtypes => '{text,text,interval,bool}', proargmodes => '{o,o,o,o}',
-  proargnames => '{name,abbrev,utc_offset,is_dst}',
-  prosrc => 'pg_timezone_names' },
+  proargnames => '{name,abbrev,utc_offset,is_dst}' },
 { oid => '2730', descr => 'trigger description with pretty-print option',
   proname => 'pg_get_triggerdef', provolatile => 's', prorettype => 'text',
   proargtypes => 'oid bool', prosrc => 'pg_get_triggerdef_ext' },
@@ -7662,16 +6944,14 @@
   descr => 'get the channels that the current backend listens to',
   proname => 'pg_listening_channels', prorows => '10', proretset => 't',
   provolatile => 's', proparallel => 'r', prorettype => 'text',
-  proargtypes => '', prosrc => 'pg_listening_channels' },
+  proargtypes => '' },
 { oid => '3036', descr => 'send a notification event',
   proname => 'pg_notify', proisstrict => 'f', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'text text',
-  prosrc => 'pg_notify' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'text text' },
 { oid => '3296',
   descr => 'get the fraction of the asynchronous notification queue currently in use',
   proname => 'pg_notification_queue_usage', provolatile => 'v',
-  prorettype => 'float8', proargtypes => '',
-  prosrc => 'pg_notification_queue_usage' },
+  prorettype => 'float8', proargtypes => '' },
 
 # non-persistent series generator
 { oid => '1066', descr => 'non-persistent series generator',
@@ -7711,22 +6991,20 @@
 # boolean aggregates
 { oid => '2515', descr => 'aggregate transition function',
   proname => 'booland_statefunc', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'booland_statefunc' },
+  proargtypes => 'bool bool' },
 { oid => '2516', descr => 'aggregate transition function',
   proname => 'boolor_statefunc', prorettype => 'bool',
-  proargtypes => 'bool bool', prosrc => 'boolor_statefunc' },
+  proargtypes => 'bool bool' },
 { oid => '3496', descr => 'aggregate transition function',
   proname => 'bool_accum', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal bool', prosrc => 'bool_accum' },
+  proargtypes => 'internal bool' },
 { oid => '3497', descr => 'aggregate transition function',
   proname => 'bool_accum_inv', proisstrict => 'f', prorettype => 'internal',
-  proargtypes => 'internal bool', prosrc => 'bool_accum_inv' },
+  proargtypes => 'internal bool' },
 { oid => '3498', descr => 'aggregate final function',
-  proname => 'bool_alltrue', prorettype => 'bool', proargtypes => 'internal',
-  prosrc => 'bool_alltrue' },
+  proname => 'bool_alltrue', prorettype => 'bool', proargtypes => 'internal' },
 { oid => '3499', descr => 'aggregate final function',
-  proname => 'bool_anytrue', prorettype => 'bool', proargtypes => 'internal',
-  prosrc => 'bool_anytrue' },
+  proname => 'bool_anytrue', prorettype => 'bool', proargtypes => 'internal' },
 { oid => '2517', descr => 'boolean-and aggregate',
   proname => 'bool_and', prokind => 'a', proisstrict => 'f',
   prorettype => 'bool', proargtypes => 'bool', prosrc => 'aggregate_dummy' },
@@ -7786,8 +7064,7 @@
 
 { oid => '2556', descr => 'get OIDs of databases in a tablespace',
   proname => 'pg_tablespace_databases', prorows => '1000', proretset => 't',
-  provolatile => 's', prorettype => 'oid', proargtypes => 'oid',
-  prosrc => 'pg_tablespace_databases' },
+  provolatile => 's', prorettype => 'oid', proargtypes => 'oid' },
 
 { oid => '2557', descr => 'convert int4 to boolean',
   proname => 'bool', prorettype => 'bool', proargtypes => 'int4',
@@ -7797,122 +7074,106 @@
   prosrc => 'bool_int4' },
 { oid => '2559', descr => 'current value from last used sequence',
   proname => 'lastval', provolatile => 'v', proparallel => 'u',
-  prorettype => 'int8', proargtypes => '', prosrc => 'lastval' },
+  prorettype => 'int8', proargtypes => '' },
 
 # start time function
 { oid => '2560', descr => 'postmaster start time',
   proname => 'pg_postmaster_start_time', provolatile => 's',
-  prorettype => 'timestamptz', proargtypes => '',
-  prosrc => 'pg_postmaster_start_time' },
+  prorettype => 'timestamptz', proargtypes => '' },
 
 # config reload time function
 { oid => '2034', descr => 'configuration load time',
   proname => 'pg_conf_load_time', provolatile => 's', proparallel => 'r',
-  prorettype => 'timestamptz', proargtypes => '',
-  prosrc => 'pg_conf_load_time' },
+  prorettype => 'timestamptz', proargtypes => '' },
 
 # new functions for Y-direction rtree opclasses
 { oid => '2562',
-  proname => 'box_below', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_below' },
+  proname => 'box_below', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '2563',
-  proname => 'box_overbelow', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_overbelow' },
+  proname => 'box_overbelow', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '2564',
-  proname => 'box_overabove', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_overabove' },
+  proname => 'box_overabove', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '2565',
-  proname => 'box_above', prorettype => 'bool', proargtypes => 'box box',
-  prosrc => 'box_above' },
+  proname => 'box_above', prorettype => 'bool', proargtypes => 'box box' },
 { oid => '2566',
   proname => 'poly_below', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_below' },
+  proargtypes => 'polygon polygon' },
 { oid => '2567',
   proname => 'poly_overbelow', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_overbelow' },
+  proargtypes => 'polygon polygon' },
 { oid => '2568',
   proname => 'poly_overabove', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_overabove' },
+  proargtypes => 'polygon polygon' },
 { oid => '2569',
   proname => 'poly_above', prorettype => 'bool',
-  proargtypes => 'polygon polygon', prosrc => 'poly_above' },
+  proargtypes => 'polygon polygon' },
 { oid => '2587',
   proname => 'circle_overbelow', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_overbelow' },
+  proargtypes => 'circle circle' },
 { oid => '2588',
   proname => 'circle_overabove', prorettype => 'bool',
-  proargtypes => 'circle circle', prosrc => 'circle_overabove' },
+  proargtypes => 'circle circle' },
 
 # support functions for GiST r-tree emulation
 { oid => '2578', descr => 'GiST support',
   proname => 'gist_box_consistent', prorettype => 'bool',
-  proargtypes => 'internal box int2 oid internal',
-  prosrc => 'gist_box_consistent' },
+  proargtypes => 'internal box int2 oid internal' },
 { oid => '2581', descr => 'GiST support',
   proname => 'gist_box_penalty', prorettype => 'internal',
-  proargtypes => 'internal internal internal', prosrc => 'gist_box_penalty' },
+  proargtypes => 'internal internal internal' },
 { oid => '2582', descr => 'GiST support',
   proname => 'gist_box_picksplit', prorettype => 'internal',
-  proargtypes => 'internal internal', prosrc => 'gist_box_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '2583', descr => 'GiST support',
   proname => 'gist_box_union', prorettype => 'box',
-  proargtypes => 'internal internal', prosrc => 'gist_box_union' },
+  proargtypes => 'internal internal' },
 { oid => '2584', descr => 'GiST support',
   proname => 'gist_box_same', prorettype => 'internal',
-  proargtypes => 'box box internal', prosrc => 'gist_box_same' },
+  proargtypes => 'box box internal' },
 { oid => '2585', descr => 'GiST support',
   proname => 'gist_poly_consistent', prorettype => 'bool',
-  proargtypes => 'internal polygon int2 oid internal',
-  prosrc => 'gist_poly_consistent' },
+  proargtypes => 'internal polygon int2 oid internal' },
 { oid => '2586', descr => 'GiST support',
   proname => 'gist_poly_compress', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'gist_poly_compress' },
+  proargtypes => 'internal' },
 { oid => '2591', descr => 'GiST support',
   proname => 'gist_circle_consistent', prorettype => 'bool',
-  proargtypes => 'internal circle int2 oid internal',
-  prosrc => 'gist_circle_consistent' },
+  proargtypes => 'internal circle int2 oid internal' },
 { oid => '2592', descr => 'GiST support',
   proname => 'gist_circle_compress', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'gist_circle_compress' },
+  proargtypes => 'internal' },
 { oid => '1030', descr => 'GiST support',
   proname => 'gist_point_compress', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'gist_point_compress' },
+  proargtypes => 'internal' },
 { oid => '3282', descr => 'GiST support',
   proname => 'gist_point_fetch', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'gist_point_fetch' },
+  proargtypes => 'internal' },
 { oid => '2179', descr => 'GiST support',
   proname => 'gist_point_consistent', prorettype => 'bool',
-  proargtypes => 'internal point int2 oid internal',
-  prosrc => 'gist_point_consistent' },
+  proargtypes => 'internal point int2 oid internal' },
 { oid => '3064', descr => 'GiST support',
   proname => 'gist_point_distance', prorettype => 'float8',
-  proargtypes => 'internal point int2 oid internal',
-  prosrc => 'gist_point_distance' },
+  proargtypes => 'internal point int2 oid internal' },
 { oid => '3280', descr => 'GiST support',
   proname => 'gist_circle_distance', prorettype => 'float8',
-  proargtypes => 'internal circle int2 oid internal',
-  prosrc => 'gist_circle_distance' },
+  proargtypes => 'internal circle int2 oid internal' },
 { oid => '3288', descr => 'GiST support',
   proname => 'gist_poly_distance', prorettype => 'float8',
-  proargtypes => 'internal polygon int2 oid internal',
-  prosrc => 'gist_poly_distance' },
+  proargtypes => 'internal polygon int2 oid internal' },
 
 # GIN array support
 { oid => '2743', descr => 'GIN array support',
   proname => 'ginarrayextract', prorettype => 'internal',
-  proargtypes => 'anyarray internal internal', prosrc => 'ginarrayextract' },
+  proargtypes => 'anyarray internal internal' },
 { oid => '2774', descr => 'GIN array support',
   proname => 'ginqueryarrayextract', prorettype => 'internal',
-  proargtypes => 'anyarray internal int2 internal internal internal internal',
-  prosrc => 'ginqueryarrayextract' },
+  proargtypes => 'anyarray internal int2 internal internal internal internal' },
 { oid => '2744', descr => 'GIN array support',
   proname => 'ginarrayconsistent', prorettype => 'bool',
-  proargtypes => 'internal int2 anyarray int4 internal internal internal internal',
-  prosrc => 'ginarrayconsistent' },
+  proargtypes => 'internal int2 anyarray int4 internal internal internal internal' },
 { oid => '3920', descr => 'GIN array support',
   proname => 'ginarraytriconsistent', prorettype => 'char',
-  proargtypes => 'internal int2 anyarray int4 internal internal internal',
-  prosrc => 'ginarraytriconsistent' },
+  proargtypes => 'internal int2 anyarray int4 internal internal internal' },
 { oid => '3076', descr => 'GIN array support (obsolete)',
   proname => 'ginarrayextract', prorettype => 'internal',
   proargtypes => 'anyarray internal', prosrc => 'ginarrayextract_2args' },
@@ -7920,46 +7181,41 @@
 # overlap/contains/contained
 { oid => '2747',
   proname => 'arrayoverlap', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'arrayoverlap' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '2748',
   proname => 'arraycontains', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'arraycontains' },
+  proargtypes => 'anyarray anyarray' },
 { oid => '2749',
   proname => 'arraycontained', prorettype => 'bool',
-  proargtypes => 'anyarray anyarray', prosrc => 'arraycontained' },
+  proargtypes => 'anyarray anyarray' },
 
 # BRIN minmax
 { oid => '3383', descr => 'BRIN minmax support',
   proname => 'brin_minmax_opcinfo', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'brin_minmax_opcinfo' },
+  proargtypes => 'internal' },
 { oid => '3384', descr => 'BRIN minmax support',
   proname => 'brin_minmax_add_value', prorettype => 'bool',
-  proargtypes => 'internal internal internal internal',
-  prosrc => 'brin_minmax_add_value' },
+  proargtypes => 'internal internal internal internal' },
 { oid => '3385', descr => 'BRIN minmax support',
   proname => 'brin_minmax_consistent', prorettype => 'bool',
-  proargtypes => 'internal internal internal',
-  prosrc => 'brin_minmax_consistent' },
+  proargtypes => 'internal internal internal' },
 { oid => '3386', descr => 'BRIN minmax support',
   proname => 'brin_minmax_union', prorettype => 'bool',
-  proargtypes => 'internal internal internal', prosrc => 'brin_minmax_union' },
+  proargtypes => 'internal internal internal' },
 
 # BRIN inclusion
 { oid => '4105', descr => 'BRIN inclusion support',
   proname => 'brin_inclusion_opcinfo', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'brin_inclusion_opcinfo' },
+  proargtypes => 'internal' },
 { oid => '4106', descr => 'BRIN inclusion support',
   proname => 'brin_inclusion_add_value', prorettype => 'bool',
-  proargtypes => 'internal internal internal internal',
-  prosrc => 'brin_inclusion_add_value' },
+  proargtypes => 'internal internal internal internal' },
 { oid => '4107', descr => 'BRIN inclusion support',
   proname => 'brin_inclusion_consistent', prorettype => 'bool',
-  proargtypes => 'internal internal internal',
-  prosrc => 'brin_inclusion_consistent' },
+  proargtypes => 'internal internal internal' },
 { oid => '4108', descr => 'BRIN inclusion support',
   proname => 'brin_inclusion_union', prorettype => 'bool',
-  proargtypes => 'internal internal internal',
-  prosrc => 'brin_inclusion_union' },
+  proargtypes => 'internal internal internal' },
 
 # userlock replacements
 { oid => '2880', descr => 'obtain exclusive advisory lock',
@@ -8044,34 +7300,31 @@
   prosrc => 'pg_advisory_unlock_shared_int4' },
 { oid => '2892', descr => 'release all advisory locks',
   proname => 'pg_advisory_unlock_all', provolatile => 'v', proparallel => 'u',
-  prorettype => 'void', proargtypes => '', prosrc => 'pg_advisory_unlock_all' },
+  prorettype => 'void', proargtypes => '' },
 
 # XML support
 { oid => '2893', descr => 'I/O',
   proname => 'xml_in', provolatile => 's', prorettype => 'xml',
-  proargtypes => 'cstring', prosrc => 'xml_in' },
+  proargtypes => 'cstring' },
 { oid => '2894', descr => 'I/O',
-  proname => 'xml_out', prorettype => 'cstring', proargtypes => 'xml',
-  prosrc => 'xml_out' },
+  proname => 'xml_out', prorettype => 'cstring', proargtypes => 'xml' },
 { oid => '2895', descr => 'generate XML comment',
-  proname => 'xmlcomment', prorettype => 'xml', proargtypes => 'text',
-  prosrc => 'xmlcomment' },
+  proname => 'xmlcomment', prorettype => 'xml', proargtypes => 'text' },
 { oid => '2896',
   descr => 'perform a non-validating parse of a character string to produce an XML value',
   proname => 'xml', provolatile => 's', prorettype => 'xml',
   proargtypes => 'text', prosrc => 'texttoxml' },
 { oid => '2897', descr => 'validate an XML value',
-  proname => 'xmlvalidate', prorettype => 'bool', proargtypes => 'xml text',
-  prosrc => 'xmlvalidate' },
+  proname => 'xmlvalidate', prorettype => 'bool', proargtypes => 'xml text' },
 { oid => '2898', descr => 'I/O',
   proname => 'xml_recv', provolatile => 's', prorettype => 'xml',
-  proargtypes => 'internal', prosrc => 'xml_recv' },
+  proargtypes => 'internal' },
 { oid => '2899', descr => 'I/O',
   proname => 'xml_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'xml', prosrc => 'xml_send' },
+  proargtypes => 'xml' },
 { oid => '2900', descr => 'aggregate transition function',
   proname => 'xmlconcat2', proisstrict => 'f', prorettype => 'xml',
-  proargtypes => 'xml xml', prosrc => 'xmlconcat2' },
+  proargtypes => 'xml xml' },
 { oid => '2901', descr => 'concatenate XML values',
   proname => 'xmlagg', prokind => 'a', proisstrict => 'f', prorettype => 'xml',
   proargtypes => 'xml', prosrc => 'aggregate_dummy' },
@@ -8083,159 +7336,138 @@
   proname => 'table_to_xml', procost => '100', provolatile => 's',
   proparallel => 'r', prorettype => 'xml',
   proargtypes => 'regclass bool bool text',
-  proargnames => '{tbl,nulls,tableforest,targetns}', prosrc => 'table_to_xml' },
+  proargnames => '{tbl,nulls,tableforest,targetns}' },
 { oid => '2924', descr => 'map query result to XML',
   proname => 'query_to_xml', procost => '100', provolatile => 'v',
   proparallel => 'u', prorettype => 'xml', proargtypes => 'text bool bool text',
-  proargnames => '{query,nulls,tableforest,targetns}',
-  prosrc => 'query_to_xml' },
+  proargnames => '{query,nulls,tableforest,targetns}' },
 { oid => '2925', descr => 'map rows from cursor to XML',
   proname => 'cursor_to_xml', procost => '100', provolatile => 'v',
   proparallel => 'u', prorettype => 'xml',
   proargtypes => 'refcursor int4 bool bool text',
-  proargnames => '{cursor,count,nulls,tableforest,targetns}',
-  prosrc => 'cursor_to_xml' },
+  proargnames => '{cursor,count,nulls,tableforest,targetns}' },
 { oid => '2926', descr => 'map table structure to XML Schema',
   proname => 'table_to_xmlschema', procost => '100', provolatile => 's',
   proparallel => 'r', prorettype => 'xml',
   proargtypes => 'regclass bool bool text',
-  proargnames => '{tbl,nulls,tableforest,targetns}',
-  prosrc => 'table_to_xmlschema' },
+  proargnames => '{tbl,nulls,tableforest,targetns}' },
 { oid => '2927', descr => 'map query result structure to XML Schema',
   proname => 'query_to_xmlschema', procost => '100', provolatile => 'v',
   proparallel => 'u', prorettype => 'xml', proargtypes => 'text bool bool text',
-  proargnames => '{query,nulls,tableforest,targetns}',
-  prosrc => 'query_to_xmlschema' },
+  proargnames => '{query,nulls,tableforest,targetns}' },
 { oid => '2928', descr => 'map cursor structure to XML Schema',
   proname => 'cursor_to_xmlschema', procost => '100', provolatile => 'v',
   proparallel => 'u', prorettype => 'xml',
   proargtypes => 'refcursor bool bool text',
-  proargnames => '{cursor,nulls,tableforest,targetns}',
-  prosrc => 'cursor_to_xmlschema' },
+  proargnames => '{cursor,nulls,tableforest,targetns}' },
 { oid => '2929',
   descr => 'map table contents and structure to XML and XML Schema',
   proname => 'table_to_xml_and_xmlschema', procost => '100', provolatile => 's',
   proparallel => 'r', prorettype => 'xml',
   proargtypes => 'regclass bool bool text',
-  proargnames => '{tbl,nulls,tableforest,targetns}',
-  prosrc => 'table_to_xml_and_xmlschema' },
+  proargnames => '{tbl,nulls,tableforest,targetns}' },
 { oid => '2930',
   descr => 'map query result and structure to XML and XML Schema',
   proname => 'query_to_xml_and_xmlschema', procost => '100', provolatile => 'v',
   proparallel => 'u', prorettype => 'xml', proargtypes => 'text bool bool text',
-  proargnames => '{query,nulls,tableforest,targetns}',
-  prosrc => 'query_to_xml_and_xmlschema' },
+  proargnames => '{query,nulls,tableforest,targetns}' },
 
 { oid => '2933', descr => 'map schema contents to XML',
   proname => 'schema_to_xml', procost => '100', provolatile => 's',
   proparallel => 'r', prorettype => 'xml', proargtypes => 'name bool bool text',
-  proargnames => '{schema,nulls,tableforest,targetns}',
-  prosrc => 'schema_to_xml' },
+  proargnames => '{schema,nulls,tableforest,targetns}' },
 { oid => '2934', descr => 'map schema structure to XML Schema',
   proname => 'schema_to_xmlschema', procost => '100', provolatile => 's',
   proparallel => 'r', prorettype => 'xml', proargtypes => 'name bool bool text',
-  proargnames => '{schema,nulls,tableforest,targetns}',
-  prosrc => 'schema_to_xmlschema' },
+  proargnames => '{schema,nulls,tableforest,targetns}' },
 { oid => '2935',
   descr => 'map schema contents and structure to XML and XML Schema',
   proname => 'schema_to_xml_and_xmlschema', procost => '100',
   provolatile => 's', proparallel => 'r', prorettype => 'xml',
   proargtypes => 'name bool bool text',
-  proargnames => '{schema,nulls,tableforest,targetns}',
-  prosrc => 'schema_to_xml_and_xmlschema' },
+  proargnames => '{schema,nulls,tableforest,targetns}' },
 
 { oid => '2936', descr => 'map database contents to XML',
   proname => 'database_to_xml', procost => '100', provolatile => 's',
   proparallel => 'r', prorettype => 'xml', proargtypes => 'bool bool text',
-  proargnames => '{nulls,tableforest,targetns}', prosrc => 'database_to_xml' },
+  proargnames => '{nulls,tableforest,targetns}' },
 { oid => '2937', descr => 'map database structure to XML Schema',
   proname => 'database_to_xmlschema', procost => '100', provolatile => 's',
   proparallel => 'r', prorettype => 'xml', proargtypes => 'bool bool text',
-  proargnames => '{nulls,tableforest,targetns}',
-  prosrc => 'database_to_xmlschema' },
+  proargnames => '{nulls,tableforest,targetns}' },
 { oid => '2938',
   descr => 'map database contents and structure to XML and XML Schema',
   proname => 'database_to_xml_and_xmlschema', procost => '100',
   provolatile => 's', proparallel => 'r', prorettype => 'xml',
   proargtypes => 'bool bool text',
-  proargnames => '{nulls,tableforest,targetns}',
-  prosrc => 'database_to_xml_and_xmlschema' },
+  proargnames => '{nulls,tableforest,targetns}' },
 
 { oid => '2931',
   descr => 'evaluate XPath expression, with namespaces support',
-  proname => 'xpath', prorettype => '_xml', proargtypes => 'text xml _text',
-  prosrc => 'xpath' },
+  proname => 'xpath', prorettype => '_xml', proargtypes => 'text xml _text' },
 { oid => '2932', descr => 'evaluate XPath expression',
   proname => 'xpath', prolang => '14', prorettype => '_xml',
   proargtypes => 'text xml',
   prosrc => 'select pg_catalog.xpath($1, $2, \'{}\'::pg_catalog.text[])' },
 
 { oid => '2614', descr => 'test XML value against XPath expression',
-  proname => 'xmlexists', prorettype => 'bool', proargtypes => 'text xml',
-  prosrc => 'xmlexists' },
+  proname => 'xmlexists', prorettype => 'bool', proargtypes => 'text xml' },
 
 { oid => '3049',
   descr => 'test XML value against XPath expression, with namespace support',
   proname => 'xpath_exists', prorettype => 'bool',
-  proargtypes => 'text xml _text', prosrc => 'xpath_exists' },
+  proargtypes => 'text xml _text' },
 { oid => '3050', descr => 'test XML value against XPath expression',
   proname => 'xpath_exists', prolang => '14', prorettype => 'bool',
   proargtypes => 'text xml',
   prosrc => 'select pg_catalog.xpath_exists($1, $2, \'{}\'::pg_catalog.text[])' },
 { oid => '3051', descr => 'determine if a string is well formed XML',
   proname => 'xml_is_well_formed', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'text', prosrc => 'xml_is_well_formed' },
+  proargtypes => 'text' },
 { oid => '3052', descr => 'determine if a string is well formed XML document',
   proname => 'xml_is_well_formed_document', prorettype => 'bool',
-  proargtypes => 'text', prosrc => 'xml_is_well_formed_document' },
+  proargtypes => 'text' },
 { oid => '3053', descr => 'determine if a string is well formed XML content',
   proname => 'xml_is_well_formed_content', prorettype => 'bool',
-  proargtypes => 'text', prosrc => 'xml_is_well_formed_content' },
+  proargtypes => 'text' },
 
 # json
 { oid => '321', descr => 'I/O',
-  proname => 'json_in', prorettype => 'json', proargtypes => 'cstring',
-  prosrc => 'json_in' },
+  proname => 'json_in', prorettype => 'json', proargtypes => 'cstring' },
 { oid => '322', descr => 'I/O',
-  proname => 'json_out', prorettype => 'cstring', proargtypes => 'json',
-  prosrc => 'json_out' },
+  proname => 'json_out', prorettype => 'cstring', proargtypes => 'json' },
 { oid => '323', descr => 'I/O',
-  proname => 'json_recv', prorettype => 'json', proargtypes => 'internal',
-  prosrc => 'json_recv' },
+  proname => 'json_recv', prorettype => 'json', proargtypes => 'internal' },
 { oid => '324', descr => 'I/O',
-  proname => 'json_send', prorettype => 'bytea', proargtypes => 'json',
-  prosrc => 'json_send' },
+  proname => 'json_send', prorettype => 'bytea', proargtypes => 'json' },
 { oid => '3153', descr => 'map array to json',
   proname => 'array_to_json', provolatile => 's', prorettype => 'json',
-  proargtypes => 'anyarray', prosrc => 'array_to_json' },
+  proargtypes => 'anyarray' },
 { oid => '3154', descr => 'map array to json with optional pretty printing',
   proname => 'array_to_json', provolatile => 's', prorettype => 'json',
   proargtypes => 'anyarray bool', prosrc => 'array_to_json_pretty' },
 { oid => '3155', descr => 'map row to json',
   proname => 'row_to_json', provolatile => 's', prorettype => 'json',
-  proargtypes => 'record', prosrc => 'row_to_json' },
+  proargtypes => 'record' },
 { oid => '3156', descr => 'map row to json with optional pretty printing',
   proname => 'row_to_json', provolatile => 's', prorettype => 'json',
   proargtypes => 'record bool', prosrc => 'row_to_json_pretty' },
 { oid => '3173', descr => 'json aggregate transition function',
   proname => 'json_agg_transfn', proisstrict => 'f', provolatile => 's',
-  prorettype => 'internal', proargtypes => 'internal anyelement',
-  prosrc => 'json_agg_transfn' },
+  prorettype => 'internal', proargtypes => 'internal anyelement' },
 { oid => '3174', descr => 'json aggregate final function',
   proname => 'json_agg_finalfn', proisstrict => 'f', prorettype => 'json',
-  proargtypes => 'internal', prosrc => 'json_agg_finalfn' },
+  proargtypes => 'internal' },
 { oid => '3175', descr => 'aggregate input into json',
   proname => 'json_agg', prokind => 'a', proisstrict => 'f', provolatile => 's',
   prorettype => 'json', proargtypes => 'anyelement',
   prosrc => 'aggregate_dummy' },
 { oid => '3180', descr => 'json object aggregate transition function',
   proname => 'json_object_agg_transfn', proisstrict => 'f', provolatile => 's',
-  prorettype => 'internal', proargtypes => 'internal any any',
-  prosrc => 'json_object_agg_transfn' },
+  prorettype => 'internal', proargtypes => 'internal any any' },
 { oid => '3196', descr => 'json object aggregate final function',
   proname => 'json_object_agg_finalfn', proisstrict => 'f',
-  prorettype => 'json', proargtypes => 'internal',
-  prosrc => 'json_object_agg_finalfn' },
+  prorettype => 'json', proargtypes => 'internal' },
 { oid => '3197', descr => 'aggregate input into a json object',
   proname => 'json_object_agg', prokind => 'a', proisstrict => 'f',
   provolatile => 's', prorettype => 'json', proargtypes => 'any any',
@@ -8243,8 +7475,7 @@
 { oid => '3198', descr => 'build a json array from any inputs',
   proname => 'json_build_array', provariadic => 'any', proisstrict => 'f',
   provolatile => 's', prorettype => 'json', proargtypes => 'any',
-  proallargtypes => '{any}', proargmodes => '{v}',
-  prosrc => 'json_build_array' },
+  proallargtypes => '{any}', proargmodes => '{v}' },
 { oid => '3199', descr => 'build an empty json array',
   proname => 'json_build_array', proisstrict => 'f', provolatile => 's',
   prorettype => 'json', proargtypes => '',
@@ -8253,232 +7484,192 @@
   descr => 'build a json object from pairwise key/value inputs',
   proname => 'json_build_object', provariadic => 'any', proisstrict => 'f',
   provolatile => 's', prorettype => 'json', proargtypes => 'any',
-  proallargtypes => '{any}', proargmodes => '{v}',
-  prosrc => 'json_build_object' },
+  proallargtypes => '{any}', proargmodes => '{v}' },
 { oid => '3201', descr => 'build an empty json object',
   proname => 'json_build_object', proisstrict => 'f', provolatile => 's',
   prorettype => 'json', proargtypes => '',
   prosrc => 'json_build_object_noargs' },
 { oid => '3202', descr => 'map text array of key value pairs to json object',
-  proname => 'json_object', prorettype => 'json', proargtypes => '_text',
-  prosrc => 'json_object' },
+  proname => 'json_object', prorettype => 'json', proargtypes => '_text' },
 { oid => '3203', descr => 'map text arrays of keys and values to json object',
   proname => 'json_object', prorettype => 'json', proargtypes => '_text _text',
   prosrc => 'json_object_two_arg' },
 { oid => '3176', descr => 'map input to json',
   proname => 'to_json', provolatile => 's', prorettype => 'json',
-  proargtypes => 'anyelement', prosrc => 'to_json' },
+  proargtypes => 'anyelement' },
 { oid => '3261', descr => 'remove object fields with null values from json',
-  proname => 'json_strip_nulls', prorettype => 'json', proargtypes => 'json',
-  prosrc => 'json_strip_nulls' },
+  proname => 'json_strip_nulls', prorettype => 'json', proargtypes => 'json' },
 
 { oid => '3947',
   proname => 'json_object_field', prorettype => 'json',
-  proargtypes => 'json text', proargnames => '{from_json, field_name}',
-  prosrc => 'json_object_field' },
+  proargtypes => 'json text', proargnames => '{from_json, field_name}' },
 { oid => '3948',
   proname => 'json_object_field_text', prorettype => 'text',
-  proargtypes => 'json text', proargnames => '{from_json, field_name}',
-  prosrc => 'json_object_field_text' },
+  proargtypes => 'json text', proargnames => '{from_json, field_name}' },
 { oid => '3949',
   proname => 'json_array_element', prorettype => 'json',
-  proargtypes => 'json int4', proargnames => '{from_json, element_index}',
-  prosrc => 'json_array_element' },
+  proargtypes => 'json int4', proargnames => '{from_json, element_index}' },
 { oid => '3950',
   proname => 'json_array_element_text', prorettype => 'text',
-  proargtypes => 'json int4', proargnames => '{from_json, element_index}',
-  prosrc => 'json_array_element_text' },
+  proargtypes => 'json int4', proargnames => '{from_json, element_index}' },
 { oid => '3951', descr => 'get value from json with path elements',
   proname => 'json_extract_path', provariadic => 'text', prorettype => 'json',
   proargtypes => 'json _text', proallargtypes => '{json,_text}',
-  proargmodes => '{i,v}', proargnames => '{from_json,path_elems}',
-  prosrc => 'json_extract_path' },
+  proargmodes => '{i,v}', proargnames => '{from_json,path_elems}' },
 { oid => '3953', descr => 'get value from json as text with path elements',
   proname => 'json_extract_path_text', provariadic => 'text',
   prorettype => 'text', proargtypes => 'json _text',
   proallargtypes => '{json,_text}', proargmodes => '{i,v}',
-  proargnames => '{from_json,path_elems}', prosrc => 'json_extract_path_text' },
+  proargnames => '{from_json,path_elems}' },
 { oid => '3955', descr => 'key value pairs of a json object',
   proname => 'json_array_elements', prorows => '100', proretset => 't',
   prorettype => 'json', proargtypes => 'json', proallargtypes => '{json,json}',
-  proargmodes => '{i,o}', proargnames => '{from_json,value}',
-  prosrc => 'json_array_elements' },
+  proargmodes => '{i,o}', proargnames => '{from_json,value}' },
 { oid => '3969', descr => 'elements of json array',
   proname => 'json_array_elements_text', prorows => '100', proretset => 't',
   prorettype => 'text', proargtypes => 'json', proallargtypes => '{json,text}',
-  proargmodes => '{i,o}', proargnames => '{from_json,value}',
-  prosrc => 'json_array_elements_text' },
+  proargmodes => '{i,o}', proargnames => '{from_json,value}' },
 { oid => '3956', descr => 'length of json array',
-  proname => 'json_array_length', prorettype => 'int4', proargtypes => 'json',
-  prosrc => 'json_array_length' },
+  proname => 'json_array_length', prorettype => 'int4', proargtypes => 'json' },
 { oid => '3957', descr => 'get json object keys',
   proname => 'json_object_keys', prorows => '100', proretset => 't',
-  prorettype => 'text', proargtypes => 'json', prosrc => 'json_object_keys' },
+  prorettype => 'text', proargtypes => 'json' },
 { oid => '3958', descr => 'key value pairs of a json object',
   proname => 'json_each', prorows => '100', proretset => 't',
   prorettype => 'record', proargtypes => 'json',
   proallargtypes => '{json,text,json}', proargmodes => '{i,o,o}',
-  proargnames => '{from_json,key,value}', prosrc => 'json_each' },
+  proargnames => '{from_json,key,value}' },
 { oid => '3959', descr => 'key value pairs of a json object',
   proname => 'json_each_text', prorows => '100', proretset => 't',
   prorettype => 'record', proargtypes => 'json',
   proallargtypes => '{json,text,text}', proargmodes => '{i,o,o}',
-  proargnames => '{from_json,key,value}', prosrc => 'json_each_text' },
+  proargnames => '{from_json,key,value}' },
 { oid => '3960', descr => 'get record fields from a json object',
   proname => 'json_populate_record', proisstrict => 'f', provolatile => 's',
-  prorettype => 'anyelement', proargtypes => 'anyelement json bool',
-  prosrc => 'json_populate_record' },
+  prorettype => 'anyelement', proargtypes => 'anyelement json bool' },
 { oid => '3961',
   descr => 'get set of records with fields from a json array of objects',
   proname => 'json_populate_recordset', prorows => '100', proisstrict => 'f',
   proretset => 't', provolatile => 's', prorettype => 'anyelement',
-  proargtypes => 'anyelement json bool', prosrc => 'json_populate_recordset' },
+  proargtypes => 'anyelement json bool' },
 { oid => '3204', descr => 'get record fields from a json object',
   proname => 'json_to_record', provolatile => 's', prorettype => 'record',
-  proargtypes => 'json', prosrc => 'json_to_record' },
+  proargtypes => 'json' },
 { oid => '3205',
   descr => 'get set of records with fields from a json array of objects',
   proname => 'json_to_recordset', prorows => '100', proisstrict => 'f',
   proretset => 't', provolatile => 's', prorettype => 'record',
-  proargtypes => 'json', prosrc => 'json_to_recordset' },
+  proargtypes => 'json' },
 { oid => '3968', descr => 'get the type of a json value',
-  proname => 'json_typeof', prorettype => 'text', proargtypes => 'json',
-  prosrc => 'json_typeof' },
+  proname => 'json_typeof', prorettype => 'text', proargtypes => 'json' },
 
 # uuid
 { oid => '2952', descr => 'I/O',
-  proname => 'uuid_in', prorettype => 'uuid', proargtypes => 'cstring',
-  prosrc => 'uuid_in' },
+  proname => 'uuid_in', prorettype => 'uuid', proargtypes => 'cstring' },
 { oid => '2953', descr => 'I/O',
-  proname => 'uuid_out', prorettype => 'cstring', proargtypes => 'uuid',
-  prosrc => 'uuid_out' },
+  proname => 'uuid_out', prorettype => 'cstring', proargtypes => 'uuid' },
 { oid => '2954',
   proname => 'uuid_lt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'uuid uuid', prosrc => 'uuid_lt' },
+  proargtypes => 'uuid uuid' },
 { oid => '2955',
   proname => 'uuid_le', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'uuid uuid', prosrc => 'uuid_le' },
+  proargtypes => 'uuid uuid' },
 { oid => '2956',
   proname => 'uuid_eq', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'uuid uuid', prosrc => 'uuid_eq' },
+  proargtypes => 'uuid uuid' },
 { oid => '2957',
   proname => 'uuid_ge', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'uuid uuid', prosrc => 'uuid_ge' },
+  proargtypes => 'uuid uuid' },
 { oid => '2958',
   proname => 'uuid_gt', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'uuid uuid', prosrc => 'uuid_gt' },
+  proargtypes => 'uuid uuid' },
 { oid => '2959',
   proname => 'uuid_ne', proleakproof => 't', prorettype => 'bool',
-  proargtypes => 'uuid uuid', prosrc => 'uuid_ne' },
+  proargtypes => 'uuid uuid' },
 { oid => '2960', descr => 'less-equal-greater',
-  proname => 'uuid_cmp', prorettype => 'int4', proargtypes => 'uuid uuid',
-  prosrc => 'uuid_cmp' },
+  proname => 'uuid_cmp', prorettype => 'int4', proargtypes => 'uuid uuid' },
 { oid => '3300', descr => 'sort support',
   proname => 'uuid_sortsupport', prorettype => 'void',
-  proargtypes => 'internal', prosrc => 'uuid_sortsupport' },
+  proargtypes => 'internal' },
 { oid => '2961', descr => 'I/O',
-  proname => 'uuid_recv', prorettype => 'uuid', proargtypes => 'internal',
-  prosrc => 'uuid_recv' },
+  proname => 'uuid_recv', prorettype => 'uuid', proargtypes => 'internal' },
 { oid => '2962', descr => 'I/O',
-  proname => 'uuid_send', prorettype => 'bytea', proargtypes => 'uuid',
-  prosrc => 'uuid_send' },
+  proname => 'uuid_send', prorettype => 'bytea', proargtypes => 'uuid' },
 { oid => '2963', descr => 'hash',
-  proname => 'uuid_hash', prorettype => 'int4', proargtypes => 'uuid',
-  prosrc => 'uuid_hash' },
+  proname => 'uuid_hash', prorettype => 'int4', proargtypes => 'uuid' },
 { oid => '3412', descr => 'hash',
   proname => 'uuid_hash_extended', prorettype => 'int8',
-  proargtypes => 'uuid int8', prosrc => 'uuid_hash_extended' },
+  proargtypes => 'uuid int8' },
 
 # pg_lsn
 { oid => '3229', descr => 'I/O',
-  proname => 'pg_lsn_in', prorettype => 'pg_lsn', proargtypes => 'cstring',
-  prosrc => 'pg_lsn_in' },
+  proname => 'pg_lsn_in', prorettype => 'pg_lsn', proargtypes => 'cstring' },
 { oid => '3230', descr => 'I/O',
-  proname => 'pg_lsn_out', prorettype => 'cstring', proargtypes => 'pg_lsn',
-  prosrc => 'pg_lsn_out' },
+  proname => 'pg_lsn_out', prorettype => 'cstring', proargtypes => 'pg_lsn' },
 { oid => '3231',
-  proname => 'pg_lsn_lt', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn',
-  prosrc => 'pg_lsn_lt' },
+  proname => 'pg_lsn_lt', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3232',
-  proname => 'pg_lsn_le', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn',
-  prosrc => 'pg_lsn_le' },
+  proname => 'pg_lsn_le', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3233',
-  proname => 'pg_lsn_eq', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn',
-  prosrc => 'pg_lsn_eq' },
+  proname => 'pg_lsn_eq', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3234',
-  proname => 'pg_lsn_ge', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn',
-  prosrc => 'pg_lsn_ge' },
+  proname => 'pg_lsn_ge', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3235',
-  proname => 'pg_lsn_gt', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn',
-  prosrc => 'pg_lsn_gt' },
+  proname => 'pg_lsn_gt', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3236',
-  proname => 'pg_lsn_ne', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn',
-  prosrc => 'pg_lsn_ne' },
+  proname => 'pg_lsn_ne', prorettype => 'bool', proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3237',
   proname => 'pg_lsn_mi', prorettype => 'numeric',
-  proargtypes => 'pg_lsn pg_lsn', prosrc => 'pg_lsn_mi' },
+  proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3238', descr => 'I/O',
-  proname => 'pg_lsn_recv', prorettype => 'pg_lsn', proargtypes => 'internal',
-  prosrc => 'pg_lsn_recv' },
+  proname => 'pg_lsn_recv', prorettype => 'pg_lsn', proargtypes => 'internal' },
 { oid => '3239', descr => 'I/O',
-  proname => 'pg_lsn_send', prorettype => 'bytea', proargtypes => 'pg_lsn',
-  prosrc => 'pg_lsn_send' },
+  proname => 'pg_lsn_send', prorettype => 'bytea', proargtypes => 'pg_lsn' },
 { oid => '3251', descr => 'less-equal-greater',
-  proname => 'pg_lsn_cmp', prorettype => 'int4', proargtypes => 'pg_lsn pg_lsn',
-  prosrc => 'pg_lsn_cmp' },
+  proname => 'pg_lsn_cmp', prorettype => 'int4', proargtypes => 'pg_lsn pg_lsn' },
 { oid => '3252', descr => 'hash',
-  proname => 'pg_lsn_hash', prorettype => 'int4', proargtypes => 'pg_lsn',
-  prosrc => 'pg_lsn_hash' },
+  proname => 'pg_lsn_hash', prorettype => 'int4', proargtypes => 'pg_lsn' },
 { oid => '3413', descr => 'hash',
   proname => 'pg_lsn_hash_extended', prorettype => 'int8',
-  proargtypes => 'pg_lsn int8', prosrc => 'pg_lsn_hash_extended' },
+  proargtypes => 'pg_lsn int8' },
 
 # enum related procs
 { oid => '3504', descr => 'I/O',
-  proname => 'anyenum_in', prorettype => 'anyenum', proargtypes => 'cstring',
-  prosrc => 'anyenum_in' },
+  proname => 'anyenum_in', prorettype => 'anyenum', proargtypes => 'cstring' },
 { oid => '3505', descr => 'I/O',
   proname => 'anyenum_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'anyenum', prosrc => 'anyenum_out' },
+  proargtypes => 'anyenum' },
 { oid => '3506', descr => 'I/O',
   proname => 'enum_in', provolatile => 's', prorettype => 'anyenum',
-  proargtypes => 'cstring oid', prosrc => 'enum_in' },
+  proargtypes => 'cstring oid' },
 { oid => '3507', descr => 'I/O',
   proname => 'enum_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'anyenum', prosrc => 'enum_out' },
+  proargtypes => 'anyenum' },
 { oid => '3508',
-  proname => 'enum_eq', prorettype => 'bool', proargtypes => 'anyenum anyenum',
-  prosrc => 'enum_eq' },
+  proname => 'enum_eq', prorettype => 'bool', proargtypes => 'anyenum anyenum' },
 { oid => '3509',
-  proname => 'enum_ne', prorettype => 'bool', proargtypes => 'anyenum anyenum',
-  prosrc => 'enum_ne' },
+  proname => 'enum_ne', prorettype => 'bool', proargtypes => 'anyenum anyenum' },
 { oid => '3510',
-  proname => 'enum_lt', prorettype => 'bool', proargtypes => 'anyenum anyenum',
-  prosrc => 'enum_lt' },
+  proname => 'enum_lt', prorettype => 'bool', proargtypes => 'anyenum anyenum' },
 { oid => '3511',
-  proname => 'enum_gt', prorettype => 'bool', proargtypes => 'anyenum anyenum',
-  prosrc => 'enum_gt' },
+  proname => 'enum_gt', prorettype => 'bool', proargtypes => 'anyenum anyenum' },
 { oid => '3512',
-  proname => 'enum_le', prorettype => 'bool', proargtypes => 'anyenum anyenum',
-  prosrc => 'enum_le' },
+  proname => 'enum_le', prorettype => 'bool', proargtypes => 'anyenum anyenum' },
 { oid => '3513',
-  proname => 'enum_ge', prorettype => 'bool', proargtypes => 'anyenum anyenum',
-  prosrc => 'enum_ge' },
+  proname => 'enum_ge', prorettype => 'bool', proargtypes => 'anyenum anyenum' },
 { oid => '3514', descr => 'less-equal-greater',
-  proname => 'enum_cmp', prorettype => 'int4', proargtypes => 'anyenum anyenum',
-  prosrc => 'enum_cmp' },
+  proname => 'enum_cmp', prorettype => 'int4', proargtypes => 'anyenum anyenum' },
 { oid => '3515', descr => 'hash',
-  proname => 'hashenum', prorettype => 'int4', proargtypes => 'anyenum',
-  prosrc => 'hashenum' },
+  proname => 'hashenum', prorettype => 'int4', proargtypes => 'anyenum' },
 { oid => '3414', descr => 'hash',
   proname => 'hashenumextended', prorettype => 'int8',
-  proargtypes => 'anyenum int8', prosrc => 'hashenumextended' },
+  proargtypes => 'anyenum int8' },
 { oid => '3524', descr => 'smaller of two',
   proname => 'enum_smaller', prorettype => 'anyenum',
-  proargtypes => 'anyenum anyenum', prosrc => 'enum_smaller' },
+  proargtypes => 'anyenum anyenum' },
 { oid => '3525', descr => 'larger of two',
   proname => 'enum_larger', prorettype => 'anyenum',
-  proargtypes => 'anyenum anyenum', prosrc => 'enum_larger' },
+  proargtypes => 'anyenum anyenum' },
 { oid => '3526', descr => 'maximum value of all enum input values',
   proname => 'max', prokind => 'a', proisstrict => 'f', prorettype => 'anyenum',
   proargtypes => 'anyenum', prosrc => 'aggregate_dummy' },
@@ -8487,10 +7678,10 @@
   proargtypes => 'anyenum', prosrc => 'aggregate_dummy' },
 { oid => '3528', descr => 'first value of the input enum type',
   proname => 'enum_first', proisstrict => 'f', provolatile => 's',
-  prorettype => 'anyenum', proargtypes => 'anyenum', prosrc => 'enum_first' },
+  prorettype => 'anyenum', proargtypes => 'anyenum' },
 { oid => '3529', descr => 'last value of the input enum type',
   proname => 'enum_last', proisstrict => 'f', provolatile => 's',
-  prorettype => 'anyenum', proargtypes => 'anyenum', prosrc => 'enum_last' },
+  prorettype => 'anyenum', proargtypes => 'anyenum' },
 { oid => '3530',
   descr => 'range between the two given enum values, as an ordered array',
   proname => 'enum_range', proisstrict => 'f', provolatile => 's',
@@ -8502,64 +7693,56 @@
   prosrc => 'enum_range_all' },
 { oid => '3532', descr => 'I/O',
   proname => 'enum_recv', provolatile => 's', prorettype => 'anyenum',
-  proargtypes => 'internal oid', prosrc => 'enum_recv' },
+  proargtypes => 'internal oid' },
 { oid => '3533', descr => 'I/O',
   proname => 'enum_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'anyenum', prosrc => 'enum_send' },
+  proargtypes => 'anyenum' },
 
 # text search stuff
 { oid => '3610', descr => 'I/O',
-  proname => 'tsvectorin', prorettype => 'tsvector', proargtypes => 'cstring',
-  prosrc => 'tsvectorin' },
+  proname => 'tsvectorin', prorettype => 'tsvector', proargtypes => 'cstring' },
 { oid => '3639', descr => 'I/O',
   proname => 'tsvectorrecv', prorettype => 'tsvector',
-  proargtypes => 'internal', prosrc => 'tsvectorrecv' },
+  proargtypes => 'internal' },
 { oid => '3611', descr => 'I/O',
-  proname => 'tsvectorout', prorettype => 'cstring', proargtypes => 'tsvector',
-  prosrc => 'tsvectorout' },
+  proname => 'tsvectorout', prorettype => 'cstring', proargtypes => 'tsvector' },
 { oid => '3638', descr => 'I/O',
-  proname => 'tsvectorsend', prorettype => 'bytea', proargtypes => 'tsvector',
-  prosrc => 'tsvectorsend' },
+  proname => 'tsvectorsend', prorettype => 'bytea', proargtypes => 'tsvector' },
 { oid => '3612', descr => 'I/O',
-  proname => 'tsqueryin', prorettype => 'tsquery', proargtypes => 'cstring',
-  prosrc => 'tsqueryin' },
+  proname => 'tsqueryin', prorettype => 'tsquery', proargtypes => 'cstring' },
 { oid => '3641', descr => 'I/O',
-  proname => 'tsqueryrecv', prorettype => 'tsquery', proargtypes => 'internal',
-  prosrc => 'tsqueryrecv' },
+  proname => 'tsqueryrecv', prorettype => 'tsquery', proargtypes => 'internal' },
 { oid => '3613', descr => 'I/O',
-  proname => 'tsqueryout', prorettype => 'cstring', proargtypes => 'tsquery',
-  prosrc => 'tsqueryout' },
+  proname => 'tsqueryout', prorettype => 'cstring', proargtypes => 'tsquery' },
 { oid => '3640', descr => 'I/O',
-  proname => 'tsquerysend', prorettype => 'bytea', proargtypes => 'tsquery',
-  prosrc => 'tsquerysend' },
+  proname => 'tsquerysend', prorettype => 'bytea', proargtypes => 'tsquery' },
 { oid => '3646', descr => 'I/O',
-  proname => 'gtsvectorin', prorettype => 'gtsvector', proargtypes => 'cstring',
-  prosrc => 'gtsvectorin' },
+  proname => 'gtsvectorin', prorettype => 'gtsvector', proargtypes => 'cstring' },
 { oid => '3647', descr => 'I/O',
   proname => 'gtsvectorout', prorettype => 'cstring',
-  proargtypes => 'gtsvector', prosrc => 'gtsvectorout' },
+  proargtypes => 'gtsvector' },
 
 { oid => '3616',
   proname => 'tsvector_lt', prorettype => 'bool',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_lt' },
+  proargtypes => 'tsvector tsvector' },
 { oid => '3617',
   proname => 'tsvector_le', prorettype => 'bool',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_le' },
+  proargtypes => 'tsvector tsvector' },
 { oid => '3618',
   proname => 'tsvector_eq', prorettype => 'bool',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_eq' },
+  proargtypes => 'tsvector tsvector' },
 { oid => '3619',
   proname => 'tsvector_ne', prorettype => 'bool',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_ne' },
+  proargtypes => 'tsvector tsvector' },
 { oid => '3620',
   proname => 'tsvector_ge', prorettype => 'bool',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_ge' },
+  proargtypes => 'tsvector tsvector' },
 { oid => '3621',
   proname => 'tsvector_gt', prorettype => 'bool',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_gt' },
+  proargtypes => 'tsvector tsvector' },
 { oid => '3622', descr => 'less-equal-greater',
   proname => 'tsvector_cmp', prorettype => 'int4',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_cmp' },
+  proargtypes => 'tsvector tsvector' },
 
 { oid => '3711', descr => 'number of lexemes',
   proname => 'length', prorettype => 'int4', proargtypes => 'tsvector',
@@ -8576,7 +7759,7 @@
   prosrc => 'tsvector_setweight_by_filter' },
 { oid => '3625',
   proname => 'tsvector_concat', prorettype => 'tsvector',
-  proargtypes => 'tsvector tsvector', prosrc => 'tsvector_concat' },
+  proargtypes => 'tsvector tsvector' },
 { oid => '3321', descr => 'delete lexeme',
   proname => 'ts_delete', prorettype => 'tsvector',
   proargtypes => 'tsvector text', prosrc => 'tsvector_delete_str' },
@@ -8591,10 +7774,10 @@
   prosrc => 'tsvector_unnest' },
 { oid => '3326', descr => 'convert tsvector to array of lexemes',
   proname => 'tsvector_to_array', prorettype => '_text',
-  proargtypes => 'tsvector', prosrc => 'tsvector_to_array' },
+  proargtypes => 'tsvector' },
 { oid => '3327', descr => 'build tsvector from array of lexemes',
   proname => 'array_to_tsvector', prorettype => 'tsvector',
-  proargtypes => '_text', prosrc => 'array_to_tsvector' },
+  proargtypes => '_text' },
 { oid => '3319',
   descr => 'delete lexemes that do not have one of the given weights',
   proname => 'ts_filter', prorettype => 'tsvector',
@@ -8602,40 +7785,38 @@
 
 { oid => '3634',
   proname => 'ts_match_vq', prorettype => 'bool',
-  proargtypes => 'tsvector tsquery', prosrc => 'ts_match_vq' },
+  proargtypes => 'tsvector tsquery' },
 { oid => '3635',
   proname => 'ts_match_qv', prorettype => 'bool',
-  proargtypes => 'tsquery tsvector', prosrc => 'ts_match_qv' },
+  proargtypes => 'tsquery tsvector' },
 { oid => '3760',
   proname => 'ts_match_tt', procost => '100', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'text text', prosrc => 'ts_match_tt' },
+  prorettype => 'bool', proargtypes => 'text text' },
 { oid => '3761',
   proname => 'ts_match_tq', procost => '100', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'text tsquery',
-  prosrc => 'ts_match_tq' },
+  prorettype => 'bool', proargtypes => 'text tsquery' },
 
 { oid => '3648', descr => 'GiST tsvector support',
   proname => 'gtsvector_compress', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'gtsvector_compress' },
+  proargtypes => 'internal' },
 { oid => '3649', descr => 'GiST tsvector support',
   proname => 'gtsvector_decompress', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'gtsvector_decompress' },
+  proargtypes => 'internal' },
 { oid => '3650', descr => 'GiST tsvector support',
   proname => 'gtsvector_picksplit', prorettype => 'internal',
-  proargtypes => 'internal internal', prosrc => 'gtsvector_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '3651', descr => 'GiST tsvector support',
   proname => 'gtsvector_union', prorettype => 'gtsvector',
-  proargtypes => 'internal internal', prosrc => 'gtsvector_union' },
+  proargtypes => 'internal internal' },
 { oid => '3652', descr => 'GiST tsvector support',
   proname => 'gtsvector_same', prorettype => 'internal',
-  proargtypes => 'gtsvector gtsvector internal', prosrc => 'gtsvector_same' },
+  proargtypes => 'gtsvector gtsvector internal' },
 { oid => '3653', descr => 'GiST tsvector support',
   proname => 'gtsvector_penalty', prorettype => 'internal',
-  proargtypes => 'internal internal internal', prosrc => 'gtsvector_penalty' },
+  proargtypes => 'internal internal internal' },
 { oid => '3654', descr => 'GiST tsvector support',
   proname => 'gtsvector_consistent', prorettype => 'bool',
-  proargtypes => 'internal tsvector int2 oid internal',
-  prosrc => 'gtsvector_consistent' },
+  proargtypes => 'internal tsvector int2 oid internal' },
 { oid => '3790', descr => 'GiST tsvector support (obsolete)',
   proname => 'gtsvector_consistent', prorettype => 'bool',
   proargtypes => 'internal gtsvector int4 oid internal',
@@ -8643,26 +7824,22 @@
 
 { oid => '3656', descr => 'GIN tsvector support',
   proname => 'gin_extract_tsvector', prorettype => 'internal',
-  proargtypes => 'tsvector internal internal',
-  prosrc => 'gin_extract_tsvector' },
+  proargtypes => 'tsvector internal internal' },
 { oid => '3657', descr => 'GIN tsvector support',
   proname => 'gin_extract_tsquery', prorettype => 'internal',
-  proargtypes => 'tsvector internal int2 internal internal internal internal',
-  prosrc => 'gin_extract_tsquery' },
+  proargtypes => 'tsvector internal int2 internal internal internal internal' },
 { oid => '3658', descr => 'GIN tsvector support',
   proname => 'gin_tsquery_consistent', prorettype => 'bool',
-  proargtypes => 'internal int2 tsvector int4 internal internal internal internal',
-  prosrc => 'gin_tsquery_consistent' },
+  proargtypes => 'internal int2 tsvector int4 internal internal internal internal' },
 { oid => '3921', descr => 'GIN tsvector support',
   proname => 'gin_tsquery_triconsistent', prorettype => 'char',
-  proargtypes => 'internal int2 tsvector int4 internal internal internal',
-  prosrc => 'gin_tsquery_triconsistent' },
+  proargtypes => 'internal int2 tsvector int4 internal internal internal' },
 { oid => '3724', descr => 'GIN tsvector support',
   proname => 'gin_cmp_tslexeme', prorettype => 'int4',
-  proargtypes => 'text text', prosrc => 'gin_cmp_tslexeme' },
+  proargtypes => 'text text' },
 { oid => '2700', descr => 'GIN tsvector support',
   proname => 'gin_cmp_prefix', prorettype => 'int4',
-  proargtypes => 'text text int2 internal', prosrc => 'gin_cmp_prefix' },
+  proargtypes => 'text text int2 internal' },
 { oid => '3077', descr => 'GIN tsvector support (obsolete)',
   proname => 'gin_extract_tsvector', prorettype => 'internal',
   proargtypes => 'tsvector internal', prosrc => 'gin_extract_tsvector_2args' },
@@ -8685,53 +7862,51 @@
 
 { oid => '3789', descr => 'clean up GIN pending list',
   proname => 'gin_clean_pending_list', provolatile => 'v', proparallel => 'u',
-  prorettype => 'int8', proargtypes => 'regclass',
-  prosrc => 'gin_clean_pending_list' },
+  prorettype => 'int8', proargtypes => 'regclass' },
 
 { oid => '3662',
   proname => 'tsquery_lt', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_lt' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3663',
   proname => 'tsquery_le', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_le' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3664',
   proname => 'tsquery_eq', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_eq' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3665',
   proname => 'tsquery_ne', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_ne' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3666',
   proname => 'tsquery_ge', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_ge' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3667',
   proname => 'tsquery_gt', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_gt' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3668', descr => 'less-equal-greater',
   proname => 'tsquery_cmp', prorettype => 'int4',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_cmp' },
+  proargtypes => 'tsquery tsquery' },
 
 { oid => '3669',
   proname => 'tsquery_and', prorettype => 'tsquery',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_and' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3670',
   proname => 'tsquery_or', prorettype => 'tsquery',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_or' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '5003',
   proname => 'tsquery_phrase', prorettype => 'tsquery',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsquery_phrase' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '5004', descr => 'phrase-concatenate with distance',
   proname => 'tsquery_phrase', prorettype => 'tsquery',
   proargtypes => 'tsquery tsquery int4', prosrc => 'tsquery_phrase_distance' },
 { oid => '3671',
-  proname => 'tsquery_not', prorettype => 'tsquery', proargtypes => 'tsquery',
-  prosrc => 'tsquery_not' },
+  proname => 'tsquery_not', prorettype => 'tsquery', proargtypes => 'tsquery' },
 
 { oid => '3691',
   proname => 'tsq_mcontains', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsq_mcontains' },
+  proargtypes => 'tsquery tsquery' },
 { oid => '3692',
   proname => 'tsq_mcontained', prorettype => 'bool',
-  proargtypes => 'tsquery tsquery', prosrc => 'tsq_mcontained' },
+  proargtypes => 'tsquery tsquery' },
 
 { oid => '3672', descr => 'number of nodes',
   proname => 'numnode', prorettype => 'int4', proargtypes => 'tsquery',
@@ -8750,23 +7925,22 @@
 
 { oid => '3695', descr => 'GiST tsquery support',
   proname => 'gtsquery_compress', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'gtsquery_compress' },
+  proargtypes => 'internal' },
 { oid => '3697', descr => 'GiST tsquery support',
   proname => 'gtsquery_picksplit', prorettype => 'internal',
-  proargtypes => 'internal internal', prosrc => 'gtsquery_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '3698', descr => 'GiST tsquery support',
   proname => 'gtsquery_union', prorettype => 'int8',
-  proargtypes => 'internal internal', prosrc => 'gtsquery_union' },
+  proargtypes => 'internal internal' },
 { oid => '3699', descr => 'GiST tsquery support',
   proname => 'gtsquery_same', prorettype => 'internal',
-  proargtypes => 'int8 int8 internal', prosrc => 'gtsquery_same' },
+  proargtypes => 'int8 int8 internal' },
 { oid => '3700', descr => 'GiST tsquery support',
   proname => 'gtsquery_penalty', prorettype => 'internal',
-  proargtypes => 'internal internal internal', prosrc => 'gtsquery_penalty' },
+  proargtypes => 'internal internal internal' },
 { oid => '3701', descr => 'GiST tsquery support',
   proname => 'gtsquery_consistent', prorettype => 'bool',
-  proargtypes => 'internal tsquery int2 oid internal',
-  prosrc => 'gtsquery_consistent' },
+  proargtypes => 'internal tsquery int2 oid internal' },
 { oid => '3793', descr => 'GiST tsquery support (obsolete)',
   proname => 'gtsquery_consistent', prorettype => 'bool',
   proargtypes => 'internal internal int4 oid internal',
@@ -8774,14 +7948,13 @@
 
 { oid => '3686', descr => 'restriction selectivity of tsvector @@ tsquery',
   proname => 'tsmatchsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'tsmatchsel' },
+  proargtypes => 'internal oid internal int4' },
 { oid => '3687', descr => 'join selectivity of tsvector @@ tsquery',
   proname => 'tsmatchjoinsel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int2 internal',
-  prosrc => 'tsmatchjoinsel' },
+  proargtypes => 'internal oid internal int2 internal' },
 { oid => '3688', descr => 'tsvector typanalyze',
   proname => 'ts_typanalyze', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'internal', prosrc => 'ts_typanalyze' },
+  proargtypes => 'internal' },
 
 { oid => '3689', descr => 'statistics of tsvector column',
   proname => 'ts_stat', procost => '10', prorows => '10000', proretset => 't',
@@ -8846,55 +8019,50 @@
 
 { oid => '3717', descr => '(internal)',
   proname => 'prsd_start', prorettype => 'internal',
-  proargtypes => 'internal int4', prosrc => 'prsd_start' },
+  proargtypes => 'internal int4' },
 { oid => '3718', descr => '(internal)',
   proname => 'prsd_nexttoken', prorettype => 'internal',
-  proargtypes => 'internal internal internal', prosrc => 'prsd_nexttoken' },
+  proargtypes => 'internal internal internal' },
 { oid => '3719', descr => '(internal)',
-  proname => 'prsd_end', prorettype => 'void', proargtypes => 'internal',
-  prosrc => 'prsd_end' },
+  proname => 'prsd_end', prorettype => 'void', proargtypes => 'internal' },
 { oid => '3720', descr => '(internal)',
   proname => 'prsd_headline', prorettype => 'internal',
-  proargtypes => 'internal internal tsquery', prosrc => 'prsd_headline' },
+  proargtypes => 'internal internal tsquery' },
 { oid => '3721', descr => '(internal)',
   proname => 'prsd_lextype', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'prsd_lextype' },
+  proargtypes => 'internal' },
 
 { oid => '3723', descr => 'normalize one word by dictionary',
   proname => 'ts_lexize', prorettype => '_text',
-  proargtypes => 'regdictionary text', prosrc => 'ts_lexize' },
+  proargtypes => 'regdictionary text' },
 
 { oid => '3725', descr => '(internal)',
   proname => 'dsimple_init', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'dsimple_init' },
+  proargtypes => 'internal' },
 { oid => '3726', descr => '(internal)',
   proname => 'dsimple_lexize', prorettype => 'internal',
-  proargtypes => 'internal internal internal internal',
-  prosrc => 'dsimple_lexize' },
+  proargtypes => 'internal internal internal internal' },
 
 { oid => '3728', descr => '(internal)',
   proname => 'dsynonym_init', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'dsynonym_init' },
+  proargtypes => 'internal' },
 { oid => '3729', descr => '(internal)',
   proname => 'dsynonym_lexize', prorettype => 'internal',
-  proargtypes => 'internal internal internal internal',
-  prosrc => 'dsynonym_lexize' },
+  proargtypes => 'internal internal internal internal' },
 
 { oid => '3731', descr => '(internal)',
   proname => 'dispell_init', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'dispell_init' },
+  proargtypes => 'internal' },
 { oid => '3732', descr => '(internal)',
   proname => 'dispell_lexize', prorettype => 'internal',
-  proargtypes => 'internal internal internal internal',
-  prosrc => 'dispell_lexize' },
+  proargtypes => 'internal internal internal internal' },
 
 { oid => '3740', descr => '(internal)',
   proname => 'thesaurus_init', prorettype => 'internal',
-  proargtypes => 'internal', prosrc => 'thesaurus_init' },
+  proargtypes => 'internal' },
 { oid => '3741', descr => '(internal)',
   proname => 'thesaurus_lexize', prorettype => 'internal',
-  proargtypes => 'internal internal internal internal',
-  prosrc => 'thesaurus_lexize' },
+  proargtypes => 'internal internal internal internal' },
 
 { oid => '3743', descr => 'generate headline',
   proname => 'ts_headline', procost => '100', prorettype => 'text',
@@ -8909,8 +8077,7 @@
   prosrc => 'ts_headline_opt' },
 { oid => '3755', descr => 'generate headline',
   proname => 'ts_headline', procost => '100', provolatile => 's',
-  prorettype => 'text', proargtypes => 'text tsquery',
-  prosrc => 'ts_headline' },
+  prorettype => 'text', proargtypes => 'text tsquery' },
 
 { oid => '4201', descr => 'generate headline from jsonb',
   proname => 'ts_headline', procost => '100', prorettype => 'jsonb',
@@ -8962,37 +8129,33 @@
   proargtypes => 'regconfig text', prosrc => 'websearch_to_tsquery_byid' },
 { oid => '3749', descr => 'transform to tsvector',
   proname => 'to_tsvector', procost => '100', provolatile => 's',
-  prorettype => 'tsvector', proargtypes => 'text', prosrc => 'to_tsvector' },
+  prorettype => 'tsvector', proargtypes => 'text' },
 { oid => '3750', descr => 'make tsquery',
   proname => 'to_tsquery', procost => '100', provolatile => 's',
-  prorettype => 'tsquery', proargtypes => 'text', prosrc => 'to_tsquery' },
+  prorettype => 'tsquery', proargtypes => 'text' },
 { oid => '3751', descr => 'transform to tsquery',
   proname => 'plainto_tsquery', procost => '100', provolatile => 's',
-  prorettype => 'tsquery', proargtypes => 'text', prosrc => 'plainto_tsquery' },
+  prorettype => 'tsquery', proargtypes => 'text' },
 { oid => '5001', descr => 'transform to tsquery',
   proname => 'phraseto_tsquery', procost => '100', provolatile => 's',
-  prorettype => 'tsquery', proargtypes => 'text',
-  prosrc => 'phraseto_tsquery' },
+  prorettype => 'tsquery', proargtypes => 'text' },
 { oid => '5009', descr => 'transform to tsquery',
   proname => 'websearch_to_tsquery', procost => '100', provolatile => 's',
-  prorettype => 'tsquery', proargtypes => 'text',
-  prosrc => 'websearch_to_tsquery' },
+  prorettype => 'tsquery', proargtypes => 'text' },
 { oid => '4209', descr => 'transform string values from jsonb to tsvector',
   proname => 'to_tsvector', procost => '100', provolatile => 's',
   prorettype => 'tsvector', proargtypes => 'jsonb',
   prosrc => 'jsonb_string_to_tsvector' },
 { oid => '4213', descr => 'transform specified values from jsonb to tsvector',
   proname => 'jsonb_to_tsvector', procost => '100', provolatile => 's',
-  prorettype => 'tsvector', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_to_tsvector' },
+  prorettype => 'tsvector', proargtypes => 'jsonb jsonb' },
 { oid => '4210', descr => 'transform string values from json to tsvector',
   proname => 'to_tsvector', procost => '100', provolatile => 's',
   prorettype => 'tsvector', proargtypes => 'json',
   prosrc => 'json_string_to_tsvector' },
 { oid => '4215', descr => 'transform specified values from json to tsvector',
   proname => 'json_to_tsvector', procost => '100', provolatile => 's',
-  prorettype => 'tsvector', proargtypes => 'json jsonb',
-  prosrc => 'json_to_tsvector' },
+  prorettype => 'tsvector', proargtypes => 'json jsonb' },
 { oid => '4211', descr => 'transform string values from jsonb to tsvector',
   proname => 'to_tsvector', procost => '100', prorettype => 'tsvector',
   proargtypes => 'regconfig jsonb', prosrc => 'jsonb_string_to_tsvector_byid' },
@@ -9017,79 +8180,67 @@
 
 { oid => '3759', descr => 'get current tsearch configuration',
   proname => 'get_current_ts_config', provolatile => 's',
-  prorettype => 'regconfig', proargtypes => '',
-  prosrc => 'get_current_ts_config' },
+  prorettype => 'regconfig', proargtypes => '' },
 
 { oid => '3736', descr => 'I/O',
   proname => 'regconfigin', provolatile => 's', prorettype => 'regconfig',
-  proargtypes => 'cstring', prosrc => 'regconfigin' },
+  proargtypes => 'cstring' },
 { oid => '3737', descr => 'I/O',
   proname => 'regconfigout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regconfig', prosrc => 'regconfigout' },
+  proargtypes => 'regconfig' },
 { oid => '3738', descr => 'I/O',
   proname => 'regconfigrecv', prorettype => 'regconfig',
-  proargtypes => 'internal', prosrc => 'regconfigrecv' },
+  proargtypes => 'internal' },
 { oid => '3739', descr => 'I/O',
-  proname => 'regconfigsend', prorettype => 'bytea', proargtypes => 'regconfig',
-  prosrc => 'regconfigsend' },
+  proname => 'regconfigsend', prorettype => 'bytea', proargtypes => 'regconfig' },
 
 { oid => '3771', descr => 'I/O',
   proname => 'regdictionaryin', provolatile => 's',
-  prorettype => 'regdictionary', proargtypes => 'cstring',
-  prosrc => 'regdictionaryin' },
+  prorettype => 'regdictionary', proargtypes => 'cstring' },
 { oid => '3772', descr => 'I/O',
   proname => 'regdictionaryout', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'regdictionary', prosrc => 'regdictionaryout' },
+  proargtypes => 'regdictionary' },
 { oid => '3773', descr => 'I/O',
   proname => 'regdictionaryrecv', prorettype => 'regdictionary',
-  proargtypes => 'internal', prosrc => 'regdictionaryrecv' },
+  proargtypes => 'internal' },
 { oid => '3774', descr => 'I/O',
   proname => 'regdictionarysend', prorettype => 'bytea',
-  proargtypes => 'regdictionary', prosrc => 'regdictionarysend' },
+  proargtypes => 'regdictionary' },
 
 # jsonb
 { oid => '3806', descr => 'I/O',
-  proname => 'jsonb_in', prorettype => 'jsonb', proargtypes => 'cstring',
-  prosrc => 'jsonb_in' },
+  proname => 'jsonb_in', prorettype => 'jsonb', proargtypes => 'cstring' },
 { oid => '3805', descr => 'I/O',
-  proname => 'jsonb_recv', prorettype => 'jsonb', proargtypes => 'internal',
-  prosrc => 'jsonb_recv' },
+  proname => 'jsonb_recv', prorettype => 'jsonb', proargtypes => 'internal' },
 { oid => '3804', descr => 'I/O',
-  proname => 'jsonb_out', prorettype => 'cstring', proargtypes => 'jsonb',
-  prosrc => 'jsonb_out' },
+  proname => 'jsonb_out', prorettype => 'cstring', proargtypes => 'jsonb' },
 { oid => '3803', descr => 'I/O',
-  proname => 'jsonb_send', prorettype => 'bytea', proargtypes => 'jsonb',
-  prosrc => 'jsonb_send' },
+  proname => 'jsonb_send', prorettype => 'bytea', proargtypes => 'jsonb' },
 
 { oid => '3263', descr => 'map text array of key value pairs to jsonb object',
-  proname => 'jsonb_object', prorettype => 'jsonb', proargtypes => '_text',
-  prosrc => 'jsonb_object' },
+  proname => 'jsonb_object', prorettype => 'jsonb', proargtypes => '_text' },
 { oid => '3264', descr => 'map text array of key value pairs to jsonb object',
   proname => 'jsonb_object', prorettype => 'jsonb',
   proargtypes => '_text _text', prosrc => 'jsonb_object_two_arg' },
 { oid => '3787', descr => 'map input to jsonb',
   proname => 'to_jsonb', provolatile => 's', prorettype => 'jsonb',
-  proargtypes => 'anyelement', prosrc => 'to_jsonb' },
+  proargtypes => 'anyelement' },
 { oid => '3265', descr => 'jsonb aggregate transition function',
   proname => 'jsonb_agg_transfn', proisstrict => 'f', provolatile => 's',
-  prorettype => 'internal', proargtypes => 'internal anyelement',
-  prosrc => 'jsonb_agg_transfn' },
+  prorettype => 'internal', proargtypes => 'internal anyelement' },
 { oid => '3266', descr => 'jsonb aggregate final function',
   proname => 'jsonb_agg_finalfn', proisstrict => 'f', provolatile => 's',
-  prorettype => 'jsonb', proargtypes => 'internal',
-  prosrc => 'jsonb_agg_finalfn' },
+  prorettype => 'jsonb', proargtypes => 'internal' },
 { oid => '3267', descr => 'aggregate input into jsonb',
   proname => 'jsonb_agg', prokind => 'a', proisstrict => 'f',
   provolatile => 's', prorettype => 'jsonb', proargtypes => 'anyelement',
   prosrc => 'aggregate_dummy' },
 { oid => '3268', descr => 'jsonb object aggregate transition function',
   proname => 'jsonb_object_agg_transfn', proisstrict => 'f', provolatile => 's',
-  prorettype => 'internal', proargtypes => 'internal any any',
-  prosrc => 'jsonb_object_agg_transfn' },
+  prorettype => 'internal', proargtypes => 'internal any any' },
 { oid => '3269', descr => 'jsonb object aggregate final function',
   proname => 'jsonb_object_agg_finalfn', proisstrict => 'f', provolatile => 's',
-  prorettype => 'jsonb', proargtypes => 'internal',
-  prosrc => 'jsonb_object_agg_finalfn' },
+  prorettype => 'jsonb', proargtypes => 'internal' },
 { oid => '3270', descr => 'aggregate inputs into jsonb object',
   proname => 'jsonb_object_agg', prokind => 'a', proisstrict => 'f',
   prorettype => 'jsonb', proargtypes => 'any any',
@@ -9097,8 +8248,7 @@
 { oid => '3271', descr => 'build a jsonb array from any inputs',
   proname => 'jsonb_build_array', provariadic => 'any', proisstrict => 'f',
   provolatile => 's', prorettype => 'jsonb', proargtypes => 'any',
-  proallargtypes => '{any}', proargmodes => '{v}',
-  prosrc => 'jsonb_build_array' },
+  proallargtypes => '{any}', proargmodes => '{v}' },
 { oid => '3272', descr => 'build an empty jsonb array',
   proname => 'jsonb_build_array', proisstrict => 'f', provolatile => 's',
   prorettype => 'jsonb', proargtypes => '',
@@ -9107,171 +8257,143 @@
   descr => 'build a jsonb object from pairwise key/value inputs',
   proname => 'jsonb_build_object', provariadic => 'any', proisstrict => 'f',
   provolatile => 's', prorettype => 'jsonb', proargtypes => 'any',
-  proallargtypes => '{any}', proargmodes => '{v}',
-  prosrc => 'jsonb_build_object' },
+  proallargtypes => '{any}', proargmodes => '{v}' },
 { oid => '3274', descr => 'build an empty jsonb object',
   proname => 'jsonb_build_object', proisstrict => 'f', provolatile => 's',
   prorettype => 'jsonb', proargtypes => '',
   prosrc => 'jsonb_build_object_noargs' },
 { oid => '3262', descr => 'remove object fields with null values from jsonb',
-  proname => 'jsonb_strip_nulls', prorettype => 'jsonb', proargtypes => 'jsonb',
-  prosrc => 'jsonb_strip_nulls' },
+  proname => 'jsonb_strip_nulls', prorettype => 'jsonb', proargtypes => 'jsonb' },
 
 { oid => '3478',
   proname => 'jsonb_object_field', prorettype => 'jsonb',
-  proargtypes => 'jsonb text', proargnames => '{from_json, field_name}',
-  prosrc => 'jsonb_object_field' },
+  proargtypes => 'jsonb text', proargnames => '{from_json, field_name}' },
 { oid => '3214',
   proname => 'jsonb_object_field_text', prorettype => 'text',
-  proargtypes => 'jsonb text', proargnames => '{from_json, field_name}',
-  prosrc => 'jsonb_object_field_text' },
+  proargtypes => 'jsonb text', proargnames => '{from_json, field_name}' },
 { oid => '3215',
   proname => 'jsonb_array_element', prorettype => 'jsonb',
-  proargtypes => 'jsonb int4', proargnames => '{from_json, element_index}',
-  prosrc => 'jsonb_array_element' },
+  proargtypes => 'jsonb int4', proargnames => '{from_json, element_index}' },
 { oid => '3216',
   proname => 'jsonb_array_element_text', prorettype => 'text',
-  proargtypes => 'jsonb int4', proargnames => '{from_json, element_index}',
-  prosrc => 'jsonb_array_element_text' },
+  proargtypes => 'jsonb int4', proargnames => '{from_json, element_index}' },
 { oid => '3217', descr => 'get value from jsonb with path elements',
   proname => 'jsonb_extract_path', provariadic => 'text', prorettype => 'jsonb',
   proargtypes => 'jsonb _text', proallargtypes => '{jsonb,_text}',
-  proargmodes => '{i,v}', proargnames => '{from_json,path_elems}',
-  prosrc => 'jsonb_extract_path' },
+  proargmodes => '{i,v}', proargnames => '{from_json,path_elems}' },
 { oid => '3940', descr => 'get value from jsonb as text with path elements',
   proname => 'jsonb_extract_path_text', provariadic => 'text',
   prorettype => 'text', proargtypes => 'jsonb _text',
   proallargtypes => '{jsonb,_text}', proargmodes => '{i,v}',
-  proargnames => '{from_json,path_elems}',
-  prosrc => 'jsonb_extract_path_text' },
+  proargnames => '{from_json,path_elems}' },
 { oid => '3219', descr => 'elements of a jsonb array',
   proname => 'jsonb_array_elements', prorows => '100', proretset => 't',
   prorettype => 'jsonb', proargtypes => 'jsonb',
   proallargtypes => '{jsonb,jsonb}', proargmodes => '{i,o}',
-  proargnames => '{from_json,value}', prosrc => 'jsonb_array_elements' },
+  proargnames => '{from_json,value}' },
 { oid => '3465', descr => 'elements of jsonb array',
   proname => 'jsonb_array_elements_text', prorows => '100', proretset => 't',
   prorettype => 'text', proargtypes => 'jsonb',
   proallargtypes => '{jsonb,text}', proargmodes => '{i,o}',
-  proargnames => '{from_json,value}', prosrc => 'jsonb_array_elements_text' },
+  proargnames => '{from_json,value}' },
 { oid => '3207', descr => 'length of jsonb array',
-  proname => 'jsonb_array_length', prorettype => 'int4', proargtypes => 'jsonb',
-  prosrc => 'jsonb_array_length' },
+  proname => 'jsonb_array_length', prorettype => 'int4', proargtypes => 'jsonb' },
 { oid => '3931', descr => 'get jsonb object keys',
   proname => 'jsonb_object_keys', prorows => '100', proretset => 't',
-  prorettype => 'text', proargtypes => 'jsonb', prosrc => 'jsonb_object_keys' },
+  prorettype => 'text', proargtypes => 'jsonb' },
 { oid => '3208', descr => 'key value pairs of a jsonb object',
   proname => 'jsonb_each', prorows => '100', proretset => 't',
   prorettype => 'record', proargtypes => 'jsonb',
   proallargtypes => '{jsonb,text,jsonb}', proargmodes => '{i,o,o}',
-  proargnames => '{from_json,key,value}', prosrc => 'jsonb_each' },
+  proargnames => '{from_json,key,value}' },
 { oid => '3932', descr => 'key value pairs of a jsonb object',
   proname => 'jsonb_each_text', prorows => '100', proretset => 't',
   prorettype => 'record', proargtypes => 'jsonb',
   proallargtypes => '{jsonb,text,text}', proargmodes => '{i,o,o}',
-  proargnames => '{from_json,key,value}', prosrc => 'jsonb_each_text' },
+  proargnames => '{from_json,key,value}' },
 { oid => '3209', descr => 'get record fields from a jsonb object',
   proname => 'jsonb_populate_record', proisstrict => 'f', provolatile => 's',
-  prorettype => 'anyelement', proargtypes => 'anyelement jsonb',
-  prosrc => 'jsonb_populate_record' },
+  prorettype => 'anyelement', proargtypes => 'anyelement jsonb' },
 { oid => '3475',
   descr => 'get set of records with fields from a jsonb array of objects',
   proname => 'jsonb_populate_recordset', prorows => '100', proisstrict => 'f',
   proretset => 't', provolatile => 's', prorettype => 'anyelement',
-  proargtypes => 'anyelement jsonb', prosrc => 'jsonb_populate_recordset' },
+  proargtypes => 'anyelement jsonb' },
 { oid => '3490', descr => 'get record fields from a jsonb object',
   proname => 'jsonb_to_record', provolatile => 's', prorettype => 'record',
-  proargtypes => 'jsonb', prosrc => 'jsonb_to_record' },
+  proargtypes => 'jsonb' },
 { oid => '3491',
   descr => 'get set of records with fields from a jsonb array of objects',
   proname => 'jsonb_to_recordset', prorows => '100', proisstrict => 'f',
   proretset => 't', provolatile => 's', prorettype => 'record',
-  proargtypes => 'jsonb', prosrc => 'jsonb_to_recordset' },
+  proargtypes => 'jsonb' },
 { oid => '3210', descr => 'get the type of a jsonb value',
-  proname => 'jsonb_typeof', prorettype => 'text', proargtypes => 'jsonb',
-  prosrc => 'jsonb_typeof' },
+  proname => 'jsonb_typeof', prorettype => 'text', proargtypes => 'jsonb' },
 { oid => '4038',
-  proname => 'jsonb_ne', prorettype => 'bool', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_ne' },
+  proname => 'jsonb_ne', prorettype => 'bool', proargtypes => 'jsonb jsonb' },
 { oid => '4039',
-  proname => 'jsonb_lt', prorettype => 'bool', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_lt' },
+  proname => 'jsonb_lt', prorettype => 'bool', proargtypes => 'jsonb jsonb' },
 { oid => '4040',
-  proname => 'jsonb_gt', prorettype => 'bool', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_gt' },
+  proname => 'jsonb_gt', prorettype => 'bool', proargtypes => 'jsonb jsonb' },
 { oid => '4041',
-  proname => 'jsonb_le', prorettype => 'bool', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_le' },
+  proname => 'jsonb_le', prorettype => 'bool', proargtypes => 'jsonb jsonb' },
 { oid => '4042',
-  proname => 'jsonb_ge', prorettype => 'bool', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_ge' },
+  proname => 'jsonb_ge', prorettype => 'bool', proargtypes => 'jsonb jsonb' },
 { oid => '4043',
-  proname => 'jsonb_eq', prorettype => 'bool', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_eq' },
+  proname => 'jsonb_eq', prorettype => 'bool', proargtypes => 'jsonb jsonb' },
 { oid => '4044', descr => 'less-equal-greater',
-  proname => 'jsonb_cmp', prorettype => 'int4', proargtypes => 'jsonb jsonb',
-  prosrc => 'jsonb_cmp' },
+  proname => 'jsonb_cmp', prorettype => 'int4', proargtypes => 'jsonb jsonb' },
 { oid => '4045', descr => 'hash',
-  proname => 'jsonb_hash', prorettype => 'int4', proargtypes => 'jsonb',
-  prosrc => 'jsonb_hash' },
+  proname => 'jsonb_hash', prorettype => 'int4', proargtypes => 'jsonb' },
 { oid => '3416', descr => 'hash',
   proname => 'jsonb_hash_extended', prorettype => 'int8',
-  proargtypes => 'jsonb int8', prosrc => 'jsonb_hash_extended' },
+  proargtypes => 'jsonb int8' },
 { oid => '4046',
   proname => 'jsonb_contains', prorettype => 'bool',
-  proargtypes => 'jsonb jsonb', prosrc => 'jsonb_contains' },
+  proargtypes => 'jsonb jsonb' },
 { oid => '4047',
-  proname => 'jsonb_exists', prorettype => 'bool', proargtypes => 'jsonb text',
-  prosrc => 'jsonb_exists' },
+  proname => 'jsonb_exists', prorettype => 'bool', proargtypes => 'jsonb text' },
 { oid => '4048',
   proname => 'jsonb_exists_any', prorettype => 'bool',
-  proargtypes => 'jsonb _text', prosrc => 'jsonb_exists_any' },
+  proargtypes => 'jsonb _text' },
 { oid => '4049',
   proname => 'jsonb_exists_all', prorettype => 'bool',
-  proargtypes => 'jsonb _text', prosrc => 'jsonb_exists_all' },
+  proargtypes => 'jsonb _text' },
 { oid => '4050',
   proname => 'jsonb_contained', prorettype => 'bool',
-  proargtypes => 'jsonb jsonb', prosrc => 'jsonb_contained' },
+  proargtypes => 'jsonb jsonb' },
 { oid => '3480', descr => 'GIN support',
   proname => 'gin_compare_jsonb', prorettype => 'int4',
-  proargtypes => 'text text', prosrc => 'gin_compare_jsonb' },
+  proargtypes => 'text text' },
 { oid => '3482', descr => 'GIN support',
   proname => 'gin_extract_jsonb', prorettype => 'internal',
-  proargtypes => 'jsonb internal internal', prosrc => 'gin_extract_jsonb' },
+  proargtypes => 'jsonb internal internal' },
 { oid => '3483', descr => 'GIN support',
   proname => 'gin_extract_jsonb_query', prorettype => 'internal',
-  proargtypes => 'jsonb internal int2 internal internal internal internal',
-  prosrc => 'gin_extract_jsonb_query' },
+  proargtypes => 'jsonb internal int2 internal internal internal internal' },
 { oid => '3484', descr => 'GIN support',
   proname => 'gin_consistent_jsonb', prorettype => 'bool',
-  proargtypes => 'internal int2 jsonb int4 internal internal internal internal',
-  prosrc => 'gin_consistent_jsonb' },
+  proargtypes => 'internal int2 jsonb int4 internal internal internal internal' },
 { oid => '3488', descr => 'GIN support',
   proname => 'gin_triconsistent_jsonb', prorettype => 'char',
-  proargtypes => 'internal int2 jsonb int4 internal internal internal',
-  prosrc => 'gin_triconsistent_jsonb' },
+  proargtypes => 'internal int2 jsonb int4 internal internal internal' },
 { oid => '3485', descr => 'GIN support',
   proname => 'gin_extract_jsonb_path', prorettype => 'internal',
-  proargtypes => 'jsonb internal internal',
-  prosrc => 'gin_extract_jsonb_path' },
+  proargtypes => 'jsonb internal internal' },
 { oid => '3486', descr => 'GIN support',
   proname => 'gin_extract_jsonb_query_path', prorettype => 'internal',
-  proargtypes => 'jsonb internal int2 internal internal internal internal',
-  prosrc => 'gin_extract_jsonb_query_path' },
+  proargtypes => 'jsonb internal int2 internal internal internal internal' },
 { oid => '3487', descr => 'GIN support',
   proname => 'gin_consistent_jsonb_path', prorettype => 'bool',
-  proargtypes => 'internal int2 jsonb int4 internal internal internal internal',
-  prosrc => 'gin_consistent_jsonb_path' },
+  proargtypes => 'internal int2 jsonb int4 internal internal internal internal' },
 { oid => '3489', descr => 'GIN support',
   proname => 'gin_triconsistent_jsonb_path', prorettype => 'char',
-  proargtypes => 'internal int2 jsonb int4 internal internal internal',
-  prosrc => 'gin_triconsistent_jsonb_path' },
+  proargtypes => 'internal int2 jsonb int4 internal internal internal' },
 { oid => '3301',
   proname => 'jsonb_concat', prorettype => 'jsonb',
-  proargtypes => 'jsonb jsonb', prosrc => 'jsonb_concat' },
+  proargtypes => 'jsonb jsonb' },
 { oid => '3302',
-  proname => 'jsonb_delete', prorettype => 'jsonb', proargtypes => 'jsonb text',
-  prosrc => 'jsonb_delete' },
+  proname => 'jsonb_delete', prorettype => 'jsonb', proargtypes => 'jsonb text' },
 { oid => '3303',
   proname => 'jsonb_delete', prorettype => 'jsonb', proargtypes => 'jsonb int4',
   prosrc => 'jsonb_delete_idx' },
@@ -9282,130 +8404,116 @@
   prosrc => 'jsonb_delete_array' },
 { oid => '3304',
   proname => 'jsonb_delete_path', prorettype => 'jsonb',
-  proargtypes => 'jsonb _text', prosrc => 'jsonb_delete_path' },
+  proargtypes => 'jsonb _text' },
 { oid => '3305', descr => 'Set part of a jsonb',
   proname => 'jsonb_set', prorettype => 'jsonb',
-  proargtypes => 'jsonb _text jsonb bool', prosrc => 'jsonb_set' },
+  proargtypes => 'jsonb _text jsonb bool' },
 { oid => '3306', descr => 'Indented text from jsonb',
-  proname => 'jsonb_pretty', prorettype => 'text', proargtypes => 'jsonb',
-  prosrc => 'jsonb_pretty' },
+  proname => 'jsonb_pretty', prorettype => 'text', proargtypes => 'jsonb' },
 { oid => '3579', descr => 'Insert value into a jsonb',
   proname => 'jsonb_insert', prorettype => 'jsonb',
-  proargtypes => 'jsonb _text jsonb bool', prosrc => 'jsonb_insert' },
+  proargtypes => 'jsonb _text jsonb bool' },
 
 # txid
 { oid => '2939', descr => 'I/O',
   proname => 'txid_snapshot_in', prorettype => 'txid_snapshot',
-  proargtypes => 'cstring', prosrc => 'txid_snapshot_in' },
+  proargtypes => 'cstring' },
 { oid => '2940', descr => 'I/O',
   proname => 'txid_snapshot_out', prorettype => 'cstring',
-  proargtypes => 'txid_snapshot', prosrc => 'txid_snapshot_out' },
+  proargtypes => 'txid_snapshot' },
 { oid => '2941', descr => 'I/O',
   proname => 'txid_snapshot_recv', prorettype => 'txid_snapshot',
-  proargtypes => 'internal', prosrc => 'txid_snapshot_recv' },
+  proargtypes => 'internal' },
 { oid => '2942', descr => 'I/O',
   proname => 'txid_snapshot_send', prorettype => 'bytea',
-  proargtypes => 'txid_snapshot', prosrc => 'txid_snapshot_send' },
+  proargtypes => 'txid_snapshot' },
 { oid => '2943', descr => 'get current transaction ID',
   proname => 'txid_current', provolatile => 's', proparallel => 'u',
-  prorettype => 'int8', proargtypes => '', prosrc => 'txid_current' },
+  prorettype => 'int8', proargtypes => '' },
 { oid => '3348', descr => 'get current transaction ID',
   proname => 'txid_current_if_assigned', provolatile => 's', proparallel => 'u',
-  prorettype => 'int8', proargtypes => '',
-  prosrc => 'txid_current_if_assigned' },
+  prorettype => 'int8', proargtypes => '' },
 { oid => '2944', descr => 'get current snapshot',
   proname => 'txid_current_snapshot', provolatile => 's',
-  prorettype => 'txid_snapshot', proargtypes => '',
-  prosrc => 'txid_current_snapshot' },
+  prorettype => 'txid_snapshot', proargtypes => '' },
 { oid => '2945', descr => 'get xmin of snapshot',
   proname => 'txid_snapshot_xmin', prorettype => 'int8',
-  proargtypes => 'txid_snapshot', prosrc => 'txid_snapshot_xmin' },
+  proargtypes => 'txid_snapshot' },
 { oid => '2946', descr => 'get xmax of snapshot',
   proname => 'txid_snapshot_xmax', prorettype => 'int8',
-  proargtypes => 'txid_snapshot', prosrc => 'txid_snapshot_xmax' },
+  proargtypes => 'txid_snapshot' },
 { oid => '2947', descr => 'get set of in-progress txids in snapshot',
   proname => 'txid_snapshot_xip', prorows => '50', proretset => 't',
-  prorettype => 'int8', proargtypes => 'txid_snapshot',
-  prosrc => 'txid_snapshot_xip' },
+  prorettype => 'int8', proargtypes => 'txid_snapshot' },
 { oid => '2948', descr => 'is txid visible in snapshot?',
   proname => 'txid_visible_in_snapshot', prorettype => 'bool',
-  proargtypes => 'int8 txid_snapshot', prosrc => 'txid_visible_in_snapshot' },
+  proargtypes => 'int8 txid_snapshot' },
 { oid => '3360', descr => 'commit status of transaction',
   proname => 'txid_status', provolatile => 'v', prorettype => 'text',
-  proargtypes => 'int8', prosrc => 'txid_status' },
+  proargtypes => 'int8' },
 
 # record comparison using normal comparison rules
 { oid => '2981',
-  proname => 'record_eq', prorettype => 'bool', proargtypes => 'record record',
-  prosrc => 'record_eq' },
+  proname => 'record_eq', prorettype => 'bool', proargtypes => 'record record' },
 { oid => '2982',
-  proname => 'record_ne', prorettype => 'bool', proargtypes => 'record record',
-  prosrc => 'record_ne' },
+  proname => 'record_ne', prorettype => 'bool', proargtypes => 'record record' },
 { oid => '2983',
-  proname => 'record_lt', prorettype => 'bool', proargtypes => 'record record',
-  prosrc => 'record_lt' },
+  proname => 'record_lt', prorettype => 'bool', proargtypes => 'record record' },
 { oid => '2984',
-  proname => 'record_gt', prorettype => 'bool', proargtypes => 'record record',
-  prosrc => 'record_gt' },
+  proname => 'record_gt', prorettype => 'bool', proargtypes => 'record record' },
 { oid => '2985',
-  proname => 'record_le', prorettype => 'bool', proargtypes => 'record record',
-  prosrc => 'record_le' },
+  proname => 'record_le', prorettype => 'bool', proargtypes => 'record record' },
 { oid => '2986',
-  proname => 'record_ge', prorettype => 'bool', proargtypes => 'record record',
-  prosrc => 'record_ge' },
+  proname => 'record_ge', prorettype => 'bool', proargtypes => 'record record' },
 { oid => '2987', descr => 'less-equal-greater',
   proname => 'btrecordcmp', prorettype => 'int4',
-  proargtypes => 'record record', prosrc => 'btrecordcmp' },
+  proargtypes => 'record record' },
 
 # record comparison using raw byte images
 { oid => '3181',
   proname => 'record_image_eq', prorettype => 'bool',
-  proargtypes => 'record record', prosrc => 'record_image_eq' },
+  proargtypes => 'record record' },
 { oid => '3182',
   proname => 'record_image_ne', prorettype => 'bool',
-  proargtypes => 'record record', prosrc => 'record_image_ne' },
+  proargtypes => 'record record' },
 { oid => '3183',
   proname => 'record_image_lt', prorettype => 'bool',
-  proargtypes => 'record record', prosrc => 'record_image_lt' },
+  proargtypes => 'record record' },
 { oid => '3184',
   proname => 'record_image_gt', prorettype => 'bool',
-  proargtypes => 'record record', prosrc => 'record_image_gt' },
+  proargtypes => 'record record' },
 { oid => '3185',
   proname => 'record_image_le', prorettype => 'bool',
-  proargtypes => 'record record', prosrc => 'record_image_le' },
+  proargtypes => 'record record' },
 { oid => '3186',
   proname => 'record_image_ge', prorettype => 'bool',
-  proargtypes => 'record record', prosrc => 'record_image_ge' },
+  proargtypes => 'record record' },
 { oid => '3187', descr => 'less-equal-greater based on byte images',
   proname => 'btrecordimagecmp', prorettype => 'int4',
-  proargtypes => 'record record', prosrc => 'btrecordimagecmp' },
+  proargtypes => 'record record' },
 
 # Extensions
 { oid => '3082', descr => 'list available extensions',
   proname => 'pg_available_extensions', procost => '10', prorows => '100',
   proretset => 't', provolatile => 's', prorettype => 'record',
   proargtypes => '', proallargtypes => '{name,text,text}',
-  proargmodes => '{o,o,o}', proargnames => '{name,default_version,comment}',
-  prosrc => 'pg_available_extensions' },
+  proargmodes => '{o,o,o}', proargnames => '{name,default_version,comment}' },
 { oid => '3083', descr => 'list available extension versions',
   proname => 'pg_available_extension_versions', procost => '10',
   prorows => '100', proretset => 't', provolatile => 's',
   prorettype => 'record', proargtypes => '',
   proallargtypes => '{name,text,bool,bool,name,_name,text}',
   proargmodes => '{o,o,o,o,o,o,o}',
-  proargnames => '{name,version,superuser,relocatable,schema,requires,comment}',
-  prosrc => 'pg_available_extension_versions' },
+  proargnames => '{name,version,superuser,relocatable,schema,requires,comment}' },
 { oid => '3084', descr => 'list an extension\'s version update paths',
   proname => 'pg_extension_update_paths', procost => '10', prorows => '100',
   proretset => 't', provolatile => 's', prorettype => 'record',
   proargtypes => 'name', proallargtypes => '{name,text,text,text}',
-  proargmodes => '{i,o,o,o}', proargnames => '{name,source,target,path}',
-  prosrc => 'pg_extension_update_paths' },
+  proargmodes => '{i,o,o,o}', proargnames => '{name,source,target,path}' },
 { oid => '3086',
   descr => 'flag an extension\'s table contents to be emitted by pg_dump',
   proname => 'pg_extension_config_dump', provolatile => 'v', proparallel => 'u',
-  prorettype => 'void', proargtypes => 'regclass text',
-  prosrc => 'pg_extension_config_dump' },
+  prorettype => 'void', proargtypes => 'regclass text' },
 
 # SQL-spec window functions
 { oid => '3100', descr => 'row number within partition',
@@ -9459,22 +8567,22 @@
 # functions for range types
 { oid => '3832', descr => 'I/O',
   proname => 'anyrange_in', provolatile => 's', prorettype => 'anyrange',
-  proargtypes => 'cstring oid int4', prosrc => 'anyrange_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '3833', descr => 'I/O',
   proname => 'anyrange_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'anyrange', prosrc => 'anyrange_out' },
+  proargtypes => 'anyrange' },
 { oid => '3834', descr => 'I/O',
   proname => 'range_in', provolatile => 's', prorettype => 'anyrange',
-  proargtypes => 'cstring oid int4', prosrc => 'range_in' },
+  proargtypes => 'cstring oid int4' },
 { oid => '3835', descr => 'I/O',
   proname => 'range_out', provolatile => 's', prorettype => 'cstring',
-  proargtypes => 'anyrange', prosrc => 'range_out' },
+  proargtypes => 'anyrange' },
 { oid => '3836', descr => 'I/O',
   proname => 'range_recv', provolatile => 's', prorettype => 'anyrange',
-  proargtypes => 'internal oid int4', prosrc => 'range_recv' },
+  proargtypes => 'internal oid int4' },
 { oid => '3837', descr => 'I/O',
   proname => 'range_send', provolatile => 's', prorettype => 'bytea',
-  proargtypes => 'anyrange', prosrc => 'range_send' },
+  proargtypes => 'anyrange' },
 { oid => '3848', descr => 'lower bound of range',
   proname => 'lower', prorettype => 'anyelement', proargtypes => 'anyrange',
   prosrc => 'range_lower' },
@@ -9498,125 +8606,123 @@
   prosrc => 'range_upper_inf' },
 { oid => '3855',
   proname => 'range_eq', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_eq' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3856',
   proname => 'range_ne', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_ne' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3857',
   proname => 'range_overlaps', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_overlaps' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3858',
   proname => 'range_contains_elem', prorettype => 'bool',
-  proargtypes => 'anyrange anyelement', prosrc => 'range_contains_elem' },
+  proargtypes => 'anyrange anyelement' },
 { oid => '3859',
   proname => 'range_contains', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_contains' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3860',
   proname => 'elem_contained_by_range', prorettype => 'bool',
-  proargtypes => 'anyelement anyrange', prosrc => 'elem_contained_by_range' },
+  proargtypes => 'anyelement anyrange' },
 { oid => '3861',
   proname => 'range_contained_by', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_contained_by' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3862',
   proname => 'range_adjacent', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_adjacent' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3863',
   proname => 'range_before', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_before' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3864',
   proname => 'range_after', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_after' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3865',
   proname => 'range_overleft', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_overleft' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3866',
   proname => 'range_overright', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_overright' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3867',
   proname => 'range_union', prorettype => 'anyrange',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_union' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '4057',
   descr => 'the smallest range which includes both of the given ranges',
   proname => 'range_merge', prorettype => 'anyrange',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_merge' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3868',
   proname => 'range_intersect', prorettype => 'anyrange',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_intersect' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3869',
   proname => 'range_minus', prorettype => 'anyrange',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_minus' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3870', descr => 'less-equal-greater',
   proname => 'range_cmp', prorettype => 'int4',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_cmp' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3871',
   proname => 'range_lt', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_lt' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3872',
   proname => 'range_le', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_le' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3873',
   proname => 'range_ge', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_ge' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3874',
   proname => 'range_gt', prorettype => 'bool',
-  proargtypes => 'anyrange anyrange', prosrc => 'range_gt' },
+  proargtypes => 'anyrange anyrange' },
 { oid => '3875', descr => 'GiST support',
   proname => 'range_gist_consistent', prorettype => 'bool',
-  proargtypes => 'internal anyrange int2 oid internal',
-  prosrc => 'range_gist_consistent' },
+  proargtypes => 'internal anyrange int2 oid internal' },
 { oid => '3876', descr => 'GiST support',
   proname => 'range_gist_union', prorettype => 'anyrange',
-  proargtypes => 'internal internal', prosrc => 'range_gist_union' },
+  proargtypes => 'internal internal' },
 { oid => '3879', descr => 'GiST support',
   proname => 'range_gist_penalty', prorettype => 'internal',
-  proargtypes => 'internal internal internal', prosrc => 'range_gist_penalty' },
+  proargtypes => 'internal internal internal' },
 { oid => '3880', descr => 'GiST support',
   proname => 'range_gist_picksplit', prorettype => 'internal',
-  proargtypes => 'internal internal', prosrc => 'range_gist_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '3881', descr => 'GiST support',
   proname => 'range_gist_same', prorettype => 'internal',
-  proargtypes => 'anyrange anyrange internal', prosrc => 'range_gist_same' },
+  proargtypes => 'anyrange anyrange internal' },
 { oid => '3902', descr => 'hash a range',
-  proname => 'hash_range', prorettype => 'int4', proargtypes => 'anyrange',
-  prosrc => 'hash_range' },
+  proname => 'hash_range', prorettype => 'int4', proargtypes => 'anyrange' },
 { oid => '3417', descr => 'hash a range',
   proname => 'hash_range_extended', prorettype => 'int8',
-  proargtypes => 'anyrange int8', prosrc => 'hash_range_extended' },
+  proargtypes => 'anyrange int8' },
 { oid => '3916', descr => 'range typanalyze',
   proname => 'range_typanalyze', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'internal', prosrc => 'range_typanalyze' },
+  proargtypes => 'internal' },
 { oid => '3169', descr => 'restriction selectivity for range operators',
   proname => 'rangesel', provolatile => 's', prorettype => 'float8',
-  proargtypes => 'internal oid internal int4', prosrc => 'rangesel' },
+  proargtypes => 'internal oid internal int4' },
 
 { oid => '3914', descr => 'convert an int4 range to canonical form',
   proname => 'int4range_canonical', prorettype => 'int4range',
-  proargtypes => 'int4range', prosrc => 'int4range_canonical' },
+  proargtypes => 'int4range' },
 { oid => '3928', descr => 'convert an int8 range to canonical form',
   proname => 'int8range_canonical', prorettype => 'int8range',
-  proargtypes => 'int8range', prosrc => 'int8range_canonical' },
+  proargtypes => 'int8range' },
 { oid => '3915', descr => 'convert a date range to canonical form',
   proname => 'daterange_canonical', prorettype => 'daterange',
-  proargtypes => 'daterange', prosrc => 'daterange_canonical' },
+  proargtypes => 'daterange' },
 { oid => '3922', descr => 'float8 difference of two int4 values',
   proname => 'int4range_subdiff', prorettype => 'float8',
-  proargtypes => 'int4 int4', prosrc => 'int4range_subdiff' },
+  proargtypes => 'int4 int4' },
 { oid => '3923', descr => 'float8 difference of two int8 values',
   proname => 'int8range_subdiff', prorettype => 'float8',
-  proargtypes => 'int8 int8', prosrc => 'int8range_subdiff' },
+  proargtypes => 'int8 int8' },
 { oid => '3924', descr => 'float8 difference of two numeric values',
   proname => 'numrange_subdiff', prorettype => 'float8',
-  proargtypes => 'numeric numeric', prosrc => 'numrange_subdiff' },
+  proargtypes => 'numeric numeric' },
 { oid => '3925', descr => 'float8 difference of two date values',
   proname => 'daterange_subdiff', prorettype => 'float8',
-  proargtypes => 'date date', prosrc => 'daterange_subdiff' },
+  proargtypes => 'date date' },
 { oid => '3929', descr => 'float8 difference of two timestamp values',
   proname => 'tsrange_subdiff', prorettype => 'float8',
-  proargtypes => 'timestamp timestamp', prosrc => 'tsrange_subdiff' },
+  proargtypes => 'timestamp timestamp' },
 { oid => '3930',
   descr => 'float8 difference of two timestamp with time zone values',
   proname => 'tstzrange_subdiff', prorettype => 'float8',
-  proargtypes => 'timestamptz timestamptz', prosrc => 'tstzrange_subdiff' },
+  proargtypes => 'timestamptz timestamptz' },
 
 { oid => '3840', descr => 'int4range constructor',
   proname => 'int4range', proisstrict => 'f', prorettype => 'int4range',
@@ -9659,20 +8765,18 @@
 # date, time, timestamp constructors
 { oid => '3846', descr => 'construct date',
   proname => 'make_date', prorettype => 'date', proargtypes => 'int4 int4 int4',
-  proargnames => '{year,month,day}', prosrc => 'make_date' },
+  proargnames => '{year,month,day}' },
 { oid => '3847', descr => 'construct time',
   proname => 'make_time', prorettype => 'time',
-  proargtypes => 'int4 int4 float8', proargnames => '{hour,min,sec}',
-  prosrc => 'make_time' },
+  proargtypes => 'int4 int4 float8', proargnames => '{hour,min,sec}' },
 { oid => '3461', descr => 'construct timestamp',
   proname => 'make_timestamp', prorettype => 'timestamp',
   proargtypes => 'int4 int4 int4 int4 int4 float8',
-  proargnames => '{year,month,mday,hour,min,sec}', prosrc => 'make_timestamp' },
+  proargnames => '{year,month,mday,hour,min,sec}' },
 { oid => '3462', descr => 'construct timestamp with time zone',
   proname => 'make_timestamptz', provolatile => 's',
   prorettype => 'timestamptz', proargtypes => 'int4 int4 int4 int4 int4 float8',
-  proargnames => '{year,month,mday,hour,min,sec}',
-  prosrc => 'make_timestamptz' },
+  proargnames => '{year,month,mday,hour,min,sec}' },
 { oid => '3463', descr => 'construct timestamp with time zone',
   proname => 'make_timestamptz', provolatile => 's',
   prorettype => 'timestamptz',
@@ -9682,99 +8786,94 @@
 { oid => '3464', descr => 'construct interval',
   proname => 'make_interval', prorettype => 'interval',
   proargtypes => 'int4 int4 int4 int4 int4 int4 float8',
-  proargnames => '{years,months,weeks,days,hours,mins,secs}',
-  prosrc => 'make_interval' },
+  proargnames => '{years,months,weeks,days,hours,mins,secs}' },
 
 # spgist opclasses
 { oid => '4018', descr => 'SP-GiST support for quad tree over point',
   proname => 'spg_quad_config', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_quad_config' },
+  proargtypes => 'internal internal' },
 { oid => '4019', descr => 'SP-GiST support for quad tree over point',
   proname => 'spg_quad_choose', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_quad_choose' },
+  proargtypes => 'internal internal' },
 { oid => '4020', descr => 'SP-GiST support for quad tree over point',
   proname => 'spg_quad_picksplit', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_quad_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '4021', descr => 'SP-GiST support for quad tree over point',
   proname => 'spg_quad_inner_consistent', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_quad_inner_consistent' },
+  proargtypes => 'internal internal' },
 { oid => '4022',
   descr => 'SP-GiST support for quad tree and k-d tree over point',
   proname => 'spg_quad_leaf_consistent', prorettype => 'bool',
-  proargtypes => 'internal internal', prosrc => 'spg_quad_leaf_consistent' },
+  proargtypes => 'internal internal' },
 
 { oid => '4023', descr => 'SP-GiST support for k-d tree over point',
   proname => 'spg_kd_config', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_kd_config' },
+  proargtypes => 'internal internal' },
 { oid => '4024', descr => 'SP-GiST support for k-d tree over point',
   proname => 'spg_kd_choose', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_kd_choose' },
+  proargtypes => 'internal internal' },
 { oid => '4025', descr => 'SP-GiST support for k-d tree over point',
   proname => 'spg_kd_picksplit', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_kd_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '4026', descr => 'SP-GiST support for k-d tree over point',
   proname => 'spg_kd_inner_consistent', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_kd_inner_consistent' },
+  proargtypes => 'internal internal' },
 
 { oid => '4027', descr => 'SP-GiST support for radix tree over text',
   proname => 'spg_text_config', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_text_config' },
+  proargtypes => 'internal internal' },
 { oid => '4028', descr => 'SP-GiST support for radix tree over text',
   proname => 'spg_text_choose', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_text_choose' },
+  proargtypes => 'internal internal' },
 { oid => '4029', descr => 'SP-GiST support for radix tree over text',
   proname => 'spg_text_picksplit', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_text_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '4030', descr => 'SP-GiST support for radix tree over text',
   proname => 'spg_text_inner_consistent', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_text_inner_consistent' },
+  proargtypes => 'internal internal' },
 { oid => '4031', descr => 'SP-GiST support for radix tree over text',
   proname => 'spg_text_leaf_consistent', prorettype => 'bool',
-  proargtypes => 'internal internal', prosrc => 'spg_text_leaf_consistent' },
+  proargtypes => 'internal internal' },
 
 { oid => '3469', descr => 'SP-GiST support for quad tree over range',
   proname => 'spg_range_quad_config', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_range_quad_config' },
+  proargtypes => 'internal internal' },
 { oid => '3470', descr => 'SP-GiST support for quad tree over range',
   proname => 'spg_range_quad_choose', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_range_quad_choose' },
+  proargtypes => 'internal internal' },
 { oid => '3471', descr => 'SP-GiST support for quad tree over range',
   proname => 'spg_range_quad_picksplit', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_range_quad_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '3472', descr => 'SP-GiST support for quad tree over range',
   proname => 'spg_range_quad_inner_consistent', prorettype => 'void',
-  proargtypes => 'internal internal',
-  prosrc => 'spg_range_quad_inner_consistent' },
+  proargtypes => 'internal internal' },
 { oid => '3473', descr => 'SP-GiST support for quad tree over range',
   proname => 'spg_range_quad_leaf_consistent', prorettype => 'bool',
-  proargtypes => 'internal internal',
-  prosrc => 'spg_range_quad_leaf_consistent' },
+  proargtypes => 'internal internal' },
 
 { oid => '5012', descr => 'SP-GiST support for quad tree over box',
   proname => 'spg_box_quad_config', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_box_quad_config' },
+  proargtypes => 'internal internal' },
 { oid => '5013', descr => 'SP-GiST support for quad tree over box',
   proname => 'spg_box_quad_choose', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_box_quad_choose' },
+  proargtypes => 'internal internal' },
 { oid => '5014', descr => 'SP-GiST support for quad tree over box',
   proname => 'spg_box_quad_picksplit', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_box_quad_picksplit' },
+  proargtypes => 'internal internal' },
 { oid => '5015', descr => 'SP-GiST support for quad tree over box',
   proname => 'spg_box_quad_inner_consistent', prorettype => 'void',
-  proargtypes => 'internal internal',
-  prosrc => 'spg_box_quad_inner_consistent' },
+  proargtypes => 'internal internal' },
 { oid => '5016', descr => 'SP-GiST support for quad tree over box',
   proname => 'spg_box_quad_leaf_consistent', prorettype => 'bool',
-  proargtypes => 'internal internal',
-  prosrc => 'spg_box_quad_leaf_consistent' },
+  proargtypes => 'internal internal' },
 
 { oid => '5010',
   descr => 'SP-GiST support for quad tree over 2-D types represented by their bounding boxes',
   proname => 'spg_bbox_quad_config', prorettype => 'void',
-  proargtypes => 'internal internal', prosrc => 'spg_bbox_quad_config' },
+  proargtypes => 'internal internal' },
 { oid => '5011', descr => 'SP-GiST support for quad tree over polygons',
   proname => 'spg_poly_quad_compress', prorettype => 'box',
-  proargtypes => 'polygon', prosrc => 'spg_poly_quad_compress' },
+  proargtypes => 'polygon' },
 
 # replication slots
 { oid => '3779', descr => 'create a physical replication slot',
@@ -9782,12 +8881,10 @@
   proparallel => 'u', prorettype => 'record', proargtypes => 'name bool bool',
   proallargtypes => '{name,bool,bool,name,pg_lsn}',
   proargmodes => '{i,i,i,o,o}',
-  proargnames => '{slot_name,immediately_reserve,temporary,slot_name,lsn}',
-  prosrc => 'pg_create_physical_replication_slot' },
+  proargnames => '{slot_name,immediately_reserve,temporary,slot_name,lsn}' },
 { oid => '3780', descr => 'drop a replication slot',
   proname => 'pg_drop_replication_slot', provolatile => 'v', proparallel => 'u',
-  prorettype => 'void', proargtypes => 'name',
-  prosrc => 'pg_drop_replication_slot' },
+  prorettype => 'void', proargtypes => 'name' },
 { oid => '3781',
   descr => 'information about replication slots currently in use',
   proname => 'pg_get_replication_slots', prorows => '10', proisstrict => 'f',
@@ -9795,15 +8892,13 @@
   proargtypes => '',
   proallargtypes => '{name,name,text,oid,bool,bool,int4,xid,xid,pg_lsn,pg_lsn}',
   proargmodes => '{o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{slot_name,plugin,slot_type,datoid,temporary,active,active_pid,xmin,catalog_xmin,restart_lsn,confirmed_flush_lsn}',
-  prosrc => 'pg_get_replication_slots' },
+  proargnames => '{slot_name,plugin,slot_type,datoid,temporary,active,active_pid,xmin,catalog_xmin,restart_lsn,confirmed_flush_lsn}' },
 { oid => '3786', descr => 'set up a logical replication slot',
   proname => 'pg_create_logical_replication_slot', provolatile => 'v',
   proparallel => 'u', prorettype => 'record', proargtypes => 'name name bool',
   proallargtypes => '{name,name,bool,text,pg_lsn}',
   proargmodes => '{i,i,i,o,o}',
-  proargnames => '{slot_name,plugin,temporary,slot_name,lsn}',
-  prosrc => 'pg_create_logical_replication_slot' },
+  proargnames => '{slot_name,plugin,temporary,slot_name,lsn}' },
 { oid => '3782', descr => 'get changes from replication slot',
   proname => 'pg_logical_slot_get_changes', procost => '1000',
   prorows => '1000', provariadic => 'text', proisstrict => 'f',
@@ -9811,8 +8906,7 @@
   prorettype => 'record', proargtypes => 'name pg_lsn int4 _text',
   proallargtypes => '{name,pg_lsn,int4,_text,pg_lsn,xid,text}',
   proargmodes => '{i,i,i,v,o,o,o}',
-  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}',
-  prosrc => 'pg_logical_slot_get_changes' },
+  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}' },
 { oid => '3783', descr => 'get binary changes from replication slot',
   proname => 'pg_logical_slot_get_binary_changes', procost => '1000',
   prorows => '1000', provariadic => 'text', proisstrict => 'f',
@@ -9820,8 +8914,7 @@
   prorettype => 'record', proargtypes => 'name pg_lsn int4 _text',
   proallargtypes => '{name,pg_lsn,int4,_text,pg_lsn,xid,bytea}',
   proargmodes => '{i,i,i,v,o,o,o}',
-  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}',
-  prosrc => 'pg_logical_slot_get_binary_changes' },
+  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}' },
 { oid => '3784', descr => 'peek at changes from replication slot',
   proname => 'pg_logical_slot_peek_changes', procost => '1000',
   prorows => '1000', provariadic => 'text', proisstrict => 'f',
@@ -9829,8 +8922,7 @@
   prorettype => 'record', proargtypes => 'name pg_lsn int4 _text',
   proallargtypes => '{name,pg_lsn,int4,_text,pg_lsn,xid,text}',
   proargmodes => '{i,i,i,v,o,o,o}',
-  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}',
-  prosrc => 'pg_logical_slot_peek_changes' },
+  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}' },
 { oid => '3785', descr => 'peek at binary changes from replication slot',
   proname => 'pg_logical_slot_peek_binary_changes', procost => '1000',
   prorows => '1000', provariadic => 'text', proisstrict => 'f',
@@ -9838,14 +8930,12 @@
   prorettype => 'record', proargtypes => 'name pg_lsn int4 _text',
   proallargtypes => '{name,pg_lsn,int4,_text,pg_lsn,xid,bytea}',
   proargmodes => '{i,i,i,v,o,o,o}',
-  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}',
-  prosrc => 'pg_logical_slot_peek_binary_changes' },
+  proargnames => '{slot_name,upto_lsn,upto_nchanges,options,lsn,xid,data}' },
 { oid => '3878', descr => 'advance logical replication slot',
   proname => 'pg_replication_slot_advance', provolatile => 'v',
   proparallel => 'u', prorettype => 'record', proargtypes => 'name pg_lsn',
   proallargtypes => '{name,pg_lsn,name,pg_lsn}', proargmodes => '{i,i,o,o}',
-  proargnames => '{slot_name,upto_lsn,slot_name,end_lsn}',
-  prosrc => 'pg_replication_slot_advance' },
+  proargnames => '{slot_name,upto_lsn,slot_name,end_lsn}' },
 { oid => '3577', descr => 'emit a textual logical decoding message',
   proname => 'pg_logical_emit_message', provolatile => 'v', proparallel => 'u',
   prorettype => 'pg_lsn', proargtypes => 'bool text text',
@@ -9862,17 +8952,14 @@
   prorettype => 'record', proargtypes => '',
   proallargtypes => '{oid,oid,int4,bool,bool,bool,text,text,text,text,_text,_text}',
   proargmodes => '{o,o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{classid, objid, objsubid, original, normal, is_temporary, object_type, schema_name, object_name, object_identity, address_names, address_args}',
-  prosrc => 'pg_event_trigger_dropped_objects' },
+  proargnames => '{classid, objid, objsubid, original, normal, is_temporary, object_type, schema_name, object_name, object_identity, address_names, address_args}' },
 { oid => '4566', descr => 'return Oid of the table getting rewritten',
   proname => 'pg_event_trigger_table_rewrite_oid', provolatile => 's',
   proparallel => 'r', prorettype => 'oid', proargtypes => '',
-  proallargtypes => '{oid}', proargmodes => '{o}', proargnames => '{oid}',
-  prosrc => 'pg_event_trigger_table_rewrite_oid' },
+  proallargtypes => '{oid}', proargmodes => '{o}', proargnames => '{oid}' },
 { oid => '4567', descr => 'return reason code for table getting rewritten',
   proname => 'pg_event_trigger_table_rewrite_reason', provolatile => 's',
-  proparallel => 'r', prorettype => 'int4', proargtypes => '',
-  prosrc => 'pg_event_trigger_table_rewrite_reason' },
+  proparallel => 'r', prorettype => 'int4', proargtypes => '' },
 { oid => '4568',
   descr => 'list DDL actions being executed by the current command',
   proname => 'pg_event_trigger_ddl_commands', procost => '10', prorows => '100',
@@ -9880,19 +8967,16 @@
   prorettype => 'record', proargtypes => '',
   proallargtypes => '{oid,oid,int4,text,text,text,text,bool,pg_ddl_command}',
   proargmodes => '{o,o,o,o,o,o,o,o,o}',
-  proargnames => '{classid, objid, objsubid, command_tag, object_type, schema_name, object_identity, in_extension, command}',
-  prosrc => 'pg_event_trigger_ddl_commands' },
+  proargnames => '{classid, objid, objsubid, command_tag, object_type, schema_name, object_identity, in_extension, command}' },
 
 # generic transition functions for ordered-set aggregates
 { oid => '3970', descr => 'aggregate transition function',
   proname => 'ordered_set_transition', proisstrict => 'f',
-  prorettype => 'internal', proargtypes => 'internal any',
-  prosrc => 'ordered_set_transition' },
+  prorettype => 'internal', proargtypes => 'internal any' },
 { oid => '3971', descr => 'aggregate transition function',
   proname => 'ordered_set_transition_multi', provariadic => 'any',
   proisstrict => 'f', prorettype => 'internal', proargtypes => 'internal any',
-  proallargtypes => '{internal,any}', proargmodes => '{i,v}',
-  prosrc => 'ordered_set_transition_multi' },
+  proallargtypes => '{internal,any}', proargmodes => '{i,v}' },
 
 # inverse distribution aggregates (and their support functions)
 { oid => '3972', descr => 'discrete percentile',
@@ -9901,55 +8985,49 @@
   prosrc => 'aggregate_dummy' },
 { oid => '3973', descr => 'aggregate final function',
   proname => 'percentile_disc_final', proisstrict => 'f',
-  prorettype => 'anyelement', proargtypes => 'internal float8 anyelement',
-  prosrc => 'percentile_disc_final' },
+  prorettype => 'anyelement', proargtypes => 'internal float8 anyelement' },
 { oid => '3974', descr => 'continuous distribution percentile',
   proname => 'percentile_cont', prokind => 'a', proisstrict => 'f',
   prorettype => 'float8', proargtypes => 'float8 float8',
   prosrc => 'aggregate_dummy' },
 { oid => '3975', descr => 'aggregate final function',
   proname => 'percentile_cont_float8_final', proisstrict => 'f',
-  prorettype => 'float8', proargtypes => 'internal float8',
-  prosrc => 'percentile_cont_float8_final' },
+  prorettype => 'float8', proargtypes => 'internal float8' },
 { oid => '3976', descr => 'continuous distribution percentile',
   proname => 'percentile_cont', prokind => 'a', proisstrict => 'f',
   prorettype => 'interval', proargtypes => 'float8 interval',
   prosrc => 'aggregate_dummy' },
 { oid => '3977', descr => 'aggregate final function',
   proname => 'percentile_cont_interval_final', proisstrict => 'f',
-  prorettype => 'interval', proargtypes => 'internal float8',
-  prosrc => 'percentile_cont_interval_final' },
+  prorettype => 'interval', proargtypes => 'internal float8' },
 { oid => '3978', descr => 'multiple discrete percentiles',
   proname => 'percentile_disc', prokind => 'a', proisstrict => 'f',
   prorettype => 'anyarray', proargtypes => '_float8 anyelement',
   prosrc => 'aggregate_dummy' },
 { oid => '3979', descr => 'aggregate final function',
   proname => 'percentile_disc_multi_final', proisstrict => 'f',
-  prorettype => 'anyarray', proargtypes => 'internal _float8 anyelement',
-  prosrc => 'percentile_disc_multi_final' },
+  prorettype => 'anyarray', proargtypes => 'internal _float8 anyelement' },
 { oid => '3980', descr => 'multiple continuous percentiles',
   proname => 'percentile_cont', prokind => 'a', proisstrict => 'f',
   prorettype => '_float8', proargtypes => '_float8 float8',
   prosrc => 'aggregate_dummy' },
 { oid => '3981', descr => 'aggregate final function',
   proname => 'percentile_cont_float8_multi_final', proisstrict => 'f',
-  prorettype => '_float8', proargtypes => 'internal _float8',
-  prosrc => 'percentile_cont_float8_multi_final' },
+  prorettype => '_float8', proargtypes => 'internal _float8' },
 { oid => '3982', descr => 'multiple continuous percentiles',
   proname => 'percentile_cont', prokind => 'a', proisstrict => 'f',
   prorettype => '_interval', proargtypes => '_float8 interval',
   prosrc => 'aggregate_dummy' },
 { oid => '3983', descr => 'aggregate final function',
   proname => 'percentile_cont_interval_multi_final', proisstrict => 'f',
-  prorettype => '_interval', proargtypes => 'internal _float8',
-  prosrc => 'percentile_cont_interval_multi_final' },
+  prorettype => '_interval', proargtypes => 'internal _float8' },
 { oid => '3984', descr => 'most common value',
   proname => 'mode', prokind => 'a', proisstrict => 'f',
   prorettype => 'anyelement', proargtypes => 'anyelement',
   prosrc => 'aggregate_dummy' },
 { oid => '3985', descr => 'aggregate final function',
   proname => 'mode_final', proisstrict => 'f', prorettype => 'anyelement',
-  proargtypes => 'internal anyelement', prosrc => 'mode_final' },
+  proargtypes => 'internal anyelement' },
 
 # hypothetical-set aggregates (and their support functions)
 { oid => '3986', descr => 'rank of hypothetical row',
@@ -9995,133 +9073,110 @@
 # pg_upgrade support
 { oid => '3582', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_pg_type_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_pg_type_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3584', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_array_pg_type_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_array_pg_type_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3585', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_toast_pg_type_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_toast_pg_type_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3586', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_heap_pg_class_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_heap_pg_class_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3587', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_index_pg_class_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_index_pg_class_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3588', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_toast_pg_class_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_toast_pg_class_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3589', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_pg_enum_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_pg_enum_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3590', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_next_pg_authid_oid', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'oid',
-  prosrc => 'binary_upgrade_set_next_pg_authid_oid' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'oid' },
 { oid => '3591', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_create_empty_extension', proisstrict => 'f',
   provolatile => 'v', proparallel => 'u', prorettype => 'void',
-  proargtypes => 'text text bool text _oid _text _text',
-  prosrc => 'binary_upgrade_create_empty_extension' },
+  proargtypes => 'text text bool text _oid _text _text' },
 { oid => '4083', descr => 'for use by pg_upgrade',
   proname => 'binary_upgrade_set_record_init_privs', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'bool',
-  prosrc => 'binary_upgrade_set_record_init_privs' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'bool' },
 
 # replication/origin.h
 { oid => '6003', descr => 'create a replication origin',
   proname => 'pg_replication_origin_create', provolatile => 'v',
-  proparallel => 'u', prorettype => 'oid', proargtypes => 'text',
-  prosrc => 'pg_replication_origin_create' },
+  proparallel => 'u', prorettype => 'oid', proargtypes => 'text' },
 
 { oid => '6004', descr => 'drop replication origin identified by its name',
   proname => 'pg_replication_origin_drop', provolatile => 'v',
-  proparallel => 'u', prorettype => 'void', proargtypes => 'text',
-  prosrc => 'pg_replication_origin_drop' },
+  proparallel => 'u', prorettype => 'void', proargtypes => 'text' },
 
 { oid => '6005',
   descr => 'translate the replication origin\'s name to its id',
   proname => 'pg_replication_origin_oid', provolatile => 's',
-  prorettype => 'oid', proargtypes => 'text',
-  prosrc => 'pg_replication_origin_oid' },
+  prorettype => 'oid', proargtypes => 'text' },
 
 { oid => '6006',
   descr => 'configure session to maintain replication progress tracking for the passed in origin',
   proname => 'pg_replication_origin_session_setup', provolatile => 'v',
-  proparallel => 'u', prorettype => 'void', proargtypes => 'text',
-  prosrc => 'pg_replication_origin_session_setup' },
+  proparallel => 'u', prorettype => 'void', proargtypes => 'text' },
 
 { oid => '6007', descr => 'teardown configured replication progress tracking',
   proname => 'pg_replication_origin_session_reset', provolatile => 'v',
-  proparallel => 'u', prorettype => 'void', proargtypes => '',
-  prosrc => 'pg_replication_origin_session_reset' },
+  proparallel => 'u', prorettype => 'void', proargtypes => '' },
 
 { oid => '6008',
   descr => 'is a replication origin configured in this session',
   proname => 'pg_replication_origin_session_is_setup', provolatile => 'v',
-  proparallel => 'r', prorettype => 'bool', proargtypes => '',
-  prosrc => 'pg_replication_origin_session_is_setup' },
+  proparallel => 'r', prorettype => 'bool', proargtypes => '' },
 
 { oid => '6009',
   descr => 'get the replication progress of the current session',
   proname => 'pg_replication_origin_session_progress', provolatile => 'v',
-  proparallel => 'u', prorettype => 'pg_lsn', proargtypes => 'bool',
-  prosrc => 'pg_replication_origin_session_progress' },
+  proparallel => 'u', prorettype => 'pg_lsn', proargtypes => 'bool' },
 
 { oid => '6010', descr => 'setup the transaction\'s origin lsn and timestamp',
   proname => 'pg_replication_origin_xact_setup', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => 'pg_lsn timestamptz',
-  prosrc => 'pg_replication_origin_xact_setup' },
+  proparallel => 'r', prorettype => 'void', proargtypes => 'pg_lsn timestamptz' },
 
 { oid => '6011', descr => 'reset the transaction\'s origin lsn and timestamp',
   proname => 'pg_replication_origin_xact_reset', provolatile => 'v',
-  proparallel => 'r', prorettype => 'void', proargtypes => '',
-  prosrc => 'pg_replication_origin_xact_reset' },
+  proparallel => 'r', prorettype => 'void', proargtypes => '' },
 
 { oid => '6012',
   descr => 'advance replication identifier to specific location',
   proname => 'pg_replication_origin_advance', provolatile => 'v',
-  proparallel => 'u', prorettype => 'void', proargtypes => 'text pg_lsn',
-  prosrc => 'pg_replication_origin_advance' },
+  proparallel => 'u', prorettype => 'void', proargtypes => 'text pg_lsn' },
 
 { oid => '6013',
   descr => 'get an individual replication origin\'s replication progress',
   proname => 'pg_replication_origin_progress', provolatile => 'v',
-  proparallel => 'u', prorettype => 'pg_lsn', proargtypes => 'text bool',
-  prosrc => 'pg_replication_origin_progress' },
+  proparallel => 'u', prorettype => 'pg_lsn', proargtypes => 'text bool' },
 
 { oid => '6014', descr => 'get progress for all replication origins',
   proname => 'pg_show_replication_origin_status', prorows => '100',
   proisstrict => 'f', proretset => 't', provolatile => 'v', proparallel => 'r',
   prorettype => 'record', proargtypes => '',
   proallargtypes => '{oid,text,pg_lsn,pg_lsn}', proargmodes => '{o,o,o,o}',
-  proargnames => '{local_id, external_id, remote_lsn, local_lsn}',
-  prosrc => 'pg_show_replication_origin_status' },
+  proargnames => '{local_id, external_id, remote_lsn, local_lsn}' },
 
 # publications
 { oid => '6119', descr => 'get OIDs of tables in a publication',
   proname => 'pg_get_publication_tables', prorows => '1000', proretset => 't',
   provolatile => 's', prorettype => 'oid', proargtypes => 'text',
   proallargtypes => '{text,oid}', proargmodes => '{i,o}',
-  proargnames => '{pubname,relid}', prosrc => 'pg_get_publication_tables' },
+  proargnames => '{pubname,relid}' },
 { oid => '6121',
   descr => 'returns whether a relation can be part of a publication',
   proname => 'pg_relation_is_publishable', provolatile => 's',
-  prorettype => 'bool', proargtypes => 'regclass',
-  prosrc => 'pg_relation_is_publishable' },
+  prorettype => 'bool', proargtypes => 'regclass' },
 
 # rls
 { oid => '3298',
   descr => 'row security for current context active on table by table oid',
   proname => 'row_security_active', provolatile => 's', prorettype => 'bool',
-  proargtypes => 'oid', prosrc => 'row_security_active' },
+  proargtypes => 'oid' },
 { oid => '3299',
   descr => 'row security for current context active on table by table name',
   proname => 'row_security_active', provolatile => 's', prorettype => 'bool',
@@ -10131,8 +9186,7 @@
 { oid => '3400', descr => 'pg_config binary as a function',
   proname => 'pg_config', prorows => '23', proretset => 't', proparallel => 'r',
   prorettype => 'record', proargtypes => '', proallargtypes => '{text,text}',
-  proargmodes => '{o,o}', proargnames => '{name,setting}',
-  prosrc => 'pg_config' },
+  proargmodes => '{o,o}', proargnames => '{name,setting}' },
 
 # pg_controldata related functions
 { oid => '3441',
@@ -10140,8 +9194,7 @@
   proname => 'pg_control_system', provolatile => 'v', prorettype => 'record',
   proargtypes => '', proallargtypes => '{int4,int4,int8,timestamptz}',
   proargmodes => '{o,o,o,o}',
-  proargnames => '{pg_control_version,catalog_version_no,system_identifier,pg_control_last_modified}',
-  prosrc => 'pg_control_system' },
+  proargnames => '{pg_control_version,catalog_version_no,system_identifier,pg_control_last_modified}' },
 
 { oid => '3442',
   descr => 'pg_controldata checkpoint state information as a function',
@@ -10149,16 +9202,14 @@
   prorettype => 'record', proargtypes => '',
   proallargtypes => '{pg_lsn,pg_lsn,text,int4,int4,bool,text,oid,xid,xid,xid,oid,xid,xid,oid,xid,xid,timestamptz}',
   proargmodes => '{o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{checkpoint_lsn,redo_lsn,redo_wal_file,timeline_id,prev_timeline_id,full_page_writes,next_xid,next_oid,next_multixact_id,next_multi_offset,oldest_xid,oldest_xid_dbid,oldest_active_xid,oldest_multi_xid,oldest_multi_dbid,oldest_commit_ts_xid,newest_commit_ts_xid,checkpoint_time}',
-  prosrc => 'pg_control_checkpoint' },
+  proargnames => '{checkpoint_lsn,redo_lsn,redo_wal_file,timeline_id,prev_timeline_id,full_page_writes,next_xid,next_oid,next_multixact_id,next_multi_offset,oldest_xid,oldest_xid_dbid,oldest_active_xid,oldest_multi_xid,oldest_multi_dbid,oldest_commit_ts_xid,newest_commit_ts_xid,checkpoint_time}' },
 
 { oid => '3443',
   descr => 'pg_controldata recovery state information as a function',
   proname => 'pg_control_recovery', provolatile => 'v', prorettype => 'record',
   proargtypes => '', proallargtypes => '{pg_lsn,int4,pg_lsn,pg_lsn,bool}',
   proargmodes => '{o,o,o,o,o}',
-  proargnames => '{min_recovery_end_lsn,min_recovery_end_timeline,backup_start_lsn,backup_end_lsn,end_of_backup_record_required}',
-  prosrc => 'pg_control_recovery' },
+  proargnames => '{min_recovery_end_lsn,min_recovery_end_timeline,backup_start_lsn,backup_end_lsn,end_of_backup_record_required}' },
 
 { oid => '3444',
   descr => 'pg_controldata init state information as a function',
@@ -10166,37 +9217,36 @@
   proargtypes => '',
   proallargtypes => '{int4,int4,int4,int4,int4,int4,int4,int4,int4,bool,bool,int4}',
   proargmodes => '{o,o,o,o,o,o,o,o,o,o,o,o}',
-  proargnames => '{max_data_alignment,database_block_size,blocks_per_segment,wal_block_size,bytes_per_wal_segment,max_identifier_length,max_index_columns,max_toast_chunk_size,large_object_chunk_size,float4_pass_by_value,float8_pass_by_value,data_page_checksum_version}',
-  prosrc => 'pg_control_init' },
+  proargnames => '{max_data_alignment,database_block_size,blocks_per_segment,wal_block_size,bytes_per_wal_segment,max_identifier_length,max_index_columns,max_toast_chunk_size,large_object_chunk_size,float4_pass_by_value,float8_pass_by_value,data_page_checksum_version}' },
 
 # collation management functions
 { oid => '3445', descr => 'import collations from operating system',
   proname => 'pg_import_system_collations', procost => '100',
   provolatile => 'v', proparallel => 'u', prorettype => 'int4',
-  proargtypes => 'regnamespace', prosrc => 'pg_import_system_collations' },
+  proargtypes => 'regnamespace' },
 
 { oid => '3448',
   descr => 'get actual version of collation from operating system',
   proname => 'pg_collation_actual_version', procost => '100',
-  provolatile => 'v', prorettype => 'text', proargtypes => 'oid',
-  prosrc => 'pg_collation_actual_version' },
+  provolatile => 'v', prorettype => 'text', proargtypes => 'oid' },
 
 # system management/monitoring related functions
 { oid => '3353', descr => 'list files in the log directory',
   proname => 'pg_ls_logdir', procost => '10', prorows => '20', proretset => 't',
   provolatile => 'v', prorettype => 'record', proargtypes => '',
   proallargtypes => '{text,int8,timestamptz}', proargmodes => '{o,o,o}',
-  proargnames => '{name,size,modification}', prosrc => 'pg_ls_logdir' },
+  proargnames => '{name,size,modification}' },
 { oid => '3354', descr => 'list of files in the WAL directory',
   proname => 'pg_ls_waldir', procost => '10', prorows => '20', proretset => 't',
   provolatile => 'v', prorettype => 'record', proargtypes => '',
   proallargtypes => '{text,int8,timestamptz}', proargmodes => '{o,o,o}',
-  proargnames => '{name,size,modification}', prosrc => 'pg_ls_waldir' },
+  proargnames => '{name,size,modification}' },
 
 # hash partitioning constraint function
 { oid => '5028', descr => 'hash partition CHECK constraint',
   proname => 'satisfies_hash_partition', provariadic => 'any',
   proisstrict => 'f', prorettype => 'bool', proargtypes => 'oid int4 int4 any',
-  proargmodes => '{i,i,i,v}', prosrc => 'satisfies_hash_partition' },
+  proargmodes => '{i,i,i,v}' },
 
 ]
+},
\ No newline at end of file
diff --git a/src/include/catalog/pg_proc.h b/src/include/catalog/pg_proc.h
index a34b2596fa..3a88dab078 100644
--- a/src/include/catalog/pg_proc.h
+++ b/src/include/catalog/pg_proc.h
@@ -111,7 +111,7 @@ CATALOG(pg_proc,1255,ProcedureRelationId) BKI_BOOTSTRAP BKI_ROWTYPE_OID(81,Proce
 	Oid			protrftypes[1] BKI_DEFAULT(_null_);
 
 	/* procedure source text */
-	text		prosrc BKI_FORCE_NOT_NULL;
+	text		prosrc BKI_DEFAULT("${proname}") BKI_FORCE_NOT_NULL;
 
 	/* secondary procedure info (can be NULL) */
 	text		probin BKI_DEFAULT(_null_);
diff --git a/src/include/catalog/pg_type.dat b/src/include/catalog/pg_type.dat
index 48e01cd694..7346bd1064 100644
--- a/src/include/catalog/pg_type.dat
+++ b/src/include/catalog/pg_type.dat
@@ -32,72 +32,51 @@
 
 { oid => '16', descr => 'boolean, \'true\'/\'false\'',
   typname => 'bool', typlen => '1', typbyval => 't', typcategory => 'B',
-  typispreferred => 't', typarray => '_bool', typinput => 'boolin',
-  typoutput => 'boolout', typreceive => 'boolrecv', typsend => 'boolsend',
-  typalign => 'c' },
+  typispreferred => 't', typarray => '_bool', typalign => 'c' },
 { oid => '17', descr => 'variable-length string, binary values escaped',
   typname => 'bytea', typlen => '-1', typbyval => 'f', typcategory => 'U',
-  typarray => '_bytea', typinput => 'byteain', typoutput => 'byteaout',
-  typreceive => 'bytearecv', typsend => 'byteasend', typalign => 'i',
-  typstorage => 'x' },
+  typarray => '_bytea', typalign => 'i', typstorage => 'x' },
 { oid => '18', descr => 'single character',
   typname => 'char', typlen => '1', typbyval => 't', typcategory => 'S',
-  typarray => '_char', typinput => 'charin', typoutput => 'charout',
-  typreceive => 'charrecv', typsend => 'charsend', typalign => 'c' },
+  typarray => '_char', typalign => 'c' },
 { oid => '19', descr => '63-byte type for storing system identifiers',
   typname => 'name', typlen => 'NAMEDATALEN', typbyval => 'f',
   typcategory => 'S', typelem => 'char', typarray => '_name',
-  typinput => 'namein', typoutput => 'nameout', typreceive => 'namerecv',
-  typsend => 'namesend', typalign => 'c' },
+  typalign => 'c' },
 { oid => '20', descr => '~18 digit integer, 8-byte storage',
   typname => 'int8', typlen => '8', typbyval => 'FLOAT8PASSBYVAL',
-  typcategory => 'N', typarray => '_int8', typinput => 'int8in',
-  typoutput => 'int8out', typreceive => 'int8recv', typsend => 'int8send',
-  typalign => 'd' },
+  typcategory => 'N', typarray => '_int8', typalign => 'd' },
 { oid => '21', descr => '-32 thousand to 32 thousand, 2-byte storage',
   typname => 'int2', typlen => '2', typbyval => 't', typcategory => 'N',
-  typarray => '_int2', typinput => 'int2in', typoutput => 'int2out',
-  typreceive => 'int2recv', typsend => 'int2send', typalign => 's' },
+  typarray => '_int2', typalign => 's' },
 { oid => '22', descr => 'array of int2, used in system tables',
   typname => 'int2vector', typlen => '-1', typbyval => 'f', typcategory => 'A',
-  typelem => 'int2', typarray => '_int2vector', typinput => 'int2vectorin',
-  typoutput => 'int2vectorout', typreceive => 'int2vectorrecv',
-  typsend => 'int2vectorsend', typalign => 'i' },
+  typelem => 'int2', typarray => '_int2vector', typalign => 'i' },
 { oid => '23', descr => '-2 billion to 2 billion integer, 4-byte storage',
   typname => 'int4', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_int4', typinput => 'int4in', typoutput => 'int4out',
-  typreceive => 'int4recv', typsend => 'int4send', typalign => 'i' },
+  typarray => '_int4', typalign => 'i' },
 { oid => '24', descr => 'registered procedure',
   typname => 'regproc', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regproc', typinput => 'regprocin', typoutput => 'regprocout',
-  typreceive => 'regprocrecv', typsend => 'regprocsend', typalign => 'i' },
+  typarray => '_regproc', typalign => 'i' },
 { oid => '25', descr => 'variable-length string, no limit specified',
   typname => 'text', typlen => '-1', typbyval => 'f', typcategory => 'S',
-  typispreferred => 't', typarray => '_text', typinput => 'textin',
-  typoutput => 'textout', typreceive => 'textrecv', typsend => 'textsend',
-  typalign => 'i', typstorage => 'x', typcollation => '100' },
+  typispreferred => 't', typarray => '_text', typalign => 'i',
+  typstorage => 'x', typcollation => '100' },
 { oid => '26', descr => 'object identifier(oid), maximum 4 billion',
   typname => 'oid', typlen => '4', typbyval => 't', typcategory => 'N',
-  typispreferred => 't', typarray => '_oid', typinput => 'oidin',
-  typoutput => 'oidout', typreceive => 'oidrecv', typsend => 'oidsend',
-  typalign => 'i' },
+  typispreferred => 't', typarray => '_oid', typalign => 'i' },
 { oid => '27', descr => '(block, offset), physical location of tuple',
   typname => 'tid', typlen => '6', typbyval => 'f', typcategory => 'U',
-  typarray => '_tid', typinput => 'tidin', typoutput => 'tidout',
-  typreceive => 'tidrecv', typsend => 'tidsend', typalign => 's' },
+  typarray => '_tid', typalign => 's' },
 { oid => '28', descr => 'transaction id',
   typname => 'xid', typlen => '4', typbyval => 't', typcategory => 'U',
-  typarray => '_xid', typinput => 'xidin', typoutput => 'xidout',
-  typreceive => 'xidrecv', typsend => 'xidsend', typalign => 'i' },
+  typarray => '_xid', typalign => 'i' },
 { oid => '29', descr => 'command identifier type, sequence in transaction id',
   typname => 'cid', typlen => '4', typbyval => 't', typcategory => 'U',
-  typarray => '_cid', typinput => 'cidin', typoutput => 'cidout',
-  typreceive => 'cidrecv', typsend => 'cidsend', typalign => 'i' },
+  typarray => '_cid', typalign => 'i' },
 { oid => '30', descr => 'array of oids, used in system tables',
   typname => 'oidvector', typlen => '-1', typbyval => 'f', typcategory => 'A',
-  typelem => 'oid', typarray => '_oidvector', typinput => 'oidvectorin',
-  typoutput => 'oidvectorout', typreceive => 'oidvectorrecv',
-  typsend => 'oidvectorsend', typalign => 'i' },
+  typelem => 'oid', typarray => '_oidvector', typalign => 'i' },
 
 # hand-built rowtype entries for bootstrapped catalogs
 # NB: OIDs assigned here must match the BKI_ROWTYPE_OID declarations
@@ -176,8 +155,7 @@
 
 { oid => '210', descr => 'storage manager',
   typname => 'smgr', typlen => '2', typbyval => 't', typcategory => 'U',
-  typinput => 'smgrin', typoutput => 'smgrout', typreceive => '-',
-  typsend => '-', typalign => 's' },
+  typreceive => '-', typsend => '-', typalign => 's' },
 
 # OIDS 600 - 699
 
@@ -222,34 +200,26 @@
 { oid => '700',
   descr => 'single-precision floating point number, 4-byte storage',
   typname => 'float4', typlen => '4', typbyval => 'FLOAT4PASSBYVAL',
-  typcategory => 'N', typarray => '_float4', typinput => 'float4in',
-  typoutput => 'float4out', typreceive => 'float4recv', typsend => 'float4send',
-  typalign => 'i' },
+  typcategory => 'N', typarray => '_float4', typalign => 'i' },
 { oid => '701',
   descr => 'double-precision floating point number, 8-byte storage',
   typname => 'float8', typlen => '8', typbyval => 'FLOAT8PASSBYVAL',
   typcategory => 'N', typispreferred => 't', typarray => '_float8',
-  typinput => 'float8in', typoutput => 'float8out', typreceive => 'float8recv',
-  typsend => 'float8send', typalign => 'd' },
+  typalign => 'd' },
 { oid => '702',
   descr => 'absolute, limited-range date and time (Unix system time)',
   typname => 'abstime', typlen => '4', typbyval => 't', typcategory => 'D',
-  typarray => '_abstime', typinput => 'abstimein', typoutput => 'abstimeout',
-  typreceive => 'abstimerecv', typsend => 'abstimesend', typalign => 'i' },
+  typarray => '_abstime', typalign => 'i' },
 { oid => '703',
   descr => 'relative, limited-range time interval (Unix delta time)',
   typname => 'reltime', typlen => '4', typbyval => 't', typcategory => 'T',
-  typarray => '_reltime', typinput => 'reltimein', typoutput => 'reltimeout',
-  typreceive => 'reltimerecv', typsend => 'reltimesend', typalign => 'i' },
+  typarray => '_reltime', typalign => 'i' },
 { oid => '704', descr => '(abstime,abstime), time interval',
   typname => 'tinterval', typlen => '12', typbyval => 'f', typcategory => 'T',
-  typarray => '_tinterval', typinput => 'tintervalin',
-  typoutput => 'tintervalout', typreceive => 'tintervalrecv',
-  typsend => 'tintervalsend', typalign => 'i' },
+  typarray => '_tinterval', typalign => 'i' },
 { oid => '705',
   typname => 'unknown', typlen => '-2', typbyval => 'f', typtype => 'p',
-  typcategory => 'X', typinput => 'unknownin', typoutput => 'unknownout',
-  typreceive => 'unknownrecv', typsend => 'unknownsend', typalign => 'c' },
+  typcategory => 'X', typalign => 'c' },
 { oid => '718', descr => 'geometric circle \'(center,radius)\'',
   typname => 'circle', typlen => '24', typbyval => 'f', typcategory => 'G',
   typarray => '_circle', typinput => 'circle_in', typoutput => 'circle_out',
@@ -437,8 +407,7 @@
   typanalyze => 'array_typanalyze', typalign => 'd', typstorage => 'x' },
 { oid => '1033', descr => 'access control list',
   typname => 'aclitem', typlen => '12', typbyval => 'f', typcategory => 'U',
-  typarray => '_aclitem', typinput => 'aclitemin', typoutput => 'aclitemout',
-  typreceive => '-', typsend => '-', typalign => 'i' },
+  typarray => '_aclitem', typreceive => '-', typsend => '-', typalign => 'i' },
 { oid => '1034',
   typname => '_aclitem', typlen => '-1', typbyval => 'f', typcategory => 'A',
   typelem => 'aclitem', typinput => 'array_in', typoutput => 'array_out',
@@ -472,15 +441,13 @@
 { oid => '1042',
   descr => 'char(length), blank-padded string, fixed storage length',
   typname => 'bpchar', typlen => '-1', typbyval => 'f', typcategory => 'S',
-  typarray => '_bpchar', typinput => 'bpcharin', typoutput => 'bpcharout',
-  typreceive => 'bpcharrecv', typsend => 'bpcharsend',
-  typmodin => 'bpchartypmodin', typmodout => 'bpchartypmodout', typalign => 'i',
-  typstorage => 'x', typcollation => '100' },
+  typarray => '_bpchar', typmodin => 'bpchartypmodin',
+  typmodout => 'bpchartypmodout', typalign => 'i', typstorage => 'x',
+  typcollation => '100' },
 { oid => '1043',
   descr => 'varchar(length), non-blank-padded string, variable storage length',
   typname => 'varchar', typlen => '-1', typbyval => 'f', typcategory => 'S',
-  typarray => '_varchar', typinput => 'varcharin', typoutput => 'varcharout',
-  typreceive => 'varcharrecv', typsend => 'varcharsend',
+  typarray => '_varchar',
   typmodin => 'varchartypmodin', typmodout => 'varchartypmodout',
   typalign => 'i', typstorage => 'x', typcollation => '100' },
 { oid => '1082', descr => 'date',
@@ -617,35 +584,25 @@
 
 { oid => '2202', descr => 'registered procedure (with args)',
   typname => 'regprocedure', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regprocedure', typinput => 'regprocedurein',
-  typoutput => 'regprocedureout', typreceive => 'regprocedurerecv',
-  typsend => 'regproceduresend', typalign => 'i' },
+  typarray => '_regprocedure', typalign => 'i' },
 { oid => '2203', descr => 'registered operator',
   typname => 'regoper', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regoper', typinput => 'regoperin', typoutput => 'regoperout',
-  typreceive => 'regoperrecv', typsend => 'regopersend', typalign => 'i' },
+  typarray => '_regoper', typalign => 'i' },
 { oid => '2204', descr => 'registered operator (with args)',
   typname => 'regoperator', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regoperator', typinput => 'regoperatorin',
-  typoutput => 'regoperatorout', typreceive => 'regoperatorrecv',
-  typsend => 'regoperatorsend', typalign => 'i' },
+  typarray => '_regoperator', typalign => 'i' },
 { oid => '2205', descr => 'registered class',
   typname => 'regclass', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regclass', typinput => 'regclassin', typoutput => 'regclassout',
-  typreceive => 'regclassrecv', typsend => 'regclasssend', typalign => 'i' },
+  typarray => '_regclass', typalign => 'i' },
 { oid => '2206', descr => 'registered type',
   typname => 'regtype', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regtype', typinput => 'regtypein', typoutput => 'regtypeout',
-  typreceive => 'regtyperecv', typsend => 'regtypesend', typalign => 'i' },
+  typarray => '_regtype', typalign => 'i' },
 { oid => '4096', descr => 'registered role',
   typname => 'regrole', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regrole', typinput => 'regrolein', typoutput => 'regroleout',
-  typreceive => 'regrolerecv', typsend => 'regrolesend', typalign => 'i' },
+  typarray => '_regrole', typalign => 'i' },
 { oid => '4089', descr => 'registered namespace',
   typname => 'regnamespace', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regnamespace', typinput => 'regnamespacein',
-  typoutput => 'regnamespaceout', typreceive => 'regnamespacerecv',
-  typsend => 'regnamespacesend', typalign => 'i' },
+  typarray => '_regnamespace', typalign => 'i' },
 { oid => '2207',
   typname => '_regprocedure', typlen => '-1', typbyval => 'f',
   typcategory => 'A', typelem => 'regprocedure', typinput => 'array_in',
@@ -708,29 +665,22 @@
 # text search
 { oid => '3614', descr => 'text representation for text search',
   typname => 'tsvector', typlen => '-1', typbyval => 'f', typcategory => 'U',
-  typarray => '_tsvector', typinput => 'tsvectorin', typoutput => 'tsvectorout',
-  typreceive => 'tsvectorrecv', typsend => 'tsvectorsend',
-  typanalyze => 'ts_typanalyze', typalign => 'i', typstorage => 'x' },
+  typarray => '_tsvector', typanalyze => 'ts_typanalyze', typalign => 'i',
+  typstorage => 'x' },
 { oid => '3642',
   descr => 'GiST index internal text representation for text search',
   typname => 'gtsvector', typlen => '-1', typbyval => 'f', typcategory => 'U',
-  typarray => '_gtsvector', typinput => 'gtsvectorin',
-  typoutput => 'gtsvectorout', typreceive => '-', typsend => '-',
+  typarray => '_gtsvector', typreceive => '-', typsend => '-',
   typalign => 'i' },
 { oid => '3615', descr => 'query representation for text search',
   typname => 'tsquery', typlen => '-1', typbyval => 'f', typcategory => 'U',
-  typarray => '_tsquery', typinput => 'tsqueryin', typoutput => 'tsqueryout',
-  typreceive => 'tsqueryrecv', typsend => 'tsquerysend', typalign => 'i' },
+  typarray => '_tsquery', typalign => 'i' },
 { oid => '3734', descr => 'registered text search configuration',
   typname => 'regconfig', typlen => '4', typbyval => 't', typcategory => 'N',
-  typarray => '_regconfig', typinput => 'regconfigin',
-  typoutput => 'regconfigout', typreceive => 'regconfigrecv',
-  typsend => 'regconfigsend', typalign => 'i' },
+  typarray => '_regconfig', typalign => 'i' },
 { oid => '3769', descr => 'registered text search dictionary',
   typname => 'regdictionary', typlen => '4', typbyval => 't',
   typcategory => 'N', typarray => '_regdictionary',
-  typinput => 'regdictionaryin', typoutput => 'regdictionaryout',
-  typreceive => 'regdictionaryrecv', typsend => 'regdictionarysend',
   typalign => 'i' },
 
 { oid => '3643',
diff --git a/src/include/catalog/pg_type.h b/src/include/catalog/pg_type.h
index 5914ee706a..eb9a5b07c4 100644
--- a/src/include/catalog/pg_type.h
+++ b/src/include/catalog/pg_type.h
@@ -122,12 +122,12 @@ CATALOG(pg_type,1247,TypeRelationId) BKI_BOOTSTRAP BKI_ROWTYPE_OID(71,TypeRelati
 	 */
 
 	/* text format (required) */
-	regproc		typinput BKI_LOOKUP(pg_proc);
-	regproc		typoutput BKI_LOOKUP(pg_proc);
+	regproc		typinput BKI_DEFAULT("${typname}in") BKI_LOOKUP(pg_proc);
+	regproc		typoutput BKI_DEFAULT("${typname}out") BKI_LOOKUP(pg_proc);
 
 	/* binary format (optional) */
-	regproc		typreceive BKI_LOOKUP(pg_proc);
-	regproc		typsend BKI_LOOKUP(pg_proc);
+	regproc		typreceive BKI_DEFAULT("${typname}recv") BKI_LOOKUP(pg_proc);
+	regproc		typsend BKI_DEFAULT("${typname}send") BKI_LOOKUP(pg_proc);
 
 	/*
 	 * I/O functions for optional type modifiers.
